#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

religions_data = {
    "Albanian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة ألبان",
    "Algerian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة جزائريون",
    "American Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة أمريكيون",
    "Arab Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة عرب",
    "Australian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة أستراليون",
    "Bangladeshi Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة بنغلاديشيون",
    "Bosnian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة بوسنيون",
    "Egyptian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة مصريون",
    "English Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة إنجليز",
    "Filipino Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة فلبينيون",
    "Indian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة هنود",
    "Indonesian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة إندونيسيون",
    "Iraqi Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة عراقيون",
    "Mauritanian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة موريتانيون",
    "Moroccan Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة مغاربة",
    "Pakistani Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة باكستانيون",
    "Palestinian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة فلسطينيون",
    "Persian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة فرس",
    "Saudi Arabian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة سعوديون",
    "Somalian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة صوماليون",
    "Syrian Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة سوريون",
    "Turkish Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة أتراك",
    "Yemeni Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة يمنيون",
    "13th-century indian muslims": "هنود مسلمون في القرن 13",
    "14th-century indian muslims": "هنود مسلمون في القرن 14",
    "15th-century indian muslims": "هنود مسلمون في القرن 15",
    "16th-century indian muslims": "هنود مسلمون في القرن 16",
    "17th-century indian muslims": "هنود مسلمون في القرن 17",
    "18th-century indian muslims": "هنود مسلمون في القرن 18",
    "19th-century indian muslims": "هنود مسلمون في القرن 19",
    "20th-century indian muslims": "هنود مسلمون في القرن 20",
    "21st-century indian muslims": "هنود مسلمون في القرن 21",
    "afghan muslims": "أفغان مسلمون",
    "african muslims": "أفارقة مسلمون",
    "african-american muslims": "أمريكيون أفارقة مسلمون",
    "albanian muslims": "ألبان مسلمون",
    "algerian muslims": "جزائريون مسلمون",
    "american muslims": "أمريكيون مسلمون",
    "arab muslims": "عرب مسلمون",
    "argentine muslims": "أرجنتينيون مسلمون",
    "armenian muslims": "أرمن مسلمون",
    "asian muslims": "آسيويون مسلمون",
    "australian muslims": "أستراليون مسلمون",
    "austrian muslims": "نمساويون مسلمون",
    "azerbaijani muslims": "أذربيجانيون مسلمون",
    "bahraini muslims": "بحرينيون مسلمون",
    "bangladeshi muslims": "بنغلاديشيون مسلمون",
    "basque muslims": "باسكيون مسلمون",
    "belarusian muslims": "بيلاروسيون مسلمون",
    "belgian muslims": "بلجيكيون مسلمون",
    "bengali muslims": "بنغاليون مسلمون",
    "beninese muslims": "بنينيون مسلمون",
    "bosnia and herzegovina muslims": "بوسنيون مسلمون",
    "bosnian muslim collaborators with nazi germany": "بوسنيون مسلمون متعاونون مع ألمانيا النازية",
    "bosnian muslims from ottoman empire": "بوسنيون مسلمون من الدولة العثمانية",
    "bosnian muslims": "بوسنيون مسلمون",
    "brazilian muslims": "برازيليون مسلمون",
    "british muslims": "بريطانيون مسلمون",
    "bruneian muslims": "برونيون مسلمون",
    "bulgarian muslims": "بلغاريون مسلمون",
    "burkinabe muslims": "بوركينابيون مسلمون",
    "burmese muslims": "بورميون مسلمون",
    "burundian muslims": "بورونديون مسلمون",
    "byzantine muslims": "بيزنطيون مسلمون",
    "cambodian muslims": "كمبوديون مسلمون",
    "cameroonian muslims": "كاميرونيون مسلمون",
    "canadian muslims": "كنديون مسلمون",
    "central african republic muslims": "أفارقة أوسطيون مسلمون",
    "central asian muslims": "آسيويون أوسطيون مسلمون",
    "chadian muslims": "تشاديون مسلمون",
    "chinese muslims": "صينيون مسلمون",
    "colombian muslims": "كولومبيون مسلمون",
    "comorian muslims": "قمريون مسلمون",
    "croatian muslims": "كروات مسلمون",
    "cuban muslims": "كوبيون مسلمون",
    "cypriot muslims": "قبرصيون مسلمون",
    "czech muslims": "تشيكيون مسلمون",
    "danish muslims": "دنماركيون مسلمون",
    "democratic republic of congo muslims": "كونغويون ديمقراطيون مسلمون",
    "dutch muslims": "هولنديون مسلمون",
    "east timorese muslims": "تيموريون شرقيون مسلمون",
    "egyptian muslims": "مصريون مسلمون",
    "emirati muslims": "إماراتيون مسلمون",
    "english muslims": "إنجليز مسلمون",
    "eritrean muslims": "إريتريون مسلمون",
    "ethiopian muslims": "إثيوبيون مسلمون",
    "european muslims": "أوروبيون مسلمون",
    "fijian muslims": "فيجيون مسلمون",
    "filipino muslims": "فلبينيون مسلمون",
    "finnish muslims": "فنلنديون مسلمون",
    "french muslims": "فرنسيون مسلمون",
    "gabonese muslims": "غابونيون مسلمون",
    "gambian muslims": "غامبيون مسلمون",
    "georgian muslims": "جورجيون مسلمون",
    "german muslims": "ألمان مسلمون",
    "ghanaian muslims": "غانيون مسلمون",
    "greek muslims": "يونانيون مسلمون",
    "guinean muslims": "غينيون مسلمون",
    "gujarati muslims": "غجراتيون مسلمون",
    "guyanese muslims": "غيانيون مسلمون",
    "haitian muslims": "هايتيون مسلمون",
    "hong kong muslims": "هونغ كونغيون مسلمون",
    "hungarian muslims": "مجريون مسلمون",
    "icelandic muslims": "آيسلنديون مسلمون",
    "indian muslims by century": "هنود مسلمون حسب القرن",
    "indian muslims": "هنود مسلمون",
    "indonesian muslims": "إندونيسيون مسلمون",
    "iranian muslims": "إيرانيون مسلمون",
    "iraqi muslims": "عراقيون مسلمون",
    "irish muslims": "أيرلنديون مسلمون",
    "israeli muslims": "إسرائيليون مسلمون",
    "italian muslims": "إيطاليون مسلمون",
    "ivorian muslims": "إيفواريون مسلمون",
    "jamaican muslims": "جامايكيون مسلمون",
    "japanese muslims": "يابانيون مسلمون",
    "jordanian muslims": "أردنيون مسلمون",
    "kashmiri muslims": "كشميريون مسلمون",
    "kazakhstani muslims": "كازاخستانيون مسلمون",
    "kenyan muslims": "كينيون مسلمون",
    "korean muslims": "كوريون مسلمون",
    "kosovan muslims": "كوسوفيون مسلمون",
    "kurdish muslims": "أكراد مسلمون",
    "kuwaiti muslims": "كويتيون مسلمون",
    "kyrgyzstani muslims": "قيرغيزستانيون مسلمون",
    "latvian muslims": "لاتفيون مسلمون",
    "lebanese muslims": "لبنانيون مسلمون",
    "liberian muslims": "ليبيريون مسلمون",
    "libyan muslims": "ليبيون مسلمون",
    "macedonian muslims": "مقدونيون مسلمون",
    "malagasy muslims": "مدغشقريون مسلمون",
    "malawian muslims": "ملاويون مسلمون",
    "malaysian muslims": "ماليزيون مسلمون",
    "maldivian muslims": "مالديفيون مسلمون",
    "malian muslims": "ماليون مسلمون",
    "mass murder of sri lankan muslims": "قتل جماعي في سريلانكيون مسلمون",
    "massacres of bengali muslims": "مذابح في بنغاليون مسلمون",
    "mauritanian muslims": "موريتانيون مسلمون",
    "mauritian muslims": "موريشيوسيون مسلمون",
    "mexican muslims": "مكسيكيون مسلمون",
    "middle eastern muslims": "شرقيون أوسطيون مسلمون",
    "moldovan muslims": "مولدوفيون مسلمون",
    "mongolian muslims": "منغوليون مسلمون",
    "montenegrin muslims": "مونتينيغريون مسلمون",
    "moroccan muslims": "مغاربة مسلمون",
    "mozambican muslims": "موزمبيقيون مسلمون",
    "namibian muslims": "ناميبيون مسلمون",
    "nepalese muslims": "نيباليون مسلمون",
    "nigerian muslims": "نيجيريون مسلمون",
    "nigerien muslims": "نيجريون مسلمون",
    "north american muslims": "أمريكيون شماليون مسلمون",
    "norwegian muslims": "نرويجيون مسلمون",
    "oceanian muslims": "أوقيانوسيون مسلمون",
    "omani muslims": "عمانيون مسلمون",
    "pakistani muslims": "باكستانيون مسلمون",
    "palestinian muslims": "فلسطينيون مسلمون",
    "panamanian muslims": "بنميون مسلمون",
    "persecution of bengali muslims": "اضطهاد بنغاليون مسلمون",
    "persecution of ottoman muslims": "اضطهاد عثمانيون مسلمون",
    "peruvian muslims": "بيرويون مسلمون",
    "polish muslims": "بولنديون مسلمون",
    "portuguese muslims": "برتغاليون مسلمون",
    "puerto rican muslims": "بورتوريكيون مسلمون",
    "qatari muslims": "قطريون مسلمون",
    "romanian muslims": "رومان مسلمون",
    "russian muslims": "روس مسلمون",
    "rwandan muslims": "روانديون مسلمون",
    "salvadoran muslims": "سلفادوريون مسلمون",
    "saudi arabian muslims": "سعوديون مسلمون",
    "scottish muslims": "إسكتلنديون مسلمون",
    "senegalese muslims": "سنغاليون مسلمون",
    "serbian muslims": "صرب مسلمون",
    "sierra leonean muslims": "سيراليونيون مسلمون",
    "singaporean muslims": "سنغافوريون مسلمون",
    "somalian muslims": "صوماليون مسلمون",
    "south american muslims": "أمريكيون جنوبيون مسلمون",
    "south korean muslims": "كوريون جنوبيون مسلمون",
    "south sudanese muslims": "سودانيون جنوبيون مسلمون",
    "soviet muslims": "سوفيت مسلمون",
    "spanish muslims": "إسبان مسلمون",
    "sri lankan muslims": "سريلانكيون مسلمون",
    "sudanese muslims": "سودانيون مسلمون",
    "surinamese muslims": "سوريناميون مسلمون",
    "swedish muslims": "سويديون مسلمون",
    "swiss muslims": "سويسريون مسلمون",
    "syrian muslims": "سوريون مسلمون",
    "taiwanese muslims": "تايوانيون مسلمون",
    "tajikistani muslims": "طاجيك مسلمون",
    "tamil muslims": "تاميليون مسلمون",
    "tanzanian muslims": "تنزانيون مسلمون",
    "thai muslims": "تايلنديون مسلمون",
    "tongan muslims": "تونغانيون مسلمون",
    "trinidad and tobago muslims": "ترنيداديون مسلمون",
    "tunisian muslims": "تونسيون مسلمون",
    "turkish cypriot muslims": "قبرصيون شماليون مسلمون",
    "turkish muslims": "أتراك مسلمون",
    "turkmenistan muslims": "تركمانيون مسلمون",
    "ugandan muslims": "أوغنديون مسلمون",
    "ukrainian muslims": "أوكرانيون مسلمون",
    "uruguayan muslims": "أوروغويانيون مسلمون",
    "uzbekistani muslims": "أوزبكستانيون مسلمون",
    "venezuelan muslims": "فنزويليون مسلمون",
    "vietnamese muslims": "فيتناميون مسلمون",
    "welsh muslims": "ويلزيون مسلمون",
    "yemeni muslims": "يمنيون مسلمون",
    "yugoslav muslims": "يوغسلافيون مسلمون",
    "zambian muslims": "زامبيون مسلمون",
    "zimbabwean muslims": "زيمبابويون مسلمون",
    "anti-muslim sentiment": "مشاعر معادية للمسلمون",
}

data2 = {
    "muslim league (2050–2050)": "الدوري المسلم (2050–2050)",
    "timelines of muslim history": "التسلسل الزمني تاريخ مسلم",
    "muslim families": "عائلات مسلمة",
    "muslim festivals": "مهرجانات مسلمة",
    "muslim league (1947–1958)": "الدوري المسلم (1947–1958)",
    "muslim members of united states house of representatives": "مسلمون أعضاء في مجلس النواب الأمريكي",
    "muslim nationalism in south asia": "قومية مسلمة في جنوب آسيا",
    "bengali muslim surnames": "ألقاب مسلمة بنغالية",
    "muslim rebellions": "تمردات مسلمة",
}


@pytest.mark.parametrize("category, expected", religions_data.items(), ids=religions_data.keys())
def test_muslims(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


to_test = [
    ("test_muslims_1", religions_data),
    # ("test_muslims_2", data2),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
