"""
Data mappings for country name category translations.
This module provides comprehensive dictionaries of template patterns and
Arabic translations for categories involving country names and their
geographic or political attributes.
"""

from typing import Dict

from ...helps import len_print

formatted_data_of_no_in: Dict[str, str] = {
    "governments": "حكومات",
    "history": "تاريخ",
    "secretaries": "وزراء",
    "banks": "بنوك",
    "treaties": "معاهدات",
}

# NOTE: formatted_data_en_ar_only used in other resolver
formatted_data_en_ar_only: Dict[str, str] = {
    "spies for {en}": "جواسيس لصالح {ar}",
    "world-war-i spies for {en}": "جواسيس الحرب العالمية الأولى لصالح {ar}",
    "world war i spies for {en}": "جواسيس الحرب العالمية الأولى لصالح {ar}",
    "world-war-ii spies for {en}": "جواسيس الحرب العالمية الثانية لصالح {ar}",
    "world war ii spies for {en}": "جواسيس الحرب العالمية الثانية لصالح {ar}",
    "warm springs of {en}": "ينابيع دائفة في {ar}",
    "hot springs of {en}": "ينابيع حارة في {ar}",
    "acting presidents of {en}": "رؤساء {ar} بالإنابة",
    "bilateral military relations of {en}": "علاقات {ar} الثنائية العسكرية",
    "bilateral relations of {en}": "علاقات {ar} الثنائية",
    "diplomatic missions of {en}": "بعثات {ar} الدبلوماسية",
    "fictional presidents of {en}": "رؤساء {ar} الخياليون",
    "military units and formations of {en}": "وحدات وتشكيلات {ar} العسكرية",
    "military-equipment of {en}": "عتاد {ar} العسكري",
    "national symbols of {en}": "رموز {ar} الوطنية",
    "permanent delegates of {en}": "مندوبو {ar} الدائمون",
    "naval units and formations of {en}": "وحدات وتشكيلات {ar} البحرية",
    "permanent representatives of {en}": "مندوبو {ar} الدائمون",
    "{en} motorcycle grand prix": "جائزة {ar} الكبرى للدراجات النارية",
    "{en} grand prix": "جائزة {ar} الكبرى",
    "university of arts of {en}": "جامعة {ar} للفنون",
    "military installations of {en}": "منشآت {ar} العسكرية",
    # "Germany politics and government templates": "قوالب سياسة وحكومة ألمانيا",
    "{en} politics and government templates": "قوالب سياسة وحكومة {ar}",
    "prehistory of {en}": "{ar} ما قبل التاريخ",
    "history of {en}": "تاريخ {ar}",
    "umayyad governors of {en}": "ولاة {ar} الأمويون",
    "ancient history of {en}": "تاريخ {ar} القديم",
    "contemporary history of {en}": "تاريخ {ar} المعاصر",
    "cultural history of {en}": "تاريخ {ar} الثقافي",
    "demographic history of {en}": "تاريخ {ar} الديموغرافي",
    "early modern history of {en}": "تاريخ {ar} الحديث المبكر",
    "early-modern history of {en}": "تاريخ {ar} الحديث المبكر",
    "economic history of {en}": "تاريخ {ar} الاقتصادي",
    "geographic history of {en}": "تاريخ {ar} الجغرافي",
    "islamic history of {en}": "تاريخ {ar} الإسلامي",
    "legal history of {en}": "تاريخ {ar} القانوني",
    "maritime history of {en}": "تاريخ {ar} البحري",
    "military equipment of {en}": "عتاد {ar} العسكري",
    "military history of {en}": "تاريخ {ar} العسكري",
    "modern history of {en}": "تاريخ {ar} الحديث",
    "natural history of {en}": "تاريخ {ar} الطبيعي",
    "naval history of {en}": "تاريخ {ar} العسكري البحري",
    "nuclear history of {en}": "تاريخ {ar} النووي",
    "political history of {en}": "تاريخ {ar} السياسي",
    "social history of {en}": "تاريخ {ar} الاجتماعي",
    "first league of {en}": "دوري {ar} الممتاز",
    "academic staff of university of {en}": "أعضاء هيئة تدريس جامعة {ar}",
    "ministries of the government of {en}": "وزارات حكومة {ar}",
    "government ministers of {en}": "وزراء {ar}",
    "bilateral treaties of {en}": "معاهدات {ar} الثنائية",
    "secretaries of {en}": "وزراء {ar}",
    "united states secretaries of state": "وزراء خارجية أمريكيون",
    "state cabinet secretaries of {en}": "أعضاء مجلس وزراء {ar}",
    "{en}": "{ar}",
    "{en} women's international footballers": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's youth international footballers": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} international footballers": "لاعبو منتخب {ar} لكرة القدم",
    "police of {en}": "شرطة {ar}",
    "army of {en}": "جيش {ar}",
    "national congress ({en})": "المؤتمر الوطني ({ar})",
    "national council ({en})": "المجلس الوطني ({ar})",
    "national assembly ({en})": "الجمعية الوطنية ({ar})",
    "members of national assembly ({en})": "أعضاء الجمعية الوطنية ({ar})",
    "women members of national assembly ({en})": "عضوات الجمعية الوطنية ({ar})",
    "members of parliament of {en}": "أعضاء برلمان {ar}",
    "women members of parliament of {en}": "عضوات برلمان {ar}",
    "senate ({en})": "مجلس الشيوخ ({ar})",
    "{en} general assembly": "جمعية {ar} العامة",
    "parliament of {en}": "برلمان {ar}",
    "accidental deaths from falls in {en}": "وفيات عرضية نتيجة السقوط في {ar}",
    "bodies of water of {en}": "مسطحات مائية في {ar}",
    "national university of {en}": "جامعة {ar} الوطنية",
    "national library of {en}": "مكتبة {ar} الوطنية",
    "{en} afc asian cup squad": "تشكيلات {ar} في كأس آسيا",
    "{en} afc women's asian cup squad": "تشكيلات {ar} في كأس آسيا للسيدات",
    "{en} board members": "أعضاء مجلس {ar}",
    "{en} conflict": "نزاع {ar}",
    "{en} cup": "كأس {ar}",
    "{en} elections": "انتخابات {ar}",
    "{en} executive cabinet": "مجلس وزراء {ar} التنفيذي",
    "{en} fifa futsal world cup squad": "تشكيلات {ar} في كأس العالم لكرة الصالات",
    "{en} fifa world cup squad": "تشكيلات {ar} في كأس العالم",
    "{en} government personnel": "موظفي حكومة {ar}",
    "{en} government": "حكومة {ar}",
    "{en} governorate": "محافظة {ar}",
    "{en} olympics squad": "تشكيلات {ar} في الألعاب الأولمبية",
    "{en} presidents": "رؤساء {ar}",
    "{en} responses": "استجابات {ar}",
    "{en} summer olympics squad": "تشكيلات {ar} في الألعاب الأولمبية الصيفية",
    "{en} summer olympics": " {ar} في الألعاب الأولمبية الصيفية",
    "{en} territorial judges": "قضاة أقاليم {ar}",
    "{en} territorial officials": "مسؤولو أقاليم {ar}",
    "{en} war and conflict": "حروب ونزاعات {ar}",
    "{en} war": "حرب {ar}",
    "{en} winter olympics squad": "تشكيلات {ar} في الألعاب الأولمبية الشتوية",
    "{en} winter olympics": " {ar} في الألعاب الأولمبية الشتوية",
}


formatted_data_en_ar_only.update(
    {
        # "history of {en}": "تاريخ {ar}",
        f"{x} of {{en}}": f"{v} {{ar}}"
        for x, v in formatted_data_of_no_in.items()
    }
)

keys_of_without_in_data = {
    "air defence units and formations of {en}": "وحدات وتشكيلات دفاع جوي في {ar}",
    "archipelagoes of {en}": "أرخبيلات {ar}",
    "armies of {en}": "جيوش {ar}",
    "arrondissements of {en}": "دوائر {ar}",
    "bank of {en}": "بنك {ar}",
    "basins of {en}": "أحواض {ar}",
    "battles and operations of {en}": "معارك وعمليات {ar}",
    "battles of {en}": "معارك {ar}",
    "bays of {en}": "خلجان {ar}",
    "beaches of {en}": "شواطئ {ar}",
    "bibliographies of {en}": "ببليوجرافيات {ar}",
    "biota of {en}": "حيويات {ar}",
    "birds of {en}": "طيور {ar}",
    "borders of {en}": "حدود {ar}",
    "cabinet of {en}": "مجلس وزراء {ar}",
    "cabinet secretaries of {en}": "أعضاء مجلس وزراء {ar}",
    "campaigns of {en}": "حملات {ar}",
    "campuses of {en}": "حرم {ar}",
    "cantons of {en}": "كانتونات {ar}",
    "capitals of {en}": "عواصم {ar}",
    "caves of {en}": "كهوف {ar}",
    "chief justices of {en}": "رؤساء قضاء {ar}",
    "children of presidents of {en}": "أبناء رؤساء {ar}",
    "children of prime ministers of {en}": "أبناء رؤساء وزراء {ar}",
    "cities of {en}": "مدن {ar}",
    "city of {en}": "مدينة {ar}",
    "cliffs of {en}": "منحدرات {ar}",
    "climate of {en}": "مناخ {ar}",
    "coastline of {en}": "ساحل {ar}",
    "coasts of {en}": "سواحل {ar}",
    "colleges of {en}": "كليات {ar}",
    "communes of {en}": "بلديات {ar}",
    "consequences of {en}": "عواقب {ar}",
    "court systems of {en}": "أنظمة محاكم {ar}",
    "culture of {en}": "ثقافة {ar}",
    "daughters of {en}": "بنات {ar}",
    "death of {en}": "موت {ar}",
    "depressions of {en}": "منخفضات {ar}",
    "deserts of {en}": "صحاري {ar}",
    "diplomatic-missions-of {en}": "بعثات {ar} الدبلوماسية",
    "dukes of {en}": "دوقات {ar}",
    "economies of {en}": "اقتصادات {ar}",
    "economy of {en}": "اقتصاد {ar}",
    "encyclopedias of {en}": "موسوعات {ar}",
    "environment of {en}": "بيئة {ar}",
    "executions of {en}": "إعدامات {ar}",
    "families of {en}": "عائلات {ar}",
    "fauna of {en}": "حيوانات {ar}",
    "fellows of {en}": "زملاء {ar}",
    "finances of {en}": "مالية {ar}",
    "flags of {en}": "أعلام {ar}",
    "flora of {en}": "نباتات {ar}",
    "foreign relations of {en}": "علاقات {ar} الخارجية",
    "forests and woodlands of {en}": "غابات {ar}",
    "forests of {en}": "غابات {ar}",
    "forms of {en}": "أشكال {ar}",
    "generals of {en}": "جنرالات {ar}",
    "genres of {en}": "أجناس {ar}",
    "geography of {en}": "جغرافيا {ar}",
    "geology of {en}": "جيولوجيا {ar}",
    "government of {en}": "حكومة {ar}",
    "gulfs of {en}": "خلجان {ar}",
    "harbours of {en}": "مرافئ {ar}",
    "heads of state of {en}": "قادة {ar}",
    "heads of {en}": "قادة {ar}",
    "heraldry of {en}": "نبالة {ar}",
    "high commissioners to {en}": "مندوبون ساميون لدى {ar}",
    "hills of {en}": "تلال {ar}",
    "historiography of {en}": "تأريخ {ar}",
    "impact of {en}": "تأثيرات {ar}",
    "impacts of {en}": "آثار {ar}",
    "incidents of {en}": "حوادث {ar}",
    "independence of {en}": "استقلال {ar}",
    "institution of {en}": "مؤسسة {ar}",
    "internment of {en}": "اعتقال {ar}",
    "islands of {en}": "جزر {ar}",
    "judiciary of {en}": "النظام القضائي {ar}",
    "kings of {en}": "ملوك {ar}",
    "lakes of {en}": "بحيرات {ar}",
    "landform of {en}": "تضاريس {ar}",
    "landforms of {en}": "تضاريس {ar}",
    "laws of {en}": "قوانين {ar}",
    "leaders of {en}": "قادة {ar}",
    "lieutenant governors of {en}": "نواب حكام {ar}",
    "lists of {en}": "قوائم {ar}",
    "lords of {en}": "لوردات {ar}",
    "maritime incidents of {en}": "حوادث بحرية {ar}",
    "masters of {en}": "أساتذة {ar}",
    "mayors of {en}": "عمدات {ar}",
    "members of {en}": "أعضاء {ar}",
    "mistresses of {en}": "عشيقات {ar}",
    "mountains of {en}": "جبال {ar}",
    "municipalities of {en}": "بلديات {ar}",
    "music of {en}": "موسيقى {ar}",
    "naval battles of {en}": "معارك بحرية {ar}",
    "occupation of {en}": "احتلال {ar}",
    "order of {en}": "وسام {ar}",
    "parishes of {en}": "أبرشيات {ar}",
    "party chairs of {en}": "رؤساء أحزاب {ar}",
    "peoples of {en}": "شعوب {ar}",
    "persecution of {en}": "اضطهاد {ar}",
    "personalities of {en}": "شخصيات {ar}",
    "plains of {en}": "سهول {ar}",
    "plateaus of {en}": "هضاب {ar}",
    "politics of {en}": "سياسة {ar}",
    "ports and harbours of {en}": "مرافئ وموانئ {ar}",
    "ports of {en}": "موانئ {ar}",
    "presidencies of {en}": "رئاسات {ar}",
    "presidency of {en}": "رئاسة {ar}",
    "president of {en}": "رئيس {ar}",
    "presidents of {en}": "رؤساء {ar}",
    "princesses of {en}": "أميرات {ar}",
    "provinces of {en}": "مقاطعات {ar}",
    "rectors of {en}": "عمدات {ar}",
    "reefs of {en}": "شعاب {ar}",
    "regions of {en}": "مناطق {ar}",
    "rivers of {en}": "أنهار {ar}",
    "rornadoes of {en}": "أعاصير {ar}",
    "royal families of {en}": "عائلات ملكية {ar}",
    "rulers of {en}": "حكام {ar}",
    "seas of {en}": "بحار {ar}",
    "series of {en}": "سلسلات {ar}",
    "sieges of {en}": "حصارات {ar}",
    "society of {en}": "مجتمع {ar}",
    "speakers of {en}": "رؤساء {ar}",
    "spillover of {en}": "امتدادات {ar}",
    "springs of {en}": "ينابيع {ar}",
    "state appellate courts of {en}": "محاكم استئناف ولايات {ar}",
    "state superior courts of {en}": "محاكم عليا {ar}",
    "state treasurers of {en}": "أمناء خزينة ولاية {ar}",
    "straits of {en}": "مضائق {ar}",
    "streams of {en}": "جداول {ar}",
    "subdivisions of {en}": "تقسيمات {ar}",
    "submarines of {en}": "غواصات {ar}",
    "suburbs of {en}": "ضواحي {ar}",
    "sultans of {en}": "سلاطين {ar}",
    "superintendents of public instruction of {en}": "مدراء تعليم عام في {ar}",
    "superior courts of {en}": "محاكم عليا {ar}",
    "symbols of {en}": "رموز {ar}",
    "terminology of {en}": "مصطلحات {ar}",
    "terms of {en}": "فترات {ar}",
    "tour of {en}": "طواف {ar}",
    "treasurers of {en}": "أمناء خزينة {ar}",
    "tribes of {en}": "قبائل {ar}",
    "typhoons of {en}": "تيفونات {ar}",
    "umpires of {en}": "حكام {ar}",
    "underground culture of {en}": "ثقافة باطنية {ar}",
    "university of {en}": "جامعة {ar}",
    "valleys of {en}": "أودية {ar}",
    "variants of {en}": "أشكال {ar}",
    "variations of {en}": "أشكال {ar}",
    "vehicles of {en}": "مركبات {ar}",
    "venues of {en}": "ملاعب {ar}",
    "vice presidents of {en}": "نواب رؤساء {ar}",
    "victims of {en}": "ضحايا {ar}",
    "volcanoes of {en}": "براكين {ar}",
    "wadis of {en}": "وديان {ar}",
    "waterfalls of {en}": "شلالات {ar}",
    "wives of {en}": "زوجات {ar}",
    "works of {en}": "أعمال {ar}",
    "years of {en}": "سنوات {ar}",
}

formatted_data_en_ar_only.update(keys_of_without_in_data)

from_russia_data = {
    "agriculture ministers of {en}": "وزراء زراعة {ar}",
    "culture ministers of {en}": "وزراء ثقافة {ar}",
    "economy ministers of {en}": "وزراء اقتصاد {ar}",
    "education ministers of {en}": "وزراء تعليم {ar}",
    "energy ministers of {en}": "وزراء طاقة {ar}",
    "finance ministers of {en}": "وزراء مالية {ar}",
    "health ministers of {en}": "وزراء صحة {ar}",
    "justice ministers of {en}": "وزراء عدل {ar}",
    "ministers of defence of {en}": "وزراء دفاع {ar}",
    "ministers of foreign affairs of {en}": "وزراء شؤون خارجية {ar}",
    "ministers of internal affairs of {en}": "وزراء شؤون داخلية {ar}",
    "aircraft carriers of {en}": "حاملات طائرات في {ar}",
    "airlines of {en}": "شركات طيران في {ar}",
    "ambassadors of {en}": "سفراء {ar}",
    "amphibians of {en}": "برمائيات {ar}",
    "amphibious warfare vessels of {en}": "سفن حربية برمائية في {ar}",
    "archaeology of {en}": "علم الآثار في {ar}",
    "architecture firms of {en}": "شركات هندسة معمارية في {ar}",
    "arthropods of {en}": "مفصليات {ar}",
    "artificial islands of {en}": "جزر اصطناعية في {ar}",
    "artillery of {en}": "مدفعية في {ar}",
    "auxiliary ships of {en}": "سفن مساعدة في {ar}",
    "battlecruisers of {en}": "طرادات معركة في {ar}",
    "battleships of {en}": "بوارج في {ar}",
    "bodies of ice of {en}": "هيئات جليد في {ar}",
    "border crossings of {en}": "معابر حدودية في {ar}",
    "bus manufacturers of {en}": "مصانع الباصات في {ar}",
    "candidates for president of {en}": "مرشحون لمنصب رئيس {ar}",
    "canyons and gorges of {en}": "أخاديد في {ar}",
    "cargo airlines of {en}": "شحن جوي في {ar}",
    "cargo ships of {en}": "سفن بضائع {ar}",
    "cars of {en}": "سيارات في {ar}",
    "charter airlines of {en}": "طيران عارض في {ar}",
    "cinema of {en}": "سينما في {ar}",
    "citizenship of {en}": "المواطنة في {ar}",
    "civil awards and decorations of {en}": "جوائز وأوسمة مدنية في {ar}",
    "constitutions of {en}": "دساتير في {ar}",
    "construction industry of {en}": "صناعة بناء في {ar}",
    "corvettes of {en}": "فرقيطات في {ar}",
    "cruisers of {en}": "طرادات في {ar}",
    "crustaceans of {en}": "قشريات {ar}",
    "cultural depictions of presidents of {en}": "تصوير ثقافي عن رؤساء {ar}",
    "currencies of {en}": "عملات في {ar}",
    "defence agencies of {en}": "وكالات دفاع في {ar}",
    "defunct airlines of {en}": "شركات طيران سابقة في {ar}",
    "defunct banks of {en}": "بنوك سابقة في {ar}",
    "defunct motor vehicle manufacturers of {en}": "مصانع سيارات سابقة في {ar}",
    "demographics of {en}": "التركيبة السكانية في {ar}",
    "destroyers of {en}": "مدمرات في {ar}",
    "dinosaurs of {en}": "ديناصورات في {ar}",
    "districts of {en}": "مديريات {ar}",
    "drainage basins of {en}": "أحواض تصريف في {ar}",
    "drug policy of {en}": "سياسة المخدرات في {ar}",
    "dunes of {en}": "كثبان رملية في {ar}",
    "ecoregions of {en}": "مناطق بيئية في {ar}",
    "elizabeth of {en}": "إليزابيث إمبراطورة {ar}",
    "escort ships of {en}": "سفن مرافقة في {ar}",
    "fast-food chains of {en}": "سلاسل وجبات سريعة في {ar}",
    "featured pictures of {en}": "صور مميزة عن {ar}",
    "federal subjects of {en}": "كيانات {ar} الاتحادية",
    "federal universities of {en}": "جامعات فيدرالية في {ar}",
    "female candidates for president of {en}": "مرشحات لمنصب رئيس {ar}",
    "ferries of {en}": "عبارات في {ar}",
    "first ladies of {en}": "السيدات الأولى في {ar}",
    "fish of {en}": "أسماك {ar}",
    "flags of the federal subjects of {en}": "أعلام كيانات {ar} الاتحادية",
    "folklore of {en}": "فلكور في {ar}",
    "frigates of {en}": "فرقاطات في {ar}",
    "fungi of {en}": "فطريات {ar}",
    "glaciers of {en}": "أنهار جليدية في {ar}",
    "golden ring of {en}": "الجولدن رنج في {ar}",
    "government agencies of {en}": "وكالات حكومية في {ar}",
    "government ministries of federal subjects of {en}": "وزارات حكومة كيانات {ar} الاتحادية",
    "grand duchess anastasia nikolaevna of {en}": "الدوقة الكبرى أناستاسيا نيكولايفنا من {ar}",
    "grasslands of {en}": "أراضي عشبية في {ar}",
    "headlands of {en}": "أراضي رأسية في {ar}",
    "heads of government of {en}": "قادة حكومة {ar}",
    "heads of the federal subjects of {en}": "قادة كيانات {ar} الاتحادية",
    "historians of {en}": "مؤرخو {ar}",
    "history of the foreign relations of {en}": "تاريخ علاقات خارجية {ar}",
    "images of {en}": "صور من {ar}",
    "indigenous peoples of {en}": "شعوب أصلية في {ar}",
    "insects of {en}": "حشرات {ar}",
    "internet service providers of {en}": "تزويد خدمة الإنترنت في {ar}",
    "invasions of {en}": "غزوات في {ar}",
    "invertebrates of {en}": "لافقاريات {ar}",
    "languages of {en}": "لغات {ar}",
    "law enforcement agencies of {en}": "وكالات تطبيق القانون في {ar}",
    "law of {en}": "قانون في {ar}",
    "learned societies of {en}": "جمعيات علمية في {ar}",
    "legislatures of the federal subjects of {en}": "هيئات تشريعية في كيانات {ar} الاتحادية",
    "locomotive manufacturers of {en}": "مصانع القاطرات في {ar}",
    "mammals of {en}": "ثدييات {ar}",
    "military academies of {en}": "أكاديميات عسكرية في {ar}",
    "military communications of {en}": "اتصالات عسكرية في {ar}",
    "military logistics of {en}": "لوجستية عسكرية في {ar}",
    "military of {en}": "عسكرية {ar}",
    "military ranks of {en}": "رتب عسكرية في {ar}",
    "military research facilities of {en}": "مرافق بحثية عسكرية في {ar}",
    "military research of {en}": "أبحاث عسكرية في {ar}",
    "mine warfare vessels of {en}": "سفن حرب ألغام في {ar}",
    "minesweepers of {en}": "كاسحات ألغام في {ar}",
    "missile boats of {en}": "قوارب صواريخ في {ar}",
    "motor vehicle manufacturers of {en}": "مصانع السيارات في {ar}",
    "mountain passes of {en}": "ممرات جبلية في {ar}",
    "mountain ranges of {en}": "سلاسل جبلية في {ar}",
    "muslim communities of {en}": "مجتمعات إسلامية في {ar}",
    "national guard of {en}": "الحرس الوطني في {ar}",
    "national parks of {en}": "متنزهات وطنية في {ar}",
    "national trade union centers of {en}": "مراكز نقابية وطنية في {ar}",
    "naturalized citizens of {en}": "متجنسون في {ar}",
    "naval ships of {en}": "سفن قوات بحرية في {ar}",
    "nuclear missiles of {en}": "صواريخ نووية في {ar}",
    "nuclear weapons of {en}": "أسلحة نووية في {ar}",
    "oil fields of {en}": "حقول نفط في {ar}",
    "orders, decorations, and medals of {en}": "مراتب تشريفية وأوسمة وميداليات {ar}",
    "passenger ships of {en}": "سفن ركاب في {ar}",
    "patrol vessels of {en}": "سفن دورية في {ar}",
    "peace treaties of {en}": "معاهدات سلام {ar}",
    "peninsulas of {en}": "أشباه جزر في {ar}",
    "people of {en}": "أشخاص من {ar}",
    "prisoners and detainees of {en}": "سجناء ومعتقلون في {ar}",
    "protected areas of {en}": "مناطق محمية في {ar}",
    "reptiles of {en}": "زواحف {ar}",
    "ridges of {en}": "نتوئات جبلية في {ar}",
    "rock formations of {en}": "تكوينات صخرية في {ar}",
    "rocket engines of {en}": "محركات صواريخ في {ar}",
    "rolling stock of {en}": "القطارات في {ar}",
    "satellites of {en}": "أقمار صناعية تتبع {ar}",
    "service vessels of {en}": "سفن خدمة في {ar}",
    "ships of {en}": "سفن {ar}",
    "shipwrecks of {en}": "حطام سفن في {ar}",
    "shipyards of {en}": "حوض بناء سفن في {ar}",
    "social groups of {en}": "مجموعات اجتماعية في {ar}",
    "spiders of {en}": "عناكب في {ar}",
    "sports organisations of {en}": "منظمات رياضية في {ar}",
    "sports organizations of {en}": "منظمات رياضية في {ar}",
    "stratovolcanoes of {en}": "براكين طبقية في {ar}",
    "supermarkets of {en}": "محلات سوبر ماركت في {ar}",
    "swamps of {en}": "مستنقعات في {ar}",
    "tall ships of {en}": "سفن طويلة في {ar}",
    "tanks of {en}": "دبابات {ar}",
    "torpedoes of {en}": "الطوربيدات في {ar}",
    "training units and formations of {en}": "وحدات وتشكيلات تدريبية في {ar}",
    "truck manufacturers of {en}": "مصانع الشاحنات في {ar}",
    "uninhabited islands of {en}": "جزر غير مأهولة في {ar}",
    "vertebrates of {en}": "فقاريات {ar}",
    "wetlands of {en}": "مناطق رطبة في {ar}",
}

main_data = {
    "{en} amateur international footballers": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} amateur international soccer players": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} amateur international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} international footballers": "لاعبو منتخب {ar} لكرة القدم",
    "{en} international rally": "رالي {ar} الدولي",
    "{en} international rules football team": "منتخب {ar} لكرة القدم الدولية",
    "{en} international soccer players": "لاعبو منتخب {ar} لكرة القدم",
    "{en} international soccer playerss": "لاعبو منتخب {ar} لكرة القدم",
    "{en} men's a' international footballers": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's a' international soccer players": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's a' international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's b international footballers": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's b international soccer players": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's b international soccer playerss": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's international footballers": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's international soccer players": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's youth international footballers": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} men's youth international soccer players": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} men's youth international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} national football team managers": "مدربو منتخب {ar} لكرة القدم",
    "{en} national team": "منتخبات {ar} الوطنية",
    "{en} national teams": "منتخبات {ar} الوطنية",
    "{en} rally championship": "بطولة {ar} للراليات",
    "{en} sports templates": "قوالب {ar} الرياضية",
    "{en} women's international footballers": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's international soccer players": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's international soccer playerss": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's youth international footballers": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} women's youth international soccer players": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} women's youth international soccer playerss": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} youth international footballers": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} youth international soccer players": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} youth international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للشباب",
}

formatted_data_en_ar_only.update(main_data)

formatted_data_en_ar_only.update(from_russia_data)

formatted_data_en_ar_only.update(
    {
        x.replace("secretaries of", "secretaries-of"): y
        for x, y in formatted_data_en_ar_only.items()
        if "secretaries of" in x
    }
)

__all__ = [
    "formatted_data_en_ar_only",
]

len_print.data_len(
    "countries_names_data.py",
    {
        "keys_of_without_in_data": keys_of_without_in_data,
        "from_russia_data": from_russia_data,
    },
)
