#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_virginia_0 = {
    "Lists of West Virginia politicians": "قوائم سياسيو فرجينيا الغربية",
    "West Virginia politicians by century": "سياسيو فرجينيا الغربية حسب القرن",
    "West Virginia politicians by party": "سياسيو فرجينيا الغربية حسب الحزب",
    "21st-century West Virginia politicians": "سياسيو فرجينيا الغربية في القرن 21",
    "20th-century West Virginia politicians": "سياسيو فرجينيا الغربية في القرن 20",
    "19th-century West Virginia politicians": "سياسيو فرجينيا الغربية في القرن 19",
}

data_virginia_1 = {
    "Baseball in West Virginia": "كرة القاعدة في فرجينيا الغربية",
    "Baseball players from Alexandria, Virginia": "لاعبو كرة قاعدة من الإسكندرية (فرجينيا)",
    "Baseball players from Danville, Virginia": "لاعبو كرة قاعدة من دانفيل (فرجينيا)",
    "Baseball players from Fredericksburg, Virginia": "لاعبو كرة قاعدة من فريدريكسبيورغ (فرجينيا)",
    "Baseball players from Harrisonburg, Virginia": "لاعبو كرة قاعدة من هاريسونبورغ (فرجينيا)",
    "Baseball players from Huntington, West Virginia": "لاعبو كرة قاعدة من هنغتينغتون (فرجينيا الغربية)",
}

data_virginia_2 = {
    "1778 establishments in Virginia": "تأسيسات سنة 1778 في فرجينيا",
    "1781 in Virginia": "فرجينيا في 1781",
    "1819 establishments in Virginia": "تأسيسات سنة 1819 في فرجينيا",
    "1824 establishments in Virginia": "تأسيسات سنة 1824 في فرجينيا",
    "1824 in Virginia": "فرجينيا في 1824",
    "1831 establishments in Virginia": "تأسيسات سنة 1831 في فرجينيا",
    "1836 establishments in Virginia": "تأسيسات سنة 1836 في فرجينيا",
    "1845 establishments in Virginia": "تأسيسات سنة 1845 في فرجينيا",
    "1861 establishments in Virginia": "تأسيسات سنة 1861 في فرجينيا",
    "1869 establishments in West Virginia": "تأسيسات سنة 1869 في فرجينيا الغربية",
    "1869 in West Virginia": "فرجينيا الغربية في 1869",
    "1870 establishments in West Virginia": "تأسيسات سنة 1870 في فرجينيا الغربية",
    "1870 in West Virginia": "فرجينيا الغربية في 1870",
    "1872 establishments in Virginia": "تأسيسات سنة 1872 في فرجينيا",
    "1874 establishments in West Virginia": "تأسيسات سنة 1874 في فرجينيا الغربية",
    "1879 establishments in West Virginia": "تأسيسات سنة 1879 في فرجينيا الغربية",
    "1880 establishments in Virginia": "تأسيسات سنة 1880 في فرجينيا",
    "1880s disestablishments in West Virginia": "انحلالات عقد 1880 في فرجينيا الغربية",
    "1882 establishments in West Virginia": "تأسيسات سنة 1882 في فرجينيا الغربية",
    "1886 disestablishments in West Virginia": "انحلالات سنة 1886 في فرجينيا الغربية",
    "1886 in West Virginia": "فرجينيا الغربية في 1886",
    "1887 in West Virginia": "فرجينيا الغربية في 1887",
    "1888 establishments in West Virginia": "تأسيسات سنة 1888 في فرجينيا الغربية",
    "1888 in West Virginia": "فرجينيا الغربية في 1888",
    "1890 establishments in West Virginia": "تأسيسات سنة 1890 في فرجينيا الغربية",
    "1890 in West Virginia": "فرجينيا الغربية في 1890",
    "1891 establishments in West Virginia": "تأسيسات سنة 1891 في فرجينيا الغربية",
    "1892 establishments in West Virginia": "تأسيسات سنة 1892 في فرجينيا الغربية",
    "1892 in West Virginia": "فرجينيا الغربية في 1892",
    "1894 establishments in West Virginia": "تأسيسات سنة 1894 في فرجينيا الغربية",
    "1894 in West Virginia": "فرجينيا الغربية في 1894",
    "1896 establishments in West Virginia": "تأسيسات سنة 1896 في فرجينيا الغربية",
    "1897 establishments in West Virginia": "تأسيسات سنة 1897 في فرجينيا الغربية",
    "1897 in West Virginia": "فرجينيا الغربية في 1897",
    "1905 establishments in West Virginia": "تأسيسات سنة 1905 في فرجينيا الغربية",
    "1906 establishments in Virginia": "تأسيسات سنة 1906 في فرجينيا",
    "1906 establishments in West Virginia": "تأسيسات سنة 1906 في فرجينيا الغربية",
    "1916 establishments in West Virginia": "تأسيسات سنة 1916 في فرجينيا الغربية",
    "1920s establishments in West Virginia": "تأسيسات عقد 1920 في فرجينيا الغربية",
    "1921 establishments in West Virginia": "تأسيسات سنة 1921 في فرجينيا الغربية",
    "1924 establishments in Virginia": "تأسيسات سنة 1924 في فرجينيا",
    "1940 in Virginia": "فرجينيا في 1940",
    "1949 in Virginia": "فرجينيا في 1949",
    "1950s establishments in West Virginia": "تأسيسات عقد 1950 في فرجينيا الغربية",
    "1960s establishments in West Virginia": "تأسيسات عقد 1960 في فرجينيا الغربية",
    "1973 establishments in Virginia": "تأسيسات سنة 1973 في فرجينيا",
    "1978 establishments in West Virginia": "تأسيسات سنة 1978 في فرجينيا الغربية",
    "1992 establishments in Virginia": "تأسيسات سنة 1992 في فرجينيا",
    "19th-century disestablishments in West Virginia": "انحلالات القرن 19 في فرجينيا الغربية",
    "19th-century mayors of places in West Virginia": "رؤساء بلديات في فرجينيا الغربية في القرن 19",
    "19th-century members of the West Virginia Legislature": "أعضاء هيئة فرجينيا الغربية التشريعية في القرن 19",
    "19th-century people from West Virginia": "أشخاص من فرجينيا الغربية في القرن 19",
    "2007 establishments in Virginia": "تأسيسات سنة 2007 في فرجينيا",
    "2010s disestablishments in West Virginia": "انحلالات عقد 2010 في فرجينيا الغربية",
    "2012 in Virginia": "فرجينيا في 2012",
    "2017 disestablishments in West Virginia": "انحلالات سنة 2017 في فرجينيا الغربية",
    "2020s disestablishments in West Virginia": "انحلالات عقد 2020 في فرجينيا الغربية",
    "2022 disestablishments in West Virginia": "انحلالات سنة 2022 في فرجينيا الغربية",
    "20th-century mayors of places in West Virginia": "رؤساء بلديات في فرجينيا الغربية في القرن 20",
    "20th-century members of the West Virginia Legislature": "أعضاء هيئة فرجينيا الغربية التشريعية في القرن 20",
    "20th-century people from West Virginia": "أشخاص من فرجينيا الغربية في القرن 20",
    "21st-century disestablishments in West Virginia": "انحلالات القرن 21 في فرجينيا الغربية",
    "21st-century establishments in West Virginia": "تأسيسات القرن 21 في فرجينيا الغربية",
    "21st-century members of the West Virginia Legislature": "أعضاء هيئة فرجينيا الغربية التشريعية في القرن 21",
    "21st-century people from West Virginia": "أشخاص من فرجينيا الغربية في القرن 21",
    "3rd-millennium disestablishments in West Virginia": "انحلالات الألفية 3 في فرجينيا الغربية",
    "3rd-millennium establishments in West Virginia": "تأسيسات الألفية 3 في فرجينيا الغربية",
    "Academics from Bluefield, West Virginia": "أكاديميون من بلوفيلد (فرجينيا الغربية)",
    "Accomack County, Virginia": "مقاطعة أكوماك (فرجينيا)",
    "Actors from Fairfax, Virginia": "ممثلون من فيرفاكس (فرجينيا)",
    "Actors from Monongalia County, West Virginia": "ممثلون من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Actors from Tucker County, West Virginia": "ممثلون من مقاطعة تاكر (فرجينيا الغربية)",
    "Actresses from Alexandria, Virginia": "ممثلات من الإسكندرية (فرجينيا)",
    "Actresses from Charleston, West Virginia": "ممثلات من تشارلستون (فرجينيا الغربية)",
    "Actresses from Fairfax, Virginia": "ممثلات من فيرفاكس (فرجينيا)",
    "African-American history of West Virginia": "تاريخ أمريكي إفريقي في فرجينيا الغربية",
    "African-American state legislators in West Virginia": "مشرعو الولايات أمريكيون أفارقة في فرجينيا الغربية",
    "Airliner accidents and incidents in West Virginia": "حوادث طائرات في فرجينيا الغربية",
    "Albemarle County, Virginia": "مقاطعة ألبمارل (فرجينيا)",
    "Alderson, West Virginia": "ألدرسن (فرجينيا الغربية)",
    "Alexandria, Virginia": "الإسكندرية (فرجينيا)",
    "Alleghany County, Virginia": "مقاطعة أليغاني (فرجينيا)",
    "Amelia County, Virginia": "مقاطعة أميليا (فرجينيا)",
    "Amherst County, Virginia": "مقاطعة أمهيرست (فرجينيا)",
    "Ansted, West Virginia": "أنستيد (فرجينيا الغربية)",
    "Appomattox County, Virginia": "مقاطعة أبوماتوكس (فرجينيا)",
    "Architects from Charleston, West Virginia": "معماريون من تشارلستون (فرجينيا الغربية)",
    "Architects from Wheeling, West Virginia": "معماريون من ويلينغ (فرجينيا الغربية)",
    "Arlington County, Virginia": "مقاطعة أرلنغتون (فرجينيا)",
    "Artists from Alexandria, Virginia": "فنانون من الإسكندرية (فرجينيا)",
    "Artists from Charleston, West Virginia": "فنانون من تشارلستون (فرجينيا الغربية)",
    "Artists from Roanoke, Virginia": "فنانون من روانوك (فرجينيا)",
    "Artists from West Virginia by populated place": "فنانون من فرجينيا الغربية حسب المكان المأهول",
    "Artists from Wheeling, West Virginia": "فنانون من ويلينغ (فرجينيا الغربية)",
    "Athens, West Virginia": "أثينا (فرجينيا الغربية)",
    "Augusta County, Virginia": "مقاطعة أوغوستا (فرجينيا)",
    "Aviation accidents and incidents in West Virginia": "حوادث طيران في فرجينيا الغربية",
    "Baseball coaches from West Virginia": "مدربو كرة قاعدة من فرجينيا الغربية",
    "Baseball in West Virginia": "كرة القاعدة في فرجينيا الغربية",
    "Baseball players from Alexandria, Virginia": "لاعبو كرة قاعدة من الإسكندرية (فرجينيا)",
    "Baseball players from Danville, Virginia": "لاعبو كرة قاعدة من دانفيل (فرجينيا)",
    "Baseball players from Fredericksburg, Virginia": "لاعبو كرة قاعدة من فريدريكسبيورغ (فرجينيا)",
    "Baseball players from Harrisonburg, Virginia": "لاعبو كرة قاعدة من هاريسونبورغ (فرجينيا)",
    "Baseball players from Huntington, West Virginia": "لاعبو كرة قاعدة من هنغتينغتون (فرجينيا الغربية)",
    "Baseball players from Lynchburg, Virginia": "لاعبو كرة قاعدة من لينشبرغ (فرجينيا)",
    "Baseball players from Portsmouth, Virginia": "لاعبو كرة قاعدة من بورتسموث (فرجينيا)",
    "Baseball players from Prince Edward County, Virginia": "لاعبو كرة قاعدة من مقاطعة برينس إدورد (فرجينيا)",
    "Baseball players from Staunton, Virginia": "لاعبو كرة قاعدة من ستونتون (فرجينيا)",
    "Baseball players from Wheeling, West Virginia": "لاعبو كرة قاعدة من ويلينغ (فرجينيا الغربية)",
    "Baseball players from Williamsburg, Virginia": "لاعبو كرة قاعدة من ويليامزبرغ (فرجينيا)",
    "Baseball players in Lynchburg, Virginia by team": "لاعبو كرة قاعدة في لينشبرغ (فرجينيا) حسب الفريق",
    "Basketball in West Virginia": "كرة السلة في فرجينيا الغربية",
    "Basketball players from Alexandria, Virginia": "لاعبو كرة سلة من الإسكندرية (فرجينيا)",
    "Basketball players from Portsmouth, Virginia": "لاعبو كرة سلة من بورتسموث (فرجينيا)",
    "Bath County, Virginia": "مقاطعة باث (فرجينيا)",
    "Bedford County, Virginia": "مقاطعة بيدفورد (فرجينيا)",
    "Berkeley County, West Virginia": "مقاطعة بيركلي (فرجينيا الغربية)",
    "Bethany, West Virginia": "بيثاني (فرجينيا الغربية)",
    "Beverly, West Virginia": "بيفرلي (فرجينيا الغربية)",
    "Biologists from West Virginia": "علماء أحياء من فرجينيا الغربية",
    "Bland County, Virginia": "مقاطعة بلاند (فرجينيا)",
    "Bluegrass musicians from West Virginia": "موسيقيو بلوغراس من فرجينيا الغربية",
    "Blues musicians from West Virginia": "موسيقيو بلوز من فرجينيا الغربية",
    "Bodies of water of King George County, Virginia": "مسطحات مائية في مقاطعة كينغ جورج (فرجينيا)",
    "Books about West Virginia": "كتب عن فرجينيا الغربية",
    "Boone County, West Virginia": "مقاطعة بوون (فرجينيا الغربية)",
    "Botetourt County, Virginia": "مقاطعة بوتيتورت (فرجينيا)",
    "Bramwell, West Virginia": "برامويل (فرجينيا الغربية)",
    "Braxton County, West Virginia": "مقاطعة براكستون (فرجينيا الغربية)",
    "Bridges in Mason County, West Virginia": "جسور في مقاطعة ماسون (فرجينيا الغربية)",
    "Bridges in West Virginia by county": "جسور في فرجينيا الغربية حسب المقاطعة",
    "Bristol, Virginia": "بريستول (فرجينيا)",
    "Brooke County, West Virginia": "مقاطعة بروك (فرجينيا الغربية)",
    "Brunswick County, Virginia": "مقاطعة برونزويك (فرجينيا)",
    "Buchanan County, Virginia": "مقاطعة بوكانان (فرجينيا)",
    "Buckingham County, Virginia": "مقاطعة باكنغهام (فرجينيا)",
    "Buildings and structures in Albemarle County, Virginia": "مبان ومنشآت في مقاطعة ألبمارل (فرجينيا)",
    "Buildings and structures in Alexandria, Virginia": "مبان ومنشآت في الإسكندرية (فرجينيا)",
    "Buildings and structures in Arlington County, Virginia": "مبان ومنشآت في مقاطعة أرلنغتون (فرجينيا)",
    "Buildings and structures in Bluefield, West Virginia": "مبان ومنشآت في بلوفيلد (فرجينيا الغربية)",
    "Buildings and structures in Danville, Virginia": "مبان ومنشآت في دانفيل (فرجينيا)",
    "Buildings and structures in Fairfax County, Virginia": "مبان ومنشآت في مقاطعة فيرفاكس (فرجينيا)",
    "Buildings and structures in Floyd County, Virginia": "مبان ومنشآت في مقاطعة فلويد (فرجينيا)",
    "Buildings and structures in Greenbrier County, West Virginia": "مبان ومنشآت في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Buildings and structures in Hampshire County, West Virginia": "مبان ومنشآت في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Buildings and structures in Harrisonburg, Virginia": "مبان ومنشآت في هاريسونبورغ (فرجينيا)",
    "Buildings and structures in Lexington, Virginia": "مبان ومنشآت في كسينغتون (فرجينيا)",
    "Buildings and structures in Loudoun County, Virginia": "مبان ومنشآت في مقاطعة لودون (فرجينيا)",
    "Buildings and structures in Parkersburg, West Virginia": "مبان ومنشآت في باركرسبورغ (فرجينيا الغربية)",
    "Buildings and structures in Radford, Virginia": "مبان ومنشآت في رادفورد (فرجينيا)",
    "Buildings and structures in Romney, West Virginia": "مبان ومنشآت في رومني (فرجينيا الغربية)",
    "Buildings and structures in Tucker County, West Virginia": "مبان ومنشآت في مقاطعة تاكر (فرجينيا الغربية)",
    "Buildings and structures in West Virginia by condition": "مبان ومنشآت في فرجينيا الغربية حسب الحالة",
    "Buildings and structures in West Virginia by type": "مبان ومنشآت في فرجينيا الغربية حسب الفئة",
    "Buildings and structures in Wheeling, West Virginia": "مبان ومنشآت في ويلينغ (فرجينيا الغربية)",
    "Buildings and structures in White Sulphur Springs, West Virginia": "مبان ومنشآت في وايت سولفور سبرينغز (فرجينيا الغربية)",
    "Buildings and structures in Williamsburg, Virginia": "مبان ومنشآت في ويليامزبرغ (فرجينيا)",
    "Buildings and structures in York County, Virginia": "مبان ومنشآت في مقاطعة يورك (فرجينيا)",
    "Buildings and structures on the National Register of Historic Places in West Virginia": "مبان ومنشآت في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Burial monuments and structures in West Virginia": "معالم ومنشآت أماكن الدفن في فرجينيا الغربية",
    "Burnsville, West Virginia": "بورنسفيل (فرجينيا الغربية)",
    "Businesspeople from Alexandria, Virginia": "شخصيات أعمال من الإسكندرية (فرجينيا)",
    "Businesspeople from Beckley, West Virginia": "شخصيات أعمال من بيكلي (فرجينيا الغربية)",
    "Businesspeople from Bluefield, West Virginia": "شخصيات أعمال من بلوفيلد (فرجينيا الغربية)",
    "Businesspeople from Charleston, West Virginia": "شخصيات أعمال من تشارلستون (فرجينيا الغربية)",
    "Businesspeople from Clarksburg, West Virginia": "شخصيات أعمال من كلاركسبورغ (فرجينيا الغربية)",
    "Businesspeople from Morgantown, West Virginia": "شخصيات أعمال من مورغانتاون (فرجينيا الغربية)",
    "Businesspeople from Parkersburg, West Virginia": "شخصيات أعمال من باركرسبورغ (فرجينيا الغربية)",
    "Businesspeople from Romney, West Virginia": "شخصيات أعمال من رومني (فرجينيا الغربية)",
    "Businesspeople from West Virginia by populated place": "شخصيات أعمال من فرجينيا الغربية حسب المكان المأهول",
    "Businesspeople from Wheeling, West Virginia": "شخصيات أعمال من ويلينغ (فرجينيا الغربية)",
    "Campbell County, Virginia": "مقاطعة كامبل (فرجينيا)",
    "Capon Bridge, West Virginia": "كابون بريدج (فرجينيا الغربية)",
    "Caroline County, Virginia": "مقاطعة كارولين (فرجينيا)",
    "Carroll County, Virginia": "مقاطعة كارول (فرجينيا)",
    "Catholics from West Virginia": "كاثوليك من فرجينيا الغربية",
    "Cemeteries in Arlington County, Virginia": "مقابر في مقاطعة أرلنغتون (فرجينيا)",
    "Census-designated places in Alleghany County, Virginia": "مناطق إحصاء سكاني في مقاطعة أليغاني (فرجينيا)",
    "Census-designated places in Augusta County, Virginia": "مناطق إحصاء سكاني في مقاطعة أوغوستا (فرجينيا)",
    "Census-designated places in Bedford County, Virginia": "مناطق إحصاء سكاني في مقاطعة بيدفورد (فرجينيا)",
    "Census-designated places in Botetourt County, Virginia": "مناطق إحصاء سكاني في مقاطعة بوتيتورت (فرجينيا)",
    "Census-designated places in Brooke County, West Virginia": "مناطق إحصاء سكاني في مقاطعة بروك (فرجينيا الغربية)",
    "Census-designated places in Carroll County, Virginia": "مناطق إحصاء سكاني في مقاطعة كارول (فرجينيا)",
    "Census-designated places in Chesterfield County, Virginia": "مناطق إحصاء سكاني في مقاطعة تشيسترفيلد (فرجينيا)",
    "Census-designated places in Fairfax County, Virginia": "مناطق إحصاء سكاني في مقاطعة فيرفاكس (فرجينيا)",
    "Census-designated places in Franklin County, Virginia": "مناطق إحصاء سكاني في مقاطعة فرانكلين (فرجينيا)",
    "Census-designated places in Gloucester County, Virginia": "مناطق إحصاء سكاني في مقاطعة غلوستر (فرجينيا)",
    "Census-designated places in Henrico County, Virginia": "مناطق إحصاء سكاني في مقاطعة هنريكو (فرجينيا)",
    "Census-designated places in Isle of Wight County, Virginia": "مناطق إحصاء سكاني في مقاطعة آيل أوف وايت (فرجينيا)",
    "Census-designated places in King George County, Virginia": "مناطق إحصاء سكاني في مقاطعة كينغ جورج (فرجينيا)",
    "Census-designated places in Lee County, Virginia": "مناطق إحصاء سكاني في مقاطعة لي (فرجينيا)",
    "Census-designated places in Patrick County, Virginia": "مناطق إحصاء سكاني في مقاطعة باتريك (فرجينيا)",
    "Census-designated places in Prince Edward County, Virginia": "مناطق إحصاء سكاني في مقاطعة برينس إدورد (فرجينيا)",
    "Census-designated places in Prince William County, Virginia": "مناطق إحصاء سكاني في مقاطعة برينس ويليام (فرجينيا)",
    "Census-designated places in Roanoke County, Virginia": "مناطق إحصاء سكاني في مقاطعة رونوك (فرجينيا)",
    "Census-designated places in Russell County, Virginia": "مناطق إحصاء سكاني في مقاطعة روسيل (فرجينيا)",
    "Census-designated places in Smyth County, Virginia": "مناطق إحصاء سكاني في مقاطعة سميث (فرجينيا)",
    "Census-designated places in Spotsylvania County, Virginia": "مناطق إحصاء سكاني في مقاطعة سبوتسيلفانيا (فرجينيا)",
    "Charles City County, Virginia": "مقاطعة تشارلز سيتي (فرجينيا)",
    "Charlotte County, Virginia": "مقاطعة شارلوت (فرجينيا)",
    "Chemists from West Virginia": "كيميائيون من فرجينيا الغربية",
    "Chesterfield County, Virginia": "مقاطعة تشيسترفيلد (فرجينيا)",
    "Cities in Fayette County, West Virginia": "مدن في مقاطعة فيات (فرجينيا الغربية)",
    "Civil servants from Bluefield, West Virginia": "موظفو خدمة مدنية من بلوفيلد (فرجينيا الغربية)",
    "Civil servants from Charleston, West Virginia": "موظفو خدمة مدنية من تشارلستون (فرجينيا الغربية)",
    "Civil servants from Romney, West Virginia": "موظفو خدمة مدنية من رومني (فرجينيا الغربية)",
    "Civil servants from West Virginia": "موظفو خدمة مدنية من فرجينيا الغربية",
    "Clarke County, Virginia": "مقاطعة كلارك (فرجينيا)",
    "Clergy from West Virginia": "رجال دين من فرجينيا الغربية",
    "Clifton, Virginia": "كليفتون (فرجينيا)",
    "Clubhouses in West Virginia": "نوادي في فرجينيا الغربية",
    "Clubhouses on the National Register of Historic Places in West Virginia": "نوادي في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Companies based in Fairfax, Virginia": "شركات مقرها في فيرفاكس (فرجينيا)",
    "Companies based in Fairfax County, Virginia": "شركات مقرها في مقاطعة فيرفاكس (فرجينيا)",
    "Companies based in Reston, Virginia": "شركات مقرها في رستون (فرجينيا)",
    "Congressional delegations from West Virginia navigational boxes": "صناديق تصفح وفود الكونغرس من فرجينيا الغربية",
    "County clerks in West Virginia": "كاتبو مقاطعات في فرجينيا الغربية",
    "County commissioners in West Virginia": "مفوضو مقاطعات في فرجينيا الغربية",
    "Covington, Virginia": "كوفينغتون (فرجينيا)",
    "Craig County, Virginia": "مقاطعة كريغ (فرجينيا)",
    "Culpeper County, Virginia": "مقاطعة كلبيبر (فرجينيا)",
    "Cultural organizations based in West Virginia": "منظمات ثقافية مقرها في فرجينيا الغربية",
    "Culture of Beckley, West Virginia": "ثقافة بيكلي (فرجينيا الغربية)",
    "Culture of Bluefield, West Virginia": "ثقافة بلوفيلد (فرجينيا الغربية)",
    "Culture of Clarksburg, West Virginia": "ثقافة كلاركسبورغ (فرجينيا الغربية)",
    "Culture of Elkins, West Virginia": "ثقافة إلكينز (فرجينيا الغربية)",
    "Culture of Martinsburg, West Virginia": "ثقافة مرتينسبورغ (فرجينيا الغربية)",
    "Culture of Parkersburg, West Virginia": "ثقافة باركرسبورغ (فرجينيا الغربية)",
    "Cumberland County, Virginia": "مقاطعة كومبرلاند (فرجينيا)",
    "Danville, Virginia": "دانفيل (فرجينيا)",
    "Deaths from brain cancer in West Virginia": "وفيات سرطان الدماغ في فرجينيا الغربية",
    "Deaths in West Virginia": "وفيات في فرجينيا الغربية",
    "Defunct organizations based in West Virginia": "منظمات سابقة مقرها في فرجينيا الغربية",
    "Defunct schools in West Virginia": "مدارس سابقة في فرجينيا الغربية",
    "Defunct universities and colleges in West Virginia": "جامعات وكليات سابقة في فرجينيا الغربية",
    "Democratic Party United States senators from West Virginia": "أعضاء مجلس الشيوخ الأمريكي من الحزب الديمقراطي من فرجينيا الغربية",
    "Demographics of West Virginia": "التركيبة السكانية في فرجينيا الغربية",
    "Demolished buildings and structures in West Virginia": "مبان ومنشآت مهدمة في فرجينيا الغربية",
    "Dickenson County, Virginia": "مقاطعة ديكينسون (فرجينيا)",
    "Dinwiddie County, Virginia": "مقاطعة دينويدي (فرجينيا)",
    "Disasters in Virginia": "كوارث في فرجينيا",
    "Drummers from West Virginia": "طبالون من فرجينيا الغربية",
    "Economy of Alexandria, Virginia": "اقتصاد الإسكندرية (فرجينيا)",
    "Education in Albemarle County, Virginia": "التعليم في مقاطعة ألبمارل (فرجينيا)",
    "Education in Arlington County, Virginia": "التعليم في مقاطعة أرلنغتون (فرجينيا)",
    "Education in Berkeley County, West Virginia": "التعليم في مقاطعة بيركلي (فرجينيا الغربية)",
    "Education in Danville, Virginia": "التعليم في دانفيل (فرجينيا)",
    "Education in Fairfax County, Virginia": "التعليم في مقاطعة فيرفاكس (فرجينيا)",
    "Education in Greenbrier County, West Virginia": "التعليم في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Education in Hampshire County, West Virginia": "التعليم في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Education in Harrisonburg, Virginia": "التعليم في هاريسونبورغ (فرجينيا)",
    "Education in James City County, Virginia": "التعليم في مقاطعة جيمس سيتي (فرجينيا)",
    "Education in Jefferson County, West Virginia": "التعليم في مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Education in Lexington, Virginia": "التعليم في كسينغتون (فرجينيا)",
    "Education in Loudoun County, Virginia": "التعليم في مقاطعة لودون (فرجينيا)",
    "Education in Martinsburg, West Virginia": "التعليم في مرتينسبورغ (فرجينيا الغربية)",
    "Education in Monongalia County, West Virginia": "التعليم في مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Education in Montgomery County, Virginia": "التعليم في مقاطعة مونغومري (فرجينيا)",
    "Education in Ohio County, West Virginia": "التعليم في مقاطعة أوهايو (فرجينيا الغربية)",
    "Education in Portsmouth, Virginia": "التعليم في بورتسموث (فرجينيا)",
    "Education in Prince William County, Virginia": "التعليم في مقاطعة برينس ويليام (فرجينيا)",
    "Education in Radford, Virginia": "التعليم في رادفورد (فرجينيا)",
    "Education in Raleigh County, West Virginia": "التعليم في مقاطعة رالي (فرجينيا الغربية)",
    "Education in Romney, West Virginia": "التعليم في رومني (فرجينيا الغربية)",
    "Education in Virginia": "التعليم في فرجينيا",
    "Educational buildings in West Virginia": "مبان تعليمية في فرجينيا الغربية",
    "Educational buildings on the National Register of Historic Places in West Virginia": "مبان تعليمية في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Educational organizations based in West Virginia": "منظمات تعليمية مقرها في فرجينيا الغربية",
    "Educators from Bluefield, West Virginia": "معلمون من بلوفيلد (فرجينيا الغربية)",
    "Educators from Charleston, West Virginia": "معلمون من تشارلستون (فرجينيا الغربية)",
    "Educators from Huntington, West Virginia": "معلمون من هنغتينغتون (فرجينيا الغربية)",
    "Educators from Martinsburg, West Virginia": "معلمون من مرتينسبورغ (فرجينيا الغربية)",
    "Educators from Romney, West Virginia": "معلمون من رومني (فرجينيا الغربية)",
    "Educators from Wheeling, West Virginia": "معلمون من ويلينغ (فرجينيا الغربية)",
    "Entertainers from Fredericksburg, Virginia": "فنانون ترفيهيون من فريدريكسبيورغ (فرجينيا)",
    "Episcopalians from West Virginia": "أسقفيون من فرجينيا الغربية",
    "Essays by Virginia Woolf": "مقالات بواسطة فرجينيا وولف",
    "Essex County, Virginia": "مقاطعة إيسيكس (فرجينيا)",
    "Fairfax, Virginia": "فيرفاكس (فرجينيا)",
    "Fairfax County, Virginia": "مقاطعة فيرفاكس (فرجينيا)",
    "Fayetteville, West Virginia": "فايتفيل (فرجينيا الغربية)",
    "Film producers from West Virginia": "منتجو أفلام من فرجينيا الغربية",
    "Films based on works by Virginia Woolf": "أفلام مبنية على أعمال فرجينيا وولف",
    "Films set in Virginia": "أفلام تقع أحداثها في فرجينيا",
    "Fires in West Virginia": "حرائق في فرجينيا الغربية",
    "Floods in West Virginia": "فيضانات في فرجينيا الغربية",
    "Floyd County, Virginia": "مقاطعة فلويد (فرجينيا)",
    "Fluvanna County, Virginia": "مقاطعة فلوفانان (فرجينيا)",
    "Former buildings and structures in West Virginia": "مبان ومنشآت سابقة في فرجينيا الغربية",
    "Franklin, Virginia": "فرانكلين (فرجينيا)",
    "Franklin County, Virginia": "مقاطعة فرانكلين (فرجينيا)",
    "Frederick County, Virginia": "مقاطعة فريدريك (فرجينيا)",
    "Front Royal, Virginia": "فرونت رويال (فرجينيا)",
    "Geography of Albemarle County, Virginia": "جغرافيا مقاطعة ألبمارل (فرجينيا)",
    "Geography of Alexandria, Virginia": "جغرافيا الإسكندرية (فرجينيا)",
    "Geography of Arlington County, Virginia": "جغرافيا مقاطعة أرلنغتون (فرجينيا)",
    "Geography of Berkeley County, West Virginia": "جغرافيا مقاطعة بيركلي (فرجينيا الغربية)",
    "Geography of Boone County, West Virginia": "جغرافيا مقاطعة بوون (فرجينيا الغربية)",
    "Geography of Grant County, West Virginia": "جغرافيا مقاطعة غرانت (فرجينيا الغربية)",
    "Geography of Jackson County, West Virginia": "جغرافيا مقاطعة جاكسون (فرجينيا الغربية)",
    "Geography of James City County, Virginia": "جغرافيا مقاطعة جيمس سيتي (فرجينيا)",
    "Geography of King George County, Virginia": "جغرافيا مقاطعة كينغ جورج (فرجينيا)",
    "Geography of Pleasants County, West Virginia": "جغرافيا مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Geography of Preston County, West Virginia": "جغرافيا مقاطعة بريستون (فرجينيا الغربية)",
    "Geography of Prince Edward County, Virginia": "جغرافيا مقاطعة برينس إدورد (فرجينيا)",
    "Geography of Ritchie County, West Virginia": "جغرافيا مقاطعة ريتشي (فرجينيا الغربية)",
    "Geography of Taylor County, West Virginia": "جغرافيا مقاطعة تايلور (فرجينيا الغربية)",
    "Geography of Tazewell County, Virginia": "جغرافيا مقاطعة تازويل (فرجينيا)",
    "Geography of Tucker County, West Virginia": "جغرافيا مقاطعة تاكر (فرجينيا الغربية)",
    "Geography of Williamsburg, Virginia": "جغرافيا ويليامزبرغ (فرجينيا)",
    "Geography of Winchester, Virginia": "جغرافيا وينشستر (فرجينيا)",
    "Giles County, Virginia": "مقاطعة غيلز (فرجينيا)",
    "Gilmer County, West Virginia": "مقاطعة غيلمر (فرجينيا الغربية)",
    "Gloucester County, Virginia": "مقاطعة غلوستر (فرجينيا)",
    "Goochland County, Virginia": "مقاطعة غووتشلاند (فرجينيا)",
    "Government buildings in West Virginia": "مبان حكومية في فرجينيا الغربية",
    "Grayson County, Virginia": "مقاطعة غرايسون (فرجينيا)",
    "Greenbrier County, West Virginia": "مقاطعة غرينبريه (فرجينيا الغربية)",
    "Greene County, Virginia": "مقاطعة غرين (فرجينيا)",
    "Greensville County, Virginia": "مقاطعة غرينزفيل (فرجينيا)",
    "Gymnastics in West Virginia": "الجمباز في فرجينيا الغربية",
    "Halifax County, Virginia": "مقاطعة هاليفاكس (فرجينيا)",
    "Hampshire County, West Virginia": "مقاطعة هامبشاير (فرجينيا الغربية)",
    "Hampton, Virginia": "هامبتون (فرجينيا)",
    "Hancock County, West Virginia": "مقاطعة هانكوك (فرجينيا الغربية)",
    "Hanover County, Virginia": "مقاطعة هانوفر (فرجينيا)",
    "Harpers Ferry, West Virginia": "هاربرز فيري (فرجينيا الغربية)",
    "Henrico County, Virginia": "مقاطعة هنريكو (فرجينيا)",
    "Henry County, Virginia": "مقاطعة هنري (فرجينيا)",
    "Herndon, Virginia": "هيرندون (فرجينيا)",
    "Highland County, Virginia": "مقاطعة هايلاند (فرجينيا)",
    "History of Alexandria, Virginia": "تاريخ الإسكندرية (فرجينيا)",
    "History of Virginia": "تاريخ فرجينيا",
    "History of women in West Virginia": "تاريخ المرأة في فرجينيا الغربية",
    "Hotel buildings on the National Register of Historic Places in West Virginia": "مبان فنادق في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "International schools in West Virginia": "مدارس دولية في فرجينيا الغربية",
    "Islands of Kanawha County, West Virginia": "جزر مقاطعة كاناوا (فرجينيا الغربية)",
    "Italian-American culture in West Virginia": "ثقافة أمريكية إيطالية في فرجينيا الغربية",
    "Jackson County, West Virginia": "مقاطعة جاكسون (فرجينيا الغربية)",
    "James City County, Virginia": "مقاطعة جيمس سيتي (فرجينيا)",
    "Journalists from Alexandria, Virginia": "صحفيون من الإسكندرية (فرجينيا)",
    "King and Queen County, Virginia": "مقاطعة كينغ أند كوين (فرجينيا)",
    "King George County, Virginia": "مقاطعة كينغ جورج (فرجينيا)",
    "King William County, Virginia": "مقاطعة كينغ ويليام (فرجينيا)",
    "Lancaster County, Virginia": "مقاطعة لانكستر (فرجينيا)",
    "Landforms of Greenbrier County, West Virginia": "تضاريس مقاطعة غرينبريه (فرجينيا الغربية)",
    "Landforms of King George County, Virginia": "تضاريس مقاطعة كينغ جورج (فرجينيا)",
    "Landforms of Randolph County, West Virginia": "تضاريس مقاطعة راندولف (فرجينيا الغربية)",
    "Lawyers from Alexandria, Virginia": "محامون من الإسكندرية (فرجينيا)",
    "Lawyers from Beckley, West Virginia": "محامون من بيكلي (فرجينيا الغربية)",
    "Lawyers from Bluefield, West Virginia": "محامون من بلوفيلد (فرجينيا الغربية)",
    "Lawyers from Charleston, West Virginia": "محامون من تشارلستون (فرجينيا الغربية)",
    "Lawyers from Clarksburg, West Virginia": "محامون من كلاركسبورغ (فرجينيا الغربية)",
    "Lawyers from Fairmont, West Virginia": "محامون من فيرمونت (فرجينيا الغربية)",
    "Lawyers from Martinsburg, West Virginia": "محامون من مرتينسبورغ (فرجينيا الغربية)",
    "Lawyers from Morgantown, West Virginia": "محامون من مورغانتاون (فرجينيا الغربية)",
    "Lawyers from Parkersburg, West Virginia": "محامون من باركرسبورغ (فرجينيا الغربية)",
    "Lawyers from Roanoke, Virginia": "محامون من روانوك (فرجينيا)",
    "Lawyers from Romney, West Virginia": "محامون من رومني (فرجينيا الغربية)",
    "Lawyers from Wheeling, West Virginia": "محامون من ويلينغ (فرجينيا الغربية)",
    "Lee County, Virginia": "مقاطعة لي (فرجينيا)",
    "Leesburg, Virginia": "ليسبورغ (فرجينيا)",
    "Libraries in West Virginia": "مكتبات في فرجينيا الغربية",
    "Libraries on the National Register of Historic Places in West Virginia": "مكتبات في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Lincoln County, West Virginia": "مقاطعة لينكون (فرجينيا الغربية)",
    "Lists of mayors of places in West Virginia": "قوائم رؤساء بلديات في فرجينيا الغربية",
    "Lists of people from West Virginia": "قوائم أشخاص من فرجينيا الغربية",
    "Loudoun County, Virginia": "مقاطعة لودون (فرجينيا)",
    "Louisa, Virginia": "لوييسا (فرجينيا)",
    "Louisa County, Virginia": "مقاطعة لويزا (فرجينيا)",
    "Lunenburg County, Virginia": "مقاطعة لونينبرغ (فرجينيا)",
    "Madison County, Virginia": "مقاطعة ماديسون (فرجينيا)",
    "Male actors from Charleston, West Virginia": "ممثلون ذكور من تشارلستون (فرجينيا الغربية)",
    "Male actors from Fairfax, Virginia": "ممثلون ذكور من فيرفاكس (فرجينيا)",
    "Marshall County, West Virginia": "مقاطعة مارشال (فرجينيا الغربية)",
    "Martinsville, Virginia": "مارتينسفيل (فرجينيا)",
    "Mason County, West Virginia": "مقاطعة ماسون (فرجينيا الغربية)",
    "Mathews County, Virginia": "مقاطعة ماثيوز (فرجينيا)",
    "Mayors of Alexandria, Virginia": "عمدات الإسكندرية (فرجينيا)",
    "Mayors of Charleston, West Virginia": "عمدات تشارلستون (فرجينيا الغربية)",
    "Mayors of Huntington, West Virginia": "عمدات هنغتينغتون (فرجينيا الغربية)",
    "Mayors of Lynchburg, Virginia": "عمدات لينشبرغ (فرجينيا)",
    "Mayors of Morgantown, West Virginia": "عمدات مورغانتاون (فرجينيا الغربية)",
    "Mayors of places in West Virginia by century": "رؤساء بلديات في فرجينيا الغربية حسب القرن",
    "Mayors of Roanoke, Virginia": "عمدات روانوك (فرجينيا)",
    "Mayors of Staunton, Virginia": "عمدات ستونتون (فرجينيا)",
    "McDowell County, West Virginia": "مقاطعة مكداويل (فرجينيا الغربية)",
    "Mecklenburg County, Virginia": "مقاطعة ميكلينبرغ (فرجينيا)",
    "Medical and health organizations based in West Virginia": "منظمات طبية وصحية مقرها في فرجينيا الغربية",
    "Medical schools in West Virginia": "مدارس طبية في فرجينيا الغربية",
    "Members of the West Virginia Board of Education": "أعضاء مجلس التعليم في ولاية فرجينيا الغربية",
    "Methodists from West Virginia": "ميثوديون من فرجينيا الغربية",
    "Middlesex County, Virginia": "مقاطعة ميديلسكس (فرجينيا)",
    "Military personnel from Alexandria, Virginia": "أفراد عسكريون من الإسكندرية (فرجينيا)",
    "Military personnel from Beckley, West Virginia": "أفراد عسكريون من بيكلي (فرجينيا الغربية)",
    "Military personnel from Bluefield, West Virginia": "أفراد عسكريون من بلوفيلد (فرجينيا الغربية)",
    "Military personnel from Charleston, West Virginia": "أفراد عسكريون من تشارلستون (فرجينيا الغربية)",
    "Military personnel from Clarksburg, West Virginia": "أفراد عسكريون من كلاركسبورغ (فرجينيا الغربية)",
    "Military personnel from Fairfax, Virginia": "أفراد عسكريون من فيرفاكس (فرجينيا)",
    "Military personnel from Fredericksburg, Virginia": "أفراد عسكريون من فريدريكسبيورغ (فرجينيا)",
    "Military personnel from Lynchburg, Virginia": "أفراد عسكريون من لينشبرغ (فرجينيا)",
    "Military personnel from Martinsburg, West Virginia": "أفراد عسكريون من مرتينسبورغ (فرجينيا الغربية)",
    "Military personnel from Morgantown, West Virginia": "أفراد عسكريون من مورغانتاون (فرجينيا الغربية)",
    "Military personnel from Parkersburg, West Virginia": "أفراد عسكريون من باركرسبورغ (فرجينيا الغربية)",
    "Military personnel from Portsmouth, Virginia": "أفراد عسكريون من بورتسموث (فرجينيا)",
    "Military personnel from Princeton, West Virginia": "أفراد عسكريون من برينستون (فرجينيا الغربية)",
    "Military personnel from Romney, West Virginia": "أفراد عسكريون من رومني (فرجينيا الغربية)",
    "Military personnel from West Virginia by populated place": "أفراد عسكريون من فرجينيا الغربية حسب المكان المأهول",
    "Military personnel from Wheeling, West Virginia": "أفراد عسكريون من ويلينغ (فرجينيا الغربية)",
    "Mineral County, West Virginia": "مقاطعة مينيرال (فرجينيا الغربية)",
    "Mingo County, West Virginia": "مقاطعة مينغو (فرجينيا الغربية)",
    "Mixed martial arts in West Virginia": "فنون القتال المختلطة في فرجينيا الغربية",
    "Monongalia County, West Virginia": "مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Montgomery County, Virginia": "مقاطعة مونغومري (فرجينيا)",
    "Mountain ranges of West Virginia": "سلاسل جبلية في فرجينيا الغربية",
    "Museums in Albemarle County, Virginia": "متاحف في مقاطعة ألبمارل (فرجينيا)",
    "Museums in Alexandria, Virginia": "متاحف في الإسكندرية (فرجينيا)",
    "Museums in Fairfax County, Virginia": "متاحف في مقاطعة فيرفاكس (فرجينيا)",
    "Museums in Greenbrier County, West Virginia": "متاحف في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Museums in Hampshire County, West Virginia": "متاحف في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Museums in West Virginia": "متاحف في فرجينيا الغربية",
    "Museums in West Virginia by county": "متاحف في فرجينيا الغربية حسب المقاطعة",
    "Museums in Williamsburg, Virginia": "متاحف في ويليامزبرغ (فرجينيا)",
    "Museums on the National Register of Historic Places in West Virginia": "متاحف في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Musicians from Alexandria, Virginia": "موسيقيون من الإسكندرية (فرجينيا)",
    "Musicians from Beckley, West Virginia": "موسيقيون من بيكلي (فرجينيا الغربية)",
    "Musicians from Bluefield, West Virginia": "موسيقيون من بلوفيلد (فرجينيا الغربية)",
    "Musicians from Charleston, West Virginia": "موسيقيون من تشارلستون (فرجينيا الغربية)",
    "Musicians from Martinsburg, West Virginia": "موسيقيون من مرتينسبورغ (فرجينيا الغربية)",
    "Musicians from Portsmouth, Virginia": "موسيقيون من بورتسموث (فرجينيا)",
    "Musicians from Princeton, West Virginia": "موسيقيون من برينستون (فرجينيا الغربية)",
    "Musicians from West Virginia by genre": "موسيقيون من فرجينيا الغربية حسب النوع الفني",
    "Musicians from Wheeling, West Virginia": "موسيقيون من ويلينغ (فرجينيا الغربية)",
    "National Natural Landmarks in West Virginia": "معالم طبيعية وطنية في فرجينيا الغربية",
    "National Register of Historic Places in Alexandria, Virginia": "السجل الوطني للأماكن التاريخية في الإسكندرية (فرجينيا)",
    "National Register of Historic Places in Fredericksburg, Virginia": "السجل الوطني للأماكن التاريخية في فريدريكسبيورغ (فرجينيا)",
    "National Register of Historic Places in Hampshire County, West Virginia": "السجل الوطني للأماكن التاريخية في مقاطعة هامبشاير (فرجينيا الغربية)",
    "National Register of Historic Places in Lexington, Virginia": "السجل الوطني للأماكن التاريخية في كسينغتون (فرجينيا)",
    "National Register of Historic Places in Wheeling, West Virginia": "السجل الوطني للأماكن التاريخية في ويلينغ (فرجينيا الغربية)",
    "National Register of Historic Places in Williamsburg, Virginia": "السجل الوطني للأماكن التاريخية في ويليامزبرغ (فرجينيا)",
    "National Register of Historic Places in Winchester, Virginia": "السجل الوطني للأماكن التاريخية في وينشستر (فرجينيا)",
    "Nelson County, Virginia": "مقاطعة نيلسون (فرجينيا)",
    "New Kent County, Virginia": "مقاطعة كينت الجديدة (فرجينيا)",
    "Non-profit organizations based in Alexandria, Virginia": "منظمات غير ربحية مقرها في الإسكندرية (فرجينيا)",
    "Non-profit organizations based in Fairfax, Virginia": "منظمات غير ربحية مقرها في فيرفاكس (فرجينيا)",
    "Non-profit organizations based in Herndon, Virginia": "منظمات غير ربحية مقرها في هيرندون (فرجينيا)",
    "Non-profit organizations based in Lynchburg, Virginia": "منظمات غير ربحية مقرها في لينشبرغ (فرجينيا)",
    "Non-profit organizations based in West Virginia": "منظمات غير ربحية مقرها في فرجينيا الغربية",
    "Northampton County, Virginia": "مقاطعة نورثهامبتون (فرجينيا)",
    "Northumberland County, Virginia": "مقاطعة نورثومبرلاند (فرجينيا)",
    "Norton, Virginia": "نورتون (فرجينيا)",
    "Nottoway County, Virginia": "مقاطعة نوتوواي (فرجينيا)",
    "Orange County, Virginia": "مقاطعة أورانج (فرجينيا)",
    "Organizations based in Alexandria, Virginia": "منظمات مقرها في الإسكندرية (فرجينيا)",
    "Organizations based in West Virginia": "منظمات مقرها في فرجينيا الغربية",
    "Page County, Virginia": "مقاطعة بيج (فرجينيا)",
    "Parks in Williamsburg, Virginia": "متنزهات في ويليامزبرغ (فرجينيا)",
    "Patrick County, Virginia": "مقاطعة باتريك (فرجينيا)",
    "People by university or college in Virginia": "أشخاص حسب الجامعة أو الكلية في فرجينيا",
    "People from Accomack County, Virginia": "أشخاص من مقاطعة أكوماك (فرجينيا)",
    "People from Albemarle County, Virginia": "أشخاص من مقاطعة ألبمارل (فرجينيا)",
    "People from Alderson, West Virginia": "أشخاص من ألدرسن (فرجينيا الغربية)",
    "People from Alleghany County, Virginia": "أشخاص من مقاطعة أليغاني (فرجينيا)",
    "People from Amelia County, Virginia": "أشخاص من مقاطعة أميليا (فرجينيا)",
    "People from Amherst County, Virginia": "أشخاص من مقاطعة أمهيرست (فرجينيا)",
    "People from Appomattox County, Virginia": "أشخاص من مقاطعة أبوماتوكس (فرجينيا)",
    "People from Arlington County, Virginia": "أشخاص من مقاطعة أرلنغتون (فرجينيا)",
    "People from Augusta County, Virginia": "أشخاص من مقاطعة أوغوستا (فرجينيا)",
    "People from Bath County, Virginia": "أشخاص من مقاطعة باث (فرجينيا)",
    "People from Bedford County, Virginia": "أشخاص من مقاطعة بيدفورد (فرجينيا)",
    "People from Berkeley County, West Virginia": "أشخاص من مقاطعة بيركلي (فرجينيا الغربية)",
    "People from Bethany, West Virginia": "أشخاص من بيثاني (فرجينيا الغربية)",
    "People from Beverly, West Virginia": "أشخاص من بيفرلي (فرجينيا الغربية)",
    "People from Boone County, West Virginia": "أشخاص من مقاطعة بوون (فرجينيا الغربية)",
    "People from Botetourt County, Virginia": "أشخاص من مقاطعة بوتيتورت (فرجينيا)",
    "People from Bramwell, West Virginia": "أشخاص من برامويل (فرجينيا الغربية)",
    "People from Braxton County, West Virginia": "أشخاص من مقاطعة براكستون (فرجينيا الغربية)",
    "People from Bristol, Virginia": "أشخاص من بريستول (فرجينيا)",
    "People from Brooke County, West Virginia": "أشخاص من مقاطعة بروك (فرجينيا الغربية)",
    "People from Brunswick County, Virginia": "أشخاص من مقاطعة برونزويك (فرجينيا)",
    "People from Buchanan, Virginia": "أشخاص من بوتشانان (فرجينيا)",
    "People from Buchanan County, Virginia": "أشخاص من مقاطعة بوكانان (فرجينيا)",
    "People from Buffalo, West Virginia": "أشخاص من بوفالو (فرجينيا الغربية)",
    "People from Burkeville, Virginia": "أشخاص من بوركفيل (فرجينيا)",
    "People from Burnsville, West Virginia": "أشخاص من بورنسفيل (فرجينيا الغربية)",
    "People from Chapmanville, West Virginia": "أشخاص من تشامبانفيل (فرجينيا الغربية)",
    "People from Charlotte County, Virginia": "أشخاص من مقاطعة شارلوت (فرجينيا)",
    "People from Chatham, Virginia": "أشخاص من تشاتهام (فرجينيا)",
    "People from Chesterfield County, Virginia": "أشخاص من مقاطعة تشيسترفيلد (فرجينيا)",
    "People from Clay County, West Virginia": "أشخاص من مقاطعة كلاي (فرجينيا الغربية)",
    "People from Clendenin, West Virginia": "أشخاص من كليندنين (فرجينيا الغربية)",
    "People from Clifton, Virginia": "أشخاص من كليفتون (فرجينيا)",
    "People from Colonial Heights, Virginia": "أشخاص من كولونيل هايتس (فرجينيا)",
    "People from Covington, Virginia": "أشخاص من كوفينغتون (فرجينيا)",
    "People from Culpeper County, Virginia": "أشخاص من مقاطعة كلبيبر (فرجينيا)",
    "People from Cumberland County, Virginia": "أشخاص من مقاطعة كومبرلاند (فرجينيا)",
    "People from Danville, Virginia": "أشخاص من دانفيل (فرجينيا)",
    "People from Dickenson County, Virginia": "أشخاص من مقاطعة ديكينسون (فرجينيا)",
    "People from Dinwiddie County, Virginia": "أشخاص من مقاطعة دينويدي (فرجينيا)",
    "People from Doddridge County, West Virginia": "أشخاص من مقاطعة دودريدج (فرجينيا الغربية)",
    "People from Fairfax, Virginia": "أشخاص من فيرفاكس (فرجينيا)",
    "People from Fairfax County, Virginia": "أشخاص من مقاطعة فيرفاكس (فرجينيا)",
    "People from Fayetteville, West Virginia": "أشخاص من فايتفيل (فرجينيا الغربية)",
    "People from Franklin, Virginia": "أشخاص من فرانكلين (فرجينيا)",
    "People from Franklin County, Virginia": "أشخاص من مقاطعة فرانكلين (فرجينيا)",
    "People from Front Royal, Virginia": "أشخاص من فرونت رويال (فرجينيا)",
    "People from Galax, Virginia": "أشخاص من جالاكس (فرجينيا)",
    "People from Giles County, Virginia": "أشخاص من مقاطعة غيلز (فرجينيا)",
    "People from Gilmer County, West Virginia": "أشخاص من مقاطعة غيلمر (فرجينيا الغربية)",
    "People from Goochland County, Virginia": "أشخاص من مقاطعة غووتشلاند (فرجينيا)",
    "People from Greenbrier County, West Virginia": "أشخاص من مقاطعة غرينبريه (فرجينيا الغربية)",
    "People from Greene County, Virginia": "أشخاص من مقاطعة غرين (فرجينيا)",
    "People from Greensville County, Virginia": "أشخاص من مقاطعة غرينزفيل (فرجينيا)",
    "People from Halifax County, Virginia": "أشخاص من مقاطعة هاليفاكس (فرجينيا)",
    "People from Hampshire County, West Virginia": "أشخاص من مقاطعة هامبشاير (فرجينيا الغربية)",
    "People from Hampton, Virginia": "أشخاص من هامبتون (فرجينيا)",
    "People from Hancock County, West Virginia": "أشخاص من مقاطعة هانكوك (فرجينيا الغربية)",
    "People from Hanover County, Virginia": "أشخاص من مقاطعة هانوفر (فرجينيا)",
    "People from Hardy County, West Virginia": "أشخاص من مقاطعة هاردي (فرجينيا الغربية)",
    "People from Henrico County, Virginia": "أشخاص من مقاطعة هنريكو (فرجينيا)",
    "People from Herndon, Virginia": "أشخاص من هيرندون (فرجينيا)",
    "People from Highland County, Virginia": "أشخاص من مقاطعة هايلاند (فرجينيا)",
    "People from Hopewell, Virginia": "أشخاص من هوبويل (فرجينيا)",
    "People from Jackson County, West Virginia": "أشخاص من مقاطعة جاكسون (فرجينيا الغربية)",
    "People from Jamestown, Virginia": "أشخاص من جيمستاون (فرجينيا)",
    "People from King and Queen County, Virginia": "أشخاص من مقاطعة كينغ أند كوين (فرجينيا)",
    "People from King George County, Virginia": "أشخاص من مقاطعة كينغ جورج (فرجينيا)",
    "People from King William County, Virginia": "أشخاص من مقاطعة كينغ ويليام (فرجينيا)",
    "People from Leesburg, Virginia": "أشخاص من ليسبورغ (فرجينيا)",
    "People from Lewis County, West Virginia": "أشخاص من مقاطعة لويس (فرجينيا الغربية)",
    "People from Lexington, Virginia": "أشخاص من كسينغتون (فرجينيا)",
    "People from Lincoln County, West Virginia": "أشخاص من مقاطعة لينكون (فرجينيا الغربية)",
    "People from Louisa, Virginia": "أشخاص من لوييسا (فرجينيا)",
    "People from Louisa County, Virginia": "أشخاص من مقاطعة لويزا (فرجينيا)",
    "People from Lunenburg County, Virginia": "أشخاص من مقاطعة لونينبرغ (فرجينيا)",
    "People from Madison County, Virginia": "أشخاص من مقاطعة ماديسون (فرجينيا)",
    "People from Marshall County, West Virginia": "أشخاص من مقاطعة مارشال (فرجينيا الغربية)",
    "People from Martinsville, Virginia": "أشخاص من مارتينسفيل (فرجينيا)",
    "People from Mason County, West Virginia": "أشخاص من مقاطعة ماسون (فرجينيا الغربية)",
    "People from McDowell County, West Virginia": "أشخاص من مقاطعة مكداويل (فرجينيا الغربية)",
    "People from Mineral County, West Virginia": "أشخاص من مقاطعة مينيرال (فرجينيا الغربية)",
    "People from Mingo County, West Virginia": "أشخاص من مقاطعة مينغو (فرجينيا الغربية)",
    "People from Monongalia County, West Virginia": "أشخاص من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "People from Monroe County, West Virginia": "أشخاص من مقاطعة مونرو (فرجينيا الغربية)",
    "People from Morgan County, West Virginia": "أشخاص من مقاطعة مورغان (فرجينيا الغربية)",
    "People from Moundsville, West Virginia": "أشخاص من مووندسفيل (فرجينيا الغربية)",
    "People from Nicholas County, West Virginia": "أشخاص من مقاطعة نيكولاس (فرجينيا الغربية)",
    "People from Northampton County, Virginia": "أشخاص من مقاطعة نورثهامبتون (فرجينيا)",
    "People from Norton, Virginia": "أشخاص من نورتون (فرجينيا)",
    "People from Oak Hill, West Virginia": "أشخاص من أوك هيل (فرجينيا الغربية)",
    "People from Ohio County, West Virginia": "أشخاص من مقاطعة أوهايو (فرجينيا الغربية)",
    "People from Orange County, Virginia": "أشخاص من مقاطعة أورانج (فرجينيا)",
    "People from Pittsylvania County, Virginia": "أشخاص من مقاطعة بيتيسيلفانيا (فرجينيا)",
    "People from Pocahontas County, West Virginia": "أشخاص من مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "People from Poquoson, Virginia": "أشخاص من بوكيوسون (فرجينيا)",
    "People from Portsmouth, Virginia": "أشخاص من بورتسموث (فرجينيا)",
    "People from Powhatan County, Virginia": "أشخاص من مقاطعة باوهاتن (فرجينيا)",
    "People from Preston County, West Virginia": "أشخاص من مقاطعة بريستون (فرجينيا الغربية)",
    "People from Prince Edward County, Virginia": "أشخاص من مقاطعة برينس إدورد (فرجينيا)",
    "People from Pulaski County, Virginia": "أشخاص من مقاطعة بولاسكي (فرجينيا)",
    "People from Putnam County, West Virginia": "أشخاص من مقاطعة بوتنام (فرجينيا الغربية)",
    "People from Raleigh County, West Virginia": "أشخاص من مقاطعة رالي (فرجينيا الغربية)",
    "People from Randolph County, West Virginia": "أشخاص من مقاطعة راندولف (فرجينيا الغربية)",
    "People from Reston, Virginia": "أشخاص من رستون (فرجينيا)",
    "People from Richmond, Virginia": "أشخاص من ريتشموند (فرجينيا)",
    "People from Ritchie County, West Virginia": "أشخاص من مقاطعة ريتشي (فرجينيا الغربية)",
    "People from Rockbridge County, Virginia": "أشخاص من مقاطعة روكبريج (فرجينيا)",
    "People from Rockingham County, Virginia": "أشخاص من مقاطعة روكنغهام (فرجينيا)",
    "People from Romney, West Virginia": "أشخاص من رومني (فرجينيا الغربية)",
    "People from Russell County, Virginia": "أشخاص من مقاطعة روسيل (فرجينيا)",
    "People from Salem, Virginia": "أشخاص من سالم (فرجينيا)",
    "People from Scott County, Virginia": "أشخاص من مقاطعة سكوت (فرجينيا)",
    "People from Shepherdstown, West Virginia": "أشخاص من شبردزتاون (فرجينيا الغربية)",
    "People from South Charleston, West Virginia": "أشخاص من ساوث تشارلستون (فرجينيا الغربية)",
    "People from Southampton County, Virginia": "أشخاص من مقاطعة ساوثهامبتون (فرجينيا)",
    "People from Spotsylvania County, Virginia": "أشخاص من مقاطعة سبوتسيلفانيا (فرجينيا)",
    "People from Stafford County, Virginia": "أشخاص من مقاطعة ستافورد (فرجينيا)",
    "People from Suffolk, Virginia": "أشخاص من سوفولك (فرجينيا)",
    "People from Sussex County, Virginia": "أشخاص من مقاطعة سوسيكس (فرجينيا)",
    "People from Taylor County, West Virginia": "أشخاص من مقاطعة تايلور (فرجينيا الغربية)",
    "People from Tazewell County, Virginia": "أشخاص من مقاطعة تازويل (فرجينيا)",
    "People from Tucker County, West Virginia": "أشخاص من مقاطعة تاكر (فرجينيا الغربية)",
    "People from Tyler County, West Virginia": "أشخاص من مقاطعة تايلر (فرجينيا الغربية)",
    "People from Upshur County, West Virginia": "أشخاص من مقاطعة أبشور (فرجينيا الغربية)",
    "People from Virginia, Minnesota": "أشخاص من فرجينيا (منيسوتا)",
    "People from Virginia City, Nevada": "أشخاص من فرجينيا سيتي",
    "People from Waynesboro, Virginia": "أشخاص من واينيسبورو (فرجينيا)",
    "People from Webster County, West Virginia": "أشخاص من مقاطعة ويبستر (فرجينيا الغربية)",
    "People from West Virginia by century": "أشخاص من فرجينيا الغربية حسب القرن",
    "People from West Virginia by occupation and populated place": "أشخاص من فرجينيا الغربية حسب المهنة والمكان المأهول",
    "People from West Virginia in the War of 1812": "أشخاص من فرجينيا الغربية في حرب 1812",
    "People from Westmoreland County, Virginia": "أشخاص من مقاطعة ويستمورلاند (فرجينيا)",
    "People from Wetzel County, West Virginia": "أشخاص من مقاطعة ويتزل (فرجينيا الغربية)",
    "People from Williamsburg, Virginia": "أشخاص من ويليامزبرغ (فرجينيا)",
    "People from Winchester, Virginia": "أشخاص من وينشستر (فرجينيا)",
    "People from Wirt County, West Virginia": "أشخاص من مقاطعة ويرت (فرجينيا الغربية)",
    "People from Wyoming County, West Virginia": "أشخاص من مقاطعة وايومنغ (فرجينيا الغربية)",
    "People from Wythe County, Virginia": "أشخاص من مقاطعة وايذ (فرجينيا)",
    "Philosophers from West Virginia": "فلاسفة من فرجينيا الغربية",
    "Physicians from Parkersburg, West Virginia": "أطباء من باركرسبورغ (فرجينيا الغربية)",
    "Physicians from Wheeling, West Virginia": "أطباء من ويلينغ (فرجينيا الغربية)",
    "Pittsylvania County, Virginia": "مقاطعة بيتيسيلفانيا (فرجينيا)",
    "Players of American football from Alexandria, Virginia": "لاعبو كرة قدم أمريكية من الإسكندرية (فرجينيا)",
    "Players of American football from Charleston, West Virginia": "لاعبو كرة قدم أمريكية من تشارلستون (فرجينيا الغربية)",
    "Players of American football from Danville, Virginia": "لاعبو كرة قدم أمريكية من دانفيل (فرجينيا)",
    "Players of American football from Fairfax, Virginia": "لاعبو كرة قدم أمريكية من فيرفاكس (فرجينيا)",
    "Players of American football from Huntington, West Virginia": "لاعبو كرة قدم أمريكية من هنغتينغتون (فرجينيا الغربية)",
    "Players of American football from Kanawha County, West Virginia": "لاعبو كرة قدم أمريكية من مقاطعة كاناوا (فرجينيا الغربية)",
    "Players of American football from Lynchburg, Virginia": "لاعبو كرة قدم أمريكية من لينشبرغ (فرجينيا)",
    "Players of American football from Portsmouth, Virginia": "لاعبو كرة قدم أمريكية من بورتسموث (فرجينيا)",
    "Players of American football from Roanoke, Virginia": "لاعبو كرة قدم أمريكية من روانوك (فرجينيا)",
    "Players of American football from Wheeling, West Virginia": "لاعبو كرة قدم أمريكية من ويلينغ (فرجينيا الغربية)",
    "Players of Canadian football from West Virginia": "لاعبو كرة قدم كندية من فرجينيا الغربية",
    "Pleasants County, West Virginia": "مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Pocahontas County, West Virginia": "مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "Politicians from Alexandria, Virginia": "سياسيون من الإسكندرية (فرجينيا)",
    "Politicians from Beckley, West Virginia": "سياسيون من بيكلي (فرجينيا الغربية)",
    "Politicians from Bluefield, West Virginia": "سياسيون من بلوفيلد (فرجينيا الغربية)",
    "Politicians from Charleston, West Virginia": "سياسيون من تشارلستون (فرجينيا الغربية)",
    "Politicians from Clarksburg, West Virginia": "سياسيون من كلاركسبورغ (فرجينيا الغربية)",
    "Politicians from Danville, Virginia": "سياسيون من دانفيل (فرجينيا)",
    "Politicians from Fairfax, Virginia": "سياسيون من فيرفاكس (فرجينيا)",
    "Politicians from Fairmont, West Virginia": "سياسيون من فيرمونت (فرجينيا الغربية)",
    "Politicians from Fredericksburg, Virginia": "سياسيون من فريدريكسبيورغ (فرجينيا)",
    "Politicians from Martinsburg, West Virginia": "سياسيون من مرتينسبورغ (فرجينيا الغربية)",
    "Politicians from Morgantown, West Virginia": "سياسيون من مورغانتاون (فرجينيا الغربية)",
    "Politicians from Parkersburg, West Virginia": "سياسيون من باركرسبورغ (فرجينيا الغربية)",
    "Politicians from Portsmouth, Virginia": "سياسيون من بورتسموث (فرجينيا)",
    "Politicians from Princeton, West Virginia": "سياسيون من برينستون (فرجينيا الغربية)",
    "Politicians from Roanoke, Virginia": "سياسيون من روانوك (فرجينيا)",
    "Politicians from Romney, West Virginia": "سياسيون من رومني (فرجينيا الغربية)",
    "Politicians from Suffolk, Virginia": "سياسيون من سوفولك (فرجينيا)",
    "Politicians from Wheeling, West Virginia": "سياسيون من ويلينغ (فرجينيا الغربية)",
    "Politicians from Winchester, Virginia": "سياسيون من وينشستر (فرجينيا)",
    "Populated places in Berkeley County, West Virginia": "أماكن مأهولة في مقاطعة بيركلي (فرجينيا الغربية)",
    "Populated places in Boone County, West Virginia": "أماكن مأهولة في مقاطعة بوون (فرجينيا الغربية)",
    "Populated places in Grant County, West Virginia": "أماكن مأهولة في مقاطعة غرانت (فرجينيا الغربية)",
    "Populated places in Jackson County, West Virginia": "أماكن مأهولة في مقاطعة جاكسون (فرجينيا الغربية)",
    "Populated places in James City County, Virginia": "أماكن مأهولة في مقاطعة جيمس سيتي (فرجينيا)",
    "Populated places in Mingo County, West Virginia": "أماكن مأهولة في مقاطعة مينغو (فرجينيا الغربية)",
    "Populated places in Pleasants County, West Virginia": "أماكن مأهولة في مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Populated places in Preston County, West Virginia": "أماكن مأهولة في مقاطعة بريستون (فرجينيا الغربية)",
    "Populated places in Prince Edward County, Virginia": "أماكن مأهولة في مقاطعة برينس إدورد (فرجينيا)",
    "Populated places in Ritchie County, West Virginia": "أماكن مأهولة في مقاطعة ريتشي (فرجينيا الغربية)",
    "Populated places in Taylor County, West Virginia": "أماكن مأهولة في مقاطعة تايلور (فرجينيا الغربية)",
    "Populated places in Tucker County, West Virginia": "أماكن مأهولة في مقاطعة تاكر (فرجينيا الغربية)",
    "Poquoson, Virginia": "بوكيوسون (فرجينيا)",
    "Portsmouth, Virginia": "بورتسموث (فرجينيا)",
    "Powhatan County, Virginia": "مقاطعة باوهاتن (فرجينيا)",
    "Preston County, West Virginia": "مقاطعة بريستون (فرجينيا الغربية)",
    "Prince Edward County, Virginia": "مقاطعة برينس إدورد (فرجينيا)",
    "Prince George County, Virginia": "مقاطعة برينس جورج (فرجينيا)",
    "Prince William County, Virginia": "مقاطعة برينس ويليام (فرجينيا)",
    "Private universities and colleges in West Virginia": "جامعات وكليات خاصة في فرجينيا الغربية",
    "Protected areas of Arlington County, Virginia": "مناطق محمية في مقاطعة أرلنغتون (فرجينيا)",
    "Protected areas of Kanawha County, West Virginia": "مناطق محمية في مقاطعة كاناوا (فرجينيا الغربية)",
    "Protected areas of Marshall County, West Virginia": "مناطق محمية في مقاطعة مارشال (فرجينيا الغربية)",
    "Protected areas of Williamsburg, Virginia": "مناطق محمية في ويليامزبرغ (فرجينيا)",
    "Protestantism in West Virginia": "البروتستانتية في فرجينيا الغربية",
    "Public universities and colleges in West Virginia": "جامعات وكليات حكومية في فرجينيا الغربية",
    "Pulaski County, Virginia": "مقاطعة بولاسكي (فرجينيا)",
    "Quakerism in West Virginia": "الكويكرية في فرجينيا الغربية",
    "Rabbis from West Virginia": "حاخامات من فرجينيا الغربية",
    "Rabbis from Wheeling, West Virginia": "حاخامات من ويلينغ (فرجينيا الغربية)",
    "Randolph County, West Virginia": "مقاطعة راندولف (فرجينيا الغربية)",
    "Rappahannock County, Virginia": "مقاطعة راباهانوك (فرجينيا)",
    "Regions of Virginia": "مناطق فرجينيا",
    "Religious leaders from Charleston, West Virginia": "قادة دينيون من تشارلستون (فرجينيا الغربية)",
    "Religious leaders from Huntington, West Virginia": "قادة دينيون من هنغتينغتون (فرجينيا الغربية)",
    "Religious leaders from Martinsburg, West Virginia": "قادة دينيون من مرتينسبورغ (فرجينيا الغربية)",
    "Religious leaders from Romney, West Virginia": "قادة دينيون من رومني (فرجينيا الغربية)",
    "Religious leaders from Wheeling, West Virginia": "قادة دينيون من ويلينغ (فرجينيا الغربية)",
    "Republican Party United States senators from West Virginia": "أعضاء مجلس الشيوخ الأمريكي من الحزب الجمهوري من فرجينيا الغربية",
    "Research institutes in West Virginia": "معاهد أبحاث في فرجينيا الغربية",
    "Reston, Virginia": "رستون (فرجينيا)",
    "Richmond County, Virginia": "مقاطعة ريتشموند (فرجينيا)",
    "Rivers of King George County, Virginia": "أنهار مقاطعة كينغ جورج (فرجينيا)",
    "Roanoke County, Virginia": "مقاطعة رونوك (فرجينيا)",
    "Rockbridge County, Virginia": "مقاطعة روكبريج (فرجينيا)",
    "Rockingham County, Virginia": "مقاطعة روكنغهام (فرجينيا)",
    "Russell County, Virginia": "مقاطعة روسيل (فرجينيا)",
    "Salem, Virginia": "سالم (فرجينيا)",
    "School board members in West Virginia": "أعضاء مجالس تعليمية في فرجينيا الغربية",
    "Schools in Cabell County, West Virginia": "مدارس في مقاطعة كابيل (فرجينيا الغربية)",
    "Schools in Hampshire County, West Virginia": "مدارس في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Schools in Romney, West Virginia": "مدارس في رومني (فرجينيا الغربية)",
    "Schools in West Virginia by populated place": "مدارس في فرجينيا الغربية حسب المكان المأهول",
    "Schoolteachers from West Virginia": "معلمو مدارس من فرجينيا الغربية",
    "Scientists from Alexandria, Virginia": "علماء من الإسكندرية (فرجينيا)",
    "Scientists from Bluefield, West Virginia": "علماء من بلوفيلد (فرجينيا الغربية)",
    "Scientists from Charleston, West Virginia": "علماء من تشارلستون (فرجينيا الغربية)",
    "Scientists from Huntington, West Virginia": "علماء من هنغتينغتون (فرجينيا الغربية)",
    "Scientists from Morgantown, West Virginia": "علماء من مورغانتاون (فرجينيا الغربية)",
    "Scientists from Parkersburg, West Virginia": "علماء من باركرسبورغ (فرجينيا الغربية)",
    "Scientists from Wheeling, West Virginia": "علماء من ويلينغ (فرجينيا الغربية)",
    "Scott County, Virginia": "مقاطعة سكوت (فرجينيا)",
    "Screenwriters from West Virginia": "كتاب سيناريو من فرجينيا الغربية",
    "Secretaries of state of West Virginia": "وزراء خارجية فرجينيا الغربية",
    "Serial killers from West Virginia": "قتلة متسلسلون من فرجينيا الغربية",
    "Shenandoah County, Virginia": "مقاطعة شيناندوا (فرجينيا)",
    "Shepherdstown, West Virginia": "شبردزتاون (فرجينيا الغربية)",
    "Ships built in Portsmouth, Virginia": "سفن بنيت في بورتسموث (فرجينيا)",
    "Smyth County, Virginia": "مقاطعة سميث (فرجينيا)",
    "Soccer players from Fairfax, Virginia": "لاعبو كرة قدم من فيرفاكس (فرجينيا)",
    "Soccer players in West Virginia by club": "لاعبو كرة قدم في فرجينيا الغربية حسب النادي",
    "Southampton County, Virginia": "مقاطعة ساوثهامبتون (فرجينيا)",
    "Sports in West Virginia by sport": "رياضات في فرجينيا الغربية حسب الرياضة",
    "Sportspeople from Alexandria, Virginia": "رياضيون من الإسكندرية (فرجينيا)",
    "Sportspeople from Arlington County, Virginia": "رياضيون من مقاطعة أرلنغتون (فرجينيا)",
    "Sportspeople from Danville, Virginia": "رياضيون من دانفيل (فرجينيا)",
    "Sportspeople from Fairfax, Virginia": "رياضيون من فيرفاكس (فرجينيا)",
    "Sportspeople from Fairfax County, Virginia": "رياضيون من مقاطعة فيرفاكس (فرجينيا)",
    "Sportspeople from Fredericksburg, Virginia": "رياضيون من فريدريكسبيورغ (فرجينيا)",
    "Sportspeople from Hancock County, West Virginia": "رياضيون من مقاطعة هانكوك (فرجينيا الغربية)",
    "Sportspeople from Leesburg, Virginia": "رياضيون من ليسبورغ (فرجينيا)",
    "Sportspeople from Manassas, Virginia": "رياضيون من ماناساس (فرجينيا)",
    "Sportspeople from Martinsville, Virginia": "رياضيون من مارتينسفيل (فرجينيا)",
    "Sportspeople from Morgan County, West Virginia": "رياضيون من مقاطعة مورغان (فرجينيا الغربية)",
    "Sportspeople from Portsmouth, Virginia": "رياضيون من بورتسموث (فرجينيا)",
    "Sportspeople from Reston, Virginia": "رياضيون من رستون (فرجينيا)",
    "Sportspeople from Staunton, Virginia": "رياضيون من ستونتون (فرجينيا)",
    "Sportspeople from Suffolk, Virginia": "رياضيون من سوفولك (فرجينيا)",
    "Sportspeople from Virginia, Minnesota": "رياضيون من فرجينيا (منيسوتا)",
    "Sportspeople from Williamsburg, Virginia": "رياضيون من ويليامزبرغ (فرجينيا)",
    "Sportspeople from Wood County, West Virginia": "رياضيون من مقاطعة وود (فرجينيا الغربية)",
    "Spotsylvania County, Virginia": "مقاطعة سبوتسيلفانيا (فرجينيا)",
    "Stafford County, Virginia": "مقاطعة ستافورد (فرجينيا)",
    "State agencies of West Virginia": "أجهزة الدولة في فرجينيا الغربية",
    "State cabinet secretaries of West Virginia": "أعضاء مجلس وزراء فرجينيا الغربية",
    "State treasurers of West Virginia": "أمناء خزينة ولاية فرجينيا الغربية",
    "Suffolk, Virginia": "سوفولك (فرجينيا)",
    "Surry County, Virginia": "مقاطعة سوري (فرجينيا)",
    "Sussex County, Virginia": "مقاطعة سوسيكس (فرجينيا)",
    "Swimming in West Virginia": "السباحة في فرجينيا الغربية",
    "Swimming venues in West Virginia": "ملاعب السباحة في فرجينيا الغربية",
    "Taylor County, West Virginia": "مقاطعة تايلور (فرجينيا الغربية)",
    "Tazewell County, Virginia": "مقاطعة تازويل (فرجينيا)",
    "Television shows filmed in West Virginia": "عروض تلفزيونية صورت في فرجينيا الغربية",
    "Television shows set in West Virginia": "عروض تلفزيونية تقع أحداثها في فرجينيا الغربية",
    "Tourist attractions in Albemarle County, Virginia": "مواقع جذب سياحي في مقاطعة ألبمارل (فرجينيا)",
    "Tourist attractions in Alexandria, Virginia": "مواقع جذب سياحي في الإسكندرية (فرجينيا)",
    "Tourist attractions in Arlington County, Virginia": "مواقع جذب سياحي في مقاطعة أرلنغتون (فرجينيا)",
    "Tourist attractions in Danville, Virginia": "مواقع جذب سياحي في دانفيل (فرجينيا)",
    "Tourist attractions in Fairfax County, Virginia": "مواقع جذب سياحي في مقاطعة فيرفاكس (فرجينيا)",
    "Tourist attractions in Floyd County, Virginia": "مواقع جذب سياحي في مقاطعة فلويد (فرجينيا)",
    "Tourist attractions in Grant County, West Virginia": "مواقع جذب سياحي في مقاطعة غرانت (فرجينيا الغربية)",
    "Tourist attractions in Hampshire County, West Virginia": "مواقع جذب سياحي في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Tourist attractions in Harrisonburg, Virginia": "مواقع جذب سياحي في هاريسونبورغ (فرجينيا)",
    "Tourist attractions in Kanawha County, West Virginia": "مواقع جذب سياحي في مقاطعة كاناوا (فرجينيا الغربية)",
    "Tourist attractions in Lexington, Virginia": "مواقع جذب سياحي في كسينغتون (فرجينيا)",
    "Tourist attractions in Lynchburg, Virginia": "مواقع جذب سياحي في لينشبرغ (فرجينيا)",
    "Tourist attractions in Marshall County, West Virginia": "مواقع جذب سياحي في مقاطعة مارشال (فرجينيا الغربية)",
    "Tourist attractions in Monongalia County, West Virginia": "مواقع جذب سياحي في مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Tourist attractions in Montgomery County, Virginia": "مواقع جذب سياحي في مقاطعة مونغومري (فرجينيا)",
    "Tourist attractions in Pendleton County, West Virginia": "مواقع جذب سياحي في مقاطعة بيندلتون (فرجينيا الغربية)",
    "Tourist attractions in Tucker County, West Virginia": "مواقع جذب سياحي في مقاطعة تاكر (فرجينيا الغربية)",
    "Tourist attractions in Winchester, Virginia": "مواقع جذب سياحي في وينشستر (فرجينيا)",
    "Towns in Pleasants County, West Virginia": "بلدات في مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Towns in Prince Edward County, Virginia": "بلدات في مقاطعة برينس إدورد (فرجينيا)",
    "Track and field in West Virginia": "سباقات المضمار والميدان في فرجينيا الغربية",
    "Transportation buildings and structures in Mason County, West Virginia": "مبان ومنشآت نقل في مقاطعة ماسون (فرجينيا الغربية)",
    "Transportation buildings and structures in West Virginia by county": "مبان ومنشآت نقل في فرجينيا الغربية حسب المقاطعة",
    "Transportation in Alexandria, Virginia": "النقل في الإسكندرية (فرجينيا)",
    "Transportation in Arlington County, Virginia": "النقل في مقاطعة أرلنغتون (فرجينيا)",
    "Transportation in Fairfax County, Virginia": "النقل في مقاطعة فيرفاكس (فرجينيا)",
    "Transportation in Loudoun County, Virginia": "النقل في مقاطعة لودون (فرجينيا)",
    "Transportation in Northampton County, Virginia": "النقل في مقاطعة نورثهامبتون (فرجينيا)",
    "Trustees of populated places in West Virginia": "أمناء أماكن مأهولة في فرجينيا الغربية",
    "Tuberculosis deaths in West Virginia": "وفيات السل في فرجينيا الغربية",
    "Tucker County, West Virginia": "مقاطعة تاكر (فرجينيا الغربية)",
    "Unincorporated communities in Greenbrier County, West Virginia": "مجتمعات فردية في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Unincorporated communities in Jefferson County, West Virginia": "مجتمعات فردية في مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Unincorporated communities in Virginia": "مجتمعات فردية في فرجينيا",
    "Unincorporated communities in West Virginia": "مجتمعات فردية في فرجينيا الغربية",
    "Unincorporated communities in Wirt County, West Virginia": "مجتمعات فردية في مقاطعة ويرت (فرجينيا الغربية)",
    "Universities and colleges in Lynchburg, Virginia": "جامعات وكليات في لينشبرغ (فرجينيا)",
    "Universities and colleges in Virginia": "جامعات وكليات في فرجينيا",
    "Universities and colleges in West Virginia by type": "جامعات وكليات في فرجينيا الغربية حسب الفئة",
    "University of Virginia alumni": "خريجو جامعة فرجينيا",
    "Upshur County, West Virginia": "مقاطعة أبشور (فرجينيا الغربية)",
    "Virginia, Minnesota": "فرجينيا (منيسوتا)",
    "Virginia Cavaliers football": "نادي فرجينيا كفاليرز",
    "Virginia Cavaliers football coaches": "مدربو نادي فرجينيا كفاليرز",
    "Virginia Cavaliers football players": "لاعبو نادي فرجينيا كفاليرز",
    "Virginia City, Nevada": "فرجينيا سيتي",
    "Virginia Squires": "فرجينيا سكوايرز",
    "Virginia Squires coaches": "مدربو فرجينيا سكوايرز",
    "Virginia Squires players": "لاعبو فرجينيا سكوايرز",
    "Virginia Woolf": "فرجينيا وولف",
    "Warren County, Virginia": "مقاطعة وارين (فرجينيا)",
    "Washington County, Virginia": "مقاطعة واشنطن (فرجينيا)",
    "Waynesboro, Virginia": "واينيسبورو (فرجينيا)",
    "Webster County, West Virginia": "مقاطعة ويبستر (فرجينيا الغربية)",
    "West Virginia Board of Education": "مجلس التعليم في ولاية فرجينيا الغربية",
    "West Virginia Democrats": "ديمقراطيون من ولاية فرجينيا الغربية",
    "West Virginia Greenbacks": "أعضاء حزب الدولار الأمريكي في فرجينيا الغربية",
    "West Virginia independents": "مستقلون من ولاية فرجينيا الغربية",
    "West Virginia politics-related lists": "قوائم متعلقة بسياسة فرجينيا الغربية",
    "West Virginia Senate": "مجلس شيوخ ولاية فرجينيا الغربية",
    "West Virginia socialists": "أعضاء الحزب الاشتراكي في فرجينيا الغربية",
    "West Virginia Unionists": "أعضاء الحزب الوحدوي في فرجينيا الغربية",
    "Westmoreland County, Virginia": "مقاطعة ويستمورلاند (فرجينيا)",
    "Winchester, Virginia": "وينشستر (فرجينيا)",
    "Wirt County, West Virginia": "مقاطعة ويرت (فرجينيا الغربية)",
    "Wise County, Virginia": "مقاطعة وايز (فرجينيا)",
    "Women in West Virginia": "المرأة في فرجينيا الغربية",
    "Women state legislators in West Virginia": "مشرعات الولايات في فرجينيا الغربية",
    "Works set in West Virginia": "أعمال تقع أحداثها في فرجينيا الغربية",
    "Wrestling in West Virginia": "المصارعة في فرجينيا الغربية",
    "Writers from Alderson, West Virginia": "كتاب من ألدرسن (فرجينيا الغربية)",
    "Writers from Alexandria, Virginia": "كتاب من الإسكندرية (فرجينيا)",
    "Writers from Barbour County, West Virginia": "كتاب من مقاطعة بربور (فرجينيا الغربية)",
    "Writers from Beckley, West Virginia": "كتاب من بيكلي (فرجينيا الغربية)",
    "Writers from Berkeley County, West Virginia": "كتاب من مقاطعة بيركلي (فرجينيا الغربية)",
    "Writers from Bluefield, West Virginia": "كتاب من بلوفيلد (فرجينيا الغربية)",
    "Writers from Braxton County, West Virginia": "كتاب من مقاطعة براكستون (فرجينيا الغربية)",
    "Writers from Brooke County, West Virginia": "كتاب من مقاطعة بروك (فرجينيا الغربية)",
    "Writers from Cabell County, West Virginia": "كتاب من مقاطعة كابيل (فرجينيا الغربية)",
    "Writers from Charleston, West Virginia": "كتاب من تشارلستون (فرجينيا الغربية)",
    "Writers from Clarksburg, West Virginia": "كتاب من كلاركسبورغ (فرجينيا الغربية)",
    "Writers from Fayette County, West Virginia": "كتاب من مقاطعة فيات (فرجينيا الغربية)",
    "Writers from Greenbrier County, West Virginia": "كتاب من مقاطعة غرينبريه (فرجينيا الغربية)",
    "Writers from Hampshire County, West Virginia": "كتاب من مقاطعة هامبشاير (فرجينيا الغربية)",
    "Writers from Hardy County, West Virginia": "كتاب من مقاطعة هاردي (فرجينيا الغربية)",
    "Writers from Harrison County, West Virginia": "كتاب من مقاطعة هاريسون (فرجينيا الغربية)",
    "Writers from Jefferson County, West Virginia": "كتاب من مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Writers from Kanawha County, West Virginia": "كتاب من مقاطعة كاناوا (فرجينيا الغربية)",
    "Writers from Lewis County, West Virginia": "كتاب من مقاطعة لويس (فرجينيا الغربية)",
    "Writers from Marshall County, West Virginia": "كتاب من مقاطعة مارشال (فرجينيا الغربية)",
    "Writers from Martinsburg, West Virginia": "كتاب من مرتينسبورغ (فرجينيا الغربية)",
    "Writers from Mason County, West Virginia": "كتاب من مقاطعة ماسون (فرجينيا الغربية)",
    "Writers from McDowell County, West Virginia": "كتاب من مقاطعة مكداويل (فرجينيا الغربية)",
    "Writers from Mercer County, West Virginia": "كتاب من مقاطعة ميرسير (فرجينيا الغربية)",
    "Writers from Monongalia County, West Virginia": "كتاب من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Writers from Morgan County, West Virginia": "كتاب من مقاطعة مورغان (فرجينيا الغربية)",
    "Writers from Ohio County, West Virginia": "كتاب من مقاطعة أوهايو (فرجينيا الغربية)",
    "Writers from Parkersburg, West Virginia": "كتاب من باركرسبورغ (فرجينيا الغربية)",
    "Writers from Pendleton County, West Virginia": "كتاب من مقاطعة بيندلتون (فرجينيا الغربية)",
    "Writers from Pocahontas County, West Virginia": "كتاب من مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "Writers from Preston County, West Virginia": "كتاب من مقاطعة بريستون (فرجينيا الغربية)",
    "Writers from Raleigh County, West Virginia": "كتاب من مقاطعة رالي (فرجينيا الغربية)",
    "Writers from Romney, West Virginia": "كتاب من رومني (فرجينيا الغربية)",
    "Writers from Taylor County, West Virginia": "كتاب من مقاطعة تايلور (فرجينيا الغربية)",
    "Writers from Tucker County, West Virginia": "كتاب من مقاطعة تاكر (فرجينيا الغربية)",
    "Writers from Upshur County, West Virginia": "كتاب من مقاطعة أبشور (فرجينيا الغربية)",
    "Writers from Wayne County, West Virginia": "كتاب من مقاطعة وين (فرجينيا الغربية)",
    "Writers from West Virginia by county": "كتاب من فرجينيا الغربية حسب المقاطعة",
    "Writers from Wetzel County, West Virginia": "كتاب من مقاطعة ويتزل (فرجينيا الغربية)",
    "Writers from Wheeling, West Virginia": "كتاب من ويلينغ (فرجينيا الغربية)",
    "Writers from Wirt County, West Virginia": "كتاب من مقاطعة ويرت (فرجينيا الغربية)",
    "Writers from Wood County, West Virginia": "كتاب من مقاطعة وود (فرجينيا الغربية)",
    "Wyoming County, West Virginia": "مقاطعة وايومنغ (فرجينيا الغربية)",
    "Wythe County, Virginia": "مقاطعة وايذ (فرجينيا)",
    "Years of the 19th century in West Virginia": "سنوات القرن 19 في فرجينيا الغربية",
    "York County, Virginia": "مقاطعة يورك (فرجينيا)",
}

to_test = [
    ("test_virginia_1", data_virginia_1),
    ("test_virginia_2", data_virginia_2),
]


@pytest.mark.parametrize("category, expected", data_virginia_1.items(), ids=data_virginia_1.keys())
@pytest.mark.fast
def test_virginia_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
