"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data_callback

data_2 = {
    "military operations of war in afghanistan (1789–1789)": "عمليات عسكرية في الحرب في أفغانستان (1789–1789)",
    "buildings and structures in georgia (u.s. state)": "مبان ومنشآت في ولاية جورجيا",
    "burials in washington (state)": "مدفونون في ولاية واشنطن",
    "disestablishments in georgia (u.s. state)": "انحلالات في ولاية جورجيا",
    "male actors from the west midlands (county)": "ممثلون ذكور من مقاطعة ميدلاند الغربية",
    "protected areas of georgia (u.s. state)": "مناطق محمية في ولاية جورجيا",
    "national-register-of-historic-places in north carolina": "السجل الوطني للأماكن التاريخية في كارولاينا الشمالية",
    "federalist party members of united states house-of-representatives": "أعضاء الحزب الفيدرالي الأمريكي في مجلس النواب الأمريكي",
    "know-nothing members of united states house-of-representatives": "أعضاء حزب لا أدري في مجلس النواب الأمريكي",
    "whig party members of united states house-of-representatives": "أعضاء حزب اليمين في مجلس النواب الأمريكي",
    "agricultural buildings and structures on the-national-register-of-historic-places": "مبان ومنشآت زراعية في السجل الوطني للأماكن التاريخية",
    "bank buildings on the-national-register-of-historic-places": "مباني بنوك في السجل الوطني للأماكن التاريخية",
    "buildings and structures on the-national-register-of-historic-places": "مبان ومنشآت في السجل الوطني للأماكن التاريخية",
    "railway stations on the-national-register-of-historic-places": "محطات السكك الحديدية في السجل الوطني للأماكن التاريخية",
    "1789 crimes in africa": "جرائم 1789 في إفريقيا",
    "1789 elections in the united states": "انتخابات 1789 في الولايات المتحدة",
    "1789 establishments in india": "تأسيسات سنة 1789 في الهند",
    "1789 in asian sport": "رياضة آسيوية في 1789",
    "1789 in brazilian sport": "رياضة برازيلية في 1789",
    "1789 in chinese sport": "رياضة صينية في 1789",
    "1789 in men's football": "كرة قدم رجالية في 1789",
    "1789 in north america": "أمريكا الشمالية في 1789",
    "1789 in south america": "أمريكا الجنوبية في 1789",
    "1789 in south american football": "كرة القدم الأمريكية الجنوبية في 1789",
    "1789 in the united kingdom": "المملكة المتحدة في 1789",
    "1789 in women's sport": "رياضة نسائية في 1789",
    "1789 in youth football": "كرة قدم شبابية في 1789",
    "anglican bishops in asia": "أساقفة أنجليكيون في آسيا",
    "basketball players in lebanon": "لاعبو كرة سلة في لبنان",
    "buildings and structures in idaho": "مبان ومنشآت في أيداهو",
    "buildings and structures in prince edward island": "مبان ومنشآت في جزيرة الأمير إدوارد",
    "christianity in the united states": "المسيحية في الولايات المتحدة",
    "establishments in southeast asia": "تأسيسات في جنوب شرق آسيا",
    "ethnic groups in china": "مجموعات عرقية في الصين",
    "field hockey players in germany": "لاعبو هوكي ميدان في ألمانيا",
    "food and drink in europe": "أطعمة ومشروبات في أوروبا",
    "historic districts in massachusetts": "المناطق التاريخية في ماساتشوستس",
    "history of nova scotia": "تاريخ نوفا سكوشا",
    "lists of bosnia and herzegovina people": "قوائم بوسنيون",
    "lists of country subdivisions": "قوائم تقسيمات البلد",
    "nations in the summer olympics": "بلدان في الألعاب الأولمبية الصيفية",
    "netball in north america": "كرة الشبكة في أمريكا الشمالية",
    "parks in south america": "متنزهات في أمريكا الجنوبية",
    "people from west sumatra": "أشخاص من سومطرة الغربية",
    "railway stations in romania": "محطات السكك الحديدية في رومانيا",
    "railway stations in the philippines": "محطات السكك الحديدية في الفلبين",
    "road incident deaths in the united states": "وفيات حوادث الطرق في الولايات المتحدة",
    "rugby union players from west yorkshire": "لاعبو اتحاد رجبي من غرب يوركشاير",
    "skyscrapers in the united arab emirates": "ناطحات سحاب في الإمارات العربية المتحدة",
    "sports governing bodies in north america": "هيئات تنظيم رياضية في أمريكا الشمالية",
    "sports-people in västmanland county": "رياضيون في مقاطعة فستمانلاند",
    "tanks of united states": "دبابات الولايات المتحدة",
    "tourism in republic-of ireland": "سياحة في جمهورية أيرلندا",
    "trade unions in the caribbean": "نقابات عمالية في الكاريبي",
    "transport infrastructure in south america": "البنية التحتية للنقل في أمريكا الجنوبية",
    "transportation buildings and structures in new hampshire": "مبان ومنشآت نقل في نيوهامشير",
    "unincorporated communities in alaska": "مجتمعات فردية في ألاسكا",
    "universities and colleges in andhra pradesh": "جامعات وكليات في أندرا برديش",
    "universities and colleges in texas": "جامعات وكليات في تكساس",
    "universities and colleges in ukraine": "جامعات وكليات في أوكرانيا",
    "volleyball competitions in asia": "منافسات كرة طائرة في آسيا",
    "women's footballers in ireland": "لاعبات كرة قدم في أيرلندا",
    "railway stations in albania": "محطات السكك الحديدية في ألبانيا",
    "railway stations in france": "محطات السكك الحديدية في فرنسا",
    "railway stations in germany": "محطات السكك الحديدية في ألمانيا",
    "railway stations in new zealand": "محطات السكك الحديدية في نيوزيلندا",
    "railway stations in northern-ireland": "محطات السكك الحديدية في أيرلندا الشمالية",
    "railway stations in republic-of ireland": "محطات السكك الحديدية في جمهورية أيرلندا",
    "attacks on buildings and structures": "هجمات على مبان ومنشآت",
    "attacks on diplomatic missions": "هجمات على بعثات دبلوماسية",
    "attacks on military installations": "هجمات على منشآت عسكرية",
    "buildings and structures under construction": "مبان ومنشآت تحت بناء",
    "expatriates from northern ireland": "مغتربون من أيرلندا الشمالية",
    "history of petroleum industry": "تاريخ صناعة بترولية",
    "impact of covid-19 pandemic": "تأثيرات جائحة فيروس كورونا",
    "installations of united states air force": "منشآت في القوات الجوية الأمريكية",
    "lists of buildings and structures": "قوائم مبان ومنشآت",
    "lists of mayors of places": "قوائم رؤساء بلديات",
    "lists of universities and colleges": "قوائم جامعات وكليات",
    "military operations of war": "عمليات عسكرية في الحرب",
    "victims of aviation accidents or incidents": "ضحايا حوادث طيران",
    "years of 16th century": "سنوات القرن 16",
    "years of 17th century": "سنوات القرن 17",
    "years of 18th century": "سنوات القرن 18",
    "years of 19th century": "سنوات القرن 19",
    "years of 20th century": "سنوات القرن 20",
    "years of 21st century": "سنوات القرن 21",
    "battles of napoleonic wars": "معارك الحروب النابليونية",
    "battles of vietnam war": "معارك حرب فيتنام",
    "military operations of syrian civil war": "عمليات عسكرية في الحرب الأهلية السورية",
    "railway stations in austria": "محطات السكك الحديدية في النمسا",
    "railway stations in bangladesh": "محطات السكك الحديدية في بنغلاديش",
    "railway stations in denmark": "محطات السكك الحديدية في الدنمارك",
    "railway stations in great britain": "محطات السكك الحديدية في بريطانيا العظمى",
    "railway stations in hong kong": "محطات السكك الحديدية في هونغ كونغ",
    "railway stations in indonesia": "محطات السكك الحديدية في إندونيسيا",
    "railway stations in japan": "محطات السكك الحديدية في اليابان",
    "railway stations in latvia": "محطات السكك الحديدية في لاتفيا",
    "railway stations in poland": "محطات السكك الحديدية في بولندا",
    "railway stations in russia": "محطات السكك الحديدية في روسيا",
    "railway stations in serbia": "محطات السكك الحديدية في صربيا",
    "railway stations in south korea": "محطات السكك الحديدية في كوريا الجنوبية",
    "railway stations in spain": "محطات السكك الحديدية في إسبانيا",
    "railway stations in sweden": "محطات السكك الحديدية في السويد",
    "railway stations in the netherlands": "محطات السكك الحديدية في هولندا",
    "railway stations in the russian empire": "محطات السكك الحديدية في الإمبراطورية الروسية",
    "railway stations in the united states": "محطات السكك الحديدية في الولايات المتحدة",
    "ambassadors of federated states-of micronesia": "سفراء ولايات ميكرونيسيا المتحدة",
    "ambassadors of south africa": "سفراء جنوب إفريقيا",
    "ambassadors of united states": "سفراء الولايات المتحدة",
    "emigrants from the russian empire": "مهاجرون من الإمبراطورية الروسية",
}


@pytest.mark.parametrize("category, output", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_get_type_lab_data_2(category: str, output: str) -> None:
    label = resolve_label_ar(category)
    assert label == output


to_test = [
    ("test_get_type_lab_data_2", data_2, resolve_label_ar),
]

test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)
