"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data_callback

data_1 = {
    "nordic skiing competitions in slovakia": "منافسات التزلج النوردية في سلوفاكيا",
    "railway stations in dordogne": "محطات السكك الحديدية في دوردونيي (إقليم فرنسي)",
    "seasons in asian football leagues": "مواسم في دوريات كرة القدم الآسيوية",
    "1550 crimes in brazil": "جرائم 1550 في البرازيل",
    "1550 crimes in israel": "جرائم 1550 في إسرائيل",
    "1550 crimes in madagascar": "جرائم 1550 في مدغشقر",
    "1550 crimes in oceania": "جرائم 1550 في أوقيانوسيا",
    "1550 disestablishments in afghanistan": "انحلالات سنة 1550 في أفغانستان",
    "1550 disestablishments in alabama": "انحلالات سنة 1550 في ألاباما",
    "1550 disestablishments in alaska": "انحلالات سنة 1550 في ألاسكا",
    "1550 disestablishments in asia": "انحلالات سنة 1550 في آسيا",
    "1550 disestablishments in belgium": "انحلالات سنة 1550 في بلجيكا",
    "1550 disestablishments in cyprus": "انحلالات سنة 1550 في قبرص",
    "1550 disestablishments in denmark": "انحلالات سنة 1550 في الدنمارك",
    "1550 disestablishments in europe": "انحلالات سنة 1550 في أوروبا",
    "1550 disestablishments in hungary": "انحلالات سنة 1550 في المجر",
    "1550 disestablishments in indiana": "انحلالات سنة 1550 في إنديانا",
    "1550 disestablishments in new york (state)": "انحلالات سنة 1550 في ولاية نيويورك",
    "1550 disestablishments in north america": "انحلالات سنة 1550 في أمريكا الشمالية",
    "1550 disestablishments in philippines": "انحلالات سنة 1550 في الفلبين",
    "1550 disestablishments in portugal": "انحلالات سنة 1550 في البرتغال",
    "1550 disestablishments in quebec": "انحلالات سنة 1550 في كيبك",
    "1550 disestablishments in scotland": "انحلالات سنة 1550 في إسكتلندا",
    "1550 disestablishments in serbia": "انحلالات سنة 1550 في صربيا",
    "1550 elections in croatia": "انتخابات 1550 في كرواتيا",
    "1550 elections in sweden": "انتخابات 1550 في السويد",
    "1550 establishments in andhra pradesh": "تأسيسات سنة 1550 في أندرا برديش",
    "1550 establishments in armenia": "تأسيسات سنة 1550 في أرمينيا",
    "1550 establishments in asia": "تأسيسات سنة 1550 في آسيا",
    "1550 establishments in bahamas": "تأسيسات سنة 1550 في باهاماس",
    "1550 establishments in barbados": "تأسيسات سنة 1550 في بربادوس",
    "1550 establishments in botswana": "تأسيسات سنة 1550 في بوتسوانا",
    "1550 establishments in british overseas territories": "تأسيسات سنة 1550 في أقاليم ما وراء البحار البريطانية",
    "1550 establishments in connecticut": "تأسيسات سنة 1550 في كونيتيكت",
    "1550 establishments in egypt": "تأسيسات سنة 1550 في مصر",
    "1550 establishments in england": "تأسيسات سنة 1550 في إنجلترا",
    "1550 establishments in europe": "تأسيسات سنة 1550 في أوروبا",
    "1550 establishments in france": "تأسيسات سنة 1550 في فرنسا",
    "1550 establishments in gambia": "تأسيسات سنة 1550 في غامبيا",
    "1550 establishments in gujarat": "تأسيسات سنة 1550 في غوجارات",
    "1550 establishments in hawaii": "تأسيسات سنة 1550 في هاواي",
    "1550 establishments in holy roman empire": "تأسيسات سنة 1550 في الإمبراطورية الرومانية المقدسة",
    "1550 establishments in hong kong": "تأسيسات سنة 1550 في هونغ كونغ",
    "1550 establishments in idaho": "تأسيسات سنة 1550 في أيداهو",
    "1550 establishments in ireland": "تأسيسات سنة 1550 في أيرلندا",
    "1550 establishments in kazakh soviet socialist republic": "تأسيسات سنة 1550 في كازاخستان السوفيتية",
    "1550 establishments in kentucky": "تأسيسات سنة 1550 في كنتاكي",
    "1550 establishments in lebanon": "تأسيسات سنة 1550 في لبنان",
    "1550 establishments in malaysia": "تأسيسات سنة 1550 في ماليزيا",
    "1550 establishments in malta": "تأسيسات سنة 1550 في مالطا",
    "1550 establishments in maryland": "تأسيسات سنة 1550 في ماريلند",
    "1550 establishments in mozambique": "تأسيسات سنة 1550 في موزمبيق",
    "1550 establishments in namibia": "تأسيسات سنة 1550 في ناميبيا",
    "1550 establishments in nepal": "تأسيسات سنة 1550 في نيبال",
    "1550 establishments in new jersey": "تأسيسات سنة 1550 في نيوجيرسي",
    "1550 establishments in new zealand": "تأسيسات سنة 1550 في نيوزيلندا",
    "1550 establishments in north carolina": "تأسيسات سنة 1550 في كارولاينا الشمالية",
    "1550 establishments in north dakota": "تأسيسات سنة 1550 في داكوتا الشمالية",
    "1550 establishments in north yemen": "تأسيسات سنة 1550 في اليمن الشمالي",
    "1550 establishments in oklahoma": "تأسيسات سنة 1550 في أوكلاهوما",
    "1550 establishments in philippines": "تأسيسات سنة 1550 في الفلبين",
    "1550 establishments in rhode island": "تأسيسات سنة 1550 في رود آيلاند",
    "1550 establishments in russia": "تأسيسات سنة 1550 في روسيا",
    "1550 establishments in singapore": "تأسيسات سنة 1550 في سنغافورة",
    "1550 establishments in south america": "تأسيسات سنة 1550 في أمريكا الجنوبية",
    "1550 establishments in south carolina": "تأسيسات سنة 1550 في كارولاينا الجنوبية",
    "1550 establishments in south dakota": "تأسيسات سنة 1550 في داكوتا الجنوبية",
    "1550 establishments in spain": "تأسيسات سنة 1550 في إسبانيا",
    "1550 establishments in spanish empire": "تأسيسات سنة 1550 في الإمبراطورية الإسبانية",
    "1550 establishments in sweden": "تأسيسات سنة 1550 في السويد",
    "1550 establishments in switzerland": "تأسيسات سنة 1550 في سويسرا",
    "1550 establishments in thirteen colonies": "تأسيسات سنة 1550 في المستعمرات الثلاث عشرة",
    "1550 establishments in uruguay": "تأسيسات سنة 1550 في أوروغواي",
    "1550 establishments in virginia": "تأسيسات سنة 1550 في فرجينيا",
    "1550 establishments in wales": "تأسيسات سنة 1550 في ويلز",
    "1550 establishments in wyoming": "تأسيسات سنة 1550 في وايومنغ",
    "1550 establishments in yugoslavia": "تأسيسات سنة 1550 في يوغسلافيا",
    "1550s elections in caribbean": "انتخابات عقد 1550 في الكاريبي",
    "airports in jalisco": "مطارات في ولاية خاليسكو",
    "american expatriate sports-people in qatar": "رياضيون أمريكيون مغتربون في قطر",
    "american expatriates in gambia": "أمريكيون مغتربون في غامبيا",
    "amusement parks in greece": "متنزهات ملاهي في اليونان",
    "amusement parks in maine": "متنزهات ملاهي في مين",
    "anglicanism in tanzania": "أنجليكية في تنزانيا",
    "april 1550 in europe": "أبريل 1550 في أوروبا",
    "april 1550 in oceania": "أبريل 1550 في أوقيانوسيا",
    "april 1550 in russia": "أبريل 1550 في روسيا",
    "april 1550 in united kingdom": "أبريل 1550 في المملكة المتحدة",
    "armenian diaspora in united states": "شتات أرميني في الولايات المتحدة",
    "armenian expatriates in lithuania": "أرمن مغتربون في ليتوانيا",
    "arts festivals in scotland": "مهرجانات فنية في إسكتلندا",
    "astronomical observatories in indiana": "مراصد فلكية في إنديانا",
    "athletics competitions in el salvador": "منافسات ألعاب قوى في السلفادور",
    "august 1550 in north america": "أغسطس 1550 في أمريكا الشمالية",
    "auto racing series in china": "سلسة سباق سيارات في الصين",
    "aviation in minnesota": "طيران في منيسوتا",
    "baseball players in florida": "لاعبو كرة قاعدة في فلوريدا",
    "baseball players in south korea": "لاعبو كرة قاعدة في كوريا الجنوبية",
    "basketball competitions in ireland": "منافسات كرة سلة في أيرلندا",
    "basketball competitions in north macedonia": "منافسات كرة سلة في مقدونيا الشمالية",
    "basketball in syria": "كرة السلة في سوريا",
    "basketball teams in senegal": "فرق كرة السلة في السنغال",
    "belarusian expatriate sports-people in austria": "رياضيون بيلاروسيون مغتربون في النمسا",
    "beninese expatriates in sweden": "بنينيون مغتربون في السويد",
    "bissau-guinean expatriates in hungary": "غينيون بيساويون مغتربون في المجر",
    "bowling in asia": "بولينج في آسيا",
    "boxing in australia": "البوكسينغ في أستراليا",
    "bridges in france": "جسور في فرنسا",
    "british expatriate sports-people in antigua and barbuda": "رياضيون بريطانيون مغتربون في أنتيغوا وباربودا",
    "buildings and structures in california": "مبان ومنشآت في كاليفورنيا",
    "buildings and structures in mato grosso do sul": "مبان ومنشآت في ماتو غروسو دو سول",
    "buildings and structures in prostějov": "مبان ومنشآت في بروستيوف",
    "buildings and structures in raichur district": "مبان ومنشآت في مقاطعة رايشور",
    "buildings and structures in vellore district": "مبان ومنشآت في مقاطعة فلور",
    "bulgaria in fiction": "بلغاريا في الخيال",
    "by newspaper in california": "حسب الصحيفة في كاليفورنيا",
    "by university or college in poland": "حسب الجامعة أو الكلية في بولندا",
    "cameroonian expatriate sports-people in egypt": "رياضيون كاميرونيون مغتربون في مصر",
    "cape verdean expatriate sports-people in chile": "رياضيون أخضريون مغتربون في تشيلي",
    "cape verdean expatriates in czech republic": "أخضريون مغتربون في التشيك",
    "castles in hesse": "قلاع في هسن",
    "chess in latvia": "الشطرنج في لاتفيا",
    "child welfare in bangladesh": "رعاية الطفل في بنغلاديش",
    "chinese restaurants in canada": "مطاعم صينية في كندا",
    "christian clergy in ukraine": "رجال دين مسيحيون في أوكرانيا",
    "christian schools in kerala": "مدارس مسيحية في كيرلا",
    "churches in ethiopia": "كنائس في إثيوبيا",
    "churches in marshall islands": "كنائس في جزر مارشال",
    "churches in nigeria": "كنائس في نيجيريا",
    "cities and towns in gandhinagar district": "مدن وبلدات في مقاطعة غانديناغار",
    "clock towers in africa": "أبراج ساعة في إفريقيا",
    "communes in bié province": "بلديات في مقاطعة بيي",
    "communism in oman": "شيوعية في سلطنة عمان",
    "conspiracy theories in lebanon": "نظريات مؤامرة في لبنان",
    "courthouses in france": "محاكم في فرنسا",
    "covid-19 pandemic in hawaii": "جائحة فيروس كورونا في هاواي",
    "crimes in peru": "جرائم في بيرو",
    "cycling events in australia": "أحداث سباق الدراجات الهوائية في أستراليا",
    "death in byzantine empire": "الموت في الإمبراطورية البيزنطية",
    "deaths from pneumonia in oklahoma": "وفيات الالتهاب الرئوي في أوكلاهوما",
    "deaths in british virgin islands": "وفيات في جزر العذراء البريطانية",
    "decades in antwerp": "عقود في أنتفيرب",
    "decades in malaysia": "عقود في ماليزيا",
    "december 1550 in asia": "ديسمبر 1550 في آسيا",
    "december 1550 in netherlands": "ديسمبر 1550 في هولندا",
    "december 1550 in thailand": "ديسمبر 1550 في تايلاند",
    "december 1550 in united states": "ديسمبر 1550 في الولايات المتحدة",
    "defunct museums in arkansas": "متاحف سابقة في أركنساس",
    "diasporas in australia": "شتات في أستراليا",
    "disease outbreaks in peru": "تفشي طبي في بيرو",
    "disease-related deaths in zimbabwe": "وفيات مرتبطة بالمرض في زيمبابوي",
    "disestablishments in ecuador": "انحلالات في الإكوادور",
    "disestablishments in yugoslavia": "انحلالات في يوغسلافيا",
    "elections in united states virgin islands": "انتخابات في جزر العذراء الأمريكية",
    "elementary schools in calgary": "مدارس إبتدائية في كالغاري",
    "energy in cameroon": "طاقة في الكاميرون",
    "entertainment venues in wisconsin": "أماكن ترفيه في ويسكونسن",
    "eritrean expatriates in sweden": "إريتريون مغتربون في السويد",
    "establishments in guernsey": "تأسيسات في غيرنزي",
    "expatriate baseball players in canada": "لاعبو كرة قاعدة مغتربون في كندا",
    "expatriate football managers in cook islands": "مدربو كرة قدم مغتربون في جزر كوك",
    "expatriate football managers in northern mariana islands": "مدربو كرة قدم مغتربون في جزر ماريانا الشمالية",
    "february 1550 in austria": "فبراير 1550 في النمسا",
    "february 1550 in india": "فبراير 1550 في الهند",
    "february 1550 in iran": "فبراير 1550 في إيران",
    "february 1550 in philippines": "فبراير 1550 في الفلبين",
    "february 1550 in united states": "فبراير 1550 في الولايات المتحدة",
    "ferry transport in indonesia": "النقل بالعبارات في إندونيسيا",
    "festivals in athens": "مهرجانات في أثينا",
    "festivals in buenos aires": "مهرجانات في بوينس آيرس",
    "food and drink in japan": "أطعمة ومشروبات في اليابان",
    "food and drink in scotland": "أطعمة ومشروبات في إسكتلندا",
    "football in cuba": "كرة القدم في كوبا",
    "football in yucatán": "كرة القدم في ولاية يوكاتان",
    "footballers in romania": "لاعبو كرة قدم في رومانيا",
    "former populated places in hormozgan province": "أماكن كانت مأهولة في محافظة هرمزغان",
    "forts in jharkhand": "حصون في جهارخاند",
    "freedom of expression in india": "حرية التعبير في الهند",
    "french expatriate handball players in germany": "لاعبو كرة يد فرنسيون مغتربون في ألمانيا",
    "gabonese expatriates in france": "غابونيون مغتربون في فرنسا",
    "georgian architecture in wyoming": "عمارة جورجية في وايومنغ",
    "government buildings in manhattan": "مبان حكومية في مانهاتن",
    "guinean expatriate sports-people in romania": "رياضيون غينيون مغتربون في رومانيا",
    "haitian expatriates in romania": "هايتيون مغتربون في رومانيا",
    "handball in 1550 summer youth olympics": "كرة اليد في الألعاب الأولمبية الشبابية الصيفية 1550",
    "health in british columbia": "الصحة في كولومبيا البريطانية",
    "high schools in india": "مدارس ثانوية في الهند",
    "hotels in italy": "فنادق في إيطاليا",
    "hotels in republic-of ireland": "فنادق في جمهورية أيرلندا",
    "ice hockey venues in ottawa": "ملاعب هوكي الجليد في أوتاوا",
    "indigenous peoples in querétaro": "شعوب أصلية في ولاية كويريتارو",
    "internet in el salvador": "إنترنت في السلفادور",
    "january 1550 in china": "يناير 1550 في الصين",
    "january 1550 in united kingdom": "يناير 1550 في المملكة المتحدة",
    "judo competitions in serbia": "منافسات جودو في صربيا",
    "judo in south africa": "الجودو في جنوب إفريقيا",
    "july 1550 in australia": "يوليو 1550 في أستراليا",
    "june 1550 in united states": "يونيو 1550 في الولايات المتحدة",
    "kurdish diaspora in united states": "شتات كردي في الولايات المتحدة",
    "legislators in india": "مشرعون في الهند",
    "lithuanian expatriate sports-people in australia": "رياضيون ليتوانيون مغتربون في أستراليا",
    "local politicians in united kingdom": "سياسيون محليون في المملكة المتحدة",
    "local-elections in india": "انتخابات محلية في الهند",
    "manslaughter in united states": "قتل خطأ في الولايات المتحدة",
    "march 1550 in oceania": "مارس 1550 في أوقيانوسيا",
    "maritime incidents in december 1550": "حوادث بحرية في ديسمبر 1550",
    "martial arts in montenegro": "الفنون القتالية في الجبل الأسود",
    "masonic buildings in iowa": "مبان ماسونية في آيوا",
    "mass shootings in africa": "إطلاق نار عشوائي في إفريقيا",
    "mass shootings in oceania": "إطلاق نار عشوائي في أوقيانوسيا",
    "mayors of places in nova scotia": "رؤساء بلديات في نوفا سكوشا",
    "mexican expatriates in belarus": "مكسيكيون مغتربون في روسيا البيضاء",
    "military and war museums in tennessee": "متاحف عسكرية وحربية في تينيسي",
    "millennia in peru": "ألفيات في بيرو",
    "mines in devon": "مناجم في ديفون",
    "montserratian expatriates in england": "مونتسراتيون مغتربون في إنجلترا",
    "monuments and memorials in dorset": "معالم أثرية ونصب تذكارية في دورست",
    "monuments and memorials in northumberland": "معالم أثرية ونصب تذكارية في نورثمبرلاند",
    "monuments and memorials in tyne and wear": "معالم أثرية ونصب تذكارية في تاين ووير",
    "municipalities in gjirokastër county": "بلديات في مقاطعة غيروكاستر",
    "murder in dublin (city)": "قتل في دبلن",
    "murder in istanbul": "قتل في إسطنبول",
    "murders in north america": "جرائم قتل في أمريكا الشمالية",
    "murders in russia": "جرائم قتل في روسيا",
    "museums in indianapolis": "متاحف في إنديانابوليس",
    "music venues in paraguay": "صالات الموسيقى في باراغواي",
    "national natural landmarks in alaska": "معالم طبيعية وطنية في ألاسكا",
    "natural disasters in united states": "كوارث طبيعية في الولايات المتحدة",
    "neighbourhoods in germany": "أحياء في ألمانيا",
    "november 1550 in argentina": "نوفمبر 1550 في الأرجنتين",
    "october 1550 in asia": "أكتوبر 1550 في آسيا",
    "october 1550 in canada": "أكتوبر 1550 في كندا",
    "october 1550 in europe": "أكتوبر 1550 في أوروبا",
    "october 1550 in japan": "أكتوبر 1550 في اليابان",
    "paintings in ireland": "لوحات في أيرلندا",
    "paleontology in connecticut": "علم الأحياء القديمة في كونيتيكت",
    "parks in county waterford": "متنزهات في مقاطعة وترفورد",
    "parks in taiwan": "متنزهات في تايوان",
    "pneumonia in oklahoma": "الالتهاب الرئوي في أوكلاهوما",
    "political controversies in yugoslavia": "خلافات سياسية في يوغسلافيا",
    "political parties in new hampshire": "أحزاب سياسية في نيوهامشير",
    "populated places in artigas department": "أماكن مأهولة في إدارة أرتيغاس",
    "populated places in cagayan valley": "أماكن مأهولة في وادي كاغيان",
    "populated places in city of zagreb": "أماكن مأهولة في مدينة زغرب",
    "presbyterianism in philippines": "مشيخية في الفلبين",
    "presidential-elections in italy": "انتخابات رئاسية في إيطاليا",
    "private schools in west yorkshire": "مدارس خاصة في غرب يوركشاير",
    "public education in maryland": "تعليم عمومي في ماريلند",
    "pubs in cumbria": "حانات في كمبريا",
    "racism in middle east": "عنصرية في الشرق الأوسط",
    "radio in gambia": "راديو في غامبيا",
    "radio in georgia (country)": "راديو في جورجيا",
    "radio stations in vermont": "محطات إذاعية في فيرمونت",
    "railway accidents in 1550s": "حوادث سكك حديد في عقد 1550",
    "railway stations in canada": "محطات السكك الحديدية في كندا",
    "railway stations in japan": "محطات السكك الحديدية في اليابان",
    "railway stations in netherlands": "محطات السكك الحديدية في هولندا",
    "railway stations in new zealand": "محطات السكك الحديدية في نيوزيلندا",
    "railway stations in north korea": "محطات السكك الحديدية في كوريا الشمالية",
    "railway stations in russia": "محطات السكك الحديدية في روسيا",
    "railway stations in united kingdom": "محطات السكك الحديدية في المملكة المتحدة",
    "railway stations in united states": "محطات السكك الحديدية في الولايات المتحدة",
    "religion in central macedonia": "الدين في إقليم مقدونيا الوسطى",
    "religion in hanoi": "الدين في هانوي",
    "religion in south america": "الدين في أمريكا الجنوبية",
    "religion in united states": "الدين في الولايات المتحدة",
    "religious buildings and structures in minnesota": "مبان ومنشآت دينية في منيسوتا",
    "research institutes in jordan": "معاهد أبحاث في الأردن",
    "reservoirs in irkutsk oblast": "خزانات مائية في إركوتسك أوبلاست",
    "roads in dnipro": "طرقات في دنيبروبتروفسك",
    "roads in united kingdom": "طرقات في المملكة المتحدة",
    "roman catholic archbishops in colombia": "رؤساء أساقفة رومان كاثوليك في كولومبيا",
    "roman catholic churches in umbria": "كنائس رومانية كاثوليكية في أومبريا",
    "rugby league in africa": "دوري الرجبي في إفريقيا",
    "russian expatriates in united arab emirates": "روس مغتربون في الإمارات العربية المتحدة",
    "saint kitts and nevis in summer olympics": "سانت كيتس ونيفيس في الألعاب الأولمبية الصيفية",
    "schools in turkey": "مدارس في تركيا",
    "science and technology in romania": "العلوم والتقانة في رومانيا",
    "science in art": "العلم في الفن",
    "senegal in world aquatics championships": "السنغال في بطولة العالم للرياضات المائية",
    "senegalese expatriate basketball people in kosovo": "أعلام كرة سلة سنغاليون مغتربون في كوسوفو",
    "september 1550 in canada": "سبتمبر 1550 في كندا",
    "september 1550 in north america": "سبتمبر 1550 في أمريكا الشمالية",
    "shipping in north america": "نقل بحري في أمريكا الشمالية",
    "shopping malls in ukraine": "مراكز تسوق في أوكرانيا",
    "softball in new york (state)": "الكرة اللينة في ولاية نيويورك",
    "solar power stations in nigeria": "محطات طاقة شمسية في نيجيريا",
    "spain in uefa euro 1550": "إسبانيا في بطولة أمم أوروبا 1550",
    "spanish expatriates in solomon islands": "إسبان مغتربون في جزر سليمان",
    "sports coaches in utah": "مدربو رياضة في يوتا",
    "sports competitions in montevideo": "منافسات رياضية في مونتفيدو",
    "sports venues in queensland": "ملاعب رياضية في كوينزلاند",
    "sports-people in ireland": "رياضيون في أيرلندا",
    "studios in greece": "استديوهات في اليونان",
    "studios in poland": "استديوهات في بولندا",
    "synagogues in switzerland": "كنس في سويسرا",
    "television stations in virginia": "محطات تلفزيونية في فرجينيا",
    "terrorism deaths in malta": "وفيات بسبب الإرهاب في مالطا",
    "togolese expatriates in israel": "توغويون مغتربون في إسرائيل",
    "togolese expatriates in turkey": "توغويون مغتربون في تركيا",
    "tourism in united kingdom": "سياحة في المملكة المتحدة",
    "tourist attractions in almaty": "مواقع جذب سياحي في ألماتي",
    "tourist attractions in amman": "مواقع جذب سياحي في عمان",
    "tourist attractions in dâmbovița county": "مواقع جذب سياحي في مقاطعة دامبوفيتا",
    "tourist attractions in marinduque": "مواقع جذب سياحي في ماريندوك",
    "track and field athletes in 1550 summer paralympics": "رياضيو المسار والميدان في الألعاب البارالمبية الصيفية 1550",
    "transport museums in zambia": "متاحف نقل في زامبيا",
    "trinidad and tobago expatriate sports-people in greece": "رياضيون ترنيداديون مغتربون في اليونان",
    "tunisian expatriate sports-people in libya": "رياضيون تونسيون مغتربون في ليبيا",
    "unincorporated communities in united states": "مجتمعات فردية في الولايات المتحدة",
    "universities and colleges in isabela (province)": "جامعات وكليات في ايزابلا (محافظة)",
    "universities and colleges in montpellier": "جامعات وكليات في مونبلييه",
    "vietnamese diaspora in canada": "شتات فيتنامي في كندا",
    "villages in datia district": "قرى في مقاطعة داتيا",
    "villages in north macedonia": "قرى في مقدونيا الشمالية",
    "villages in poltava oblast": "قرى في بولتافا أوبلاست",
    "villages in ramanagara district": "قرى في مقاطعة رامانجارا",
    "vocational education in uganda": "تعليم مهني في أوغندا",
    "volleyball players in 1550 summer paralympics": "لاعبو كرة طائرة في الألعاب البارالمبية الصيفية 1550",
    "waste management in brazil": "إدارة المخلفات في البرازيل",
    "water sports in tanzania": "رياضات مائية في تنزانيا",
    "years in curaçao": "سنوات في كوراساو",
    "youth sport in british virgin islands": "رياضة شبابية في جزر العذراء البريطانية",
}

data_2 = {
    # "sports mass media in united arab emirates" : "إعلام ألعاب رياضية في الإمارات العربية المتحدة",
    "1550 in belgian motorsport": "رياضة المحركات البلجيكية في 1550",
    "1550 in chinese motorsport": "رياضة المحركات الصينية في 1550",
    "1550 in english cricket": "الكريكت الإنجليزية في 1550",
    "1550 in french tennis": "كرة المضرب الفرنسية في 1550",
    "1550 in indian tennis": "كرة المضرب الهندية في 1550",
    "1550 in japanese football leagues": "دوريات كرة القدم اليابانية في 1550",
    "1550 in south american football leagues": "دوريات كرة القدم الأمريكية الجنوبية في 1550",
    "1550 in spanish tennis": "كرة المضرب الإسبانية في 1550",
    "1550 in swedish football leagues": "دوريات كرة القدم السويدية في 1550",
    "1550 disasters in australia": "كوارث في أستراليا في 1550",
    "1550 disasters in kenya": "كوارث في كينيا في 1550",
    "1550 disasters in mexico": "كوارث في المكسيك في 1550",
    "1550 disasters in oceania": "كوارث في أوقيانوسيا في 1550",
    "1550 in alabama": "ألاباما في 1550",
    "1550 in antarctica": "القارة القطبية الجنوبية في 1550",
    "1550 in antigua and barbuda": "أنتيغوا وباربودا في 1550",
    "1550 in archery": "النبالة في 1550",
    "1550 in australia": "أستراليا في 1550",
    "1550 in bermuda": "برمودا في 1550",
    "1550 in biotechnology": "تقانة حيوية في 1550",
    "1550 in brazilian sport": "رياضة برازيلية في 1550",
    "1550 in british columbia": "كولومبيا البريطانية في 1550",
    "1550 in british empire": "الإمبراطورية البريطانية في 1550",
    "1550 in british music": "موسيقى بريطانية في 1550",
    "1550 in bulgaria": "بلغاريا في 1550",
    "1550 in burmese sport": "رياضة بورمية في 1550",
    "1550 in cameroonian football": "كرة القدم الكاميرونية في 1550",
    "1550 in china": "الصين في 1550",
    "1550 in christianity": "المسيحية في 1550",
    "1550 in comics": "قصص مصورة في 1550",
    "1550 in danish television": "التلفزة الدنماركية في 1550",
    "1550 in delaware": "ديلاوير في 1550",
    "1550 in djibouti": "جيبوتي في 1550",
    "1550 in dominican republic": "جمهورية الدومينيكان في 1550",
    "1550 in economic history": "التاريخ الاقتصادي في 1550",
    "1550 in education": "التعليم في 1550",
    "1550 in europe": "أوروبا في 1550",
    "1550 in fencing": "مبارزة سيف الشيش في 1550",
    "1550 in field hockey": "هوكي الميدان في 1550",
    "1550 in finland": "فنلندا في 1550",
    "1550 in formula racing": "سباقات فورمولا في 1550",
    "1550 in french colonial empire": "الإمبراطورية الاستعمارية الفرنسية في 1550",
    "1550 in french television": "التلفزة الفرنسية في 1550",
    "1550 in georgia (u.s. state)": "ولاية جورجيا في 1550",
    "1550 in guam": "غوام في 1550",
    "1550 in guangzhou": "غوانزو في 1550",
    "1550 in habsburg monarchy": "ملكية هابسبورغ في 1550",
    "1550 in haiti": "هايتي في 1550",
    "1550 in holy roman empire": "الإمبراطورية الرومانية المقدسة في 1550",
    "1550 in horse racing": "سباق الخيل في 1550",
    "1550 in hungary": "المجر في 1550",
    "1550 in hurling": "القذف في 1550",
    "1550 in illinois": "إلينوي في 1550",
    "1550 in international sports": "رياضية دولية في 1550",
    "1550 in iraq": "العراق في 1550",
    "1550 in iraqi sport": "رياضة عراقية في 1550",
    "1550 in irish women's sport": "رياضة أيرلندية نسائية في 1550",
    "1550 in italian sport": "رياضة إيطالية في 1550",
    "1550 in ivory coast": "ساحل العاج في 1550",
    "1550 in khyber pakhtunkhwa": "خيبر بختونخوا في 1550",
    "1550 in law": "القانون في 1550",
    "1550 in liberia": "ليبيريا في 1550",
    "1550 in libyan sport": "رياضة ليبية في 1550",
    "1550 in lithuania": "ليتوانيا في 1550",
    "1550 in macau": "ماكاو في 1550",
    "1550 in maryland": "ماريلند في 1550",
    "1550 in mexican television": "التلفزة المكسيكية في 1550",
    "1550 in mexico": "المكسيك في 1550",
    "1550 in military history": "التاريخ العسكري في 1550",
    "1550 in minnesota": "منيسوتا في 1550",
    "1550 in missouri": "ميزوري في 1550",
    "1550 in mongolia": "منغوليا في 1550",
    "1550 in new jersey": "نيوجيرسي في 1550",
    "1550 in new zealand": "نيوزيلندا في 1550",
    "1550 in nordic combined": "التزلج النوردي المزدوج في 1550",
    "1550 in north america": "أمريكا الشمالية في 1550",
    "1550 in north macedonia": "مقدونيا الشمالية في 1550",
    "1550 in norwegian music": "موسيقى نرويجية في 1550",
    "1550 in oregon": "أوريغن في 1550",
    "1550 in outer space": "الفضاء الخارجي في 1550",
    "1550 in philippine cinema": "السينما الفلبينية في 1550",
    "1550 in professional wrestling": "مصارعة المحترفين في 1550",
    "1550 in puerto rico": "بورتوريكو في 1550",
    "1550 in religion": "الدين في 1550",
    "1550 in road cycling": "سباق الدراجات على الطريق في 1550",
    "1550 in romania": "رومانيا في 1550",
    "1550 in san marino": "سان مارينو في 1550",
    "1550 in sarawak": "ساراواك في 1550",
    "1550 in saudi arabia": "السعودية في 1550",
    "1550 in science": "العلم في 1550",
    "1550 in scotland": "إسكتلندا في 1550",
    "1550 in scottish women's sport": "رياضة إسكتلندية نسائية في 1550",
    "1550 in senegalese sport": "رياضة سنغالية في 1550",
    "1550 in serbia": "صربيا في 1550",
    "1550 in sint maarten": "سينت مارتن في 1550",
    "1550 in skeleton": "الزلاجات الصدرية في 1550",
    "1550 in somalian sport": "رياضة صومالية في 1550",
    "1550 in south america": "أمريكا الجنوبية في 1550",
    "1550 in spain": "إسبانيا في 1550",
    "1550 in spanish empire": "الإمبراطورية الإسبانية في 1550",
    "1550 in speed skating": "التزلج السريع في 1550",
    "1550 in syria": "سوريا في 1550",
    "1550 in taiwan": "تايوان في 1550",
    "1550 in taiwanese television": "التلفزة التايوانية في 1550",
    "1550 in tanzania": "تنزانيا في 1550",
    "1550 in thailand": "تايلاند في 1550",
    "1550 in toronto": "تورونتو في 1550",
    "1550 in united arab emirates": "الإمارات العربية المتحدة في 1550",
    "1550 in united nations": "الأمم المتحدة في 1550",
    "1550 in uruguayan football": "كرة القدم الأوروغويانية في 1550",
    "1550 in uzbekistani football": "كرة القدم الأوزبكستانية في 1550",
    "1550 in uzbekistani sport": "رياضة أوزبكستانية في 1550",
    "1550 in vanuatu": "فانواتو في 1550",
    "1550 in venezuela": "فنزويلا في 1550",
    "1550 in virginia": "فرجينيا في 1550",
    "1550 in washington (state)": "ولاية واشنطن في 1550",
    "1550 in west germany": "ألمانيا الغربية في 1550",
    "1550 in women's sport": "رياضة نسائية في 1550",
    "1550 mass shootings in africa": "إطلاق نار عشوائي في إفريقيا في 1550",
    "1550 mass shootings in oceania": "إطلاق نار عشوائي في أوقيانوسيا في 1550",
    "1550 murders in north america": "جرائم قتل في أمريكا الشمالية في 1550",
    "1550 murders in russia": "جرائم قتل في روسيا في 1550",
    "1550 natural disasters in united states": "كوارث طبيعية في الولايات المتحدة في 1550",
    "1550s in asia": "آسيا في عقد 1550",
    "1550s in belgium": "بلجيكا في عقد 1550",
    "1550s in dundee": "دندي في عقد 1550",
    "1550s in edmonton": "إدمونتون في عقد 1550",
    "1550s in england": "إنجلترا في عقد 1550",
    "1550s in estonia": "إستونيا في عقد 1550",
    "1550s in hangzhou": "هانغتشو في عقد 1550",
    "1550s in ice hockey": "هوكي الجليد في عقد 1550",
    "1550s in japan": "اليابان في عقد 1550",
    "1550s in literature": "الأدب في عقد 1550",
    "1550s in louisiana": "لويزيانا في عقد 1550",
    "1550s in maltese sport": "رياضة مالطية في عقد 1550",
    "1550s in north american sport": "رياضة أمريكية شمالية في عقد 1550",
    "1550s in politics": "السياسة في عقد 1550",
    "1550s in portugal": "البرتغال في عقد 1550",
    "1550s in prince edward island": "جزيرة الأمير إدوارد في عقد 1550",
    "1550s in quebec": "كيبك في عقد 1550",
    "1550s in rugby union": "اتحاد الرجبي في عقد 1550",
    "1550s in russia": "روسيا في عقد 1550",
    "1550s in saudi arabia": "السعودية في عقد 1550",
    "1550s in science": "العلم في عقد 1550",
    "1550s in somaliland": "أرض الصومال في عقد 1550",
    "1550s in south korean women's sport": "رياضة كورية جنوبية نسائية في عقد 1550",
    "1550s in technology": "التقانة في عقد 1550",
    "1550s in track cycling": "سباق الدراجات على المضمار في عقد 1550",
    "1550s in ukrainian sport": "رياضة أوكرانية في عقد 1550",
    "1550s in venezuela": "فنزويلا في عقد 1550",
    "1550s in vietnam": "فيتنام في عقد 1550",
    "1550s in winter sports": "الرياضة الشتوية في عقد 1550",
    "20th century in iraq": "العراق في القرن 20",
    "20th century in kent": "كنت في القرن 20",
    "20th century in prince edward island": "جزيرة الأمير إدوارد في القرن 20",
    "20th century in prussia": "بروسيا في القرن 20",
    "20th century in quetta": "كويته في القرن 20",
    "2nd millennium in kentucky": "كنتاكي في الألفية 2",
    "3rd millennium in ghana": "غانا في الألفية 3",
    "culture in lugano": "الثقافة في لوغانو",
    "education in caloocan": "التعليم في كالوكان",
    "transport in kirov oblast": "النقل في أوبلاست كيروف",
    "transport in newfoundland and labrador": "النقل في نيوفاوندلاند واللابرادور",
    "transport in oxford": "النقل في أكسفورد",
    "transport in ternopil oblast": "النقل في تيرنوبل أوبلاست",
    "mass media in bosnia and herzegovina by medium": "وسائل إعلام في البوسنة والهرسك حسب الوسط",
    "mass media in bosnia and herzegovina": "وسائل إعلام في البوسنة والهرسك",
    "1550 in mass media": "وسائل إعلام في 1550",
    "defunct mass media in new jersey": "وسائل إعلام سابقة في نيوجيرسي",
    "1550 awards in united states": "جوائز 1550 في الولايات المتحدة",
    "clubhouses on the-national-register-of-historic-places in maine": "نوادي في السجل الوطني للأماكن التاريخية في مين",
    "courthouses on the-national-register-of-historic-places in illinois": "محاكم في السجل الوطني للأماكن التاريخية في إلينوي",
    "courthouses on the-national-register-of-historic-places in maryland": "محاكم في السجل الوطني للأماكن التاريخية في ماريلند",
    "courthouses on the-national-register-of-historic-places in new york city": "محاكم في السجل الوطني للأماكن التاريخية في مدينة نيويورك",
    "heads of universities and colleges in zimbabwe": "قادة جامعات وكليات في زيمبابوي",
    "lists of buildings and structures in california": "قوائم مبان ومنشآت في كاليفورنيا",
    "lists of legislators in india": "قوائم مشرعون في الهند",
    "lists of mayors of places in nova scotia": "قوائم رؤساء بلديات في نوفا سكوشا",
    "lists of roads in united kingdom": "قوائم طرقات في المملكة المتحدة",
    "military facilities on the-national-register-of-historic-places in indiana": "مرافق عسكرية في السجل الوطني للأماكن التاريخية في إنديانا",
    "military operations of american civil war in north dakota": "عمليات عسكرية في الحرب الأهلية الأمريكية في داكوتا الشمالية",
    "opera houses on the-national-register-of-historic-places in minnesota": "دور أوبرا في السجل الوطني للأماكن التاريخية في منيسوتا",
    "victims of aviation accidents or incidents in dominican republic": "ضحايا حوادث طيران في جمهورية الدومينيكان",
    "years of 20th century in australia": "سنوات القرن 20 في أستراليا",
}

data_3 = {
    "1550 mass shootings in oceania": "إطلاق نار عشوائي في أوقيانوسيا في 1550",
    "argentine people of american descent": "أرجنتينيون من أصل أمريكي",
    "1550s in rugby union": "اتحاد الرجبي في عقد 1550",
    "1550 in sarawak": "ساراواك في 1550",
    "1550 in-sports-in alberta": "الرياضة في ألبرتا في 1550",
    "1550 in-sports-in arizona": "الرياضة في أريزونا في 1550",
    "1550 in-sports-in british columbia": "الرياضة في كولومبيا البريطانية في 1550",
    "1550 in-sports-in mississippi": "الرياضة في مسيسيبي في 1550",
    "1550 in-sports-in nebraska": "الرياضة في نبراسكا في 1550",
    "1550 in-sports-in new york (state)": "الرياضة في ولاية نيويورك في 1550",
    "1550 in-sports-in ohio": "الرياضة في أوهايو في 1550",
    "ambassadors to guinea-bissau": "سفراء لدى غينيا بيساو",
    "ambassadors to south sudan": "سفراء لدى جنوب السودان",
    "armenian people of ukrainian descent": "أرمن من أصل أوكراني",
    "bahraini people of ethiopian descent": "بحرينيون من أصل إثيوبي",
    "black metal albums by french artists": "ألبومات بلاك ميتال بواسطة فنانون فرنسيون",
    "cabinets of british columbia navigational boxes": "صناديق تصفح مجالس وزراء في كولومبيا البريطانية",
    "dutch people of hungarian descent": "هولنديون من أصل مجري",
    "ecuadorian television series-endings by decade": "مسلسلات تلفزيونية إكوادورية حسب عقد انتهاء العرض",
    "emirati people of tunisian descent": "إماراتيون من أصل تونسي",
    "ethiopian people of armenian descent": "إثيوبيون من أصل أرميني",
    "fiction set in 1550": "أعمال خيالية في 1550",
    "films by japanese directors": "أفلام مخرجون يابانيون",
    "ghanaian people of nigerien descent": "غانيون من أصل نيجري",
    "hard rock albums by south korean artists": "ألبومات هارد روك بواسطة فنانون كوريون جنوبيون",
    "lists of ambassadors to south sudan": "قوائم سفراء لدى جنوب السودان",
    "lists of organizations by dependent territory": "قوائم منظمات حسب الأقاليم التابعة",
    "nigerian people of hungarian descent": "نيجيريون من أصل مجري",
    "sudanese people of hungarian descent": "سودانيون من أصل مجري",
    "turkish people of georgian descent": "أتراك من أصل جورجي",
    "welsh people of singaporean descent": "ويلزيون من أصل سنغافوري",
    "works by austrian filmmakers": "أعمال صانعو أفلام نمساويون",
    "bermudian people of world-war-ii": "برموديون في الحرب العالمية الثانية",
    "baseball players in florida by team": "لاعبو كرة قاعدة في فلوريدا حسب الفريق",
    "baseball players in south korea by team": "لاعبو كرة قاعدة في كوريا الجنوبية حسب الفريق",
    "bridges in france by material": "جسور في فرنسا حسب المادة",
    "cabinets of british columbia ": "مجالس وزراء في كولومبيا البريطانية",
    "constitutions of british overseas territories": "دساتير في أقاليم ما وراء البحار البريطانية",
    "defunct learned societies of united kingdom": "جمعيات علمية سابقة في المملكة المتحدة",
    "high schools in india by state or union territory": "مدارس ثانوية في الهند حسب الولاية أو الإقليم الاتحادي",
    "local politicians in united kingdom by party": "سياسيون محليون في المملكة المتحدة حسب الحزب",
    "men's footballers in togo by club": "لاعبو كرة قدم في توغو حسب النادي",
    "mine warfare vessels of united states navy": "سفن حرب ألغام في البحرية الأمريكية",
    "railway stations in canada closed in 1550": "محطات السكك الحديدية في كندا أغلقت في 1550",
    "railway stations in japan opened in 1550": "محطات السكك الحديدية في اليابان افتتحت في 1550",
    "railway stations in netherlands opened in 1550": "محطات السكك الحديدية في هولندا افتتحت في 1550",
    "railway stations in new zealand closed in 1550": "محطات السكك الحديدية في نيوزيلندا أغلقت في 1550",
    "railway stations in north korea opened in 1550": "محطات السكك الحديدية في كوريا الشمالية افتتحت في 1550",
    "railway stations in russia opened in 1550": "محطات السكك الحديدية في روسيا افتتحت في 1550",
    "railway stations in united kingdom closed in 1550": "محطات السكك الحديدية في المملكة المتحدة أغلقت في 1550",
    "railway stations in united states closed in 1550": "محطات السكك الحديدية في الولايات المتحدة أغلقت في 1550",
    "religion in united states by region": "الدين في الولايات المتحدة حسب المنطقة",
    "saint kitts and nevis in summer olympics by year": "سانت كيتس ونيفيس في الألعاب الأولمبية الصيفية حسب السنة",
    "shopping malls in ukraine by populated place": "مراكز تسوق في أوكرانيا حسب المكان المأهول",
    "sport in ottoman empire by year": "الرياضة في الدولة العثمانية حسب السنة",
    "sports-people in ireland by club or team": "رياضيون في أيرلندا حسب النادي أو الفريق",
    "tourism in united kingdom by city": "سياحة في المملكة المتحدة حسب المدينة",
    "villages in north macedonia by municipality": "قرى في مقدونيا الشمالية حسب البلدية",
}

to_test = [
    ("test_data_list_in_1", data_1, resolve_label_ar),
    ("test_data_list_in_2", data_2, resolve_label_ar),
    ("test_data_list_in_3", data_3, resolve_label_ar),
]


@pytest.mark.parametrize("category, output", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_data_list_in_1(category: str, output: str) -> None:
    label = resolve_label_ar(category, " in ")
    assert label == output


@pytest.mark.parametrize("category, output", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_data_list_in_2(category: str, output: str) -> None:
    label = resolve_label_ar(category)
    assert label == output


@pytest.mark.parametrize("category, output", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_data_list_in_3(category: str, output: str) -> None:
    label = resolve_label_ar(category)
    assert label == output


test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)
