#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data0 = {
    "Cultural depictions of ancient Egyptian women": "تصوير ثقافي عن مصريات قدماء",
    "Cultural depictions of ancient people": "تصوير ثقافي عن أشخاص قدماء",
}

fast_data = {
    "Cultural depictions of Bulgarian people": "تصوير ثقافي عن بلغاريون",
    "Cultural depictions of Cambodian people": "تصوير ثقافي عن كمبوديون",
    "Cultural depictions of Canadian police officers": "تصوير ثقافي عن ضباط شرطة كنديون",
    "Cultural depictions of Canadian politicians": "تصوير ثقافي عن سياسيون كنديون",
    "Cultural depictions of 15th-century painters": "تصوير ثقافي عن رسامون في القرن 15",
    "Cultural depictions of 16th-century painters": "تصوير ثقافي عن رسامون في القرن 16",
    "Cultural depictions of 17th-century painters": "تصوير ثقافي عن رسامون في القرن 17",
    "Cultural depictions of 18th-century painters": "تصوير ثقافي عن رسامون في القرن 18",
    "Cultural depictions of 19th-century painters": "تصوير ثقافي عن رسامون في القرن 19",
    "Cultural depictions of 20th-century painters": "تصوير ثقافي عن رسامون في القرن 20",
    "Cultural depictions of Abraham Lincoln": "تصوير ثقافي عن أبراهام لينكون",
    "Cultural depictions of Abu Bakr": "تصوير ثقافي عن أبو بكر الصديق",
    "Cultural depictions of activists": "تصوير ثقافي عن ناشطون",
    "Cultural depictions of actors": "تصوير ثقافي عن ممثلون",
    "Cultural depictions of Adam Sandler": "تصوير ثقافي عن آدم ساندلر",
    "Cultural depictions of Adam Smith": "تصوير ثقافي عن آدم سميث",
    "Cultural depictions of admirals": "تصوير ثقافي عن أميرالات",
    "Cultural depictions of Adolf Eichmann": "تصوير ثقافي عن أدولف آيخمان",
    "Cultural depictions of Adolf Hitler": "تصوير ثقافي عن أدولف هتلر",
    "Cultural depictions of Afghan people": "تصوير ثقافي عن أفغان",
    "Cultural depictions of African-American people": "تصوير ثقافي عن أمريكيون أفارقة",
    "Cultural depictions of Agatha Christie": "تصوير ثقافي عن أجاثا كريستي",
    "Cultural depictions of Akbar": "تصوير ثقافي عن أكبر",
    "Cultural depictions of Akhenaten": "تصوير ثقافي عن أخناتون",
    "Cultural depictions of Alan Turing": "تصوير ثقافي عن آلان تورنغ",
    "Cultural depictions of Albanian people": "تصوير ثقافي عن ألبان",
    "Cultural depictions of Albert Einstein": "تصوير ثقافي عن ألبرت أينشتاين",
    "Cultural depictions of Albert Speer": "تصوير ثقافي عن ألبرت شبير",
    "Cultural depictions of Albrecht Dürer": "تصوير ثقافي عن آلبرخت دورر",
    "Cultural depictions of Albrecht von Wallenstein": "تصوير ثقافي عن ألبرشت فون فالنشتاين",
    "Cultural depictions of Al Capone": "تصوير ثقافي عن آل كابوني",
    "Cultural depictions of Aleister Crowley": "تصوير ثقافي عن آليستر كراولي",
    "Cultural depictions of Alexander Graham Bell": "تصوير ثقافي عن ألكسندر غراهام بل",
    "Cultural depictions of Alexander Hamilton": "تصوير ثقافي عن ألكسندر هاميلتون",
    "Cultural depictions of Alexander Pushkin": "تصوير ثقافي عن ألكسندر بوشكين",
    "Cultural depictions of Alexander the Great": "تصوير ثقافي عن الإسكندر الأكبر",
    "Cultural depictions of Alexios I Komnenos": "تصوير ثقافي عن ألكسيوس الأول كومنين",
    "Cultural depictions of Alfred Hitchcock": "تصوير ثقافي عن ألفريد هتشكوك",
}

data_slow = {
    "Cultural depictions of Alfred the Great": "تصوير ثقافي عن ألفريد العظيم",
    "Cultural depictions of Al Gore": "تصوير ثقافي عن آل جور",
    "Cultural depictions of Amelia Earhart": "تصوير ثقافي عن أميليا إيرهارت",
    "Cultural depictions of American police officers": "تصوير ثقافي عن ضباط شرطة أمريكيون",
    "Cultural depictions of American politicians": "تصوير ثقافي عن سياسيون أمريكيون",
    "Cultural depictions of Amitabh Bachchan": "تصوير ثقافي عن أميتاب باتشان",
    "Cultural depictions of Amy Winehouse": "تصوير ثقافي عن إيمي واينهاوس",
    "Cultural depictions of ancient Egyptian people": "تصوير ثقافي عن مصريون قدماء",
    "Cultural depictions of ancient Greek women": "تصوير ثقافي عن يونانيات قديمات",
    "Cultural depictions of ancient Persian people": "تصوير ثقافي عن فرس قدماء",
    "Cultural depictions of ancient Roman people": "تصوير ثقافي عن رومان قدماء",
    "Cultural depictions of Andrew Jackson": "تصوير ثقافي عن أندرو جاكسون",
    "Cultural depictions of Andrew Johnson": "تصوير ثقافي عن أندرو جونسون",
    "Cultural depictions of Andy Kaufman": "تصوير ثقافي عن أندي كوفمان",
    "Cultural depictions of Andy Warhol": "تصوير ثقافي عن آندي وارهول",
    "Cultural depictions of Angela Merkel": "تصوير ثقافي عن أنغيلا ميركل",
    "Cultural depictions of animals": "تصوير ثقافي عن حيوانات",
    "Cultural depictions of Anna Nicole Smith": "تصوير ثقافي عن آنا نيكول سميث",
    "Cultural depictions of Anne Boleyn": "تصوير ثقافي عن آن بولين",
    "Cultural depictions of Anne Frank": "تصوير ثقافي عن آن فرانك",
    "Cultural depictions of Anne of Cleves": "تصوير ثقافي عن آن من كليفز",
    "Cultural depictions of Anne, Queen of Great Britain": "تصوير ثقافي عن آن (ملكة بريطانيا العظمى)",
    "Cultural depictions of Anthony the Great": "تصوير ثقافي عن أنطونيوس الكبير",
    "Cultural depictions of Anton Chekhov": "تصوير ثقافي عن أنطون تشيخوف",
    "Cultural depictions of Antonio Vivaldi": "تصوير ثقافي عن أنطونيو فيفالدي",
    "Cultural depictions of Anwar Sadat": "تصوير ثقافي عن محمد أنور السادات",
    "Cultural depictions of Archimedes": "تصوير ثقافي عن أرخميدس",
    "Cultural depictions of Aristotle": "تصوير ثقافي عن أرسطو",
    "Cultural depictions of Armenian people": "تصوير ثقافي عن أرمن",
    "Cultural depictions of Arminius": "تصوير ثقافي عن أرمينيوس",
    "Cultural depictions of Arnold Schwarzenegger": "تصوير ثقافي عن أرنولد شوارزنيجر",
    "Cultural depictions of Arthur Conan Doyle": "تصوير ثقافي عن آرثر كونان دويل",
    "Cultural depictions of Arthur Rimbaud": "تصوير ثقافي عن آرثر رامبو",
    "Cultural depictions of Arthur Wellesley, 1st Duke of Wellington": "تصوير ثقافي عن آرثر ويلزلي",
    "Cultural depictions of Ashoka": "تصوير ثقافي عن أشوكا",
    "Cultural depictions of assassins": "تصوير ثقافي عن منفذو اغتيالات",
    "Cultural depictions of association football players": "تصوير ثقافي عن لاعبو كرة قدم",
    "Cultural depictions of astronauts": "تصوير ثقافي عن رواد فضاء",
    "Cultural depictions of Atal Bihari Vajpayee": "تصوير ثقافي عن أتال بيهاري فاجبايي",
    "Cultural depictions of Auguste Rodin": "تصوير ثقافي عن أوغوست رودان",
    "Cultural depictions of Augustine of Hippo": "تصوير ثقافي عن أوغسطينوس",
    "Cultural depictions of August Strindberg": "تصوير ثقافي عن أوغست ستريندبرغ",
    "Cultural depictions of Augustus": "تصوير ثقافي عن أغسطس (إمبراطور)",
    "Cultural depictions of Aurelian": "تصوير ثقافي عن أوريليان",
    "Cultural depictions of Austrian monarchs": "تصوير ثقافي عن ملكيون نمساويون",
    "Cultural depictions of Averroes": "تصوير ثقافي عن ابن رشد",
    "Cultural depictions of aviators": "تصوير ثقافي عن طيارون",
    "Cultural depictions of Ayn Rand": "تصوير ثقافي عن آين راند",
    "Cultural depictions of Ayrton Senna": "تصوير ثقافي عن آيرتون سينا",
    "Cultural depictions of Babe Ruth": "تصوير ثقافي عن بيب روث",
    "Cultural depictions of badminton players": "تصوير ثقافي عن لاعبو تنس ريشة",
    "Cultural depictions of Barack Obama": "تصوير ثقافي عن باراك أوباما",
    "Cultural depictions of Barbra Streisand": "تصوير ثقافي عن باربرا سترايساند",
    "Cultural depictions of barons": "تصوير ثقافي عن بارونات",
    "Cultural depictions of Baruch Spinoza": "تصوير ثقافي عن باروخ سبينوزا",
    "Cultural depictions of baseball players": "تصوير ثقافي عن لاعبو كرة قاعدة",
    "Cultural depictions of basketball players": "تصوير ثقافي عن لاعبو كرة سلة",
    "Cultural depictions of Bayezid I": "تصوير ثقافي عن بايزيد الأول",
    "Cultural depictions of Belshazzar": "تصوير ثقافي عن بلشاصر",
    "Cultural depictions of Benedict Arnold": "تصوير ثقافي عن بينيديكت أرنولد",
    "Cultural depictions of Benigno Aquino III": "تصوير ثقافي عن بنيغنو آكينو",
    "Cultural depictions of Benito Juárez": "تصوير ثقافي عن بينيتو خواريز",
    "Cultural depictions of Benito Mussolini": "تصوير ثقافي عن بينيتو موسوليني",
    "Cultural depictions of Benjamin Disraeli": "تصوير ثقافي عن بينجامين دزرائيلي",
    "Cultural depictions of Benjamin Franklin": "تصوير ثقافي عن بنجامين فرانكلين",
    "Cultural depictions of Benjamin Netanyahu": "تصوير ثقافي عن بنيامين نتنياهو",
    "Cultural depictions of Bertolt Brecht": "تصوير ثقافي عن برتولت بريشت",
    "Cultural depictions of Betsy Ross": "تصوير ثقافي عن إليزابيث روس",
    "Cultural depictions of Bette Davis": "تصوير ثقافي عن بيت ديفيس",
    "Cultural depictions of Beyoncé": "تصوير ثقافي عن بيونسيه",
    "Cultural depictions of biblical people": "تصوير ثقافي عن شخصيات الكتاب المقدس",
    "Cultural depictions of Bill Clinton": "تصوير ثقافي عن بيل كلينتون",
    "Cultural depictions of Bill Cosby": "تصوير ثقافي عن بيل كوسبي",
    "Cultural depictions of Bill Gates": "تصوير ثقافي عن بيل غيتس",
    "Cultural depictions of Billie Holiday": "تصوير ثقافي عن بيلي هوليدي",
    "Cultural depictions of Billy the Kid": "تصوير ثقافي عن الولد بيلي",
    "Cultural depictions of Bing Crosby": "تصوير ثقافي عن بينغ كروسبي",
    "Cultural depictions of biologists": "تصوير ثقافي عن علماء أحياء",
    "Cultural depictions of blues musicians": "تصوير ثقافي عن موسيقيو بلوز",
    "Cultural depictions of Bobby Moore": "تصوير ثقافي عن بوبي مور",
    "Cultural depictions of Bob Dylan": "تصوير ثقافي عن بوب ديلن",
    "Cultural depictions of Bob Marley": "تصوير ثقافي عن بوب مارلي",
    "Cultural depictions of bodybuilders": "تصوير ثقافي عن لاعبو كمال أجسام",
    "Cultural depictions of Booker T. Washington": "تصوير ثقافي عن بوكر تي واشنطن",
    "Cultural depictions of Boris Godunov": "تصوير ثقافي عن بوريس غودونوف",
    "Cultural depictions of Boris Johnson": "تصوير ثقافي عن بوريس جونسون",
    "Cultural depictions of Boris Yeltsin": "تصوير ثقافي عن بوريس يلتسن",
    "Cultural depictions of Boudica": "تصوير ثقافي عن بوديكا",
    "Cultural depictions of boxers": "تصوير ثقافي عن ملاكمون",
    "Cultural depictions of B. R. Ambedkar": "تصوير ثقافي عن أمبيدكار",
    "Cultural depictions of Brian Lara": "تصوير ثقافي عن بريان لارا",
    "Cultural depictions of Brigham Young": "تصوير ثقافي عن بريغهام يونغ",
    "Cultural depictions of Brigitte Bardot": "تصوير ثقافي عن بريجيت باردو",
    "Cultural depictions of British monarchs": "تصوير ثقافي عن ملكيون بريطانيون",
    "Cultural depictions of British police officers": "تصوير ثقافي عن ضباط شرطة بريطانيون",
    "Cultural depictions of British politicians": "تصوير ثقافي عن سياسيون بريطانيون",
    "Cultural depictions of Britney Spears": "تصوير ثقافي عن بريتني سبيرز",
    "Cultural depictions of Bruce Lee": "تصوير ثقافي عن بروس لي",
    "Cultural depictions of Buddy Holly": "تصوير ثقافي عن بودي هولي",
    "Cultural depictions of Buffalo Bill": "تصوير ثقافي عن بافالو بيل",
    "Cultural depictions of bullfighters": "تصوير ثقافي عن مصارعو ثيران",
    "Cultural depictions of businesspeople": "تصوير ثقافي عن شخصيات أعمال",
    "Cultural depictions of Buster Keaton": "تصوير ثقافي عن باستر كيتون",
    "Cultural depictions of Buzz Aldrin": "تصوير ثقافي عن بز ألدرن",
    "Cultural depictions of Caesarion": "تصوير ثقافي عن بطليموس الخامس عشر (قيصرون)",
    "Cultural depictions of Caligula": "تصوير ثقافي عن كاليغولا",
    "Cultural depictions of Calpurnia (wife of Caesar)": "تصوير ثقافي عن كالبورنيا",
    "Cultural depictions of Calvin Coolidge": "تصوير ثقافي عن كالفين كوليدج",
    "Cultural depictions of Camille Claudel": "تصوير ثقافي عن كاميل كلوديل",
    "Cultural depictions of Caravaggio": "تصوير ثقافي عن كارافاجيو",
    "Cultural depictions of Cardinal Mazarin": "تصوير ثقافي عن جول مازاران",
    "Cultural depictions of Carl Gustaf Emil Mannerheim": "تصوير ثقافي عن كارل غوستاف إميل مانرهايم",
    "Cultural depictions of Carl Jung": "تصوير ثقافي عن كارل يونغ",
    "Cultural depictions of Carl Linnaeus": "تصوير ثقافي عن كارولوس لينيوس",
    "Cultural depictions of Carl Nielsen": "تصوير ثقافي عن كارل نيلسن",
    "Cultural depictions of cartoonists": "تصوير ثقافي عن رسامو كارتون",
    "Cultural depictions of Casey Jones": "تصوير ثقافي عن كيسي جونز",
    "Cultural depictions of Casimir Pulaski": "تصوير ثقافي عن كازيمير بولاسكي",
    "Cultural depictions of Catherine de' Medici": "تصوير ثقافي عن كاترين دي ميديشي",
    "Cultural depictions of Catherine Howard": "تصوير ثقافي عن كاثرين هوارد",
    "Cultural depictions of Catherine of Aragon": "تصوير ثقافي عن كاثرين أرغون",
    "Cultural depictions of Catherine Parr": "تصوير ثقافي عن كاثرين بار",
    "Cultural depictions of Catherine, Princess of Wales": "تصوير ثقافي عن كاثرين أميرة ويلز",
    "Cultural depictions of Catherine the Great": "تصوير ثقافي عن كاترين الثانية",
    "Cultural depictions of Catiline": "تصوير ثقافي عن كاتيلين",
    "Cultural depictions of Cecil Rhodes": "تصوير ثقافي عن سيسل رودس",
    "Cultural depictions of Cesare Borgia": "تصوير ثقافي عن تشيزري بورجا",
    "Cultural depictions of Charlemagne": "تصوير ثقافي عن شارلمان",
    "Cultural depictions of Charles Baudelaire": "تصوير ثقافي عن شارل بودلير",
    "Cultural depictions of Charles Darwin": "تصوير ثقافي عن تشارلز داروين",
    "Cultural depictions of Charles de Gaulle": "تصوير ثقافي عن شارل دو غول",
    "Cultural depictions of Charles Dickens": "تصوير ثقافي عن تشارلز ديكنز",
    "Cultural depictions of Charles III": "تصوير ثقافي عن تشارلز الثالث",
    "Cultural depictions of Charles II of England": "تصوير ثقافي عن تشارلز الثاني ملك إنجلترا",
    "Cultural depictions of Charles I of England": "تصوير ثقافي عن تشارلز الأول ملك إنجلترا",
    "Cultural depictions of Charles IV, Holy Roman Emperor": "تصوير ثقافي عن كارل الرابع",
    "Cultural depictions of Charles IX of France": "تصوير ثقافي عن شارل التاسع ملك فرنسا",
    "Cultural depictions of Charles Lindbergh": "تصوير ثقافي عن تشارلز لندبرغ",
    "Cultural depictions of Charles Manson": "تصوير ثقافي عن تشارلز مانسن",
    "Cultural depictions of Charles V, Holy Roman Emperor": "تصوير ثقافي عن شارلكان",
    "Cultural depictions of Charles XII of Sweden": "تصوير ثقافي عن كارل الثاني عشر",
    "Cultural depictions of Charlie Chaplin": "تصوير ثقافي عن تشارلي تشابلن",
    "Cultural depictions of Che Guevara": "تصوير ثقافي عن تشي جيفارا",
    "Cultural depictions of Cher": "تصوير ثقافي عن شير (مغنية)",
    "Cultural depictions of chess players": "تصوير ثقافي عن لاعبو شطرنج",
    "Cultural depictions of Chester A. Arthur": "تصوير ثقافي عن تشستر آرثر",
    "Cultural depictions of Chet Baker": "تصوير ثقافي عن تشيت بيكر",
    "Cultural depictions of Chiang Kai-shek": "تصوير ثقافي عن شيانج كاي شيك",
    "Cultural depictions of Christina, Queen of Sweden": "تصوير ثقافي عن كرستينا ملكة السويد",
    "Cultural depictions of Christopher Columbus": "تصوير ثقافي عن كريستوفر كولومبوس",
    "Cultural depictions of Christopher Marlowe": "تصوير ثقافي عن كريستوفر مارلو",
    "Cultural depictions of Chuck Norris": "تصوير ثقافي عن تشاك نوريس",
    "Cultural depictions of Cicero": "تصوير ثقافي عن شيشرون",
    "Cultural depictions of classical musicians": "تصوير ثقافي عن موسيقيون كلاسيكيون",
    "Cultural depictions of Claude Monet": "تصوير ثقافي عن كلود مونيه",
    "Cultural depictions of Claudius": "تصوير ثقافي عن كلوديوس",
    "Cultural depictions of Cleopatra": "تصوير ثقافي عن كليوباترا السابعة",
    "Cultural depictions of Clint Eastwood": "تصوير ثقافي عن كلينت إيستوود",
    "Cultural depictions of Cnut": "تصوير ثقافي عن كانوت العظيم",
    "Cultural depictions of Cole Porter": "تصوير ثقافي عن كول بورتر",
    "Cultural depictions of Commodus": "تصوير ثقافي عن كومودوس",
    "Cultural depictions of Confucius": "تصوير ثقافي عن كونفوشيوس",
    "Cultural depictions of Constantine the Great": "تصوير ثقافي عن قسطنطين الأول",
    "Cultural depictions of Corazon Aquino": "تصوير ثقافي عن كورازون أكينو",
    "Cultural depictions of country musicians": "تصوير ثقافي عن موسيقيو كانتري",
    "Cultural depictions of cricketers": "تصوير ثقافي عن لاعبو كريكت",
    "Cultural depictions of Croatian people": "تصوير ثقافي عن كروات",
    "Cultural depictions of C. S. Lewis": "تصوير ثقافي عن سي. إس. لويس",
    "Cultural depictions of cue sports players": "تصوير ثقافي عن لاعبو بلياردو",
    "Cultural depictions of cyclists": "تصوير ثقافي عن دراجون",
    "Cultural depictions of Cyrus the Great": "تصوير ثقافي عن كورش الكبير",
    "Cultural depictions of Dalida": "تصوير ثقافي عن داليدا",
    "Cultural depictions of dance musicians": "تصوير ثقافي عن موسيقيو رقص",
    "Cultural depictions of dancers": "تصوير ثقافي عن راقصون",
    "Cultural depictions of Daniel Boone": "تصوير ثقافي عن دانيال بون",
    "Cultural depictions of Dante Alighieri": "تصوير ثقافي عن دانتي أليغييري",
    "Cultural depictions of Darius the Great": "تصوير ثقافي عن دارا الأول",
    "Cultural depictions of David Beckham": "تصوير ثقافي عن ديفيد بيكهام",
    "Cultural depictions of David Ben-Gurion": "تصوير ثقافي عن دافيد بن غوريون",
    "Cultural depictions of David Berkowitz": "تصوير ثقافي عن ديفيد بيركويتز",
    "Cultural depictions of David Bowie": "تصوير ثقافي عن ديفيد بوي",
    "Cultural depictions of David Cameron": "تصوير ثقافي عن ديفيد كاميرون",
    "Cultural depictions of David Garrick": "تصوير ثقافي عن دايفيد جاريك",
    "Cultural depictions of David Livingstone": "تصوير ثقافي عن ديفيد ليفينغستون",
    "Cultural depictions of David Lloyd George": "تصوير ثقافي عن ديفيد لويد جورج",
    "Cultural depictions of Davy Crockett": "تصوير ثقافي عن ديفي كروكيت",
    "Cultural depictions of Democratic Republic of the Congo people": "تصوير ثقافي عن كونغويون ديمقراطيون",
    "Cultural depictions of Deng Xiaoping": "تصوير ثقافي عن دينج شياو بينج",
    "Cultural depictions of dentists": "تصوير ثقافي عن أطباء أسنان",
    "Cultural depictions of D. H. Lawrence": "تصوير ثقافي عن ديفيد هربرت لورانس",
    "Cultural depictions of Diana, Princess of Wales": "تصوير ثقافي عن ديانا أميرة ويلز",
    "Cultural depictions of Dick Cheney": "تصوير ثقافي عن ديك تشيني",
    "Cultural depictions of Diego Maradona": "تصوير ثقافي عن دييغو مارادونا",
    "Cultural depictions of Diocletian": "تصوير ثقافي عن دقلديانوس",
    "Cultural depictions of Diogenes": "تصوير ثقافي عن ديوجانس الكلبي",
    "Cultural depictions of Dmitry Medvedev": "تصوير ثقافي عن دميتري ميدفيديف",
    "Cultural depictions of Dolly Parton": "تصوير ثقافي عن دوللي بارتون",
    "Cultural depictions of Domitian": "تصوير ثقافي عن دومطيانوس",
    "Cultural depictions of Donald Trump": "تصوير ثقافي عن دونالد ترمب",
    "Cultural depictions of Don Bradman": "تصوير ثقافي عن دونالد برادمان",
    "Cultural depictions of Douglas Haig, 1st Earl Haig": "تصوير ثقافي عن دوغلاس هيج",
    "Cultural depictions of Douglas MacArthur": "تصوير ثقافي عن دوغلاس ماكارثر",
    "Cultural depictions of dramatists and playwrights": "تصوير ثقافي عن كتاب دراما ومسرح",
    "Cultural depictions of Duke Ellington": "تصوير ثقافي عن ديوك إلينغتون",
    "Cultural depictions of dukes": "تصوير ثقافي عن دوقات",
    "Cultural depictions of Dutch monarchs": "تصوير ثقافي عن ملكيون هولنديون",
    "Cultural depictions of Dwight D. Eisenhower": "تصوير ثقافي عن دوايت أيزنهاور",
    "Cultural depictions of Dylan Thomas": "تصوير ثقافي عن ديلان توماس",
    "Cultural depictions of Éamon de Valera": "تصوير ثقافي عن إيمون دي فاليرا",
    "Cultural depictions of Eddy Merckx": "تصوير ثقافي عن إيدي ميركس",
    "Cultural depictions of Edgar Allan Poe": "تصوير ثقافي عن إدغار آلان بو",
    "Cultural depictions of Edgar Degas": "تصوير ثقافي عن إدغار ديغا",
    "Cultural depictions of Edgar Rice Burroughs": "تصوير ثقافي عن إدغار رايس بوروس",
    "Cultural depictions of Édith Piaf": "تصوير ثقافي عن إديث بياف",
    "Cultural depictions of Édouard Manet": "تصوير ثقافي عن إدوارد مانيه",
    "Cultural depictions of educators": "تصوير ثقافي عن معلمون",
    "Cultural depictions of Edvard Munch": "تصوير ثقافي عن إدفارت مونك",
    "Cultural depictions of Edward Heath": "تصوير ثقافي عن إدوارد هيث",
    "Cultural depictions of Edward III of England": "تصوير ثقافي عن إدوارد الثالث ملك إنجلترا",
    "Cultural depictions of Edward II of England": "تصوير ثقافي عن إدوارد الثاني ملك إنجلترا",
    "Cultural depictions of Edward I of England": "تصوير ثقافي عن إدوارد الأول ملك إنجلترا",
    "Cultural depictions of Edward IV": "تصوير ثقافي عن إدوارد الرابع ملك إنجلترا",
    "Cultural depictions of Edward Snowden": "تصوير ثقافي عن إدوارد سنودن",
    "Cultural depictions of Edward V": "تصوير ثقافي عن إدوارد الخامس",
    "Cultural depictions of Edward VI": "تصوير ثقافي عن إدوارد السادس",
    "Cultural depictions of Edward VII": "تصوير ثقافي عن إدوارد السابع ملك المملكة المتحدة",
    "Cultural depictions of Egyptian monarchs": "تصوير ثقافي عن ملكيون مصريون",
    "Cultural depictions of Elagabalus": "تصوير ثقافي عن إيل جبل",
    "Cultural depictions of El Cid": "تصوير ثقافي عن إل سيد",
    "Cultural depictions of Eleanor of Aquitaine": "تصوير ثقافي عن إليانور آكيتيان",
    "Cultural depictions of Eleanor Roosevelt": "تصوير ثقافي عن إليانور روزفلت",
    "Cultural depictions of El Greco": "تصوير ثقافي عن إل غريكو",
    "Cultural depictions of Elizabeth I": "تصوير ثقافي عن إليزابيث الأولى ملكة إنجلترا",
    "Cultural depictions of Elizabeth II": "تصوير ثقافي عن إليزابيث الثانية",
    "Cultural depictions of Elizabeth of Russia": "تصوير ثقافي عن إليزابيث إمبراطورة روسيا",
    "Cultural depictions of Elizabeth Taylor": "تصوير ثقافي عن إليزابيث تايلور",
    "Cultural depictions of Elton John": "تصوير ثقافي عن إلتون جون",
    "Cultural depictions of Elvis Presley": "تصوير ثقافي عن إلفيس بريسلي",
    "Cultural depictions of Émile Zola": "تصوير ثقافي عن إميل زولا",
    "Cultural depictions of Emilio Aguinaldo": "تصوير ثقافي عن إميليو أغينالدو",
    "Cultural depictions of Emily Dickinson": "تصوير ثقافي عن إيميلي ديكنسون",
    "Cultural depictions of Emir Kusturica": "تصوير ثقافي عن أمير كوستوريتسا",
    "Cultural depictions of Emmeline Pankhurst": "تصوير ثقافي عن إميلين بانكيرست",
    "Cultural depictions of Emperor Taizong of Tang": "تصوير ثقافي عن الإمبراطور تايزونج",
    "Cultural depictions of Empress Elisabeth of Austria": "تصوير ثقافي عن إليزابيث إمبراطورة النمسا",
    "Cultural depictions of engineers": "تصوير ثقافي عن مهندسون",
    "Cultural depictions of English monarchs": "تصوير ثقافي عن ملكيون إنجليز",
    "Cultural depictions of English people": "تصوير ثقافي عن إنجليز",
    "Cultural depictions of Enrico Caruso": "تصوير ثقافي عن إنريكو كاروسو",
    "Cultural depictions of Ernest Hemingway": "تصوير ثقافي عن إرنست همينغوي",
    "Cultural depictions of Erwin Rommel": "تصوير ثقافي عن إرفين رومل",
    "Cultural depictions of Estonian people": "تصوير ثقافي عن إستونيون",
    "Cultural depictions of Eva Perón": "تصوير ثقافي عن إيفا بيرون",
    "Cultural depictions of Ezra Pound": "تصوير ثقافي عن عزرا باوند",
    "Cultural depictions of fashion designers": "تصوير ثقافي عن مصممو أزياء",
    "Cultural depictions of Federico García Lorca": "تصوير ثقافي عن فيديريكو غارثيا لوركا",
    "Cultural depictions of Fela Kuti": "تصوير ثقافي عن فيلا كوتي",
    "Cultural depictions of female monarchs": "تصوير ثقافي عن ملكيات",
    "Cultural depictions of Ferdinand II of Aragon": "تصوير ثقافي عن فرناندو الثاني ملك أرغون",
    "Cultural depictions of Ferdinand Marcos": "تصوير ثقافي عن فرديناند ماركوس",
    "Cultural depictions of Fidel Castro": "تصوير ثقافي عن فيدل كاسترو",
    "Cultural depictions of Fidel V. Ramos": "تصوير ثقافي عن فيديل فالديس راموس",
    "Cultural depictions of figure skaters": "تصوير ثقافي عن متزلجون فنيون",
    "Cultural depictions of film directors": "تصوير ثقافي عن مخرجو أفلام",
    "Cultural depictions of Finnish people": "تصوير ثقافي عن فنلنديون",
    "Cultural depictions of first ladies of the United States": "تصوير ثقافي عن السيدات الأولى في الولايات المتحدة",
    "Cultural depictions of Florence Nightingale": "تصوير ثقافي عن فلورنس نايتينجيل",
    "Cultural depictions of folk musicians": "تصوير ثقافي عن موسيقيو فولك",
    "Cultural depictions of Francisco Franco": "تصوير ثقافي عن فرانثيسكو فرانكو",
    "Cultural depictions of Francisco Goya": "تصوير ثقافي عن فرانثيسكو غويا",
    "Cultural depictions of Francis Drake": "تصوير ثقافي عن فرنسيس دريك",
    "Cultural depictions of Francis I of France": "تصوير ثقافي عن فرانسوا الأول ملك فرنسا",
    "Cultural depictions of Francis of Assisi": "تصوير ثقافي عن فرنسيس الأسيزي",
    "Cultural depictions of François Villon": "تصوير ثقافي عن فرانسوا فيلون",
    "Cultural depictions of Franklin D. Roosevelt": "تصوير ثقافي عن فرانكلين د. روزفلت",
    "Cultural depictions of Frank Lloyd Wright": "تصوير ثقافي عن فرانك لويد رايت",
    "Cultural depictions of Frank Sinatra": "تصوير ثقافي عن فرانك سيناترا",
    "Cultural depictions of Frank Zappa": "تصوير ثقافي عن فرانك زابا",
    "Cultural depictions of Franz Joseph I of Austria": "تصوير ثقافي عن فرانتس يوزف الأول",
    "Cultural depictions of Franz Kafka": "تصوير ثقافي عن فرانس كافكا",
    "Cultural depictions of Franz Liszt": "تصوير ثقافي عن فرانز ليست",
    "Cultural depictions of Franz Schubert": "تصوير ثقافي عن فرانز شوبرت",
    "Cultural depictions of fraudsters": "تصوير ثقافي عن محتالون",
    "Cultural depictions of Fred Astaire": "تصوير ثقافي عن فريد أستير",
    "Cultural depictions of Freddie Mercury": "تصوير ثقافي عن فريدي ميركوري",
    "Cultural depictions of Frédéric Chopin": "تصوير ثقافي عن فريدريك شوبان",
    "Cultural depictions of Frederick Douglass": "تصوير ثقافي عن فريدريك دوغلاس",
    "Cultural depictions of Frederick the Great": "تصوير ثقافي عن فريدرش العظيم",
    "Cultural depictions of French monarchs": "تصوير ثقافي عن ملكيون فرنسيون",
    "Cultural depictions of Frida Kahlo": "تصوير ثقافي عن فريدا كاهلو",
    "Cultural depictions of Friedrich Nietzsche": "تصوير ثقافي عن فريدريك نيتشه",
    "Cultural depictions of Friedrich Schiller": "تصوير ثقافي عن فريدرش شيلر",
    "Cultural depictions of F. Scott Fitzgerald": "تصوير ثقافي عن فرنسيس سكوت فيتزجيرالد",
    "Cultural depictions of Gabriele D'Annunzio": "تصوير ثقافي عن غابرييل دانونزيو",
    "Cultural depictions of Galileo Galilei": "تصوير ثقافي عن غاليليو غاليلي",
    "Cultural depictions of Gamal Abdel Nasser": "تصوير ثقافي عن جمال عبد الناصر",
    "Cultural depictions of Gautama Buddha": "تصوير ثقافي عن غوتاما بودا",
    "Cultural depictions of Genghis Khan": "تصوير ثقافي عن جنكيز خان",
    "Cultural depictions of George Armstrong Custer": "تصوير ثقافي عن جورج أرمسترونغ كاستر",
    "Cultural depictions of George Bernard Shaw": "تصوير ثقافي عن جورج برنارد شو",
    "Cultural depictions of George Frideric Handel": "تصوير ثقافي عن جورج فريدريك هاندل",
    "Cultural depictions of George H. W. Bush": "تصوير ثقافي عن جورج بوش الأب",
    "Cultural depictions of George III": "تصوير ثقافي عن جورج الثالث ملك المملكة المتحدة",
    "Cultural depictions of George II of Great Britain": "تصوير ثقافي عن جورج الثاني ملك بريطانيا العظمى",
    "Cultural depictions of George I of Great Britain": "تصوير ثقافي عن جورج الأول ملك بريطانيا العظمى",
    "Cultural depictions of George IV": "تصوير ثقافي عن جورج الرابع ملك المملكة المتحدة",
    "Cultural depictions of George Lucas": "تصوير ثقافي عن لوكاس جورج",
    "Cultural depictions of George Orwell": "تصوير ثقافي عن جورج أورويل",
    "Cultural depictions of Georges Clemenceau": "تصوير ثقافي عن جورج كليمانصو",
    "Cultural depictions of Georges Danton": "تصوير ثقافي عن جورج دانتون",
    "Cultural depictions of Georges Méliès": "تصوير ثقافي عن جورج ميلييس",
    "Cultural depictions of George S. Patton": "تصوير ثقافي عن جورج باتون",
    "Cultural depictions of George V": "تصوير ثقافي عن جورج الخامس ملك المملكة المتحدة",
    "Cultural depictions of George VI": "تصوير ثقافي عن جورج السادس ملك المملكة المتحدة",
    "Cultural depictions of George Washington": "تصوير ثقافي عن جورج واشنطن",
    "Cultural depictions of George W. Bush": "تصوير ثقافي عن جورج بوش الابن",
    "Cultural depictions of Gerald Ford": "تصوير ثقافي عن جيرالد فورد",
    "Cultural depictions of Germanicus": "تصوير ثقافي عن جرمانيقوس",
    "Cultural depictions of German monarchs": "تصوير ثقافي عن ملكيون ألمان",
    "Cultural depictions of German people": "تصوير ثقافي عن ألمان",
    "Cultural depictions of Geronimo": "تصوير ثقافي عن جيرانيمو",
    "Cultural depictions of Gertrude Stein": "تصوير ثقافي عن جيرترود شتاين",
    "Cultural depictions of Giacomo Casanova": "تصوير ثقافي عن جاكومو كازانوفا",
    "Cultural depictions of Gilbert du Motier, Marquis de Lafayette": "تصوير ثقافي عن ماركيس دي لافاييت",
    "Cultural depictions of Giordano Bruno": "تصوير ثقافي عن جوردانو برونو",
    "Cultural depictions of Girolamo Savonarola": "تصوير ثقافي عن سافونارولا",
    "Cultural depictions of Giuseppe Garibaldi": "تصوير ثقافي عن جوزيبي غاريبالدي",
    "Cultural depictions of Giuseppe Verdi": "تصوير ثقافي عن جيوسيبي فيردي",
    "Cultural depictions of Gloria Macapagal Arroyo": "تصوير ثقافي عن غلوريا ماكاباغال أرويو",
    "Cultural depictions of golfers": "تصوير ثقافي عن لاعبو غولف",
    "Cultural depictions of Gordon Brown": "تصوير ثقافي عن جوردون براون",
    "Cultural depictions of governors-general of the Philippines": "تصوير ثقافي عن حكام عموم الفلبين",
    "Cultural depictions of Grace Kelly": "تصوير ثقافي عن غريس كيلي",
    "Cultural depictions of Grand Duchess Anastasia Nikolaevna of Russia": "تصوير ثقافي عن الدوقة الكبرى أناستاسيا نيكولايفنا من روسيا",
    "Cultural depictions of Grigori Rasputin": "تصوير ثقافي عن غريغوري راسبوتين",
    "Cultural depictions of Grover Cleveland": "تصوير ثقافي عن غروفر كليفلاند",
    "Cultural depictions of Guglielmo Marconi": "تصوير ثقافي عن غولييلمو ماركوني",
    "Cultural depictions of Gustav III": "تصوير ثقافي عن غوستاف الثالث",
    "Cultural depictions of Gustavus Adolphus": "تصوير ثقافي عن غوستاف الثاني أدولف",
    "Cultural depictions of Guy Fawkes": "تصوير ثقافي عن جاي فوكس",
    "Cultural depictions of gymnasts": "تصوير ثقافي عن لاعبو جمباز",
    "Cultural depictions of Hadrian": "تصوير ثقافي عن هادريان",
    "Cultural depictions of Haile Selassie": "تصوير ثقافي عن هيلا سيلاسي",
    "Cultural depictions of Haitian people": "تصوير ثقافي عن هايتيون",
    "Cultural depictions of Hank Williams": "تصوير ثقافي عن هانك ويليامز",
    "Cultural depictions of Hannibal": "تصوير ثقافي عن حنبعل",
    "Cultural depictions of Hans Christian Andersen": "تصوير ثقافي عن هانس كريستيان أندرسن",
    "Cultural depictions of Harold Wilson": "تصوير ثقافي عن هارولد ويلسون",
    "Cultural depictions of Harriet Tubman": "تصوير ثقافي عن هاريت توبمان",
    "Cultural depictions of Harry Houdini": "تصوير ثقافي عن هاري هوديني",
    "Cultural depictions of Harry S. Truman": "تصوير ثقافي عن هاري ترومان",
    "Cultural depictions of Harun al-Rashid": "تصوير ثقافي عن هارون الرشيد",
    "Cultural depictions of Hatshepsut": "تصوير ثقافي عن حتشبسوت",
    "Cultural depictions of Heinrich Himmler": "تصوير ثقافي عن هاينريش هيملر",
    "Cultural depictions of Helen Keller": "تصوير ثقافي عن هيلين كيلر",
    "Cultural depictions of Henri de Toulouse-Lautrec": "تصوير ثقافي عن أنري تولوز لوترك",
    "Cultural depictions of Henrik Ibsen": "تصوير ثقافي عن هنريك إبسن",
    "Cultural depictions of Henri Matisse": "تصوير ثقافي عن هنري ماتيس",
    "Cultural depictions of Henry Ford": "تصوير ثقافي عن هنري فورد",
    "Cultural depictions of Henry III of England": "تصوير ثقافي عن هنري الثالث ملك إنجلترا",
    "Cultural depictions of Henry III of France": "تصوير ثقافي عن هنري الثالث ملك فرنسا",
    "Cultural depictions of Henry II of England": "تصوير ثقافي عن هنري الثاني ملك إنجلترا",
    "Cultural depictions of Henry IV of England": "تصوير ثقافي عن هنري الرابع ملك إنجلترا",
    "Cultural depictions of Henry IV of France": "تصوير ثقافي عن هنري الرابع ملك فرنسا",
    "Cultural depictions of Henry Kissinger": "تصوير ثقافي عن هنري كسنجر",
    "Cultural depictions of Henry Morton Stanley": "تصوير ثقافي عن هنري مورتون ستانلي",
    "Cultural depictions of Henry VIII": "تصوير ثقافي عن هنري الثامن ملك إنجلترا",
    "Cultural depictions of Henry VII of England": "تصوير ثقافي عن هنري السابع ملك إنجلترا",
    "Cultural depictions of Henry VI of England": "تصوير ثقافي عن هنري السادس ملك إنجلترا",
    "Cultural depictions of Henry V of England": "تصوير ثقافي عن هنري الخامس ملك إنجلترا",
    "Cultural depictions of Herbert Hoover": "تصوير ثقافي عن هربرت هوفر",
    "Cultural depictions of Hermann Göring": "تصوير ثقافي عن هيرمان غورينغ",
    "Cultural depictions of Herod the Great": "تصوير ثقافي عن هيرودس الأول",
    "Cultural depictions of H. G. Wells": "تصوير ثقافي عن جورج ويلز",
    "Cultural depictions of Hideki Tojo": "تصوير ثقافي عن هيديكي توجو",
    "Cultural depictions of Hillary Clinton": "تصوير ثقافي عن هيلاري كلينتون",
    "Cultural depictions of hip-hop musicians": "تصوير ثقافي عن موسيقيو هيب هوب",
    "Cultural depictions of Hirohito": "تصوير ثقافي عن هيروهيتو",
    "Cultural depictions of Honoré de Balzac": "تصوير ثقافي عن أونوريه دي بلزاك",
    "Cultural depictions of Horatio Nelson": "تصوير ثقافي عن هوراشيو نيلسون",
    "Cultural depictions of Howard Hughes": "تصوير ثقافي عن هاوارد هيوز",
    "Cultural depictions of Hulk Hogan": "تصوير ثقافي عن هولك هوجان",
    "Cultural depictions of Hungarian monarchs": "تصوير ثقافي عن ملكيون مجريون",
    "Cultural depictions of Husayn ibn Ali": "تصوير ثقافي عن الحسين بن علي",
    "Cultural depictions of Hypatia": "تصوير ثقافي عن هيباتيا",
    "Cultural depictions of ice hockey players": "تصوير ثقافي عن لاعبو هوكي جليد",
    "Cultural depictions of Icelandic people": "تصوير ثقافي عن آيسلنديون",
    "Cultural depictions of Idi Amin": "تصوير ثقافي عن عيدي أمين",
    "Cultural depictions of Igor Stravinsky": "تصوير ثقافي عن إيغور سترافينسكي",
    "Cultural depictions of Imran Khan": "تصوير ثقافي عن عمران خان",
    "Cultural depictions of Indian people": "تصوير ثقافي عن هنود",
    "Cultural depictions of Indira Gandhi": "تصوير ثقافي عن أنديرا غاندي",
    "Cultural depictions of Indonesian people": "تصوير ثقافي عن إندونيسيون",
    "Cultural depictions of inventors": "تصوير ثقافي عن مخترعون",
    "Cultural depictions of Irene of Athens": "تصوير ثقافي عن أيرين أثينا",
    "Cultural depictions of Isaac Newton": "تصوير ثقافي عن إسحاق نيوتن",
    "Cultural depictions of Isabella I of Castile": "تصوير ثقافي عن إيزابيلا الأولى ملكة قشتالة",
    "Cultural depictions of Ivan the Terrible": "تصوير ثقافي عن إيفان الرابع",
    "Cultural depictions of Jack Dempsey": "تصوير ثقافي عن جاك دمبسي",
    "Cultural depictions of Jackie Chan": "تصوير ثقافي عن جاكي شان",
    "Cultural depictions of Jackie Robinson": "تصوير ثقافي عن جاكي روبينسون",
    "Cultural depictions of Jack Nicklaus": "تصوير ثقافي عن جاك نيكولاس",
    "Cultural depictions of Jack the Ripper": "تصوير ثقافي عن جاك السفاح",
    "Cultural depictions of Jacqueline Kennedy Onassis": "تصوير ثقافي عن جاكلين كينيدي",
    "Cultural depictions of Jacques Brel": "تصوير ثقافي عن جاك بريل",
    "Cultural depictions of Jacques Cousteau": "تصوير ثقافي عن جاك إيف كوستو",
    "Cultural depictions of Jamaican people": "تصوير ثقافي عن جامايكيون",
    "Cultural depictions of James A. Garfield": "تصوير ثقافي عن جيمس جارفيلد",
    "Cultural depictions of James Brown": "تصوير ثقافي عن جيمس براون",
    "Cultural depictions of James Buchanan": "تصوير ثقافي عن جيمس بيوكانان",
    "Cultural depictions of James Cook": "تصوير ثقافي عن جيمس كوك",
    "Cultural depictions of James Dean": "تصوير ثقافي عن جيمس دين",
    "Cultural depictions of James Francis Edward Stuart": "تصوير ثقافي عن جيمس فرانسيس إدوارد ستيوارت",
    "Cultural depictions of James II of England": "تصوير ثقافي عن جيمس الثاني ملك إنجلترا",
    "Cultural depictions of James Madison": "تصوير ثقافي عن جيمس ماديسون",
    "Cultural depictions of James Monroe": "تصوير ثقافي عن جيمس مونرو",
    "Cultural depictions of James V": "تصوير ثقافي عن جيمس الخامس ملك إسكتلندا",
    "Cultural depictions of James VI and I": "تصوير ثقافي عن جيمس الأول ملك إنجلترا",
    "Cultural depictions of Jane Austen": "تصوير ثقافي عن جاين أوستن",
    "Cultural depictions of Jane Seymour": "تصوير ثقافي عن جين سيمور",
    "Cultural depictions of Jan Hus": "تصوير ثقافي عن يان هوس",
    "Cultural depictions of Janis Joplin": "تصوير ثقافي عن جانيس جوبلين",
    "Cultural depictions of Jan Žižka": "تصوير ثقافي عن يان جيجكا",
    "Cultural depictions of Jawaharlal Nehru": "تصوير ثقافي عن جواهر لال نهرو",
    "Cultural depictions of jazz musicians": "تصوير ثقافي عن موسيقيو جاز",
    "Cultural depictions of Jean-Paul Sartre": "تصوير ثقافي عن جون بول سارتر",
    "Cultural depictions of Jeffrey Dahmer": "تصوير ثقافي عن جيفري دامر",
    "Cultural depictions of Jenny Lind": "تصوير ثقافي عن جيني ليند",
    "Cultural depictions of Jerome": "تصوير ثقافي عن جيروم",
    "Cultural depictions of Jesse James": "تصوير ثقافي عن جيسي جيمس",
    "Cultural depictions of Jesse Owens": "تصوير ثقافي عن جيسي أوينز",
    "Cultural depictions of Jessica Alba": "تصوير ثقافي عن جيسيكا ألبا",
    "Cultural depictions of Jesus": "تصوير ثقافي عن يسوع",
    "Cultural depictions of Jimi Hendrix": "تصوير ثقافي عن جيمي هندريكس",
    "Cultural depictions of Jimmy Carter": "تصوير ثقافي عن جيمي كارتر",
    "Cultural depictions of J. M. Barrie": "تصوير ثقافي عن جيمس ماثيو باري",
    "Cultural depictions of J. M. W. Turner": "تصوير ثقافي عن تيرنر",
    "Cultural depictions of Joan Crawford": "تصوير ثقافي عن جوان كراوفورد",
    "Cultural depictions of Joanna of Castile": "خوانا الأولى",
    "Cultural depictions of Joan of Arc": "تصوير ثقافي عن جان دارك",
    "Cultural depictions of Joe Biden": "تصوير ثقافي عن جو بايدن",
    "Cultural depictions of Joe Louis": "تصوير ثقافي عن جو لويس",
    "Cultural depictions of Johannes Gutenberg": "تصوير ثقافي عن يوهان غوتنبرغ",
    "Cultural depictions of Johannes Kepler": "تصوير ثقافي عن يوهانس كبلر",
    "Cultural depictions of Johannes Vermeer": "تصوير ثقافي عن يوهانس فيرمير",
    "Cultural depictions of Johann Sebastian Bach": "تصوير ثقافي عن يوهان سباستيان باخ",
    "Cultural depictions of Johann Strauss II": "تصوير ثقافي عن يوهان شتراوس الابن",
    "Cultural depictions of Johann Wolfgang von Goethe": "تصوير ثقافي عن يوهان فولفغانغ فون غوته",
    "Cultural depictions of John Adams": "تصوير ثقافي عن جون آدامز",
    "Cultural depictions of John A. Macdonald": "تصوير ثقافي عن جون ماكدونالد",
    "Cultural depictions of John Brown (abolitionist)": "تصوير ثقافي عن جون براون",
    "Cultural depictions of John Dillinger": "تصوير ثقافي عن جون ديلينجر",
    "Cultural depictions of John F. Kennedy": "تصوير ثقافي عن جون كينيدي",
    "Cultural depictions of John, King of England": "تصوير ثقافي عن جون ملك إنجلترا",
    "Cultural depictions of John Lennon": "تصوير ثقافي عن جون لينون",
    "Cultural depictions of John Major": "تصوير ثقافي عن جون ميجر",
    "Cultural depictions of Johnny Cash": "تصوير ثقافي عن جوني كاش",
    "Cultural depictions of John Quincy Adams": "تصوير ثقافي عن جون كوينسي آدامز",
    "Cultural depictions of John Travolta": "تصوير ثقافي عن جون ترافولتا",
    "Cultural depictions of John Wayne Gacy": "تصوير ثقافي عن جون واين جسي",
    "Cultural depictions of José de San Martín": "تصوير ثقافي عن خوسيه دي سان مارتين",
    "Cultural depictions of Joseph Goebbels": "تصوير ثقافي عن يوزف غوبلز",
    "Cultural depictions of Joseph Smith": "تصوير ثقافي عن جوزيف سميث",
    "Cultural depictions of Joseph Stalin": "تصوير ثقافي عن يوسف ستالين",
    "Cultural depictions of José Rizal": "تصوير ثقافي عن خوسيه ريزال",
    "Cultural depictions of Josip Broz Tito": "تصوير ثقافي عن جوزيف بروز تيتو",
    "Cultural depictions of J. Robert Oppenheimer": "تصوير ثقافي عن روبرت أوبنهايمر",
    "Cultural depictions of J. R. R. Tolkien": "تصوير ثقافي عن جون ر. تولكين",
    "Cultural depictions of Juan Perón": "تصوير ثقافي عن خوان بيرون",
    "Cultural depictions of Judas Iscariot": "تصوير ثقافي عن يهوذا الإسخريوطي",
    "Cultural depictions of judges": "تصوير ثقافي عن قضاة",
    "Cultural depictions of Judy Garland": "تصوير ثقافي عن جودي غارلند",
    "Cultural depictions of Jules Verne": "تصوير ثقافي عن جول فيرن",
    "Cultural depictions of Julian Assange": "تصوير ثقافي عن جوليان أسانج",
    "Cultural depictions of Julian (emperor)": "تصوير ثقافي عن يوليان المرتد",
    "Cultural depictions of Julius Caesar": "تصوير ثقافي عن يوليوس قيصر",
    "Cultural depictions of Justinian I": "تصوير ثقافي عن جستينيان الأول",
    "Cultural depictions of Justin Trudeau": "تصوير ثقافي عن جاستن ترودو",
    "Cultural depictions of Kamala Harris": "تصوير ثقافي عن كامالا هاريس",
    "Cultural depictions of Kanye West": "تصوير ثقافي عن كانييه ويست",
    "Cultural depictions of Karen Blixen": "تصوير ثقافي عن كارين بلكسين",
    "Cultural depictions of Karl Marx": "تصوير ثقافي عن كارل ماركس",
    "Cultural depictions of Katharine Hepburn": "تصوير ثقافي عن كاثرين هيبورن",
    "Cultural depictions of Kazi Nazrul Islam": "تصوير ثقافي عن نذر الإسلام",
    "Cultural depictions of Khufu": "تصوير ثقافي عن خوفو",
    "Cultural depictions of Kim Jong Il": "تصوير ثقافي عن كيم جونغ إل",
    "Cultural depictions of Kim Jong Un": "تصوير ثقافي عن كم جونغ أون",
    "Cultural depictions of kings": "تصوير ثقافي عن ملوك",
    "Cultural depictions of Korean people": "تصوير ثقافي عن كوريون",
    "Cultural depictions of Kublai Khan": "تصوير ثقافي عن قوبلاي خان",
    "Cultural depictions of Kurt Cobain": "تصوير ثقافي عن كيرت كوبين",
    "Cultural depictions of Kylie Minogue": "تصوير ثقافي عن كايلي مينوغ",
    "Cultural depictions of Lady Gaga": "تصوير ثقافي عن ليدي غاغا",
    "Cultural depictions of Lady Godiva": "تصوير ثقافي عن ليدي غوديفا",
    "Cultural depictions of Lady Jane Grey": "تصوير ثقافي عن ليدي جين غراي",
    "Cultural depictions of Laozi": "تصوير ثقافي عن لاوتزه",
    "Cultural depictions of Lavrentiy Beria": "تصوير ثقافي عن لافرينتي بيريا",
    "Cultural depictions of lawyers": "تصوير ثقافي عن محامون",
    "Cultural depictions of Lech Wałęsa": "تصوير ثقافي عن ليخ فاونسا",
    "Cultural depictions of Leif Erikson": "تصوير ثقافي عن ليف إريكسون",
    "Cultural depictions of Leni Riefenstahl": "تصوير ثقافي عن ليني ريفنستال",
    "Cultural depictions of Lenny Bruce": "تصوير ثقافي عن ليني بروس",
    "Cultural depictions of Leonard Nimoy": "تصوير ثقافي عن ليونارد نيموي",
    "Cultural depictions of Leonardo da Vinci": "تصوير ثقافي عن ليوناردو دا فينشي",
    "Cultural depictions of Leonid Brezhnev": "تصوير ثقافي عن ليونيد بريجنيف",
    "Cultural depictions of Leon Trotsky": "تصوير ثقافي عن ليون تروتسكي",
    "Cultural depictions of Leo Tolstoy": "تصوير ثقافي عن ليو تولستوي",
    "Cultural depictions of Lewis Carroll": "تصوير ثقافي عن لويس كارول",
    "Cultural depictions of Lionel Messi": "تصوير ثقافي عن ليونيل ميسي",
    "Cultural depictions of Livia": "تصوير ثقافي عن ليفيا دروسيلا",
    "Cultural depictions of Lizzie Borden": "تصوير ثقافي عن ليزي بوردن",
    "Cultural depictions of Lord Byron": "تصوير ثقافي عن لورد بايرون",
    "Cultural depictions of lords": "تصوير ثقافي عن لوردات",
    "Cultural depictions of Louis Armstrong": "تصوير ثقافي عن لويس أرمسترونغ",
    "Cultural depictions of Louis-Ferdinand Céline": "تصوير ثقافي عن لويس-فرديناند سيلين",
    "Cultural depictions of Louis Pasteur": "تصوير ثقافي عن لويس باستور",
    "Cultural depictions of Louis Riel": "تصوير ثقافي عن لويس رئيل",
    "Cultural depictions of Louis VIII of France": "تصوير ثقافي عن لويس الثامن ملك فرنسا",
    "Cultural depictions of Louis XIII": "تصوير ثقافي عن لويس الثالث عشر ملك فرنسا",
    "Cultural depictions of Louis XIV": "تصوير ثقافي عن لويس الرابع عشر ملك فرنسا",
    "Cultural depictions of Louis XV": "تصوير ثقافي عن لويس الخامس عشر ملك فرنسا",
    "Cultural depictions of Louis XVI": "تصوير ثقافي عن لويس السادس عشر ملك فرنسا في فرنسا",
    "Cultural depictions of Luciano Pavarotti": "تصوير ثقافي عن لوتشانو بافاروتي",
    "Cultural depictions of Lucrezia Borgia": "تصوير ثقافي عن لوكريسيا بورجيا",
    "Cultural depictions of Ludvig Holberg": "تصوير ثقافي عن لودفيغ هولبرغ",
    "Cultural depictions of Ludwig II of Bavaria": "تصوير ثقافي عن لودفيك الثاني",
    "Cultural depictions of Ludwig van Beethoven": "تصوير ثقافي عن لودفيج فان بيتهوفن",
    "Cultural depictions of Luis Buñuel": "تصوير ثقافي عن لويس بونويل",
    "Cultural depictions of Lyndon B. Johnson": "تصوير ثقافي عن ليندون جونسون",
    "Cultural depictions of Madonna": "تصوير ثقافي عن مادونا (مغنية)",
    "Cultural depictions of Mae West": "تصوير ثقافي عن ماي وست",
    "Cultural depictions of Mahatma Gandhi": "تصوير ثقافي عن مهاتما غاندي",
    "Cultural depictions of Malaysian people": "تصوير ثقافي عن ماليزيون",
    "Cultural depictions of Malcolm X": "تصوير ثقافي عن مالكوم إكس",
    "Cultural depictions of Manfred von Richthofen": "تصوير ثقافي عن مانفرد فون ريشتهوفن",
    "Cultural depictions of Manmohan Singh": "تصوير ثقافي عن مانموهان سينغ",
    "Cultural depictions of Mao Zedong": "تصوير ثقافي عن ماو تسي تونغ",
    "Cultural depictions of Marcel Proust": "تصوير ثقافي عن مارسيل بروست",
    "Cultural depictions of Marco Polo": "تصوير ثقافي عن ماركو بولو",
    "Cultural depictions of Marcus Aurelius": "تصوير ثقافي عن ماركوس أوريليوس",
    "Cultural depictions of Marcus Junius Brutus": "تصوير ثقافي عن بروتس",
    "Cultural depictions of Margaret Thatcher": "تصوير ثقافي عن مارغريت ثاتشر",
    "Cultural depictions of Marie Antoinette": "تصوير ثقافي عن ماري أنطوانيت",
    "Cultural depictions of Marie Curie": "تصوير ثقافي عن ماري كوري",
    "Cultural depictions of Marilyn Monroe": "تصوير ثقافي عن مارلين مونرو",
    "Cultural depictions of Mark Antony": "تصوير ثقافي عن مارك أنطوني",
    "Cultural depictions of Mark Twain": "تصوير ثقافي عن مارك توين",
    "Cultural depictions of Mark Wahlberg": "تصوير ثقافي عن مارك والبيرغ",
    "Cultural depictions of Marlon Brando": "تصوير ثقافي عن مارلون براندو",
    "Cultural depictions of martial artists": "تصوير ثقافي عن ممارسو فنون قتالية",
    "Cultural depictions of Martin Luther": "تصوير ثقافي عن مارتن لوثر",
    "Cultural depictions of Martin Luther King Jr.": "تصوير ثقافي عن مارتن لوثر كينغ الابن",
    "Cultural depictions of Martin Van Buren": "تصوير ثقافي عن مارتن فان بيورين",
    "Cultural depictions of Mary Boleyn": "تصوير ثقافي عن ماري بولين",
    "Cultural depictions of Mary II": "تصوير ثقافي عن ماري الثانية ملكة إنجلترا",
    "Cultural depictions of Mary I of England": "تصوير ثقافي عن ماري الأولى ملكة إنجلترا",
    "Cultural depictions of Mary-Kate and Ashley Olsen": "تصوير ثقافي عن التوأم أولسين",
    "Cultural depictions of Mary Magdalene": "تصوير ثقافي عن مريم المجدلية",
    "Cultural depictions of Mary of Teck": "تصوير ثقافي عن ماري تك",
    "Cultural depictions of Mary, Queen of Scots": "تصوير ثقافي عن ماري ملكة إسكتلندا",
    "Cultural depictions of Mary Shelley": "تصوير ثقافي عن ماري شيلي",
    "Cultural depictions of Maurice Chevalier": "تصوير ثقافي عن موريس شيفالييه",
    "Cultural depictions of Maximilian I of Mexico": "تصوير ثقافي عن ماكسيميليان إمبراطور المكسيك",
    "Cultural depictions of Maximilien Robespierre": "تصوير ثقافي عن ماكسميليان روبسبيار",
    "Cultural depictions of Meher Baba": "تصوير ثقافي عن مهير بابا",
    "Cultural depictions of Mehmed II": "تصوير ثقافي عن محمد الفاتح",
    "Cultural depictions of Mel Gibson": "تصوير ثقافي عن ميل غيبسون",
    "Cultural depictions of Menachem Begin": "تصوير ثقافي عن مناحم بيجن",
    "Cultural depictions of Michael Collins (astronaut)": "تصوير ثقافي عن مايكل كولينز (رائد فضاء)",
    "Cultural depictions of Michael Jackson": "تصوير ثقافي عن مايكل جاكسون",
    "Cultural depictions of Michael Jordan": "تصوير ثقافي عن مايكل جوردن",
    "Cultural depictions of Michael Moore": "تصوير ثقافي عن مايكل مور",
    "Cultural depictions of Michelangelo": "تصوير ثقافي عن مايكل أنجلو",
    "Cultural depictions of Miguel de Cervantes": "تصوير ثقافي عن ميغيل دي ثيربانتس",
    "Cultural depictions of Mike Tyson": "تصوير ثقافي عن مايك تايسون",
    "Cultural depictions of Mikhail Gorbachev": "تصوير ثقافي عن ميخائيل غورباتشوف",
    "Cultural depictions of Miley Cyrus": "تصوير ثقافي عن مايلي سايرس",
    "Cultural depictions of mistresses": "تصوير ثقافي عن عشيقات",
    "Cultural depictions of Miyamoto Musashi": "تصوير ثقافي عن مياموتو موساشي",
    "Cultural depictions of models": "تصوير ثقافي عن عارضو أزياء",
    "Cultural depictions of Molière": "تصوير ثقافي عن موليير",
    "Cultural depictions of Mother Teresa": "تصوير ثقافي عن الأم تريزا",
    "Cultural depictions of motorcycle racers": "تصوير ثقافي عن متسابقو دراجات نارية",
    "Cultural depictions of Mr. T": "تصوير ثقافي عن مستر تي",
    "Cultural depictions of Muammar Gaddafi": "تصوير ثقافي عن معمر القذافي",
    "Cultural depictions of Muhammad": "تصوير ثقافي عن محمد",
    "Cultural depictions of Muhammad Ali": "تصوير ثقافي عن محمد علي",
    "Cultural depictions of Muhammad Ali Jinnah": "تصوير ثقافي عن محمد علي جناح",
    "Cultural depictions of Mustafa Kemal Atatürk": "تصوير ثقافي عن مصطفى كمال أتاتورك",
    "Cultural depictions of Napoleon": "تصوير ثقافي عن نابليون",
    "Cultural depictions of Napoleon II": "تصوير ثقافي عن نابليون الثاني",
    "Cultural depictions of Napoleon III": "تصوير ثقافي عن نابليون الثالث",
    "Cultural depictions of Narendra Modi": "تصوير ثقافي عن ناريندرا مودي",
    "Cultural depictions of Nat Turner": "تصوير ثقافي عن نات ترنر",
    "Cultural depictions of Nebuchadnezzar II": "تصوير ثقافي عن نبوخذ نصر الثاني",
    "Cultural depictions of Nefertari": "تصوير ثقافي عن نفرتاري",
    "Cultural depictions of Nefertiti": "تصوير ثقافي عن نفرتيتي",
    "Cultural depictions of Neil Armstrong": "تصوير ثقافي عن نيل آرمسترونغ",
    "Cultural depictions of Nelson Mandela": "تصوير ثقافي عن نيلسون مانديلا",
    "Cultural depictions of Nepalese people": "تصوير ثقافي عن نيباليون",
    "Cultural depictions of Nero": "تصوير ثقافي عن نيرون",
    "Cultural depictions of Neville Chamberlain": "تصوير ثقافي عن نيفيل تشامبرلين",
    "Cultural depictions of Niccolò Machiavelli": "تصوير ثقافي عن نيكولو مكيافيلي",
    "Cultural depictions of Nicholas II of Russia": "تصوير ثقافي عن نيقولا الثاني",
    "Cultural depictions of Nicolae Ceaușescu": "تصوير ثقافي عن نيكولاي تشاوتشيسكو",
    "Cultural depictions of Nicolaus Copernicus": "تصوير ثقافي عن نيكولاس كوبرنيكوس",
    "Cultural depictions of Nigel Farage": "تصوير ثقافي عن نايغل فاريج",
    "Cultural depictions of Nigerian people": "تصوير ثقافي عن نيجيريون",
    "Cultural depictions of Nikita Khrushchev": "تصوير ثقافي عن نيكيتا خروتشوف",
    "Cultural depictions of Nikola Tesla": "تصوير ثقافي عن نيكولا تسلا",
    "Cultural depictions of nobility": "تصوير ثقافي عن نبلاء",
    "Cultural depictions of Nostradamus": "تصوير ثقافي عن نوستراداموس",
    "Cultural depictions of nurses": "تصوير ثقافي عن ممرضون",
    "Cultural depictions of O. J. Simpson": "تصوير ثقافي عن أو جاي سيمبسون",
    "Cultural depictions of Oliver Cromwell": "تصوير ثقافي عن أوليفر كرومويل",
    "Cultural depictions of Omar Khayyam": "تصوير ثقافي عن عمر الخيام",
    "Cultural depictions of Orson Welles": "تصوير ثقافي عن أورسن ويلز",
    "Cultural depictions of Osama bin Laden": "تصوير ثقافي عن أسامة بن لادن",
    "Cultural depictions of Oscar Wilde": "تصوير ثقافي عن أوسكار وايلد",
    "Cultural depictions of Oswald Mosley": "تصوير ثقافي عن أوزوالد موزلي",
    "Cultural depictions of Otto von Bismarck": "تصوير ثقافي عن أوتو فون بسمارك",
    "Cultural depictions of Ovid": "تصوير ثقافي عن أوفيد",
    "Cultural depictions of Ozzy Osbourne": "تصوير ثقافي عن أوزي أوزبورن",
    "Cultural depictions of Pablo Escobar": "تصوير ثقافي عن بابلو إسكوبار",
    "Cultural depictions of Pablo Neruda": "تصوير ثقافي عن بابلو نيرودا",
    "Cultural depictions of Pablo Picasso": "تصوير ثقافي عن بابلو بيكاسو",
    "Cultural depictions of painters": "تصوير ثقافي عن رسامون",
    "Cultural depictions of Panamanian people": "تصوير ثقافي عن بنميون",
    "Cultural depictions of Pancho Villa": "تصوير ثقافي عن بانشو فيا",
    "Cultural depictions of Paris Hilton": "تصوير ثقافي عن باريس هيلتون",
    "Cultural depictions of Patrick Henry": "تصوير ثقافي عن باتريك هنري",
    "Cultural depictions of Paul Gauguin": "تصوير ثقافي عن بول غوغان",
    "Cultural depictions of Paul Kruger": "تصوير ثقافي عن بول كروغر",
    "Cultural depictions of Paul Revere": "تصوير ثقافي عن بول ريفير",
    "Cultural depictions of Paul the Apostle": "تصوير ثقافي عن بولس",
    "Cultural depictions of Paul von Hindenburg": "تصوير ثقافي عن باول فون هيندنبورغ",
    "Cultural depictions of Pelé": "تصوير ثقافي عن بيليه",
    "Cultural depictions of people by ethnicity": "تصوير ثقافي عن أشخاص حسب المجموعة العرقية",
    "Cultural depictions of people by nationality": "تصوير ثقافي عن أشخاص حسب الجنسية",
    "Cultural depictions of people by occupation": "تصوير ثقافي عن أشخاص حسب المهنة",
    "Cultural depictions of people from Georgia (country)": "تصوير ثقافي عن أشخاص من جورجيا",
    "Cultural depictions of Percy Bysshe Shelley": "تصوير ثقافي عن بيرسي بيش شيلي",
    "Cultural depictions of Peter the Great": "تصوير ثقافي عن بطرس الأكبر",
    "Cultural depictions of Philip II of Spain": "تصوير ثقافي عن فيليب الثاني ملك إسبانيا",
    "Cultural depictions of Philip IV of Spain": "تصوير ثقافي عن فيليب الرابع ملك إسبانيا",
    "Cultural depictions of Philippe Pétain": "تصوير ثقافي عن فيليب بيتان",
    "Cultural depictions of philosophers": "تصوير ثقافي عن فلاسفة",
    "Cultural depictions of photographers": "تصوير ثقافي عن مصورون",
    "Cultural depictions of physicians": "تصوير ثقافي عن أطباء",
    "Cultural depictions of Pierre-Auguste Renoir": "تصوير ثقافي عن أوغوست رينوار",
    "Cultural depictions of Pierre Trudeau": "تصوير ثقافي عن بيير ترودو",
    "Cultural depictions of pirates": "تصوير ثقافي عن قراصنة",
    "Cultural depictions of Plato": "تصوير ثقافي عن أفلاطون",
    "Cultural depictions of players of American football": "تصوير ثقافي عن لاعبو كرة قدم أمريكية",
    "Cultural depictions of Pocahontas": "تصوير ثقافي عن بوكاهونتس",
    "Cultural depictions of poets": "تصوير ثقافي عن شعراء",
    "Cultural depictions of police officers": "تصوير ثقافي عن ضباط شرطة",
    "Cultural depictions of police officers by nationality": "تصوير ثقافي عن ضباط شرطة حسب الجنسية",
    "Cultural depictions of Pompeia (wife of Caesar)": "تصوير ثقافي عن بومبيه",
    "Cultural depictions of Pompey": "تصوير ثقافي عن بومبيوس الكبير",
    "Cultural depictions of Pontius Pilate": "تصوير ثقافي عن بيلاطس البنطي",
    "Cultural depictions of Pope Alexander VI": "تصوير ثقافي عن إسكندر السادس",
    "Cultural depictions of Pope Benedict XVI": "تصوير ثقافي عن بندكت السادس عشر",
    "Cultural depictions of Pope Innocent X": "تصوير ثقافي عن إينوسنت العاشر",
    "Cultural depictions of Pope John Paul I": "تصوير ثقافي عن يوحنا بولس الأول",
    "Cultural depictions of Pope John Paul II": "تصوير ثقافي عن البابا يوحنا بولص الثاني",
    "Cultural depictions of Pope John XXIII": "تصوير ثقافي عن يوحنا الثالث والعشرون",
    "Cultural depictions of Pope Julius II": "تصوير ثقافي عن يوليوس الثاني",
    "Cultural depictions of Pope Pius VII": "تصوير ثقافي عن بيوس السابع",
    "Cultural depictions of Pope Pius XII": "تصوير ثقافي عن بيوس الثاني عشر",
    "Cultural depictions of popes": "تصوير ثقافي عن بابوات",
    "Cultural depictions of Pope Urban VIII": "تصوير ثقافي عن أربانوس الثامن",
    "Cultural depictions of pop musicians": "تصوير ثقافي عن موسيقيو بوب",
    "Cultural depictions of Poppaea Sabina": "تصوير ثقافي عن بوبايا سابينا",
    "Cultural depictions of pornographic film actors": "تصوير ثقافي عن ممثلو أفلام إباحية",
    "Cultural depictions of presidents": "تصوير ثقافي عن رؤساء",
    "Cultural depictions of presidents of Chile": "تصوير ثقافي عن رؤساء تشيلي",
    "Cultural depictions of presidents of China": "تصوير ثقافي عن رؤساء الصين",
    "Cultural depictions of presidents of Cuba": "تصوير ثقافي عن رؤساء كوبا",
    "Cultural depictions of presidents of Egypt": "تصوير ثقافي عن رؤساء مصر",
    "Cultural depictions of presidents of France": "تصوير ثقافي عن رؤساء فرنسا",
    "Cultural depictions of presidents of Mexico": "تصوير ثقافي عن رؤساء المكسيك",
    "Cultural depictions of presidents of North Korea": "تصوير ثقافي عن رؤساء كوريا الشمالية",
    "Cultural depictions of presidents of Russia": "تصوير ثقافي عن رؤساء روسيا",
    "Cultural depictions of presidents of South Africa": "تصوير ثقافي عن رؤساء جنوب إفريقيا",
    "Cultural depictions of presidents of the Philippines": "تصوير ثقافي عن رؤساء الفلبين",
    "Cultural depictions of presidents of the United States": "تصوير ثقافي عن رؤساء الولايات المتحدة",
    "Cultural depictions of prime ministers of Australia": "تصوير ثقافي عن رؤساء وزراء أستراليا",
    "Cultural depictions of prime ministers of Canada": "تصوير ثقافي عن رؤساء وزراء كندا",
    "Cultural depictions of prime ministers of France": "تصوير ثقافي عن رؤساء وزراء فرنسا",
    "Cultural depictions of prime ministers of India": "تصوير ثقافي عن رؤساء وزراء الهند",
    "Cultural depictions of prime ministers of Israel": "تصوير ثقافي عن رؤساء وزراء إسرائيل",
    "Cultural depictions of prime ministers of Italy": "تصوير ثقافي عن رؤساء وزراء إيطاليا",
    "Cultural depictions of prime ministers of Sri Lanka": "تصوير ثقافي عن رؤساء وزراء سريلانكا",
    "Cultural depictions of prime ministers of the United Kingdom": "تصوير ثقافي عن رؤساء وزراء المملكة المتحدة",
    "Cultural depictions of Prince Albert of Saxe-Coburg and Gotha": "تصوير ثقافي عن ألبرت (الأمير الزوج)",
    "Cultural depictions of Prince Harry, Duke of Sussex": "تصوير ثقافي عن هاري دوق ساسكس",
    "Cultural depictions of Prince Philip, Duke of Edinburgh": "تصوير ثقافي عن فيليب دوق إدنبرة",
    "Cultural depictions of princes": "تصوير ثقافي عن أمراء",
    "Cultural depictions of princesses": "تصوير ثقافي عن أميرات",
    "Cultural depictions of Princess Margaret, Countess of Snowdon": "تصوير ثقافي عن مارجريت كونتيسة سنودون",
    "Cultural depictions of professional wrestlers": "تصوير ثقافي عن مصارعون محترفون",
    "Cultural depictions of prostitutes": "تصوير ثقافي عن داعرات",
    "Cultural depictions of publishers": "تصوير ثقافي عن ناشرون",
    "Cultural depictions of Puerto Rican people": "تصوير ثقافي عن بورتوريكيون",
    "Cultural depictions of Puyi": "تصوير ثقافي عن بوئي",
    "Cultural depictions of Pyotr Ilyich Tchaikovsky": "تصوير ثقافي عن بيتر إليتش تشايكوفسكي",
    "Cultural depictions of Pythagoras": "تصوير ثقافي عن فيثاغورس",
    "Cultural depictions of Qin Shi Huang": "تصوير ثقافي عن تشين شي هوانج",
    "Cultural depictions of Queen Camilla": "تصوير ثقافي عن كاميلا الملكة القرينة",
    "Cultural depictions of Queen Elizabeth the Queen Mother": "تصوير ثقافي عن إليزابيث باوز ليون",
    "Cultural depictions of Queen Victoria": "تصوير ثقافي عن الملكة فيكتوريا",
    "Cultural depictions of Quentin Tarantino": "تصوير ثقافي عن كوينتن تارانتينو",
    "Cultural depictions of Rabindranath Tagore": "تصوير ثقافي عن روبندرونات طاغور",
    "Cultural depictions of racing drivers": "تصوير ثقافي عن سائقو سيارات سباق",
    "Cultural depictions of Radovan Karadžić": "تصوير ثقافي عن رادوفان كاراديتش",
    "Cultural depictions of Ragnar Lodbrok": "تصوير ثقافي عن راغنار لوثبروك",
    "Cultural depictions of Rajesh Khanna": "تصوير ثقافي عن راجيش خانا",
    "Cultural depictions of Ramesses II": "تصوير ثقافي عن رمسيس الثاني",
    "Cultural depictions of Raoul Wallenberg": "تصوير ثقافي عن راؤول ولنبرغ",
    "Cultural depictions of Raphael": "تصوير ثقافي عن رافاييل",
    "Cultural depictions of reggae musicians": "تصوير ثقافي عن موسيقيو ريغيه",
    "Cultural depictions of Rembrandt": "تصوير ثقافي عن رامبرانت",
    "Cultural depictions of René Descartes": "تصوير ثقافي عن رينيه ديكارت",
    "Cultural depictions of rhythm and blues musicians": "تصوير ثقافي عن موسيقيو ريذم أند بلوز",
    "Cultural depictions of Richard Burton": "تصوير ثقافي عن ريتشارد برتون",
    "Cultural depictions of Richard III of England": "تصوير ثقافي عن ريتشارد الثالث ملك إنجلترا",
    "Cultural depictions of Richard II of England": "تصوير ثقافي عن ريتشارد الثاني ملك إنجلترا",
    "Cultural depictions of Richard I of England": "تصوير ثقافي عن ريتشارد الأول ملك إنجلترا",
    "Cultural depictions of Richard Nixon": "تصوير ثقافي عن ريتشارد نيكسون",
    "Cultural depictions of Richard Ramirez": "تصوير ثقافي عن ريتشارد راميرز",
    "Cultural depictions of Richard Wagner": "تصوير ثقافي عن ريتشارد فاغنر",
    "Cultural depictions of Roald Dahl": "تصوير ثقافي عن روالد دال",
    "Cultural depictions of robbers": "تصوير ثقافي عن لصوص",
    "Cultural depictions of Robert Burns": "تصوير ثقافي عن روبرت برنز",
    "Cultural depictions of Robert E. Lee": "تصوير ثقافي عن روبرت إدوارد لي",
    "Cultural depictions of Robert Falcon Scott": "تصوير ثقافي عن روبرت فالكون سكوت",
    "Cultural depictions of Robert F. Kennedy": "تصوير ثقافي عن روبرت كينيدي",
    "Cultural depictions of Robert Johnson": "تصوير ثقافي عن روبرت جونسون",
    "Cultural depictions of Robert Peel": "تصوير ثقافي عن روبرت بيل",
    "Cultural depictions of Robin Williams": "تصوير ثقافي عن روبن ويليامز",
    "Cultural depictions of rock musicians": "تصوير ثقافي عن موسيقيو روك",
    "Cultural depictions of Rodrigo Duterte": "تصوير ثقافي عن رودريغو دوتيرتي",
    "Cultural depictions of Roman emperors": "تصوير ثقافي عن أباطرة رومان",
    "Cultural depictions of Roman princesses": "تصوير ثقافي عن أميرات رومانيات",
    "Cultural depictions of Ronald Reagan": "تصوير ثقافي عن رونالد ريغان",
    "Cultural depictions of Rosa Luxemburg": "تصوير ثقافي عن روزا لوكسمبورغ",
    "Cultural depictions of Rosa Parks": "تصوير ثقافي عن روزا باركس",
    "Cultural depictions of Rudolf II, Holy Roman Emperor": "تصوير ثقافي عن رودولف الثاني",
    "Cultural depictions of Rudolph Valentino": "تصوير ثقافي عن رودلف فالنتينو",
    "Cultural depictions of rugby footballers": "تصوير ثقافي عن لاعبو رجبي",
    "Cultural depictions of Ruhollah Khomeini": "تصوير ثقافي عن روح الله الخميني",
    "Cultural depictions of Russian monarchs": "تصوير ثقافي عن ملكيون روس",
    "Cultural depictions of Russian people": "تصوير ثقافي عن روس",
    "Cultural depictions of Ruth Bader Ginsburg": "تصوير ثقافي عن روث بادر غينسبورغ",
    "Cultural depictions of Rutherford B. Hayes": "تصوير ثقافي عن رذرفورد هايز",
    "Cultural depictions of Sacagawea": "تصوير ثقافي عن ساكاجاويا",
    "Cultural depictions of Sachin Tendulkar": "تصوير ثقافي عن ساشين تندولكار",
    "Cultural depictions of Saddam Hussein": "تصوير ثقافي عن صدام حسين",
    "Cultural depictions of Saint Patrick": "تصوير ثقافي عن القديس باتريك",
    "Cultural depictions of Saint Peter": "تصوير ثقافي عن بطرس الرسول",
    "Cultural depictions of Saint Sava": "تصوير ثقافي عن القديس سابا",
    "Cultural depictions of Saladin": "تصوير ثقافي عن صلاح الدين الأيوبي",
    "Cultural depictions of Salman Khan": "تصوير ثقافي عن سلمان خان",
    "Cultural depictions of Salman Rushdie": "تصوير ثقافي عن سلمان رشدي",
    "Cultural depictions of Salvador Allende": "تصوير ثقافي عن سلفادور أليندي",
    "Cultural depictions of Salvadoran people": "تصوير ثقافي عن سلفادوريون",
    "Cultural depictions of Salvador Dalí": "تصوير ثقافي عن سلفادور دالي",
    "Cultural depictions of Sammy Davis Jr.": "تصوير ثقافي عن سامي ديفيس جونيور",
    "Cultural depictions of samurai": "تصوير ثقافي عن سامورايون",
    "Cultural depictions of Sappho": "تصوير ثقافي عن صافو",
    "Cultural depictions of Sarah Palin": "تصوير ثقافي عن سارة بالين",
    "Cultural depictions of Satyajit Ray": "تصوير ثقافي عن ساتياجيت راي",
    "Cultural depictions of scientists": "تصوير ثقافي عن علماء",
    "Cultural depictions of Scottish monarchs": "تصوير ثقافي عن ملكيون إسكتلنديون",
    "Cultural depictions of screenwriters": "تصوير ثقافي عن كتاب سيناريو",
    "Cultural depictions of sculptors": "تصوير ثقافي عن نحاتون",
    "Cultural depictions of Sejong the Great": "تصوير ثقافي عن سيجونغ العظيم ملك جوسون",
    "Cultural depictions of Selena": "تصوير ثقافي عن سيلينا",
    "Cultural depictions of Serbian people": "تصوير ثقافي عن صرب",
    "Cultural depictions of serial killers": "تصوير ثقافي عن قتلة متسلسلون",
    "Cultural depictions of Servius Tullius": "تصوير ثقافي عن سيرفيوس توليوس",
    "Cultural depictions of Seti I": "تصوير ثقافي عن سيتي الأول",
    "Cultural depictions of Shah Rukh Khan": "تصوير ثقافي عن شاه رخ خان",
    "Cultural depictions of Sheikh Mujibur Rahman": "تصوير ثقافي عن مجيب الرحمن",
    "Cultural depictions of Shirley Temple": "تصوير ثقافي عن شيرلي تيمبل",
    "Cultural depictions of Shivaji": "تصوير ثقافي عن شيفاجي",
    "Cultural depictions of sideshow performers": "تصوير ثقافي عن مؤدو عروض",
    "Cultural depictions of Sigmund Freud": "تصوير ثقافي عن سيغموند فرويد",
    "Cultural depictions of Silvio Berlusconi": "تصوير ثقافي عن سيلفيو برلسكوني",
    "Cultural depictions of Simón Bolívar": "تصوير ثقافي عن سيمون بوليفار",
    "Cultural depictions of Simone de Beauvoir": "تصوير ثقافي عن سيمون دو بوفوار",
    "Cultural depictions of Siti Nurhaliza": "تصوير ثقافي عن سيتي نورهاليزا",
    "Cultural depictions of Sitting Bull": "تصوير ثقافي عن الثور الجالس",
    "Cultural depictions of Skanderbeg": "تصوير ثقافي عن إسكندر بك",
    "Cultural depictions of skateboarders": "تصوير ثقافي عن متزلجو ألواح",
    "Cultural depictions of skiers": "تصوير ثقافي عن متزحلقون",
    "Cultural depictions of slaves": "تصوير ثقافي عن عبيد",
    "Cultural depictions of Slobodan Milošević": "تصوير ثقافي عن سلوبودان ميلوشيفيتش",
    "Cultural depictions of socialites": "تصوير ثقافي عن اجتماعيون",
    "Cultural depictions of Socrates": "تصوير ثقافي عن سقراط",
    "Cultural depictions of soldiers": "تصوير ثقافي عن مجندون",
    "Cultural depictions of soul musicians": "تصوير ثقافي عن موسيقيو السول",
    "Cultural depictions of Soviet people": "تصوير ثقافي عن سوفيت",
    "Cultural depictions of Spanish monarchs": "تصوير ثقافي عن ملكيون إسبان",
    "Cultural depictions of Spanish people": "تصوير ثقافي عن إسبان",
    "Cultural depictions of Spartacus": "تصوير ثقافي عن سبارتاكوس",
    "Cultural depictions of spies": "تصوير ثقافي عن جواسيس",
    "Cultural depictions of Stan Lee": "تصوير ثقافي عن ستان لي",
    "Cultural depictions of Stanley Baldwin": "تصوير ثقافي عن ستانلي بلدوين",
    "Cultural depictions of Stanley Kubrick": "تصوير ثقافي عن ستانلي كوبريك",
    "Cultural depictions of Stephen Foster": "تصوير ثقافي عن ستيفن فوستر",
    "Cultural depictions of Stephen Hawking": "تصوير ثقافي عن ستيفن هوكينغ",
    "Cultural depictions of Steve Jobs": "تصوير ثقافي عن ستيف جوبز",
    "Cultural depictions of Steven Spielberg": "تصوير ثقافي عن ستيفن سبيلبرغ",
    "Cultural depictions of Stonewall Jackson": "تصوير ثقافي عن ستونوول جاكسون",
    "Cultural depictions of Subhas Chandra Bose": "تصوير ثقافي عن سوبهاش شاندرا بوز",
    "Cultural depictions of Sudanese people": "تصوير ثقافي عن سودانيون",
    "Cultural depictions of Suleiman the Magnificent": "تصوير ثقافي عن سليمان القانوني",
    "Cultural depictions of Sulla": "تصوير ثقافي عن سولا",
    "Cultural depictions of Sun Tzu": "تصوير ثقافي عن سون تزو",
    "Cultural depictions of Sun Yat-sen": "تصوير ثقافي عن سون يات سين",
    "Cultural depictions of Susan B. Anthony": "تصوير ثقافي عن سوزان أنتوني",
    "Cultural depictions of Su Shi": "تصوير ثقافي عن سو شي",
    "Cultural depictions of Swedish monarchs": "تصوير ثقافي عن ملكيون سويديون",
    "Cultural depictions of swimmers": "تصوير ثقافي عن سباحون",
    "Cultural depictions of Sylvester Stallone": "تصوير ثقافي عن سيلفستر ستالون",
    "Cultural depictions of Syngman Rhee": "تصوير ثقافي عن إي سنغ مان",
    "Cultural depictions of table tennis players": "تصوير ثقافي عن لاعبو كرة طاولة",
    "Cultural depictions of Tadeusz Kościuszko": "تصوير ثقافي عن تاديوش كوسيوسكو",
    "Cultural depictions of Tecumseh": "تصوير ثقافي عن تيكومسيه",
    "Cultural depictions of Ted Bundy": "تصوير ثقافي عن تيد بندي",
    "Cultural depictions of T. E. Lawrence": "تصوير ثقافي عن توماس إدوارد لورنس",
    "Cultural depictions of tennis players": "تصوير ثقافي عن لاعبو كرة مضرب",
    "Cultural depictions of Teresa of Ávila": "تصوير ثقافي عن تيريزا الأفيلاوية",
    "Cultural depictions of Thai monarchs": "تصوير ثقافي عن ملكيون تايلنديون",
    "Cultural depictions of the 14th Dalai Lama": "تصوير ثقافي عن تينزن غياتسو",
    "Cultural depictions of the assassination of Julius Caesar": "تصوير ثقافي عن اغتيال يوليوس قيصر",
    "Cultural depictions of the Beach Boys": "تصوير ثقافي عن ذا بيتش بويز",
    "Cultural depictions of the Harlem Globetrotters": "تصوير ثقافي عن هارلم غلوبتروترز",
    "Cultural depictions of the Mafia": "تصوير ثقافي عن مافيا",
    "Cultural depictions of Theodore Roosevelt": "تصوير ثقافي عن ثيودور روزفلت",
    "Cultural depictions of Theseus": "تصوير ثقافي عن ثيسيوس",
    "Cultural depictions of The Undertaker": "تصوير ثقافي عن أندرتيكر",
    "Cultural depictions of the wives of Henry VIII": "تصوير ثقافي عن زوجات هنري الثامن ملك إنجلترا",
    "Cultural depictions of the Wright brothers": "تصوير ثقافي عن الأخوان رايت",
    "Cultural depictions of the Zodiac Killer": "تصوير ثقافي عن زودياك السفاح",
    "Cultural depictions of Thomas Aquinas": "تصوير ثقافي عن توما الأكويني",
    "Cultural depictions of Thomas Becket": "تصوير ثقافي عن توماس بيكيت",
    "Cultural depictions of Thomas Carlyle": "تصوير ثقافي عن توماس كارليل",
    "Cultural depictions of Thomas Edison": "تصوير ثقافي عن توماس إديسون",
    "Cultural depictions of Thomas Jefferson": "تصوير ثقافي عن توماس جفرسون",
    "Cultural depictions of Thomas Paine": "تصوير ثقافي عن توماس بين",
    "Cultural depictions of Thomas the Apostle": "تصوير ثقافي عن توما",
    "Cultural depictions of Tiberius": "تصوير ثقافي عن طيباريوس",
    "Cultural depictions of Tiger Woods": "تصوير ثقافي عن تايغر وودز",
    "Cultural depictions of Timur": "تصوير ثقافي عن تيمورلنك",
    "Cultural depictions of Tina Turner": "تصوير ثقافي عن تينا ترنر",
    "Cultural depictions of Titus": "تصوير ثقافي عن طيطوس",
    "Cultural depictions of Tom Cruise": "تصوير ثقافي عن توم كروز",
    "Cultural depictions of Tonya Harding": "تصوير ثقافي عن تونيا هاردينغ",
    "Cultural depictions of Tony Blair": "تصوير ثقافي عن توني بلير",
    "Cultural depictions of Tony Hawk": "تصوير ثقافي عن توني هوك",
    "Cultural depictions of Torquato Tasso": "تصوير ثقافي عن توركواتو تاسو",
    "Cultural depictions of Trajan": "تصوير ثقافي عن طريانوس",
    "Cultural depictions of Trinidad and Tobago people": "تصوير ثقافي عن ترنيداديون",
    "Cultural depictions of Truman Capote": "تصوير ثقافي عن ترومان كابوتي",
    "Cultural depictions of T. S. Eliot": "تصوير ثقافي عن تي. إس. إليوت",
    "Cultural depictions of Tupac Shakur": "تصوير ثقافي عن توباك شاكور",
    "Cultural depictions of Turkish people": "تصوير ثقافي عن أتراك",
    "Cultural depictions of Tutankhamun": "تصوير ثقافي عن توت عنخ آمون",
    "Cultural depictions of Ulysses S. Grant": "تصوير ثقافي عن يوليسيس جرانت",
    "Cultural depictions of Uzbekistani people": "تصوير ثقافي عن أوزبكستانيون",
    "Cultural depictions of Valdemar IV of Denmark": "تصوير ثقافي عن فلاديمير الرابع ملك الدنمارك",
    "Cultural depictions of Vallabhbhai Patel": "تصوير ثقافي عن ساردار فالاباي باتل",
    "Cultural depictions of Victor Emmanuel II": "تصوير ثقافي عن فيتوريو إمانويلي الثاني",
    "Cultural depictions of Victor Hugo": "تصوير ثقافي عن فكتور هيغو",
    "Cultural depictions of Vincent van Gogh": "تصوير ثقافي عن فينسنت فان خوخ",
    "Cultural depictions of Virgil": "تصوير ثقافي عن فيرجيل",
    "Cultural depictions of Virginia Woolf": "تصوير ثقافي عن فرجينيا وولف",
    "Cultural depictions of Vladimir Lenin": "تصوير ثقافي عن فلاديمير لينين",
    "Cultural depictions of Vladimir Putin": "تصوير ثقافي عن فلاديمير بوتين",
    "Cultural depictions of Vladimir the Great": "تصوير ثقافي عن فلاديمير الأول",
    "Cultural depictions of Vlad the Impaler": "تصوير ثقافي عن فلاد الثالث المخوزق",
    "Cultural depictions of Voltaire": "تصوير ثقافي عن فولتير",
    "Cultural depictions of Walt Disney": "تصوير ثقافي عن والت ديزني",
    "Cultural depictions of Walter Raleigh": "تصوير ثقافي عن والتر رالي",
    "Cultural depictions of Walter Scott": "تصوير ثقافي عن والتر سكوت",
    "Cultural depictions of Warren G. Harding": "تصوير ثقافي عن وارن جي. هاردينغ",
    "Cultural depictions of Wayne Gretzky": "تصوير ثقافي عن واين جريتزكي",
    "Cultural depictions of W. C. Fields": "تصوير ثقافي عن دبليو سي فيلدز",
    "Cultural depictions of Wernher von Braun": "تصوير ثقافي عن فيرنر فون براون",
    "Cultural depictions of Whitney Houston": "تصوير ثقافي عن ويتني هيوستن",
    "Cultural depictions of WikiLeaks": "تصوير ثقافي عن ويكيليكس",
    "Cultural depictions of Wilhelm II": "تصوير ثقافي عن فيلهلم الثاني",
    "Cultural depictions of Wilhelmina of the Netherlands": "تصوير ثقافي عن فيلهلمينا ملكة هولندا",
    "Cultural depictions of William Hogarth": "تصوير ثقافي عن وليم هوجرت",
    "Cultural depictions of William Howard Taft": "تصوير ثقافي عن ويليام هوارد تافت",
    "Cultural depictions of William III of England": "تصوير ثقافي عن ويليام الثالث ملك إنجلترا",
    "Cultural depictions of William IV": "تصوير ثقافي عن ويليام الرابع ملك المملكة المتحدة",
    "Cultural depictions of William Kidd": "تصوير ثقافي عن وليام كيد",
    "Cultural depictions of William McKinley": "تصوير ثقافي عن ويليام ماكينلي",
    "Cultural depictions of William Pitt the Younger": "تصوير ثقافي عن ويليام بيت الأصغر",
    "Cultural depictions of William, Prince of Wales": "تصوير ثقافي عن ويليام أمير ويلز",
    "Cultural depictions of William Randolph Hearst": "تصوير ثقافي عن ويليام راندولف هارست",
    "Cultural depictions of William Shakespeare": "تصوير ثقافي عن وليم شكسبير",
    "Cultural depictions of William the Conqueror": "تصوير ثقافي عن وليم الفاتح",
    "Cultural depictions of William the Silent": "تصوير ثقافي عن ويليام الصامت",
    "Cultural depictions of William Wallace": "تصوير ثقافي عن ويليام والاس",
    "Cultural depictions of Winston Churchill": "تصوير ثقافي عن ونستون تشرشل",
    "Cultural depictions of Wolfgang Amadeus Mozart": "تصوير ثقافي عن فولفغانغ أماديوس موتسارت",
    "Cultural depictions of women": "تصوير ثقافي عن المرأة",
    "Cultural depictions of Woodrow Wilson": "تصوير ثقافي عن وودرو ويلسون",
    "Cultural depictions of Woody Allen": "تصوير ثقافي عن وودي آلن",
    "Cultural depictions of Woody Guthrie": "تصوير ثقافي عن وودي ويلسون",
    "Cultural depictions of wrestlers": "تصوير ثقافي عن مصارعون",
    "Cultural depictions of writers": "تصوير ثقافي عن كتاب",
    "Cultural depictions of Wu Zetian": "تصوير ثقافي عن وو شتيان",
    "Cultural depictions of Xerxes I": "تصوير ثقافي عن خشايارشا الأول",
    "Cultural depictions of Xi Jinping": "تصوير ثقافي عن شي جين بينغ",
    "Cultural depictions of Yasser Arafat": "تصوير ثقافي عن ياسر عرفات",
    "Cultural depictions of Yi Sun-sin": "تصوير ثقافي عن إي سن شن",
    "Cultural depictions of Yoko Ono": "تصوير ثقافي عن يوكو أونو",
    "Cultural depictions of Yuri Gagarin": "تصوير ثقافي عن يوري جاجارين",
    "Cultural depictions of Zachary Taylor": "تصوير ثقافي عن زكاري تايلور",
    "Cultural depictions of Zhou Enlai": "تصوير ثقافي عن تشو ان لاى",
    "Cultural depictions of Zulfikar Ali Bhutto": "تصوير ثقافي عن ذو الفقار علي بوتو",
}

to_test = [
    ("test_cultural_depictions_fast", fast_data),
    ("test_cultural_depictions_slow", data_slow),
]


@pytest.mark.parametrize("category,expected", fast_data.items(), ids=fast_data.keys())
def test_cultural_depictions_fast(category: str, expected: str) -> None:
    """Test"""
    result = resolve_label_ar(category)
    assert result == expected


@pytest.mark.parametrize("category,expected", data_slow.items(), ids=data_slow.keys())
def test_cultural_depictions_slow(category: str, expected: str) -> None:
    """Test"""
    result = resolve_label_ar(category)
    assert result == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
