""" """

import pytest

from ArWikiCats.legacy_bots.resolvers.arabic_label_builder import find_ar_label

data_list2 = [
    ("paralympic competitors for cyprus", " for ", "منافسون بارالمبيون من قبرص"),
    ("african games gold medalists for chad", " for ", "فائزون بميداليات ذهبية في الألعاب الإفريقية من تشاد"),
    ("olympic silver medalists for finland", " for ", "فائزون بميداليات فضية أولمبية من فنلندا"),
    ("summer olympics competitors for peru", " for ", "منافسون أولمبيون صيفيون من بيرو"),
]

test_data_in = {
    "1550 in belgian motorsport": "1550 في رياضة المحركات البلجيكية",
    "1550 in chinese motorsport": "1550 في رياضة المحركات الصينية",
    "1550 in english cricket": "1550 في الكريكت الإنجليزية",
    "1550 in french tennis": "1550 في كرة المضرب الفرنسية",
    "1550 in indian tennis": "1550 في كرة المضرب الهندية",
    "1550 in japanese football leagues": "1550 في دوريات كرة القدم اليابانية",
    "1550 in south american football leagues": "1550 في دوريات كرة القدم الأمريكية الجنوبية",
    "1550 in spanish tennis": "1550 في كرة المضرب الإسبانية",
    "1550 in swedish football leagues": "1550 في دوريات كرة القدم السويدية",
    "1550 disasters in australia": "كوارث 1550 في أستراليا",
    "1550 disasters in kenya": "كوارث 1550 في كينيا",
    "1550 disasters in mexico": "كوارث 1550 في المكسيك",
    "1550 disasters in oceania": "كوارث 1550 في أوقيانوسيا",
    "1550 in alabama": "1550 في ألاباما",
    "1550 in antarctica": "1550 في القارة القطبية الجنوبية",
    "1550 in antigua and barbuda": "1550 في أنتيغوا وباربودا",
    "1550 in archery": "1550 في النبالة",
    "1550 in australia": "1550 في أستراليا",
    "1550 in bermuda": "1550 في برمودا",
    "1550 in biotechnology": "1550 في تقانة حيوية",
    "1550 in brazilian sport": "1550 في رياضة برازيلية",
    "1550 in british columbia": "1550 في كولومبيا البريطانية",
    "1550 in british empire": "1550 في الإمبراطورية البريطانية",
    "1550 in british music": "1550 في موسيقى بريطانية",
    "1550 in bulgaria": "1550 في بلغاريا",
    "1550 in burmese sport": "1550 في رياضة بورمية",
    "1550 in cameroonian football": "1550 في كرة القدم الكاميرونية",
    "1550 in china": "1550 في الصين",
    "1550 in christianity": "1550 في المسيحية",
    "1550 in comics": "1550 في قصص مصورة",
    "1550 in danish television": "1550 في التلفزة الدنماركية",
    "1550 in delaware": "1550 في ديلاوير",
    "1550 in djibouti": "1550 في جيبوتي",
    "1550 in dominican republic": "1550 في جمهورية الدومينيكان",
    "1550 in economic history": "1550 في التاريخ الاقتصادي",
    "1550 in education": "1550 في تعليم",
    "1550 in europe": "1550 في أوروبا",
    "1550 in fencing": "1550 في مبارزة سيف الشيش",
    "1550 in field hockey": "1550 في هوكي الميدان",
    "1550 in finland": "1550 في فنلندا",
    "1550 in formula racing": "1550 في سباقات فورمولا",
    "1550 in french colonial empire": "1550 في الإمبراطورية الاستعمارية الفرنسية",
    "1550 in french television": "1550 في التلفزة الفرنسية",
    "1550 in georgia (u.s. state)": "1550 في ولاية جورجيا",
    "1550 in guam": "1550 في غوام",
    "1550 in guangzhou": "1550 في غوانزو",
    "1550 in habsburg monarchy": "1550 في ملكية هابسبورغ",
    "1550 in haiti": "1550 في هايتي",
    "1550 in holy roman empire": "1550 في الإمبراطورية الرومانية المقدسة",
    "1550 in horse racing": "1550 في سباق الخيل",
    "1550 in hungary": "1550 في المجر",
    "1550 in hurling": "1550 في القذف",
    "1550 in illinois": "1550 في إلينوي",
    "1550 in international sports": "1550 في رياضية دولية",
    "1550 in iraq": "1550 في العراق",
    "1550 in iraqi sport": "1550 في رياضة عراقية",
    "1550 in irish women's sport": "1550 في رياضة أيرلندية نسائية",
    "1550 in italian sport": "1550 في رياضة إيطالية",
    "1550 in ivory coast": "1550 في ساحل العاج",
    "1550 in khyber pakhtunkhwa": "1550 في خيبر بختونخوا",
    "1550 in law": "1550 في قانون",
    "1550 in liberia": "1550 في ليبيريا",
    "1550 in libyan sport": "1550 في رياضة ليبية",
    "1550 in lithuania": "1550 في ليتوانيا",
    "1550 in macau": "1550 في ماكاو",
    "1550 in maryland": "1550 في ماريلند",
    "1550 in mexican television": "1550 في التلفزة المكسيكية",
    "1550 in mexico": "1550 في المكسيك",
    "1550 in military history": "1550 في التاريخ العسكري",
    "1550 in minnesota": "1550 في منيسوتا",
    "1550 in missouri": "1550 في ميزوري",
    "1550 in mongolia": "1550 في منغوليا",
    "1550 in new jersey": "1550 في نيوجيرسي",
    "1550 in new zealand": "1550 في نيوزيلندا",
    "1550 in nordic combined": "1550 في التزلج النوردي المزدوج",
    "1550 in north america": "1550 في أمريكا الشمالية",
    "1550 in north macedonia": "1550 في مقدونيا الشمالية",
    "1550 in norwegian music": "1550 في موسيقى نرويجية",
    "1550 in oregon": "1550 في أوريغن",
    "1550 in outer space": "1550 في الفضاء الخارجي",
    "1550 in philippine cinema": "1550 في السينما الفلبينية",
    "1550 in professional wrestling": "1550 في مصارعة المحترفين",
    "1550 in puerto rico": "1550 في بورتوريكو",
    "1550 in religion": "1550 في الدين",
    "1550 in road cycling": "1550 في سباق الدراجات على الطريق",
    "1550 in romania": "1550 في رومانيا",
    "1550 in san marino": "1550 في سان مارينو",
    "1550 in sarawak": "1550 في ساراواك",
    "1550 in saudi arabia": "1550 في السعودية",
    "1550 in science": "1550 في العلم",
    "1550 in scotland": "1550 في إسكتلندا",
    "1550 in scottish women's sport": "1550 في رياضة إسكتلندية نسائية",
    "1550 in senegalese sport": "1550 في رياضة سنغالية",
    "1550 in serbia": "1550 في صربيا",
    "1550 in sint maarten": "1550 في سينت مارتن",
    "1550 in skeleton": "1550 في الزلاجات الصدرية",
    "1550 in somalian sport": "1550 في رياضة صومالية",
    "1550 in south america": "1550 في أمريكا الجنوبية",
    "1550 in spain": "1550 في إسبانيا",
    "1550 in spanish empire": "1550 في الإمبراطورية الإسبانية",
    "1550 in speed skating": "1550 في التزلج السريع",
    "1550 in syria": "1550 في سوريا",
    "1550 in taiwan": "1550 في تايوان",
    "1550 in taiwanese television": "1550 في التلفزة التايوانية",
    "1550 in tanzania": "1550 في تنزانيا",
    "1550 in thailand": "1550 في تايلاند",
    "1550 in toronto": "1550 في تورونتو",
    "1550 in united arab emirates": "1550 في الإمارات العربية المتحدة",
    "1550 in united nations": "1550 في الأمم المتحدة",
    "1550 in uruguayan football": "1550 في كرة القدم الأوروغويانية",
    "1550 in uzbekistani football": "1550 في كرة القدم الأوزبكستانية",
    "1550 in uzbekistani sport": "1550 في رياضة أوزبكستانية",
    "1550 in vanuatu": "1550 في فانواتو",
    "1550 in venezuela": "1550 في فنزويلا",
    "1550 in virginia": "1550 في فرجينيا",
    "1550 in washington (state)": "1550 في ولاية واشنطن",
    "1550 in west germany": "1550 في ألمانيا الغربية",
    "1550 in women's sport": "1550 في رياضة نسائية",
    "1550 mass shootings in africa": "إطلاق نار عشوائي 1550 في إفريقيا",
    "1550 mass shootings in oceania": "إطلاق نار عشوائي 1550 في أوقيانوسيا",
    "1550 murders in north america": "جرائم قتل في 1550 في أمريكا الشمالية",
    "1550 murders in russia": "جرائم قتل في 1550 في روسيا",
    "1550 natural disasters in united states": "كوارث طبيعية في 1550 في الولايات المتحدة",
    "1550s in asia": "عقد 1550 في آسيا",
    "1550s in belgium": "عقد 1550 في بلجيكا",
    "1550s in dundee": "عقد 1550 في دندي",
    "1550s in edmonton": "عقد 1550 في إدمونتون",
    "1550s in england": "عقد 1550 في إنجلترا",
    "1550s in estonia": "عقد 1550 في إستونيا",
    "1550s in hangzhou": "عقد 1550 في هانغتشو",
    "1550s in ice hockey": "عقد 1550 في هوكي الجليد",
    "1550s in japan": "عقد 1550 في اليابان",
    "1550s in literature": "عقد 1550 في أدب",
    "1550s in louisiana": "عقد 1550 في لويزيانا",
    "1550s in maltese sport": "عقد 1550 في رياضة مالطية",
    "1550s in north american sport": "عقد 1550 في رياضة أمريكية شمالية",
    "1550s in politics": "عقد 1550 في سياسة",
    "1550s in portugal": "عقد 1550 في البرتغال",
    "1550s in prince edward island": "عقد 1550 في جزيرة الأمير إدوارد",
    "1550s in quebec": "عقد 1550 في كيبك",
    "1550s in rugby union": "عقد 1550 في اتحاد الرجبي",
    "1550s in russia": "عقد 1550 في روسيا",
    "1550s in saudi arabia": "عقد 1550 في السعودية",
    "1550s in science": "عقد 1550 في العلم",
    "1550s in somaliland": "عقد 1550 في أرض الصومال",
    "1550s in south korean women's sport": "عقد 1550 في رياضة كورية جنوبية نسائية",
    "1550s in technology": "عقد 1550 في التقانة",
    "1550s in track cycling": "عقد 1550 في سباق الدراجات على المضمار",
    "1550s in ukrainian sport": "عقد 1550 في رياضة أوكرانية",
    "1550s in venezuela": "عقد 1550 في فنزويلا",
    "1550s in vietnam": "عقد 1550 في فيتنام",
    "1550s in winter sports": "عقد 1550 في الرياضة الشتوية",
    "20th century in iraq": "القرن 20 في العراق",
    "20th century in kent": "القرن 20 في كنت",
    "20th century in prince edward island": "القرن 20 في جزيرة الأمير إدوارد",
    "20th century in prussia": "القرن 20 في بروسيا",
    "20th century in quetta": "القرن 20 في كويته",
    "2nd millennium in kentucky": "الألفية 2 في كنتاكي",
    "3rd millennium in ghana": "الألفية 3 في غانا",
    "culture in lugano": "ثقافة في لوغانو",
    "education in caloocan": "تعليم في كالوكان",
    "transport in kirov oblast": "نقل في أوبلاست كيروف",
    "transport in newfoundland and labrador": "نقل في نيوفاوندلاند واللابرادور",
    "transport in oxford": "نقل في أكسفورد",
    "transport in ternopil oblast": "نقل في تيرنوبل أوبلاست",
}


@pytest.mark.parametrize("category, output", test_data_in.items(), ids=test_data_in.keys())
@pytest.mark.fast
def test_data_list_in_1(category: str, output: str) -> None:
    label = find_ar_label(category, " in ", use_event2=False)
    assert label == output


@pytest.mark.parametrize("category, separator, output", data_list2, ids=[x[0] for x in data_list2])
@pytest.mark.fast
def test_simple_2(category: str, separator: str, output: str) -> None:
    label = find_ar_label(category, separator, use_event2=False)
    assert label == output
