"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar
from ArWikiCats.legacy_bots.resolvers.arabic_label_builder import find_ar_label
from utils.dump_runner import make_dump_test_name_data_callback

data_list = [
    ("sports venues by type", " by ", "ملاعب رياضية حسب الفئة"),
    ("university of annaba", " of ", "جامعة عنابة"),
    ("1550 by city", " by ", "1550 حسب المدينة"),
    ("1550 by country", " by ", "1550 حسب البلد"),
    ("1550 disestablishments by continent", " by ", "انحلالات سنة 1550 حسب القارة"),
    ("1550 disestablishments by country", " by ", "انحلالات سنة 1550 حسب البلد"),
    ("1550 elections by country", " by ", "انتخابات 1550 حسب البلد"),
    ("1550 elections in sweden", " in ", "انتخابات 1550 في السويد"),
    ("1550 establishments by continent", " by ", "تأسيسات سنة 1550 حسب القارة"),
    ("1550 establishments by country", " by ", "تأسيسات سنة 1550 حسب البلد"),
    ("1550 in sports by country", " by ", "ألعاب رياضية في 1550 حسب البلد"),
    ("academics from tuscany", " from ", "أكاديميون من توسكانا"),
    ("actresses from ohio", " from ", "ممثلات من أوهايو"),
    ("acts of parliament of ireland 1550", " of ", "أفعال برلمان أيرلندا 1550"),
    ("algerian companies established in 1550", " established in ", "شركات جزائرية أسست في 1550"),
    ("ambassadors of austria", " of ", "سفراء النمسا"),
    ("ambassadors of brazil", " of ", "سفراء البرازيل"),
    ("ambassadors of canada", " of ", "سفراء كندا"),
    ("ambassadors of chad", " of ", "سفراء تشاد"),
    ("ambassadors of china", " of ", "سفراء الصين"),
    ("ambassadors of fiji", " of ", "سفراء فيجي"),
    ("ambassadors of ghana", " of ", "سفراء غانا"),
    ("ambassadors of great britain", " of ", "سفراء بريطانيا العظمى"),
    ("ambassadors of italy", " of ", "سفراء إيطاليا"),
    ("ambassadors of japan", " of ", "سفراء اليابان"),
    ("ambassadors of palau", " of ", "سفراء بالاو"),
    ("amusement park attractions introduced in 1550", " introduced in ", "متنزهات ملاهي جاذبة عرضت في 1550"),
    ("animated films about mammals", " about ", "أفلام رسوم متحركة عن ثدييات"),
    ("antigua and barbuda by month", " by ", "أنتيغوا وباربودا حسب الشهر"),
    ("april 1550 by country", " by ", "أبريل 1550 حسب البلد"),
    ("artists from novi sad", " from ", "فنانون من نوفي ساد"),
    ("artists from zurich", " from ", "فنانون من زيورخ"),
    ("asia by city", " by ", "آسيا حسب المدينة"),
    ("august 1550 by continent", " by ", "أغسطس 1550 حسب القارة"),
    ("august 1550 by country", " by ", "أغسطس 1550 حسب البلد"),
    ("austrian artists by century", " by ", "فنانون نمساويون حسب القرن"),
    ("azerbaijani emigrants to united kingdom", " to ", "أذربيجانيون مهاجرون إلى المملكة المتحدة"),
    ("bahraini emigrants to united states", " to ", "بحرينيون مهاجرون إلى الولايات المتحدة"),
    ("banks based in tennessee", " based in ", "بنوك مقرها في تينيسي"),
    ("biologists from xinjiang", " from ", "علماء أحياء من سنجان"),
    ("biota of libya", " of ", "حيويات ليبيا"),
    ("blues musicians from tennessee", " from ", "موسيقيو بلوز من تينيسي"),
    ("bolivian artists by century", " by ", "فنانون بوليفيون حسب القرن"),
    ("cantons of marseille", " of ", "كانتونات مارسيليا"),
    ("chemical companies established in 1550", " established in ", "شركات كيميائية أسست في 1550"),
    ("christians from ohio", " from ", "مسيحيون من أوهايو"),
    ("churches completed in 1550", " completed in ", "كنائس اكتملت في 1550"),
    ("city of zagreb", " of ", "مدينة زغرب"),
    ("civilians killed in wars", " killed in ", "مدنيون قتلوا في حروب"),
    ("clergy from poznań", " from ", "رجال دين من بوزنان"),
    ("clubhouses on the-national-register-of-historic-places", " on ", "نوادي في السجل الوطني للأماكن التاريخية"),
    ("clubs and societies of university of sheffield", " of ", "أندية وجمعيات في جامعة شفيلد"),
    ("comedy by medium", " by ", "كوميديا حسب الوسط"),
    ("comic strips by date", " by ", "شرائط كومكس حسب التاريخ"),
    ("comics images from india", " from ", "صور قصص مصورة من الهند"),
    ("communes of saïda province", " of ", "بلديات ولاية سعيدة"),
    ("companies by former country", " by ", "شركات حسب البلد السابق"),
    ("companies of cambodia", " of ", "شركات في كمبوديا"),
    ("constituencies disestablished in 1550", " disestablished in ", "دوائر إنتخابية انحلت في 1550"),
    ("constituencies of parliament of barbados", " of ", "دوائر إنتخابية في برلمان بربادوس"),
    ("courthouses on the-national-register-of-historic-places", " on ", "محاكم في السجل الوطني للأماكن التاريخية"),
    ("crustaceans described in 1550", " described in ", "قشريات وصفت في 1550"),
    ("cultural organizations based in portugal", " based in ", "منظمات ثقافية مقرها في البرتغال"),
    ("culture of maharashtra", " of ", "ثقافة ماهاراشترا"),
    ("defunct airlines of paraguay", " of ", "شركات طيران سابقة في باراغواي"),
    ("districts of taipei", " of ", "مديريات تايبيه"),
    ("dog breeds originating in japan", " originating in ", "سلالات كلاب نشأت في اليابان"),
    ("donkey breeds originating in portugal", " originating in ", "سلالات حمير نشأت في البرتغال"),
    ("dutch companies established in 1550", " established in ", "شركات هولندية أسست في 1550"),
    ("echinoderms described in 20th century", " described in ", "شوكيات الجلد وصفت في القرن 20"),
    ("economy of burundi", " of ", "اقتصاد بوروندي"),
    ("economy of kwazulu-natal", " of ", "اقتصاد كوازولو ناتال"),
    ("economy of renfrewshire", " of ", "اقتصاد رينفروشاير"),
    ("ecuador by decade", " by ", "الإكوادور حسب العقد"),
    ("educators from meghalaya", " from ", "معلمون من ميغالايا"),
    ("energy companies established in 1550", " established in ", "شركات طاقة أسست في 1550"),
    ("environment of essex", " of ", "بيئة إسكس"),
    ("european football by country", " by ", "كرة القدم الأوروبية حسب البلد"),
    ("fauna of vermont", " of ", "حيوانات فيرمونت"),
    ("films about royal air force", " about ", "أفلام عن القوات الجوية الملكية"),
    ("films basedon works", " basedon ", "أفلام مبنية على أعمال"),
    ("films set in 1550s", " set in ", "أفلام تقع أحداثها في عقد 1550"),
    ("films set in copenhagen", " set in ", "أفلام تقع أحداثها في كوبنهاغن"),
    ("films shot in islamabad", " shot in ", "أفلام مصورة في إسلام آباد"),
    ("films shot in united states by city", " shot in ", "أفلام مصورة في الولايات المتحدة حسب المدينة"),
    ("films with screenplays by emma thompson", " with screenplays by ", "أفلام كتب نصها السينمائي إيما تومسون"),
    ("financial services companies of seychelles", " of ", "شركات خدمات مالية في سيشل"),
    ("first ladies of rwanda", " of ", "السيدات الأولى في رواندا"),
    ("fishes of europe", " of ", "أسماك أوروبا"),
    ("flags of connecticut", " of ", "أعلام كونيتيكت"),
    ("flags of vatican city", " of ", "أعلام الفاتيكان"),
    ("flora of estonia", " of ", "نباتات إستونيا"),
    ("food and drink companies of botswana", " of ", "شركات أطعمة ومشروبات في بوتسوانا"),
    ("football clubs established in 1550", " established in ", "أندية كرة قدم أسست في 1550"),
    ("footballers from harlow", " from ", "لاعبو كرة قدم من هارلو"),
    ("footballers from mexico city", " from ", "لاعبو كرة قدم من مدينة مكسيكو"),
    ("french companies disestablished in 1550", " disestablished in ", "شركات فرنسية انحلت في 1550"),
    ("geography of kansas by populated place", " by ", "جغرافيا كانساس حسب المكان المأهول"),
    ("geography of kansas", " of ", "جغرافيا كانساس"),
    ("government ministers of northern cyprus", " of ", "وزراء قبرص الشمالية"),
    ("government of chicago", " of ", "حكومة شيكاغو"),
    ("government of la rioja", " of ", "حكومة منطقة لا ريوخا"),
    ("government of moldova", " of ", "حكومة مولدوفا"),
    ("government of nazi germany", " of ", "حكومة ألمانيا النازية"),
    ("grand viziers of egypt", " of ", "صدور عظام في مصر"),
    ("greenlandic emigrants to canada", " to ", "جرينلانديون مهاجرون إلى كندا"),
    ("guatemalan people by religion", " by ", "غواتيماليون حسب الدين"),
    ("guernsey by decade", " by ", "غيرنزي حسب العقد"),
    ("heads of universities and colleges", " of ", "قادة جامعات وكليات"),
    ("history books about islam", " about ", "كتب تاريخ عن الإسلام"),
    ("history of copenhagen", " of ", "تاريخ كوبنهاغن"),
    ("history of craiova", " of ", "تاريخ كرايوفا"),
    ("holding companies established in 1550", " established in ", "شركات قابضة أسست في 1550"),
    ("horse races established in 1550", " established in ", "سباقات الخيل أسست في 1550"),
    ("hospital buildings completed in 20th century", " completed in ", "مباني مستشفيات اكتملت في القرن 20"),
    ("hotel buildings completed in 1550", " completed in ", "مبان فنادق اكتملت في 1550"),
    ("indian companies established in 1550", " established in ", "شركات هندية أسست في 1550"),
    ("industrial parks by country", " by ", "متنزهات صناعية حسب البلد"),
    ("infrastructure completed in 1550", " completed in ", "بنية تحتية اكتملت في 1550"),
    ("international gymnastics competitions hosted by germany", " hosted by ", "منافسات جمباز دولية استضافتها ألمانيا"),
    ("introductions by time", " by ", "استحداثات حسب الوقت"),
    ("iraq by city", " by ", "العراق حسب المدينة"),
    ("irish people by religion", " by ", "أيرلنديون حسب الدين"),
    ("islamic organizations based in bangladesh", " based in ", "منظمات إسلامية مقرها في بنغلاديش"),
    ("jewish organizations established in 1550", " established in ", "منظمات يهودية أسست في 1550"),
    ("july 1550 by country", " by ", "يوليو 1550 حسب البلد"),
    ("june 1550 by continent", " by ", "يونيو 1550 حسب القارة"),
    ("landforms of michigan", " of ", "تضاريس ميشيغان"),
    ("languages of gilgit-baltistan", " of ", "لغات غلغت-بلتستان"),
    ("laws regarding rape", " regarding ", "قوانين عن الاغتصاب"),
    ("lawyers from new orleans", " from ", "محامون من نيو أورلينز"),
    ("liberian sport by decade", " by ", "رياضة ليبيرية حسب العقد"),
    ("lists of ambassadors", " of ", "قوائم سفراء"),
    ("lists of buildings and structures", " of ", "قوائم مبان ومنشآت"),
    ("lists of faroese politicians", " of ", "قوائم سياسيون فارويون"),
    ("lists of fauna of vermont", " of ", "قوائم حيوانات فيرمونت"),
    ("lists of fishes of europe", " of ", "قوائم أسماك أوروبا"),
    ("lists of legislators", " of ", "قوائم مشرعون"),
    ("lists of mayors of places", " of ", "قوائم رؤساء بلديات"),
    ("lists of roads", " of ", "قوائم طرقات"),
    ("literary characters introduced in 1550", " introduced in ", "شخصيات أدبية عرضت في 1550"),
    ("magazines published in tennessee", " published in ", "مجلات نشرت في تينيسي"),
    ("malaysian people by populated place", " by ", "ماليزيون حسب المكان المأهول"),
    ("male actors from lubusz voivodeship", " from ", "ممثلون ذكور من محافظة لوبوسكي"),
    ("male voice actors from kanagawa prefecture", " from ", "ممثلو أداء صوتي ذكور من محافظة كاناغاوا"),
    ("manufacturing companies based in michigan", " based in ", "شركات تصنيع مقرها في ميشيغان"),
    ("manufacturing companies established in 1550", " established in ", "شركات تصنيع أسست في 1550"),
    ("mass shootings in oceania", " in ", "إطلاق نار عشوائي في أوقيانوسيا"),
    ("may 1550 by continent", " by ", "مايو 1550 حسب القارة"),
    ("mayors of ajaccio", " of ", "عمدات أجاكسيو"),
    ("members of maine legislature", " of ", "أعضاء هيئة مين التشريعية"),
    ("mexico by month", " by ", "المكسيك حسب الشهر"),
    ("military campaigns involving denmark", " involving ", "حملات عسكرية تشمل الدنمارك"),
    (
        "military facilities on the-national-register-of-historic-places",
        " on ",
        "مرافق عسكرية في السجل الوطني للأماكن التاريخية",
    ),
    ("military installations established in 1550s", " established in ", "منشآت عسكرية أسست في عقد 1550"),
    ("military of second bulgarian empire", " of ", "عسكرية الإمبراطورية البلغارية الثانية"),
    (
        "military operations involving soviet union by war",
        " involving ",
        "عمليات عسكرية تشمل الاتحاد السوفيتي حسب الحرب",
    ),
    ("military operations of american civil war", " of ", "عمليات عسكرية في الحرب الأهلية الأمريكية"),
    ("military personnel from ross and cromarty", " from ", "أفراد عسكريون من روس وكرومارتي"),
    (
        "military units and formations disestablished in 1550",
        " disestablished in ",
        "وحدات وتشكيلات عسكرية انحلت في 1550",
    ),
    ("models from essex", " from ", "عارضو أزياء من إسكس"),
    ("monarchs by country", " by ", "ملكيون حسب البلد"),
    ("montserratian expatriates in england", " in ", "مونتسراتيون مغتربون في إنجلترا"),
    ("mountain ranges of alaska", " of ", "سلاسل جبلية في ألاسكا"),
    ("municipalities of greenland", " of ", "بلديات جرينلاند"),
    ("museums disestablished in 1550", " disestablished in ", "متاحف انحلت في 1550"),
    ("musicals set in barcelona", " set in ", "مسرحيات غنائية تقع أحداثها في برشلونة"),
    ("mystery films by language", " by ", "أفلام غموض حسب اللغة"),
    ("newspaper people by newspaper in california", " by ", "شخصيات صحف حسب الصحيفة في كاليفورنيا"),
    ("norwegian drummers by century", " by ", "طبالون نرويجيون حسب القرن"),
    ("novels by continent of setting", " by ", "روايات حسب قارة الأحداث"),
    ("october 1550 by country", " by ", "أكتوبر 1550 حسب البلد"),
    ("olympic boxers for aruba", " for ", "ملاكمون أولمبيون في أروبا"),
    ("olympic footballers for south korea", " for ", "لاعبو كرة قدم أولمبيون في كوريا الجنوبية"),
    ("olympic judoka by year", " by ", "لاعبو جودو أولمبيون حسب السنة"),
    ("olympic lugers for estonia", " for ", "زاحفون ثلجيون أولمبيون في إستونيا"),
    ("olympic shooters for iceland", " for ", "رماة أولمبيون في آيسلندا"),
    ("olympic skeleton racers for italy", " for ", "متزلجون صدريون أولمبيون في إيطاليا"),
    ("olympic speed skaters for lithuania", " for ", "متزلجو سرعة أولمبيون في ليتوانيا"),
    ("omani expatriate sports-people by country-of-residence", " by ", "رياضيون عمانيون مغتربون حسب بلد الإقامة"),
    ("opera houses on the-national-register-of-historic-places", " on ", "دور أوبرا في السجل الوطني للأماكن التاريخية"),
    ("organizations based in paris", " based in ", "منظمات مقرها في باريس"),
    ("organizations based in western sahara by subject", " based in ", "منظمات مقرها في الصحراء الغربية حسب الموضوع"),
    ("organizations by dependent territory", " by ", "منظمات حسب الأقاليم التابعة"),
    ("paintings of queen victoria", " of ", "لوحات عن الملكة فيكتوريا"),
    ("pakistani companies established in 1550", " established in ", "شركات باكستانية أسست في 1550"),
    (
        "paralympic wheelchair curlers by year",
        " by ",
        "لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية حسب السنة",
    ),
    ("parliament of barbados", " of ", "برلمان بربادوس"),
    ("parliament of ireland 1550", " of ", "برلمان أيرلندا 1550"),
    ("people from al-andalus", " from ", "أشخاص من الأندلس"),
    ("people from al-hasakah governorate", " from ", "أشخاص من محافظة الحسكة"),
    ("people from almaty", " from ", "أشخاص من ألماتي"),
    ("people from bangkok", " from ", "أشخاص من بانكوك"),
    ("people from batangas", " from ", "أشخاص من باتانغاس"),
    ("people from brokopondo district", " from ", "أشخاص من ضاحية بروكوبوندو"),
    ("people from burhanpur", " from ", "أشخاص من برهانبور"),
    ("people from east lothian", " from ", "أشخاص من لوثيان الشرقية"),
    ("people from falkenberg", " from ", "أشخاص من فالكنبرغ"),
    ("people from leudal", " from ", "أشخاص من لودال"),
    ("people from parbhani", " from ", "أشخاص من باربهاني"),
    ("people from rimavská sobota", " from ", "أشخاص من ريمافسكا سوبوتا"),
    ("people from rivne oblast", " from ", "أشخاص من ريفنا أوبلاست"),
    ("people from rohtak", " from ", "أشخاص من روهتاك"),
    ("people from taiz", " from ", "أشخاص من تعز"),
    ("people from vyborg", " from ", "أشخاص من فيبورغ"),
    ("people from whanganui", " from ", "أشخاص من وانجانوي"),
    ("people murdered in 1550", " murdered in ", "أشخاص قتلوا في 1550"),
    ("peru by year", " by ", "بيرو حسب السنة"),
    ("peruvian people by occupation and century", " by ", "بيرويون حسب المهنة والقرن"),
    ("pharmaceutical companies of taiwan", " of ", "شركات أدوية في تايوان"),
    ("political organizations based in barbados", " based in ", "منظمات سياسية مقرها في بربادوس"),
    (
        "political organizations based in oceania by country",
        " based in ",
        "منظمات سياسية مقرها في أوقيانوسيا حسب البلد",
    ),
    ("politics of bhagalpur district", " of ", "سياسة مقاطعة بهاغالبور"),
    ("politics of second polish republic", " of ", "سياسة الجمهورية البولندية الثانية"),
    ("populated places disestablished in 20th century bc", " disestablished in ", "أماكن مأهولة انحلت في القرن 20 ق م"),
    ("populated places established in 1550", " established in ", "أماكن مأهولة أسست في 1550"),
    ("presidency of jose p. laurel", " of ", "رئاسة خوسي لوريل"),
    ("prime ministers of japan", " of ", "رؤساء وزراء اليابان"),
    ("prime ministers of ukraine", " of ", "رؤساء وزراء أوكرانيا"),
    ("prisoners and detainees of liechtenstein", " of ", "سجناء ومعتقلون في ليختنشتاين"),
    ("publications disestablished in 20th century", " disestablished in ", "منشورات انحلت في القرن 20"),
    ("publications established in 1550", " established in ", "منشورات أسست في 1550"),
    ("publications established in 1550s", " established in ", "منشورات أسست في عقد 1550"),
    ("radio stations disestablished in 1550", " disestablished in ", "محطات إذاعية انحلت في 1550"),
    ("railway stations opened in 1550s", " opened in ", "محطات السكك الحديدية افتتحت في عقد 1550"),
    ("recurring events established in 1550", " established in ", "أحداث دورية أسست في 1550"),
    ("religious buildings and structures completed in 1550", " completed in ", "مبان ومنشآت دينية اكتملت في 1550"),
    ("religious buildings and structures completed in 1550s", " completed in ", "مبان ومنشآت دينية اكتملت في عقد 1550"),
    ("religious festivals by type", " by ", "مهرجانات دينية حسب الفئة"),
    ("religious organizations based in iceland", " based in ", "منظمات دينية مقرها في آيسلندا"),
    ("religious organizations established in 1550", " established in ", "منظمات دينية أسست في 1550"),
    ("renewable energy companies of myanmar", " of ", "شركات طاقة متجددة في ميانمار"),
    ("reptiles described in 1550", " described in ", "زواحف وصفت في 1550"),
    ("restaurants established in 1550", " established in ", "مطاعم أسست في 1550"),
    ("rivers of perlis", " of ", "أنهار برليس"),
    ("rivers of qinghai", " of ", "أنهار تشينغهاي"),
    ("rivers of wales", " of ", "أنهار ويلز"),
    ("rugby league players from oldham", " from ", "لاعبو دوري رجبي من أولدهام"),
    ("rugby union players from utah", " from ", "لاعبو اتحاد رجبي من يوتا"),
    ("scientists from indianapolis", " from ", "علماء من إنديانابوليس"),
    ("secretaries-of state of nevada", " of ", "وزراء خارجية نيفادا"),
    ("singers from zacatecas", " from ", "مغنون من ولاية زاكاتيكاس"),
    ("ska albums by artist nationality", " by ", "ألبومات سكا حسب جنسية الفنان"),
    ("slovenian people by period", " by ", "سلوفينيون حسب الحقبة"),
    ("social workers from delhi", " from ", "أخصائيون اجتماعيون من دلهي"),
    ("songs about invertebrates", " about ", "أغاني عن لافقاريات"),
    ("south african mathematicians by century", " by ", "رياضياتيون جنوب إفريقيون حسب القرن"),
    ("south america by month", " by ", "أمريكا الجنوبية حسب الشهر"),
    ("spiders described in 1550", " described in ", "عناكب وصفت في 1550"),
    ("sport by continent", " by ", "رياضة حسب القارة"),
    ("sports clubs and teams disestablished in 1550", " disestablished in ", "أندية وفرق رياضية انحلت في 1550"),
    ("sports coaches from illinois", " from ", "مدربو رياضة من إلينوي"),
    ("sports coaches from oregon", " from ", "مدربو رياضة من أوريغن"),
    ("sports organizations by continent", " by ", "منظمات رياضية حسب القارة"),
    ("sports-people from central kalimantan", " from ", "رياضيون من كالمنتان الوسطى"),
    ("sports-people from florina", " from ", "رياضيون من فلورينا"),
    ("sports-people from getxo", " from ", "رياضيون من غوتكسو"),
    ("sports-people from temuco", " from ", "رياضيون من تيموكو"),
    ("sports-people from tukums", " from ", "رياضيون من توكومز"),
    ("sportswomen from new south wales", " from ", "رياضيات من نيوساوث ويلز"),
    ("states and territories disestablished in 1550", " disestablished in ", "دول وأقاليم انحلت في 1550"),
    ("states and territories established in 1550", " established in ", "دول وأقاليم أسست في 1550"),
    ("suicides by-firearm-in nevada", " by-firearm-in ", "منتحرون بإطلاق النار في نيفادا"),
    ("swedish emigrants to jordan", " to ", "سويديون مهاجرون إلى الأردن"),
    ("swedish male musicians by century", " by ", "موسيقيون ذكور سويديون حسب القرن"),
    ("symbols of nuevo león", " of ", "رموز ولاية نويفو ليون"),
    ("synagogues completed in 1550", " completed in ", "كنس اكتملت في 1550"),
    ("television channels and stations established in 1550", " established in ", "قنوات وشبكات تلفزيونية أسست في 1550"),
    ("thailand by month", " by ", "تايلاند حسب الشهر"),
    ("theatre by country", " by ", "المسرح حسب البلد"),
    ("towers completed in 1550", " completed in ", "أبراج اكتملت في 1550"),
    ("trade associations based in quebec", " based in ", "اتحادات تجارية مقرها في كيبك"),
    ("trade unionists from missouri", " from ", "نقابيون من ميزوري"),
    ("transport organizations based in bahamas", " based in ", "منظمات نقل مقرها في باهاماس"),
    ("transport organizations based in norway", " based in ", "منظمات نقل مقرها في النرويج"),
    (
        "united nations security council resolutions concerning angola",
        " concerning ",
        "قرارات مجلس الأمن التابع للأمم المتحدة بشأن أنغولا",
    ),
    (
        "united nations security council resolutions concerning turkmenistan",
        " concerning ",
        "قرارات مجلس الأمن التابع للأمم المتحدة بشأن تركمانستان",
    ),
    ("university of annaba", " of ", "جامعة عنابة"),
    ("university of sheffield", " of ", "جامعة شفيلد"),
    ("uzbekistani emigrants to australia", " to ", "أوزبكستانيون مهاجرون إلى أستراليا"),
    ("victims of aviation accidents or incidents", " of ", "ضحايا حوادث طيران"),
    ("video game franchises introduced in 1550", " introduced in ", "امتيازات ألعاب فيديو عرضت في 1550"),
    ("wars involving nepal", " involving ", "حروب تشمل نيبال"),
    ("water of novosibirsk oblast", " of ", "مياه في نوفوسيبيرسك أوبلاست"),
    ("women politicians by century", " by ", "سياسيات حسب القرن"),
    ("women's sport by country", " by ", "رياضة نسائية حسب البلد"),
    ("works about alberta", " about ", "أعمال عن ألبرتا"),
    ("works set in guinea-bissau", " set in ", "أعمال تقع أحداثها في غينيا بيساو"),
    ("writers from abruzzo", " from ", "كتاب من أبروتسو"),
    ("writers from al-andalus", " from ", "كتاب من الأندلس"),
    ("writers from celje", " from ", "كتاب من تسليه"),
    ("writers from german empire", " from ", "كتاب من الإمبراطورية الألمانية"),
    ("years of 20th century", " of ", "سنوات القرن 20"),
    ("youth organizations based in montserrat", " based in ", "منظمات شبابية مقرها في مونتسرات"),
    ("yugoslavia by year", " by ", "يوغسلافيا حسب السنة"),
    ("zoologists from austrian empire", " from ", "علماء حيوانات من الإمبراطورية النمساوية"),
]


@pytest.mark.parametrize("category, separator, output", data_list, ids=[x[0] for x in data_list])
@pytest.mark.fast
def test_simple_1(category: str, separator: str, output: str) -> None:
    label = find_ar_label(category, separator, use_event2=False)
    assert label == output


test_data = {x[0]: x[2] for x in data_list}


@pytest.mark.parametrize("category,expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_simple_3(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data_callback(
    [("test_data", test_data, resolve_label_ar)], run_same=True, just_dump=True
)
