"""
Data translations and mappings for the ArWikiCats project.
This package aggregates translation data for various categories including
geography, jobs, languages, nationalities, sports, and media.
"""

# NOTE: imports of functions have been moved to funcs.py
# (geo|jobs|mixed|nats|others|sports|tv)
from .geo import (
    CITY_TRANSLATIONS_LOWER,
    COUNTRY_LABEL_OVERRIDES,
    US_STATES,
    raw_region_overrides,
)
from .jobs import (
    FEMALE_JOBS_BASE_EXTENDED,
    NAT_BEFORE_OCC,
    NAT_BEFORE_OCC_BASE,
    PLAYERS_TO_MEN_WOMENS_JOBS,
    RELIGIOUS_KEYS_PP,
    SPORT_JOB_VARIANTS,
    Jobs_new,
    jobs_mens_data,
    jobs_womens_data,
    short_womens_jobs,
)
from .mixed import (
    ALBUMS_TYPE,
    FILM_PRODUCTION_COMPANY,
    INTER_FEDS_LOWER,
    PARTIES,
    WORD_AFTER_YEARS,
    Clubs_key_2,
    New_female_keys,
    clubs_teams_leagues,
    keys_of_without_in,
    medical_keys,
    pop_final_5,
    religious_entries,
)
from .nats import (
    All_Nat,
    Nat_men,
    Nat_mens,
    Nat_the_female,
    Nat_the_male,
    Nat_women,
    Nat_Womens,
    NationalityEntry,
    all_country_ar,
    all_country_with_nat,
    all_country_with_nat_ar,
    all_nat_sorted,
    ar_Nat_men,
    countries_en_as_nationality_keys,
    countries_from_nat,
    countries_nat_en_key,
    en_nats_to_ar_label,
    raw_nats_as_en_key,
)
from .others import (
    COMPLEX_LANGUAGE_TRANSLATIONS,
    LANGUAGE_TOPIC_FORMATS,
    PRIMARY_LANGUAGE_TRANSLATIONS,
    language_key_translations,
    ministers_keys,
)
from .sports import (
    SPORT_KEY_RECORDS,
    SPORT_KEY_RECORDS_BASE,
    SPORTS_KEYS_FOR_JOBS,
    SPORTS_KEYS_FOR_LABEL,
    SPORTS_KEYS_FOR_TEAM,
    SUMMER_WINTER_GAMES,
)
from .tv import (
    TELEVISION_KEYS,
    Films_key_CAO,
    Films_key_For_nat,
    Films_key_man,
    Films_keys_both_new_female,
    film_keys_for_female,
    films_mslslat_tab,
)

__all__ = [
    "SPORT_JOB_VARIANTS",
    "PLAYERS_TO_MEN_WOMENS_JOBS",
    "US_STATES",
    "raw_region_overrides",
    "COUNTRY_LABEL_OVERRIDES",
    "en_nats_to_ar_label",
    "CITY_TRANSLATIONS_LOWER",
    "jobs_mens_data",
    "jobs_womens_data",
    "FEMALE_JOBS_BASE_EXTENDED",
    "short_womens_jobs",
    "NAT_BEFORE_OCC",
    "NAT_BEFORE_OCC_BASE",
    "Jobs_new",
    "NationalityEntry",
    "countries_en_as_nationality_keys",
    "raw_nats_as_en_key",
    "all_nat_sorted",
    "All_Nat",
    "Nat_women",
    "all_country_ar",
    "all_country_with_nat",
    "countries_nat_en_key",
    "all_country_with_nat_ar",
    "countries_from_nat",
    "Nat_mens",
    "Nat_the_male",
    "Nat_the_female",
    "Nat_Womens",
    "Nat_men",
    "ar_Nat_men",
    "SPORT_KEY_RECORDS",
    "SPORT_KEY_RECORDS_BASE",
    "SPORTS_KEYS_FOR_TEAM",
    "SPORTS_KEYS_FOR_LABEL",
    "SPORTS_KEYS_FOR_JOBS",
    "keys_of_without_in",
    "clubs_teams_leagues",
    "WORD_AFTER_YEARS",
    "ALBUMS_TYPE",
    "FILM_PRODUCTION_COMPANY",
    "SUMMER_WINTER_GAMES",
    "INTER_FEDS_LOWER",
    "pop_final_5",
    "Clubs_key_2",
    "Films_key_CAO",
    "TELEVISION_KEYS",
    "Films_key_For_nat",
    "Films_key_man",
    "films_mslslat_tab",
    "film_keys_for_female",
    "Films_keys_both_new_female",
    "RELIGIOUS_KEYS_PP",
    "PARTIES",
    "PRIMARY_LANGUAGE_TRANSLATIONS",
    "COMPLEX_LANGUAGE_TRANSLATIONS",
    "language_key_translations",
    "LANGUAGE_TOPIC_FORMATS",
    "medical_keys",
    "religious_entries",
    "New_female_keys",
    "ministers_keys",
]
