#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_skip = {
    "Defunct airports in Papua New Guinea": "مطارات سابقة في بابوا غينيا الجديدة",
    "April 2023 in Papua New Guinea": "بابوا غينيا الجديدة في أبريل 2023",
    "February 2024 in Papua New Guinea": "بابوا غينيا الجديدة في فبراير 2024",
    "May 2024 in Papua New Guinea": "بابوا غينيا الجديدة في مايو 2024",
    "March 2024 in Papua New Guinea": "بابوا غينيا الجديدة في مارس 2024",
    "January 2024 in Papua New Guinea": "بابوا غينيا الجديدة في يناير 2024",
    "September 2022 in Papua New Guinea": "بابوا غينيا الجديدة في سبتمبر 2022",
    "September 2025 in Papua New Guinea": "بابوا غينيا الجديدة في سبتمبر 2025",
    "October 2022 in Papua New Guinea": "بابوا غينيا الجديدة في أكتوبر 2022",
    "October 2023 in Papua New Guinea": "بابوا غينيا الجديدة في أكتوبر 2023",
    "May 2016 in Papua New Guinea": "بابوا غينيا الجديدة في مايو 2016",
    "July 2022 in Papua New Guinea": "بابوا غينيا الجديدة في يوليو 2022",
    "June 2016 in Papua New Guinea": "بابوا غينيا الجديدة في يونيو 2016",
    "2020 in Papua New Guinea": "بابوا غينيا الجديدة في 2020",
}

data_0 = {
    "Papua New Guinea men's international soccer players": "لاعبو كرة قدم دوليون من بابوا غينيا الجديدة",
    "Papua New Guinea women's international soccer players": "لاعبات كرة قدم دوليات من بابوا غينيا الجديدة",
    "Buka, Papua New Guinea": "",
    "Southern Region, Papua New Guinea": "",
    "1982 in Papua New Guinea rugby league": "",
    "1986 in Papua New Guinea rugby league": "",
    "19th-century disasters in Papua New Guinea": "",
    "2009 in Papua New Guinea rugby league": "",
    "2010 in Papua New Guinea rugby league": "",
    "2013 in Papua New Guinea rugby league": "",
    "2014 in Papua New Guinea rugby league": "",
    "2015 in Papua New Guinea rugby league": "",
    "2016 in Papua New Guinea rugby league": "",
    "2017 in Papua New Guinea rugby league": "",
    "2018 in Papua New Guinea rugby league": "",
    "2019 in Papua New Guinea rugby league": "",
    "2020 in Papua New Guinea rugby league": "",
    "2021 in Papua New Guinea rugby league": "",
    "2022 in Papua New Guinea rugby league": "",
    "2023 in Papua New Guinea rugby league": "",
    "A-Class Papua New Guinea articles": "",
    "Airfields of the United States Army Air Forces in Papua New Guinea": "",
    "Apostolic nuncios to Papua New Guinea": "",
    "Articles containing Awa (Papua New Guinea)-language text": "",
    "Articles containing Kela (Papua New Guinea)-language text": "",
    "Articles containing Kele (Papua New Guinea)-language text": "",
    "Articles containing Kol (Papua New Guinea)-language text": "",
    "Articles containing Kuman (Papua New Guinea)-language text": "",
    "Articles containing Sepa (Papua New Guinea)-language text": "",
    "Articles containing Toura (Papua New Guinea)-language text": "",
    "Articles containing Ura (Papua New Guinea)-language text": "",
    "Atolls of Papua New Guinea": "",
    "Attack-class patrol boats of the Papua New Guinea Defence Force": "",
    "Australian judges on the courts of Papua New Guinea": "",
    "Aviation history of Papua New Guinea": "",
    "B-Class Papua New Guinea articles": "",
    "Balikpapan-class landing craft heavy of the Papua New Guinea Defence Force": "",
    "Bilateral sports relations of Papua New Guinea": "",
    "Burials in Commonwealth War Graves Commission cemeteries in Papua New Guinea": "",
    "By-elections in Papua New Guinea": "",
    "C-Class Papua New Guinea articles": "",
    "Calderas of Papua New Guinea": "",
    "Category-Class Papua New Guinea pages": "",
    "Catholic Church in Papua New Guinea": "",
    "Catholic elementary and primary schools in Papua New Guinea": "",
    "Catholic schools in Papua New Guinea": "",
    "Catholic secondary schools in Papua New Guinea": "",
    "Central Province (Papua New Guinea)": "",
    "Chief Ombudsmen of Papua New Guinea": "",
    "Commanders of the Papua New Guinea Defence Force": "",
    "Commissioners of the Royal Papua New Guinea Constabulary": "",
    "Commonwealth War Graves Commission cemeteries in Papua New Guinea": "",
    "Congregationalism in Papua New Guinea": "",
    "Congregationalist missionaries in Papua New Guinea": "",
    "Consumer organisations in Papua New Guinea": "",
    "Cook Island expatriates in Papua New Guinea": "",
    "Cook Islands–Papua New Guinea relations": "",
    "Copper mines in Papua New Guinea": "",
    "Copper mining companies of Papua New Guinea": "",
    "Country data templates of Papua New Guinea": "",
    "Country data templates of subdivisions of Papua New Guinea": "",
    "Cricket grounds in Papua New Guinea": "",
    "Disambig-Class Papua New Guinea pages": "",
    "Draft-Class Papua New Guinea pages": "",
    "Elementary and primary schools in Papua New Guinea": "",
    "Endemic amphibian species of Papua New Guinea": "",
    "Endemic birds of Papua New Guinea": "",
    "Endemic fauna of Papua New Guinea": "",
    "Endemic flora of Papua New Guinea": "",
    "Endemic moth species of Papua New Guinea": "",
    "Endemic reptile species of Papua New Guinea": "",
    "Environmentalism in Papua New Guinea": "",
    "Expatriate judges on the courts of Papua New Guinea": "",
    "Extinct languages of Papua New Guinea": "",
    "FA-Class Papua New Guinea articles": "",
    "File-Class Papua New Guinea pages": "",
    "FL-Class Papua New Guinea articles": "",
    "FM-Class Papua New Guinea pages": "",
    "Folk festivals in Papua New Guinea": "",
    "Foreign charities operating in Papua New Guinea": "",
    "Forestry in Papua New Guinea": "",
    "Fossils of Papua New Guinea": "",
    "Freshwater fish of Papua New Guinea": "",
    "GA-Class Papua New Guinea articles": "",
    "Gold mines in Papua New Guinea": "",
    "Gold mining companies of Papua New Guinea": "",
    "Government departments of Papua New Guinea": "",
    "Governors of Central Province (Papua New Guinea)": "",
    "Governors of the National Capital District (Papua New Guinea)": "",
    "Heads of state of Papua New Guinea": "",
    "High commissioners of Australia to Papua New Guinea": "",
    "High commissioners of Bangladesh to Papua New Guinea": "",
    "High commissioners of Brunei to Papua New Guinea": "",
    "High commissioners of Canada to Papua New Guinea": "",
    "High commissioners of Fiji to Papua New Guinea": "",
    "High commissioners of Ghana to Papua New Guinea": "",
    "High commissioners of Malaysia to Papua New Guinea": "",
    "High commissioners of New Zealand to Papua New Guinea": "",
    "High commissioners of Papua New Guinea": "",
    "High commissioners of Papua New Guinea to Australia": "",
    "High commissioners of Papua New Guinea to Canada": "",
    "High commissioners of Papua New Guinea to Cyprus": "",
    "High commissioners of Papua New Guinea to Fiji": "",
    "High commissioners of Papua New Guinea to New Zealand": "",
    "High commissioners of Papua New Guinea to South Africa": "",
    "High commissioners of Papua New Guinea to the United Kingdom": "",
    "High commissioners of Singapore to Papua New Guinea": "",
    "High commissioners of Sri Lanka to Papua New Guinea": "",
    "High commissioners of the Cook Islands to Papua New Guinea": "",
    "High commissioners of the United Kingdom to Papua New Guinea": "",
    "High commissioners of Tuvalu to Papua New Guinea": "",
    "High commissioners to Papua New Guinea": "",
    "High schools and secondary schools in Papua New Guinea": "",
    "High-importance Papua New Guinea articles": "",
    "Hiking in Papua New Guinea": "",
    "History of sport in Papua New Guinea": "",
    "Holy See–Papua New Guinea relations": "",
    "Important Bird Areas of Papua New Guinea": "",
    "Industry in Papua New Guinea": "",
    "Infectious disease deaths in Papua New Guinea": "",
    "Infobox road instances in Papua New Guinea": "",
    "International Baccalaureate schools in Papua New Guinea": "",
    "International club association football competitions hosted by Papua New Guinea": "",
    "Lagoons of Papua New Guinea": "",
    "Languages of Central Province (Papua New Guinea)": "",
    "Languages of Southern Region (Papua New Guinea)": "",
    "Languages of Western Province (Papua New Guinea)": "",
    "Leaders of the opposition (Papua New Guinea)": "",
    "LGBTQ in Papua New Guinea": "",
    "List-Class Papua New Guinea articles": "",
    "Lists of members of the National Parliament of Papua New Guinea": "",
    "Local-level governments of Central Province (Papua New Guinea)": "",
    "Local-level governments of National Capital District (Papua New Guinea)": "",
    "Local-level governments of Papua New Guinea": "",
    "Local-level governments of Western Province (Papua New Guinea)": "",
    "Low-importance Papua New Guinea articles": "",
    "Lutheran missionaries in Papua New Guinea": "",
    "Lutheranism in Papua New Guinea": "",
    "Masks in Papua New Guinea": "",
    "Members of provincial assemblies of Papua New Guinea": "",
    "Members of the National Parliament of Papua New Guinea": "",
    "Methodism in Papua New Guinea": "",
    "Mid-importance Papua New Guinea articles": "",
    "Military locations of Papua New Guinea": "",
    "Ministers of internal finance of Papua New Guinea": "",
    "Ministers of primary industry of Papua New Guinea": "",
    "Moths of Papua New Guinea": "",
    "NA-Class Papua New Guinea pages": "",
    "NA-importance Papua New Guinea pages": "",
    "National Alliance Party (Papua New Guinea) politicians": "",
    "National Capital District (Papua New Guinea)": "",
    "National high schools in Papua New Guinea": "",
    "National Parliament of Papua New Guinea": "",
    "Nature conservation in Papua New Guinea": "",
    "New Generation Party (Papua New Guinea) politicians": "",
    "New Zealand expatriate sportspeople in Papua New Guinea": "",
    "New Zealand expatriates in Papua New Guinea": "",
    "News media in Papua New Guinea": "",
    "Olympic sailors for Papua New Guinea": "",
    "Orchids of Papua New Guinea": "",
    "Organized events in Papua New Guinea": "",
    "Orogenies of Papua New Guinea": "",
    "Pacific Games bronze medalists for Papua New Guinea": "",
    "Pacific Games gold medalists for Papua New Guinea": "",
    "Pacific Games silver medalists for Papua New Guinea": "",
    "Palm oil production in Papua New Guinea": "",
    "Papua New Guinea and the Commonwealth of Nations": "",
    "Papua New Guinea articles by importance": "",
    "Papua New Guinea articles by quality": "",
    "Papua New Guinea articles missing geocoordinate data": "",
    "Papua New Guinea articles needing attention": "",
    "Papua New Guinea at the 2024 OFC Men's Nations Cup": "",
    "Papua New Guinea at the OFC Men's Nations Cup": "",
    "Papua New Guinea cricket navigational boxes": "",
    "Papua New Guinea cricket templates": "",
    "Papua New Guinea cricket-related lists": "",
    "Papua New Guinea education-related lists": "",
    "Papua New Guinea football team navigational boxes": "",
    "Papua New Guinea geography-related lists": "",
    "Papua New Guinea history-related lists": "",
    "Papua New Guinea Hunters": "",
    "Papua New Guinea Hunters captains": "",
    "Papua New Guinea Hunters players": "",
    "Papua New Guinea Hunters templates": "",
    "Papua New Guinea location map modules": "",
    "Papua New Guinea modules": "",
    "Papua New Guinea national netball team series": "",
    "Papua New Guinea National Rugby League": "",
    "Papua New Guinea national rugby league team captains": "",
    "Papua New Guinea national rugby league team tours": "",
    "Papua New Guinea One Day International cricketers": "",
    "Papua New Guinea Party politicians": "",
    "Papua New Guinea politics-related lists": "",
    "Papua New Guinea religion-related lists": "",
    "Papua New Guinea rugby union templates": "",
    "Papua New Guinea sport-related lists": "",
    "Papua New Guinea stub templates": "",
    "Papua New Guinea transport-related lists": "",
    "Papua New Guinea Twenty20 International cricketers": "",
    "Papua New Guinea University of Technology alumni": "",
    "Papua New Guinea user categories": "",
    "Papua New Guinea user templates": "",
    "Papua New Guinea women One Day International cricketers": "",
    "Papua New Guinea women Twenty20 International cricketers": "",
    "Papua New Guinea–European Union relations": "",
    "Papua New Guinea–Solomon Islands border": "",
    "Papua New Guinea–Solomon Islands relations": "",
    "Papua New Guinea–Vanuatu relations": "",
    "Patrol vessels of the Papua New Guinea Defence Force": "",
    "People from Central Province (Papua New Guinea)": "",
    "People from Southern Region (Papua New Guinea)": "",
    "People from the National Capital District (Papua New Guinea)": "",
    "People from the Western Province (Papua New Guinea)": "",
    "People's First Party (Papua New Guinea) politicians": "",
    "People's National Congress (Papua New Guinea) politicians": "",
    "Permanent representatives of Papua New Guinea to the International Maritime Organization": "",
    "Philately of Papua New Guinea": "",
    "Politics of Central Province (Papua New Guinea)": "",
    "Politics of the National Capital District (Papua New Guinea)": "",
    "Populated places in Central Province (Papua New Guinea)": "",
    "Populated places in Southern Region (Papua New Guinea)": "",
    "Populated places in the Western Province (Papua New Guinea)": "",
    "Portal-Class Papua New Guinea pages": "",
    "Project-Class Papua New Guinea pages": "",
    "Ramsar sites in Papua New Guinea": "",
    "Redirect-Class Papua New Guinea pages": "",
    "Refugees in Papua New Guinea": "",
    "Roman Catholic cathedrals in Papua New Guinea": "",
    "Roman Catholic dioceses in Papua New Guinea": "",
    "Roman Catholic missionaries in Papua New Guinea": "",
    "Rugby league players from Central Province (Papua New Guinea)": "",
    "Rugby league players from the National Capital District (Papua New Guinea)": "",
    "Rugby league tours of Papua New Guinea": "",
    "Scientific organisations based in Papua New Guinea": "",
    "Scouting and Guiding in Papua New Guinea": "",
    "Shield volcanoes of Papua New Guinea": "",
    "Ships of the Papua New Guinea Defence Force": "",
    "Sign languages of Papua New Guinea": "",
    "Social Democratic Party (Papua New Guinea) politicians": "",
    "Solomon Islands expatriate sportspeople in Papua New Guinea": "",
    "Solomon Islands expatriates in Papua New Guinea": "",
    "Speakers of the National Parliament of Papua New Guinea": "",
    "Start-Class Papua New Guinea articles": "",
    "Stub-Class Papua New Guinea articles": "",
    "Surface mines in Papua New Guinea": "",
    "Teaching in Papua New Guinea": "",
    "Template-Class Papua New Guinea pages": "",
    "Top-importance Papua New Guinea articles": "",
    "Trees of Papua New Guinea": "",
    "Unassessed Papua New Guinea articles": "",
    "United Party (Papua New Guinea) politicians": "",
    "Unknown-importance Papua New Guinea articles": "",
    "Vice-chancellors of universities in Papua New Guinea": "",
    "Western Province (Papua New Guinea)": "",
    "Wikipedia categories named after organisations based in Papua New Guinea": "",
    "Wikipedia categories named after populated places in Papua New Guinea": "",
    "Wikipedia requested images of people of Papua New Guinea": "",
    "Wikipedia requested maps in Papua New Guinea": "",
    "Wikipedia requested photographs in Papua New Guinea": "",
    "Wikipedians in Papua New Guinea": "",
    "Wikipedians interested in Papua New Guinea": "",
    "WikiProject Papua New Guinea": "",
    "WikiProject Papua New Guinea articles": "",
    "WikiProject Papua New Guinea participants": "",
    "WikiProject Papua New Guinea templates": "",
    "Women members of the National Parliament of Papua New Guinea": "",
    "Women's rights in Papua New Guinea": "",
    "World Athletics Championships athletes for Papua New Guinea": "",
    "World War I sites in Papua New Guinea": "",
    "World War II airfields in Papua New Guinea": "",
    "World War II sites in Papua New Guinea": "",
}

data_1 = {
    "Chief justices of Papua New Guinea": "رؤساء قضاء بابوا غينيا الجديدة",
    "Coaches of the Papua New Guinea national cricket team": "مدربو منتخب بابوا غينيا الجديدة للكريكت",
    "Foreign relations of Papua New Guinea": "علاقات بابوا غينيا الجديدة الخارجية",
    "National symbols of Papua New Guinea": "رموز بابوا غينيا الجديدة الوطنية",
    "Orders, decorations, and medals of Papua New Guinea": "مراتب تشريفية وأوسمة وميداليات بابوا غينيا الجديدة",
    "1910s establishments in Papua New Guinea": "تأسيسات عقد 1910 في بابوا غينيا الجديدة",
    "1910s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1910",
    "1920s establishments in Papua New Guinea": "تأسيسات عقد 1920 في بابوا غينيا الجديدة",
    "1920s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1920",
    "1927 establishments in Papua New Guinea": "تأسيسات سنة 1927 في بابوا غينيا الجديدة",
    "1929 establishments in Papua New Guinea": "تأسيسات سنة 1929 في بابوا غينيا الجديدة",
    "1940s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 1940",
    "1940s establishments in Papua New Guinea": "تأسيسات عقد 1940 في بابوا غينيا الجديدة",
    "1940s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1940",
    "1942 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1942",
    "1948 establishments in Papua New Guinea": "تأسيسات سنة 1948 في بابوا غينيا الجديدة",
    "1949 establishments in Papua New Guinea": "تأسيسات سنة 1949 في بابوا غينيا الجديدة",
    "1950s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 1950",
    "1950s establishments in Papua New Guinea": "تأسيسات عقد 1950 في بابوا غينيا الجديدة",
    "1950s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1950",
    "1951 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1951",
    "1952 establishments in Papua New Guinea": "تأسيسات سنة 1952 في بابوا غينيا الجديدة",
    "1960 establishments in Papua New Guinea": "تأسيسات سنة 1960 في بابوا غينيا الجديدة",
    "1960s disestablishments in Papua New Guinea": "انحلالات عقد 1960 في بابوا غينيا الجديدة",
    "1960s establishments in Papua New Guinea": "تأسيسات عقد 1960 في بابوا غينيا الجديدة",
    "1960s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1960",
    "1961 establishments in Papua New Guinea": "تأسيسات سنة 1961 في بابوا غينيا الجديدة",
    "1962 establishments in Papua New Guinea": "تأسيسات سنة 1962 في بابوا غينيا الجديدة",
    "1963 disestablishments in Papua New Guinea": "انحلالات سنة 1963 في بابوا غينيا الجديدة",
    "1963 establishments in Papua New Guinea": "تأسيسات سنة 1963 في بابوا غينيا الجديدة",
    "1964 establishments in Papua New Guinea": "تأسيسات سنة 1964 في بابوا غينيا الجديدة",
    "1965 establishments in Papua New Guinea": "تأسيسات سنة 1965 في بابوا غينيا الجديدة",
    "1966 establishments in Papua New Guinea": "تأسيسات سنة 1966 في بابوا غينيا الجديدة",
    "1968 establishments in Papua New Guinea": "تأسيسات سنة 1968 في بابوا غينيا الجديدة",
    "1969 establishments in Papua New Guinea": "تأسيسات سنة 1969 في بابوا غينيا الجديدة",
    "1970 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1970",
    "1970s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 1970",
    "1970s disestablishments in Papua New Guinea": "انحلالات عقد 1970 في بابوا غينيا الجديدة",
    "1970s establishments in Papua New Guinea": "تأسيسات عقد 1970 في بابوا غينيا الجديدة",
    "1970s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1970",
    "1971 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1971",
    "1972 establishments in Papua New Guinea": "تأسيسات سنة 1972 في بابوا غينيا الجديدة",
    "1973 establishments in Papua New Guinea": "تأسيسات سنة 1973 في بابوا غينيا الجديدة",
    "1974 establishments in Papua New Guinea": "تأسيسات سنة 1974 في بابوا غينيا الجديدة",
    "1975 disestablishments in Papua New Guinea": "انحلالات سنة 1975 في بابوا غينيا الجديدة",
    "1975 establishments in Papua New Guinea": "تأسيسات سنة 1975 في بابوا غينيا الجديدة",
    "1976 establishments in Papua New Guinea": "تأسيسات سنة 1976 في بابوا غينيا الجديدة",
    "1977 establishments in Papua New Guinea": "تأسيسات سنة 1977 في بابوا غينيا الجديدة",
    "1978 establishments in Papua New Guinea": "تأسيسات سنة 1978 في بابوا غينيا الجديدة",
    "1980s disestablishments in Papua New Guinea": "انحلالات عقد 1980 في بابوا غينيا الجديدة",
    "1980s establishments in Papua New Guinea": "تأسيسات عقد 1980 في بابوا غينيا الجديدة",
    "1980s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1980",
    "1981 establishments in Papua New Guinea": "تأسيسات سنة 1981 في بابوا غينيا الجديدة",
    "1982 establishments in Papua New Guinea": "تأسيسات سنة 1982 في بابوا غينيا الجديدة",
    "1983 disestablishments in Papua New Guinea": "انحلالات سنة 1983 في بابوا غينيا الجديدة",
    "1984 establishments in Papua New Guinea": "تأسيسات سنة 1984 في بابوا غينيا الجديدة",
    "1985 establishments in Papua New Guinea": "تأسيسات سنة 1985 في بابوا غينيا الجديدة",
    "1986 establishments in Papua New Guinea": "تأسيسات سنة 1986 في بابوا غينيا الجديدة",
    "1987 establishments in Papua New Guinea": "تأسيسات سنة 1987 في بابوا غينيا الجديدة",
    "1989 disestablishments in Papua New Guinea": "انحلالات سنة 1989 في بابوا غينيا الجديدة",
    "1990 establishments in Papua New Guinea": "تأسيسات سنة 1990 في بابوا غينيا الجديدة",
    "1990s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 1990",
    "1990s establishments in Papua New Guinea": "تأسيسات عقد 1990 في بابوا غينيا الجديدة",
    "1990s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 1990",
    "1991 establishments in Papua New Guinea": "تأسيسات سنة 1991 في بابوا غينيا الجديدة",
    "1992 establishments in Papua New Guinea": "تأسيسات سنة 1992 في بابوا غينيا الجديدة",
    "1993 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1993",
    "1994 establishments in Papua New Guinea": "تأسيسات سنة 1994 في بابوا غينيا الجديدة",
    "1995 establishments in Papua New Guinea": "تأسيسات سنة 1995 في بابوا غينيا الجديدة",
    "1997 establishments in Papua New Guinea": "تأسيسات سنة 1997 في بابوا غينيا الجديدة",
    "1998 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 1998",
    "1999 establishments in Papua New Guinea": "تأسيسات سنة 1999 في بابوا غينيا الجديدة",
    "19th century in Papua New Guinea": "بابوا غينيا الجديدة في القرن 19",
    "2000 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2000",
    "2000s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 2000",
    "2000s establishments in Papua New Guinea": "تأسيسات عقد 2000 في بابوا غينيا الجديدة",
    "2000s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 2000",
    "2001 establishments in Papua New Guinea": "تأسيسات سنة 2001 في بابوا غينيا الجديدة",
    "2002 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2002",
    "2003 establishments in Papua New Guinea": "تأسيسات سنة 2003 في بابوا غينيا الجديدة",
    "2004 establishments in Papua New Guinea": "تأسيسات سنة 2004 في بابوا غينيا الجديدة",
    "2005 establishments in Papua New Guinea": "تأسيسات سنة 2005 في بابوا غينيا الجديدة",
    "2006 establishments in Papua New Guinea": "تأسيسات سنة 2006 في بابوا غينيا الجديدة",
    "2007 establishments in Papua New Guinea": "تأسيسات سنة 2007 في بابوا غينيا الجديدة",
    "2008 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2008",
    "2008 establishments in Papua New Guinea": "تأسيسات سنة 2008 في بابوا غينيا الجديدة",
    "2009 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2009",
    "2009 establishments in Papua New Guinea": "تأسيسات سنة 2009 في بابوا غينيا الجديدة",
    "2010 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2010",
    "2010 establishments in Papua New Guinea": "تأسيسات سنة 2010 في بابوا غينيا الجديدة",
    "2010s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 2010",
    "2010s establishments in Papua New Guinea": "تأسيسات عقد 2010 في بابوا غينيا الجديدة",
    "2010s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 2010",
    "2011 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2011",
    "2011 establishments in Papua New Guinea": "تأسيسات سنة 2011 في بابوا غينيا الجديدة",
    "2012 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2012",
    "2012 establishments in Papua New Guinea": "تأسيسات سنة 2012 في بابوا غينيا الجديدة",
    "2013 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2013",
    "2013 establishments in Papua New Guinea": "تأسيسات سنة 2013 في بابوا غينيا الجديدة",
    "2014 establishments in Papua New Guinea": "تأسيسات سنة 2014 في بابوا غينيا الجديدة",
    "2015 establishments in Papua New Guinea": "تأسيسات سنة 2015 في بابوا غينيا الجديدة",
    "2016 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2016",
    "2016 in Papua New Guinea by month": "بابوا غينيا الجديدة في 2016 حسب الشهر",
    "2017 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2017",
    "2017 establishments in Papua New Guinea": "تأسيسات سنة 2017 في بابوا غينيا الجديدة",
    "2018 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2018",
    "2018 establishments in Papua New Guinea": "تأسيسات سنة 2018 في بابوا غينيا الجديدة",
    "2019 establishments in Papua New Guinea": "تأسيسات سنة 2019 في بابوا غينيا الجديدة",
    "2020 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2020",
    "2020s disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في عقد 2020",
    "2020s establishments in Papua New Guinea": "تأسيسات عقد 2020 في بابوا غينيا الجديدة",
    "2020s in Papua New Guinea": "بابوا غينيا الجديدة في عقد 2020",
    "2021 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2021",
    "2022 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2022",
    "2022 establishments in Papua New Guinea": "تأسيسات سنة 2022 في بابوا غينيا الجديدة",
    "2022 in Papua New Guinea by month": "بابوا غينيا الجديدة في 2022 حسب الشهر",
    "2023 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2023",
    "2023 establishments in Papua New Guinea": "تأسيسات سنة 2023 في بابوا غينيا الجديدة",
    "2023 in Papua New Guinea by month": "بابوا غينيا الجديدة في 2023 حسب الشهر",
    "2024 disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في 2024",
    "2024 in Papua New Guinea by month": "بابوا غينيا الجديدة في 2024 حسب الشهر",
    "2025 in Papua New Guinea by month": "بابوا غينيا الجديدة في 2025 حسب الشهر",
    "20th century in Papua New Guinea": "بابوا غينيا الجديدة في القرن 20",
    "20th-century disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في القرن 20",
    "20th-century disestablishments in Papua New Guinea": "انحلالات القرن 20 في بابوا غينيا الجديدة",
    "20th-century establishments in Papua New Guinea": "تأسيسات القرن 20 في بابوا غينيا الجديدة",
    "20th-century Roman Catholic archbishops in Papua New Guinea": "رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة في القرن 20",
    "20th-century Roman Catholic bishops in Papua New Guinea": "أساقفة كاثوليك رومان في بابوا غينيا الجديدة في القرن 20",
    "21st century in Papua New Guinea": "بابوا غينيا الجديدة في القرن 21",
    "21st-century disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة في القرن 21",
    "21st-century establishments in Papua New Guinea": "تأسيسات القرن 21 في بابوا غينيا الجديدة",
    "21st-century Roman Catholic archbishops in Papua New Guinea": "رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة في القرن 21",
    "21st-century Roman Catholic bishops in Papua New Guinea": "أساقفة كاثوليك رومان في بابوا غينيا الجديدة في القرن 21",
    "2nd millennium in Papua New Guinea": "بابوا غينيا الجديدة في الألفية 2",
    "2nd-millennium disestablishments in Papua New Guinea": "انحلالات الألفية 2 في بابوا غينيا الجديدة",
    "2nd-millennium establishments in Papua New Guinea": "تأسيسات الألفية 2 في بابوا غينيا الجديدة",
    "3rd millennium in Papua New Guinea": "بابوا غينيا الجديدة في الألفية 3",
    "3rd-millennium establishments in Papua New Guinea": "تأسيسات الألفية 3 في بابوا غينيا الجديدة",
    "Academia in Papua New Guinea": "أكاديمية في بابوا غينيا الجديدة",
    "Academic staff of the University of Papua New Guinea": "أعضاء هيئة تدريس جامعة بابوا غينيا الجديدة",
    "Accidental deaths in Papua New Guinea": "وفيات عرضية في بابوا غينيا الجديدة",
    "Agriculture in Papua New Guinea": "زراعة في بابوا غينيا الجديدة",
    "Airlines of Papua New Guinea": "شركات طيران في بابوا غينيا الجديدة",
    "Airports in Papua New Guinea": "مطارات في بابوا غينيا الجديدة",
    "Alumni by university or college in Papua New Guinea": "خريجون حسب الجامعة أو الكلية في بابوا غينيا الجديدة",
    "Ambassadors of Austria to Papua New Guinea": "سفراء النمسا لدى بابوا غينيا الجديدة",
    "Ambassadors of Chile to Papua New Guinea": "سفراء تشيلي لدى بابوا غينيا الجديدة",
    "Ambassadors of China to Papua New Guinea": "سفراء الصين لدى بابوا غينيا الجديدة",
    "Ambassadors of Germany to Papua New Guinea": "سفراء ألمانيا لدى بابوا غينيا الجديدة",
    "Ambassadors of Hungary to Papua New Guinea": "سفراء المجر لدى بابوا غينيا الجديدة",
    "Ambassadors of Indonesia to Papua New Guinea": "سفراء إندونيسيا لدى بابوا غينيا الجديدة",
    "Ambassadors of Israel to Papua New Guinea": "سفراء إسرائيل لدى بابوا غينيا الجديدة",
    "Ambassadors of Palestine to Papua New Guinea": "سفراء فلسطين لدى بابوا غينيا الجديدة",
    "Ambassadors of Papua New Guinea": "سفراء بابوا غينيا الجديدة",
    "Ambassadors of Papua New Guinea to Belgium": "سفراء بابوا غينيا الجديدة لدى بلجيكا",
    "Ambassadors of Papua New Guinea to Canada": "سفراء بابوا غينيا الجديدة لدى كندا",
    "Ambassadors of Papua New Guinea to China": "سفراء بابوا غينيا الجديدة لدى الصين",
    "Ambassadors of Papua New Guinea to Egypt": "سفراء بابوا غينيا الجديدة لدى مصر",
    "Ambassadors of Papua New Guinea to Greece": "سفراء بابوا غينيا الجديدة لدى اليونان",
    "Ambassadors of Papua New Guinea to Israel": "سفراء بابوا غينيا الجديدة لدى إسرائيل",
    "Ambassadors of Papua New Guinea to Italy": "سفراء بابوا غينيا الجديدة لدى إيطاليا",
    "Ambassadors of Papua New Guinea to Japan": "سفراء بابوا غينيا الجديدة لدى اليابان",
    "Ambassadors of Papua New Guinea to Mexico": "سفراء بابوا غينيا الجديدة لدى المكسيك",
    "Ambassadors of Papua New Guinea to South Korea": "سفراء بابوا غينيا الجديدة لدى كوريا الجنوبية",
    "Ambassadors of Papua New Guinea to the European Union": "سفراء بابوا غينيا الجديدة لدى الاتحاد الأوروبي",
    "Ambassadors of Papua New Guinea to the Netherlands": "سفراء بابوا غينيا الجديدة لدى هولندا",
    "Ambassadors of Papua New Guinea to the Philippines": "سفراء بابوا غينيا الجديدة لدى الفلبين",
    "Ambassadors of Papua New Guinea to the United States": "سفراء بابوا غينيا الجديدة لدى الولايات المتحدة",
    "Ambassadors of Papua New Guinea to Zimbabwe": "سفراء بابوا غينيا الجديدة لدى زيمبابوي",
    "Ambassadors of Poland to Papua New Guinea": "سفراء بولندا لدى بابوا غينيا الجديدة",
    "Ambassadors of Russia to Papua New Guinea": "سفراء روسيا لدى بابوا غينيا الجديدة",
    "Ambassadors of Sweden to Papua New Guinea": "سفراء السويد لدى بابوا غينيا الجديدة",
    "Ambassadors of Thailand to Papua New Guinea": "سفراء تايلاند لدى بابوا غينيا الجديدة",
    "Ambassadors of the Soviet Union to Papua New Guinea": "سفراء الاتحاد السوفيتي لدى بابوا غينيا الجديدة",
    "Ambassadors of the United States to Papua New Guinea": "سفراء الولايات المتحدة لدى بابوا غينيا الجديدة",
    "Ambassadors to Papua New Guinea": "سفراء لدى بابوا غينيا الجديدة",
    "American expatriate sportspeople in Papua New Guinea": "رياضيون أمريكيون مغتربون في بابوا غينيا الجديدة",
    "American expatriates in Papua New Guinea": "أمريكيون مغتربون في بابوا غينيا الجديدة",
    "Amphibians of Papua New Guinea": "برمائيات بابوا غينيا الجديدة",
    "Anglican bishops in Papua New Guinea": "أساقفة أنجليكيون في بابوا غينيا الجديدة",
    "Anglican missionaries in Papua New Guinea": "مبشرون أنجليكيون في بابوا غينيا الجديدة",
    "Anglicanism in Papua New Guinea": "أنجليكية في بابوا غينيا الجديدة",
    "Animal breeds originating in Papua New Guinea": "سلالات حيوانية نشأت في بابوا غينيا الجديدة",
    "Archaeological sites in Papua New Guinea": "مواقع أثرية في بابوا غينيا الجديدة",
    "Archaeology of Papua New Guinea": "علم الآثار في بابوا غينيا الجديدة",
    "Archbishops in Papua New Guinea": "رؤساء أساقفة في بابوا غينيا الجديدة",
    "Archipelagoes of Papua New Guinea": "أرخبيلات بابوا غينيا الجديدة",
    "Arts in Papua New Guinea": "الفنون في بابوا غينيا الجديدة",
    "Athletics in Papua New Guinea": "ألعاب القوى في بابوا غينيا الجديدة",
    "Athletics venues in Papua New Guinea": "ملاعب ألعاب القوى في بابوا غينيا الجديدة",
    "Australian emigrants to Papua New Guinea": "أستراليون مهاجرون إلى بابوا غينيا الجديدة",
    "Australian expatriate sportspeople in Papua New Guinea": "رياضيون أستراليون مغتربون في بابوا غينيا الجديدة",
    "Australian expatriates in Papua New Guinea": "أستراليون مغتربون في بابوا غينيا الجديدة",
    "Australian rules football in Papua New Guinea": "كرة القدم الأسترالية في بابوا غينيا الجديدة",
    "Austrian expatriates in Papua New Guinea": "نمساويون مغتربون في بابوا غينيا الجديدة",
    "Aviation accidents and incidents in Papua New Guinea": "حوادث طيران في بابوا غينيا الجديدة",
    "Aviation in Papua New Guinea": "طيران في بابوا غينيا الجديدة",
    "Aviation organisations based in Papua New Guinea": "منظمات طيران مقرها في بابوا غينيا الجديدة",
    "Banks of Papua New Guinea": "بنوك بابوا غينيا الجديدة",
    "Basketball in Papua New Guinea": "كرة السلة في بابوا غينيا الجديدة",
    "Basketball teams in Papua New Guinea": "فرق كرة السلة في بابوا غينيا الجديدة",
    "Battles and operations of World War II involving Papua New Guinea": "معارك وعمليات الحرب العالمية الثانية تشمل بابوا غينيا الجديدة",
    "Bays of Papua New Guinea": "خلجان بابوا غينيا الجديدة",
    "Beetles of Papua New Guinea": "خنافس في بابوا غينيا الجديدة",
    "Belgian expatriates in Papua New Guinea": "بلجيكيون مغتربون في بابوا غينيا الجديدة",
    "Bilateral relations of Papua New Guinea": "علاقات بابوا غينيا الجديدة الثنائية",
    "Biota of Papua New Guinea": "حيويات بابوا غينيا الجديدة",
    "Birds of Papua New Guinea": "طيور بابوا غينيا الجديدة",
    "Bishops in Papua New Guinea": "أساقفة في بابوا غينيا الجديدة",
    "Bodies of water of Papua New Guinea": "مسطحات مائية في بابوا غينيا الجديدة",
    "Borders of Papua New Guinea": "حدود بابوا غينيا الجديدة",
    "Botanical gardens in Papua New Guinea": "حدائق نباتية في بابوا غينيا الجديدة",
    "Bowling in Papua New Guinea": "بولينج في بابوا غينيا الجديدة",
    "Bowls in Papua New Guinea": "البولينج في بابوا غينيا الجديدة",
    "Brazilian expatriate sportspeople in Papua New Guinea": "رياضيون برازيليون مغتربون في بابوا غينيا الجديدة",
    "Bridges in Papua New Guinea": "جسور في بابوا غينيا الجديدة",
    "British emigrants to Papua New Guinea": "بريطانيون مهاجرون إلى بابوا غينيا الجديدة",
    "British expatriates in Papua New Guinea": "بريطانيون مغتربون في بابوا غينيا الجديدة",
    "Broadcasting in Papua New Guinea": "بث لاسلكي في بابوا غينيا الجديدة",
    "Buildings and structures in Papua New Guinea": "مبان ومنشآت في بابوا غينيا الجديدة",
    "Buildings and structures in Papua New Guinea by city": "مبان ومنشآت في بابوا غينيا الجديدة حسب المدينة",
    "Buildings and structures in Papua New Guinea by type": "مبان ومنشآت في بابوا غينيا الجديدة حسب الفئة",
    "Business organisations based in Papua New Guinea": "منظمات أعمال مقرها في بابوا غينيا الجديدة",
    "Categories by province of Papua New Guinea": "تصنيفات حسب المقاطعة في بابوا غينيا الجديدة",
    "Cathedrals in Papua New Guinea": "كاتدرائيات في بابوا غينيا الجديدة",
    "Caves of Papua New Guinea": "كهوف بابوا غينيا الجديدة",
    "Cemeteries in Papua New Guinea": "مقابر في بابوا غينيا الجديدة",
    "Centuries in Papua New Guinea": "قرون في بابوا غينيا الجديدة",
    "Children's books set in Papua New Guinea": "كتب أطفال تقع أحداثها في بابوا غينيا الجديدة",
    "Christian missionaries in Papua New Guinea": "مبشرون مسيحيون في بابوا غينيا الجديدة",
    "Christianity in Papua New Guinea": "المسيحية في بابوا غينيا الجديدة",
    "Churches in Papua New Guinea": "كنائس في بابوا غينيا الجديدة",
    "Cinema of Papua New Guinea": "سينما في بابوا غينيا الجديدة",
    "Civil aviation in Papua New Guinea": "الطيران المدني في بابوا غينيا الجديدة",
    "Commonwealth Games bronze medallists for Papua New Guinea": "فائزون بميداليات برونزية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Commonwealth Games competitors for Papua New Guinea": "منافسون في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Commonwealth Games gold medallists for Papua New Guinea": "فائزون بميداليات ذهبية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Commonwealth Games medallists for Papua New Guinea": "فائزون بميداليات ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Commonwealth Games silver medallists for Papua New Guinea": "فائزون بميداليات فضية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Communications in Papua New Guinea": "الاتصالات في بابوا غينيا الجديدة",
    "Companies of Papua New Guinea": "شركات في بابوا غينيا الجديدة",
    "Companies of Papua New Guinea by industry": "شركات في بابوا غينيا الجديدة حسب الصناعة",
    "Conservative parties in Papua New Guinea": "أحزاب محافظة في بابوا غينيا الجديدة",
    "COVID-19 pandemic in Papua New Guinea": "جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Cricket in Papua New Guinea": "الكريكت في بابوا غينيا الجديدة",
    "Cricket in Papua New Guinea by decade": "الكريكت في بابوا غينيا الجديدة حسب العقد",
    "Cricket in Papua New Guinea by year": "الكريكت في بابوا غينيا الجديدة حسب السنة",
    "Crime in Papua New Guinea": "جريمة في بابوا غينيا الجديدة",
    "Crime in Papua New Guinea by type": "جريمة في بابوا غينيا الجديدة حسب الفئة",
    "Cultural festivals in Papua New Guinea": "مهرجانات ثقافية في بابوا غينيا الجديدة",
    "Cultural organisations based in Papua New Guinea": "منظمات ثقافية مقرها في بابوا غينيا الجديدة",
    "Culture of Papua New Guinea": "ثقافة بابوا غينيا الجديدة",
    "Currencies of Papua New Guinea": "عملات في بابوا غينيا الجديدة",
    "Dams in Papua New Guinea": "سدود في بابوا غينيا الجديدة",
    "Dance festivals in Papua New Guinea": "مهرجانات رقص في بابوا غينيا الجديدة",
    "Danish expatriate sportspeople in Papua New Guinea": "رياضيون دنماركيون مغتربون في بابوا غينيا الجديدة",
    "Death in Papua New Guinea": "الموت في بابوا غينيا الجديدة",
    "Deaths by firearm in Papua New Guinea": "وفيات بإطلاق النار في بابوا غينيا الجديدة",
    "Deaths from cancer in Papua New Guinea": "وفيات السرطان في بابوا غينيا الجديدة",
    "Deaths in Papua New Guinea": "وفيات في بابوا غينيا الجديدة",
    "Decades in Papua New Guinea": "عقود في بابوا غينيا الجديدة",
    "Defunct airlines of Papua New Guinea": "شركات طيران سابقة في بابوا غينيا الجديدة",
    "Defunct companies of Papua New Guinea": "شركات سابقة في بابوا غينيا الجديدة",
    "Defunct organisations based in Papua New Guinea": "منظمات سابقة مقرها في بابوا غينيا الجديدة",
    "Defunct political parties in Papua New Guinea": "أحزاب سياسية سابقة في بابوا غينيا الجديدة",
    "Demographics of Papua New Guinea": "التركيبة السكانية في بابوا غينيا الجديدة",
    "Deputy prime ministers of Papua New Guinea": "نواب رؤساء وزراء بابوا غينيا الجديدة",
    "Diplomatic missions of Papua New Guinea": "بعثات بابوا غينيا الجديدة الدبلوماسية",
    "Diplomatic ranks in Papua New Guinea": "درجات دبلوماسية في بابوا غينيا الجديدة",
    "Diplomats for Papua New Guinea": "دبلوماسيون في بابوا غينيا الجديدة",
    "Disability in Papua New Guinea": "إعاقة في بابوا غينيا الجديدة",
    "Disasters in Papua New Guinea": "كوارث في بابوا غينيا الجديدة",
    "Disasters in Papua New Guinea by century": "كوارث في بابوا غينيا الجديدة حسب القرن",
    "Disasters in Papua New Guinea by decade": "كوارث في بابوا غينيا الجديدة حسب العقد",
    "Disasters in Papua New Guinea by year": "كوارث في بابوا غينيا الجديدة حسب السنة",
    "Discrimination in Papua New Guinea": "تمييز في بابوا غينيا الجديدة",
    "Disease outbreaks in Papua New Guinea": "تفشي طبي في بابوا غينيا الجديدة",
    "Disease-related deaths in Papua New Guinea": "وفيات مرتبطة بالمرض في بابوا غينيا الجديدة",
    "Disestablishments in Papua New Guinea": "انحلالات في بابوا غينيا الجديدة",
    "Disestablishments in Papua New Guinea by century": "انحلالات في بابوا غينيا الجديدة حسب القرن",
    "Disestablishments in Papua New Guinea by decade": "انحلالات في بابوا غينيا الجديدة حسب العقد",
    "Disestablishments in Papua New Guinea by millennium": "انحلالات في بابوا غينيا الجديدة حسب الألفية",
    "Disestablishments in Papua New Guinea by year": "انحلالات في بابوا غينيا الجديدة حسب السنة",
    "Districts of Papua New Guinea": "مديريات بابوا غينيا الجديدة",
    "Diving in Papua New Guinea": "الغطس في بابوا غينيا الجديدة",
    "Documentary films about Papua New Guinea": "أفلام وثائقية عن بابوا غينيا الجديدة",
    "Dog breeds originating in Papua New Guinea": "سلالات كلاب نشأت في بابوا غينيا الجديدة",
    "Drug-related deaths in Papua New Guinea": "وفيات مرتبطة بالمخدرات في بابوا غينيا الجديدة",
    "Drugs in Papua New Guinea": "عقاقير في بابوا غينيا الجديدة",
    "Earthquakes in Papua New Guinea": "زلازل في بابوا غينيا الجديدة",
    "Economic history of Papua New Guinea": "تاريخ بابوا غينيا الجديدة الاقتصادي",
    "Economy of Papua New Guinea": "اقتصاد بابوا غينيا الجديدة",
    "Ecoregions of Papua New Guinea": "مناطق بيئية في بابوا غينيا الجديدة",
    "Education in Papua New Guinea": "التعليم في بابوا غينيا الجديدة",
    "Educational organisations based in Papua New Guinea": "منظمات تعليمية مقرها في بابوا غينيا الجديدة",
    "Elections in Papua New Guinea": "انتخابات في بابوا غينيا الجديدة",
    "Electric power companies of Papua New Guinea": "شركات طاقة كهربائية في بابوا غينيا الجديدة",
    "Electric power in Papua New Guinea": "طاقة كهربائية في بابوا غينيا الجديدة",
    "Electric power infrastructure in Papua New Guinea": "بنية تحتية للقدرة الكهربائية في بابوا غينيا الجديدة",
    "Energy companies of Papua New Guinea": "شركات طاقة في بابوا غينيا الجديدة",
    "Energy in Papua New Guinea": "طاقة في بابوا غينيا الجديدة",
    "Energy infrastructure in Papua New Guinea": "بنية تحتية للطاقة في بابوا غينيا الجديدة",
    "Entertainment events in Papua New Guinea": "أحداث ترفيهية في بابوا غينيا الجديدة",
    "Entertainment in Papua New Guinea": "ترفيه في بابوا غينيا الجديدة",
    "Entertainment venues in Papua New Guinea": "أماكن ترفيه في بابوا غينيا الجديدة",
    "Environment of Papua New Guinea": "بيئة بابوا غينيا الجديدة",
    "Environmental issues in Papua New Guinea": "قضايا بيئية في بابوا غينيا الجديدة",
    "Environmental organisations based in Papua New Guinea": "منظمات بيئية مقرها في بابوا غينيا الجديدة",
    "Establishments in Papua New Guinea": "تأسيسات في بابوا غينيا الجديدة",
    "Establishments in Papua New Guinea by century": "تأسيسات في بابوا غينيا الجديدة حسب القرن",
    "Establishments in Papua New Guinea by decade": "تأسيسات في بابوا غينيا الجديدة حسب العقد",
    "Establishments in Papua New Guinea by millennium": "تأسيسات في بابوا غينيا الجديدة حسب الألفية",
    "Establishments in Papua New Guinea by year": "تأسيسات في بابوا غينيا الجديدة حسب السنة",
    "Ethnic groups in Papua New Guinea": "مجموعات عرقية في بابوا غينيا الجديدة",
    "Expatriate football managers in Papua New Guinea": "مدربو كرة قدم مغتربون في بابوا غينيا الجديدة",
    "Expatriate footballers in Papua New Guinea": "لاعبو كرة قدم مغتربون في بابوا غينيا الجديدة",
    "Expatriate sportspeople in Papua New Guinea": "رياضيون مغتربون في بابوا غينيا الجديدة",
    "Expatriate sportspeople in Papua New Guinea by nationality": "رياضيون مغتربون في بابوا غينيا الجديدة حسب الجنسية",
    "Expatriates in Papua New Guinea": "مغتربون في بابوا غينيا الجديدة",
    "Fauna of Papua New Guinea": "حيوانات بابوا غينيا الجديدة",
    "Featured pictures of Papua New Guinea": "صور مميزة عن بابوا غينيا الجديدة",
    "Festivals in Papua New Guinea": "مهرجانات في بابوا غينيا الجديدة",
    "Field hockey in Papua New Guinea": "هوكي الميدان في بابوا غينيا الجديدة",
    "Fijian expatriate sportspeople in Papua New Guinea": "رياضيون فيجيون مغتربون في بابوا غينيا الجديدة",
    "Fijian expatriates in Papua New Guinea": "فيجيون مغتربون في بابوا غينيا الجديدة",
    "Films set in Papua New Guinea": "أفلام تقع أحداثها في بابوا غينيا الجديدة",
    "Films shot in Papua New Guinea": "أفلام مصورة في بابوا غينيا الجديدة",
    "Financial services companies of Papua New Guinea": "شركات خدمات مالية في بابوا غينيا الجديدة",
    "Financial services in Papua New Guinea": "خدمات مالية في بابوا غينيا الجديدة",
    "Fish of Papua New Guinea": "أسماك بابوا غينيا الجديدة",
    "Flora of Papua New Guinea": "نباتات بابوا غينيا الجديدة",
    "Football competitions in Papua New Guinea": "منافسات كرة قدم في بابوا غينيا الجديدة",
    "Football leagues in Papua New Guinea": "دوريات كرة قدم في بابوا غينيا الجديدة",
    "Football managers in Papua New Guinea": "مدربو كرة قدم في بابوا غينيا الجديدة",
    "Football people in Papua New Guinea": "أعلام كرة قدم في بابوا غينيا الجديدة",
    "Football venues in Papua New Guinea": "ملاعب كرة القدم في بابوا غينيا الجديدة",
    "Footballers in Papua New Guinea": "لاعبو كرة قدم في بابوا غينيا الجديدة",
    "Footballers in Papua New Guinea by club": "لاعبو كرة قدم في بابوا غينيا الجديدة حسب النادي",
    "Former buildings and structures in Papua New Guinea": "مبان ومنشآت سابقة في بابوا غينيا الجديدة",
    "Fossil fuels in Papua New Guinea": "وقود أحفوري في بابوا غينيا الجديدة",
    "French expatriates in Papua New Guinea": "فرنسيون مغتربون في بابوا غينيا الجديدة",
    "Futsal in Papua New Guinea": "كرة صالات في بابوا غينيا الجديدة",
    "Gender in Papua New Guinea": "الجنس في بابوا غينيا الجديدة",
    "Geography of Papua New Guinea": "جغرافيا بابوا غينيا الجديدة",
    "Geology of Papua New Guinea": "جيولوجيا بابوا غينيا الجديدة",
    "German expatriate sportspeople in Papua New Guinea": "رياضيون ألمان مغتربون في بابوا غينيا الجديدة",
    "German expatriates in Papua New Guinea": "ألمان مغتربون في بابوا غينيا الجديدة",
    "Government ministers of Papua New Guinea": "وزراء بابوا غينيا الجديدة",
    "Government of Papua New Guinea": "حكومة بابوا غينيا الجديدة",
    "Governors of the Bank of Papua New Guinea": "حكام من بنك بابوا غينيا الجديدة",
    "Governors-general of Papua New Guinea": "حكام عموم بابوا غينيا الجديدة",
    "Headlands of Papua New Guinea": "أراضي رأسية في بابوا غينيا الجديدة",
    "Health disasters in Papua New Guinea": "كوارث صحية في بابوا غينيا الجديدة",
    "Health in Papua New Guinea": "الصحة في بابوا غينيا الجديدة",
    "Historic sites in Papua New Guinea": "مواقع تاريخية في بابوا غينيا الجديدة",
    "History of Papua New Guinea": "تاريخ بابوا غينيا الجديدة",
    "History of Papua New Guinea by period": "تاريخ بابوا غينيا الجديدة حسب الحقبة",
    "History of Papua New Guinea by topic": "تاريخ بابوا غينيا الجديدة حسب الموضوع",
    "History of the Papua New Guinea national soccer team": "تاريخ منتخب بابوا غينيا الجديدة لكرة القدم",
    "History of transport in Papua New Guinea": "تاريخ النقل في بابوا غينيا الجديدة",
    "History of women in Papua New Guinea": "تاريخ المرأة في بابوا غينيا الجديدة",
    "Hospitals in Papua New Guinea": "مستشفيات في بابوا غينيا الجديدة",
    "Hotels in Papua New Guinea": "فنادق في بابوا غينيا الجديدة",
    "Human rights abuses in Papua New Guinea": "انتهاك حقوق الإنسان في بابوا غينيا الجديدة",
    "Human rights in Papua New Guinea": "حقوق الإنسان في بابوا غينيا الجديدة",
    "Hydroelectric power stations in Papua New Guinea": "محطات طاقة كهرمائية في بابوا غينيا الجديدة",
    "Hydroelectricity in Papua New Guinea": "الطاقة الكهرومائية في بابوا غينيا الجديدة",
    "Images of Papua New Guinea": "صور من بابوا غينيا الجديدة",
    "Immigrants to Papua New Guinea": "مهاجرون إلى بابوا غينيا الجديدة",
    "Indian expatriates in Papua New Guinea": "هنود مغتربون في بابوا غينيا الجديدة",
    "Industrial buildings in Papua New Guinea": "مبان صناعية في بابوا غينيا الجديدة",
    "Infrastructure in Papua New Guinea": "بنية تحتية في بابوا غينيا الجديدة",
    "Insects of Papua New Guinea": "حشرات بابوا غينيا الجديدة",
    "International association football competitions hosted by Papua New Guinea": "منافسات كرة قدم دولية استضافتها بابوا غينيا الجديدة",
    "International cricket competitions in Papua New Guinea": "منافسات كريكت دولية في بابوا غينيا الجديدة",
    "International netball competitions hosted by Papua New Guinea": "منافسات كرة شبكة دولية استضافتها بابوا غينيا الجديدة",
    "International rugby league competitions hosted by Papua New Guinea": "منافسات دوري رجبي دولية استضافتها بابوا غينيا الجديدة",
    "International rugby union competitions hosted by Papua New Guinea": "منافسات اتحاد رجبي دولية استضافتها بابوا غينيا الجديدة",
    "International schools in Papua New Guinea": "مدارس دولية في بابوا غينيا الجديدة",
    "International sports competitions hosted by Papua New Guinea": "منافسات رياضية دولية استضافتها بابوا غينيا الجديدة",
    "Irish emigrants to Papua New Guinea": "أيرلنديون مهاجرون إلى بابوا غينيا الجديدة",
    "Islam in Papua New Guinea": "الإسلام في بابوا غينيا الجديدة",
    "Islands of Papua New Guinea": "جزر بابوا غينيا الجديدة",
    "Italian expatriates in Papua New Guinea": "إيطاليون مغتربون في بابوا غينيا الجديدة",
    "Labor disputes in Papua New Guinea": "نزاعات عمالية في بابوا غينيا الجديدة",
    "Lakes of Papua New Guinea": "بحيرات بابوا غينيا الجديدة",
    "Landforms of Papua New Guinea": "تضاريس بابوا غينيا الجديدة",
    "Landmarks in Papua New Guinea": "معالم في بابوا غينيا الجديدة",
    "Languages of Papua New Guinea": "لغات بابوا غينيا الجديدة",
    "Law enforcement in Papua New Guinea": "تطبيق القانون في بابوا غينيا الجديدة",
    "Law of Papua New Guinea": "قانون في بابوا غينيا الجديدة",
    "Leaders of political parties in Papua New Guinea": "قادة أحزاب سياسية في بابوا غينيا الجديدة",
    "Lepidoptera of Papua New Guinea": "حرشفيات الأجنحة في بابوا غينيا الجديدة",
    "Libraries in Papua New Guinea": "مكتبات في بابوا غينيا الجديدة",
    "Lists of ambassadors to Papua New Guinea": "قوائم سفراء لدى بابوا غينيا الجديدة",
    "Lists of biota of Papua New Guinea": "قوائم حيويات بابوا غينيا الجديدة",
    "Lists of buildings and structures in Papua New Guinea": "قوائم مبان ومنشآت في بابوا غينيا الجديدة",
    "Lists of islands of Papua New Guinea": "قوائم جزر بابوا غينيا الجديدة",
    "Lists of landforms of Papua New Guinea": "قوائم تضاريس بابوا غينيا الجديدة",
    "Lists of mass media in Papua New Guinea": "قوائم وسائل إعلام في بابوا غينيا الجديدة",
    "Lists of religious buildings and structures in Papua New Guinea": "قوائم مبان ومنشآت دينية في بابوا غينيا الجديدة",
    "Lists of tourist attractions in Papua New Guinea": "قوائم مواقع جذب سياحي في بابوا غينيا الجديدة",
    "Malaysian emigrants to Papua New Guinea": "ماليزيون مهاجرون إلى بابوا غينيا الجديدة",
    "Malaysian expatriates in Papua New Guinea": "ماليزيون مغتربون في بابوا غينيا الجديدة",
    "Mammals of Papua New Guinea": "ثدييات بابوا غينيا الجديدة",
    "Man-made disasters in Papua New Guinea": "كوارث من صنع الإنسان في بابوا غينيا الجديدة",
    "Maritime history of Papua New Guinea": "تاريخ بابوا غينيا الجديدة البحري",
    "Maritime incidents in Papua New Guinea": "حوادث بحرية في بابوا غينيا الجديدة",
    "Martial arts in Papua New Guinea": "الفنون القتالية في بابوا غينيا الجديدة",
    "Mass media in Papua New Guinea": "وسائل إعلام في بابوا غينيا الجديدة",
    "Medical and health organisations based in Papua New Guinea": "منظمات طبية وصحية مقرها في بابوا غينيا الجديدة",
    "Men in Papua New Guinea": "رجال في بابوا غينيا الجديدة",
    "Men's sport in Papua New Guinea": "رياضة رجالية في بابوا غينيا الجديدة",
    "Methodist missionaries in Papua New Guinea": "مبشرون ميثوديون لاهوتيون في بابوا غينيا الجديدة",
    "Military equipment of Papua New Guinea": "عتاد بابوا غينيا الجديدة العسكري",
    "Military history of Papua New Guinea": "تاريخ بابوا غينيا الجديدة العسكري",
    "Military of Papua New Guinea": "عسكرية بابوا غينيا الجديدة",
    "Military units and formations of Papua New Guinea": "وحدات وتشكيلات بابوا غينيا الجديدة العسكرية",
    "Millennia in Papua New Guinea": "ألفيات في بابوا غينيا الجديدة",
    "Mines in Papua New Guinea": "مناجم في بابوا غينيا الجديدة",
    "Mining companies of Papua New Guinea": "شركات تعدين في بابوا غينيا الجديدة",
    "Mining disasters in Papua New Guinea": "كوارث التعدين في بابوا غينيا الجديدة",
    "Mining in Papua New Guinea": "تعدين في بابوا غينيا الجديدة",
    "Ministers of defence of Papua New Guinea": "وزراء دفاع بابوا غينيا الجديدة",
    "Ministers of finance of Papua New Guinea": "وزراء مالية بابوا غينيا الجديدة",
    "Molluscs of Papua New Guinea": "رخويات بابوا غينيا الجديدة",
    "Mountain ranges of Papua New Guinea": "سلاسل جبلية في بابوا غينيا الجديدة",
    "Mountains of Papua New Guinea": "جبال بابوا غينيا الجديدة",
    "Murder in Papua New Guinea": "قتل في بابوا غينيا الجديدة",
    "Museums in Papua New Guinea": "متاحف في بابوا غينيا الجديدة",
    "Music festivals in Papua New Guinea": "مهرجانات موسيقية في بابوا غينيا الجديدة",
    "Music of Papua New Guinea": "موسيقى بابوا غينيا الجديدة",
    "National sports teams of Papua New Guinea": "منتخبات رياضية وطنية في بابوا غينيا الجديدة",
    "Natural disasters in Papua New Guinea": "كوارث طبيعية في بابوا غينيا الجديدة",
    "Natural gas in Papua New Guinea": "غاز طبيعي في بابوا غينيا الجديدة",
    "Natural history of Papua New Guinea": "تاريخ بابوا غينيا الجديدة الطبيعي",
    "Nature reserves in Papua New Guinea": "محميات طبيعية في بابوا غينيا الجديدة",
    "Naval ships of Papua New Guinea": "سفن قوات بحرية في بابوا غينيا الجديدة",
    "Netball competitions in Papua New Guinea": "منافسات كرة شبكة في بابوا غينيا الجديدة",
    "Netball in Papua New Guinea": "كرة الشبكة في بابوا غينيا الجديدة",
    "Newspapers published in Papua New Guinea": "صحف نشرت في بابوا غينيا الجديدة",
    "Novels set in Papua New Guinea": "روايات تقع أحداثها في بابوا غينيا الجديدة",
    "Oil and gas companies of Papua New Guinea": "شركات النفط والغاز في بابوا غينيا الجديدة",
    "Olympic athletes for Papua New Guinea": "لاعبو قوى أولمبيون في بابوا غينيا الجديدة",
    "Olympic boxers for Papua New Guinea": "ملاكمون أولمبيون في بابوا غينيا الجديدة",
    "Olympic competitors for Papua New Guinea": "منافسون أولمبيون من بابوا غينيا الجديدة",
    "Olympic judoka for Papua New Guinea": "لاعبو جودو أولمبيون في بابوا غينيا الجديدة",
    "Olympic shooters for Papua New Guinea": "رماة أولمبيون في بابوا غينيا الجديدة",
    "Olympic swimmers for Papua New Guinea": "سباحون أولمبيون في بابوا غينيا الجديدة",
    "Olympic taekwondo practitioners for Papua New Guinea": "لاعبو تايكوندو أولمبيون في بابوا غينيا الجديدة",
    "Olympic weightlifters for Papua New Guinea": "رباعون أولمبيون في بابوا غينيا الجديدة",
    "Organisations based in Papua New Guinea": "منظمات مقرها في بابوا غينيا الجديدة",
    "Organisations based in Papua New Guinea by subject": "منظمات مقرها في بابوا غينيا الجديدة حسب الموضوع",
    "Pacific Games medalists for Papua New Guinea": "فائزون بميداليات ألعاب المحيط الهادئ من بابوا غينيا الجديدة",
    "Paleontology in Papua New Guinea": "علم الأحياء القديمة في بابوا غينيا الجديدة",
    "Palestinian expatriates in Papua New Guinea": "فلسطينيون مغتربون في بابوا غينيا الجديدة",
    "Papua New Guinea": "بابوا غينيا الجديدة",
    "Papua New Guinea at the 2016 OFC Nations Cup": "بابوا غينيا الجديدة في كأس أوقيانوسيا للأمم 2016",
    "Papua New Guinea at the Commonwealth Games": "بابوا غينيا الجديدة في ألعاب الكومنولث",
    "Papua New Guinea at the Olympics": "بابوا غينيا الجديدة في الألعاب الأولمبية",
    "Papua New Guinea at the Pacific Games": "بابوا غينيا الجديدة في ألعاب المحيط الهادئ",
    "Papua New Guinea at the Paralympics": "بابوا غينيا الجديدة في الألعاب البارالمبية",
    "Papua New Guinea at the Summer Olympics": "بابوا غينيا الجديدة في الألعاب الأولمبية الصيفية",
    "Papua New Guinea at the Summer Olympics by year": "بابوا غينيا الجديدة في الألعاب الأولمبية الصيفية حسب السنة",
    "Papua New Guinea at the World Aquatics Championships": "بابوا غينيا الجديدة في بطولة العالم للرياضات المائية",
    "Papua New Guinea at the World Athletics Championships": "بابوا غينيا الجديدة في بطولة العالم لألعاب القوى",
    "Papua New Guinea at the Youth Olympics": "بابوا غينيا الجديدة في الألعاب الأولمبية الشبابية",
    "Papua New Guinea in fiction": "بابوا غينيا الجديدة في الخيال",
    "Papua New Guinea in World War I": "بابوا غينيا الجديدة في الحرب العالمية الأولى",
    "Papua New Guinea in World War II": "بابوا غينيا الجديدة في الحرب العالمية الثانية",
    "Papua New Guinea international women's rugby sevens players": "لاعبات سباعيات رجبي دوليات من بابوا غينيا الجديدة",
    "Papua New Guinea national netball team": "منتخب بابوا غينيا الجديدة لكرة الشبكة",
    "Papua New Guinea national rugby league team": "منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Papua New Guinea national rugby league team coaches": "مدربو منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Papua New Guinea national rugby league team players": "لاعبو منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Papua New Guinea national rugby league team templates": "قوالب منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Papua New Guinea national rugby union team": "منتخب بابوا غينيا الجديدة لاتحاد الرجبي",
    "Papua New Guinea National Soccer League": "دوري بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea National Soccer League seasons": "مواسم دوري بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea national soccer team": "منتخب بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea national soccer team managers": "مدربو منتخب بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea national soccer team matches": "مباريات منتخب بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea national soccer team navigational boxes": "صناديق تصفح منتخب بابوا غينيا الجديدة لكرة القدم",
    "Papua New Guinea navigational boxes": "صناديق تصفح بابوا غينيا الجديدة",
    "Papua New Guinea sports navigational boxes": "صناديق تصفح الرياضة في بابوا غينيا الجديدة",
    "Papua New Guinea sports templates": "قوالب بابوا غينيا الجديدة الرياضية",
    "Papua New Guinea templates": "قوالب بابوا غينيا الجديدة",
    "Papua New Guinea women's national football team": "منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "Papua New Guinea women's national rugby league team players": "لاعبات منتخب بابوا غينيا الجديدة لدوري الرجبي للسيدات",
    "Papua New Guinea women's national soccer team navigational boxes": "صناديق تصفح منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "Papua New Guinea-related lists": "قوائم متعلقة ببابوا غينيا الجديدة",
    "Paralympic athletes for Papua New Guinea": "لاعبو قوى في الألعاب البارالمبية في بابوا غينيا الجديدة",
    "Paralympic medalists for Papua New Guinea": "فائزون بميداليات الألعاب البارالمبية من بابوا غينيا الجديدة",
    "Paralympic silver medalists for Papua New Guinea": "فائزون بميداليات فضية في الألعاب البارالمبية من بابوا غينيا الجديدة",
    "Paralympic taekwondo practitioners for Papua New Guinea": "لاعبو تايكوندو في الألعاب البارالمبية في بابوا غينيا الجديدة",
    "Patrol vessels of Papua New Guinea": "سفن دورية في بابوا غينيا الجديدة",
    "Penal system in Papua New Guinea": "قانون العقوبات في بابوا غينيا الجديدة",
    "Peninsulas of Papua New Guinea": "أشباه جزر في بابوا غينيا الجديدة",
    "People by educational institution in Papua New Guinea": "أشخاص حسب الهيئة التعليمية في بابوا غينيا الجديدة",
    "People by university or college in Papua New Guinea": "أشخاص حسب الجامعة أو الكلية في بابوا غينيا الجديدة",
    "People murdered in Papua New Guinea": "أشخاص قتلوا في بابوا غينيا الجديدة",
    "Performing arts in Papua New Guinea": "الفنون التمثيلية في بابوا غينيا الجديدة",
    "Permanent representatives of Papua New Guinea to the European Union": "مندوبو بابوا غينيا الجديدة الدائمون إلى الاتحاد الأوروبي",
    "Permanent representatives of Papua New Guinea to the United Nations": "مندوبو بابوا غينيا الجديدة الدائمون لدى الأمم المتحدة",
    "Petroleum in Papua New Guinea": "بترول في بابوا غينيا الجديدة",
    "Polish expatriates in Papua New Guinea": "بولنديون مغتربون في بابوا غينيا الجديدة",
    "Political history of Papua New Guinea": "تاريخ بابوا غينيا الجديدة السياسي",
    "Political movements in Papua New Guinea": "حركات سياسية في بابوا غينيا الجديدة",
    "Political office-holders in Papua New Guinea": "أصحاب مناصب سياسية في بابوا غينيا الجديدة",
    "Political organisations based in Papua New Guinea": "منظمات سياسية مقرها في بابوا غينيا الجديدة",
    "Political parties in Papua New Guinea": "أحزاب سياسية في بابوا غينيا الجديدة",
    "Politics of Papua New Guinea": "سياسة بابوا غينيا الجديدة",
    "Politics of Papua New Guinea by province": "سياسة بابوا غينيا الجديدة حسب المقاطعة",
    "Populated coastal places in Papua New Guinea": "أماكن ساحلية مأهولة في بابوا غينيا الجديدة",
    "Populated places in Papua New Guinea": "أماكن مأهولة في بابوا غينيا الجديدة",
    "Ports and harbours of Papua New Guinea": "مرافئ وموانئ بابوا غينيا الجديدة",
    "Power stations in Papua New Guinea": "محطات طاقة في بابوا غينيا الجديدة",
    "Prime ministers of Papua New Guinea": "رؤساء وزراء بابوا غينيا الجديدة",
    "Prisoners and detainees of Papua New Guinea": "سجناء ومعتقلون في بابوا غينيا الجديدة",
    "Protected areas of Papua New Guinea": "مناطق محمية في بابوا غينيا الجديدة",
    "Protestant missionaries in Papua New Guinea": "مبشرون بروتستانتيون في بابوا غينيا الجديدة",
    "Protestantism in Papua New Guinea": "البروتستانتية في بابوا غينيا الجديدة",
    "Provincial capitals in Papua New Guinea": "عواصم محافظات في بابوا غينيا الجديدة",
    "Public holidays in Papua New Guinea": "عطلات رسمية في بابوا غينيا الجديدة",
    "Radio in Papua New Guinea": "راديو في بابوا غينيا الجديدة",
    "Reefs of Papua New Guinea": "شعاب بابوا غينيا الجديدة",
    "Regions of Papua New Guinea": "مناطق بابوا غينيا الجديدة",
    "Religion in Papua New Guinea": "الدين في بابوا غينيا الجديدة",
    "Religious buildings and structures in Papua New Guinea": "مبان ومنشآت دينية في بابوا غينيا الجديدة",
    "Religious organisations based in Papua New Guinea": "منظمات دينية مقرها في بابوا غينيا الجديدة",
    "Renewable energy in Papua New Guinea": "طاقة متجددة في بابوا غينيا الجديدة",
    "Renewable energy power stations in Papua New Guinea": "محطات طاقة متجددة في بابوا غينيا الجديدة",
    "Reptiles of Papua New Guinea": "زواحف بابوا غينيا الجديدة",
    "Research in Papua New Guinea": "أبحاث في بابوا غينيا الجديدة",
    "Research institutes in Papua New Guinea": "معاهد أبحاث في بابوا غينيا الجديدة",
    "Right-wing politics in Papua New Guinea": "سياسة يمينية في بابوا غينيا الجديدة",
    "Rivers of Papua New Guinea": "أنهار بابوا غينيا الجديدة",
    "Road incident deaths in Papua New Guinea": "وفيات حوادث الطرق في بابوا غينيا الجديدة",
    "Road incidents in Papua New Guinea": "حوادث طرق في بابوا غينيا الجديدة",
    "Road transport in Papua New Guinea": "نقل بري في بابوا غينيا الجديدة",
    "Roads in Papua New Guinea": "طرقات في بابوا غينيا الجديدة",
    "Rodents of Papua New Guinea": "قوارض بابوا غينيا الجديدة",
    "Roman Catholic archbishops in Papua New Guinea": "رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة",
    "Roman Catholic church buildings in Papua New Guinea": "مبان كنائس رومانية كاثوليكية في بابوا غينيا الجديدة",
    "Rugby league in Papua New Guinea": "دوري الرجبي في بابوا غينيا الجديدة",
    "Rugby league players in Papua New Guinea by team": "لاعبو دوري رجبي في بابوا غينيا الجديدة حسب الفريق",
    "Rugby league stadiums in Papua New Guinea": "ملاعب دوري رجبي في بابوا غينيا الجديدة",
    "Rugby league teams in Papua New Guinea": "فرق دوري الرجبي في بابوا غينيا الجديدة",
    "Rugby union in Papua New Guinea": "اتحاد الرجبي في بابوا غينيا الجديدة",
    "Sailing in Papua New Guinea": "الإبحار في بابوا غينيا الجديدة",
    "Schools in Papua New Guinea": "مدارس في بابوا غينيا الجديدة",
    "Science and technology in Papua New Guinea": "العلوم والتقانة في بابوا غينيا الجديدة",
    "Separatism in Papua New Guinea": "الانفصالية في بابوا غينيا الجديدة",
    "Service companies of Papua New Guinea": "شركات خدمات في بابوا غينيا الجديدة",
    "Service industries in Papua New Guinea": "صناعات خدمية في بابوا غينيا الجديدة",
    "Sexuality in Papua New Guinea": "الجنسانية في بابوا غينيا الجديدة",
    "Ships of Papua New Guinea": "سفن بابوا غينيا الجديدة",
    "Shipwrecks of Papua New Guinea": "حطام سفن في بابوا غينيا الجديدة",
    "Shooting sports in Papua New Guinea": "الرماية في بابوا غينيا الجديدة",
    "Short stories set in Papua New Guinea": "قصص قصيرة تقع أحداثها في بابوا غينيا الجديدة",
    "Soccer in Papua New Guinea": "كرة القدم في بابوا غينيا الجديدة",
    "Social issues in Papua New Guinea": "قضايا اجتماعية في بابوا غينيا الجديدة",
    "Society of Papua New Guinea": "مجتمع بابوا غينيا الجديدة",
    "Softball in Papua New Guinea": "الكرة اللينة في بابوا غينيا الجديدة",
    "Sport in Papua New Guinea": "الرياضة في بابوا غينيا الجديدة",
    "Sport in Papua New Guinea by sport": "الرياضة في بابوا غينيا الجديدة حسب الرياضة",
    "Sports clubs and teams in Papua New Guinea": "أندية وفرق رياضية في بابوا غينيا الجديدة",
    "Sports competitions in Papua New Guinea": "منافسات رياضية في بابوا غينيا الجديدة",
    "Sports festivals in Papua New Guinea": "مهرجانات رياضية في بابوا غينيا الجديدة",
    "Sports organisations of Papua New Guinea": "منظمات رياضية في بابوا غينيا الجديدة",
    "Sports venues in Papua New Guinea": "ملاعب رياضية في بابوا غينيا الجديدة",
    "Sportspeople in Papua New Guinea": "رياضيون في بابوا غينيا الجديدة",
    "Sportspeople in Papua New Guinea by club or team": "رياضيون في بابوا غينيا الجديدة حسب النادي أو الفريق",
    "Straits of Papua New Guinea": "مضائق بابوا غينيا الجديدة",
    "Stratovolcanoes of Papua New Guinea": "براكين طبقية في بابوا غينيا الجديدة",
    "Subdivisions of Papua New Guinea": "تقسيمات بابوا غينيا الجديدة",
    "Suburbs in Papua New Guinea": "ضواحي في بابوا غينيا الجديدة",
    "Summer Olympics competitors for Papua New Guinea": "منافسون أولمبيون صيفيون من بابوا غينيا الجديدة",
    "Swimming competitions in Papua New Guinea": "منافسات سباحة في بابوا غينيا الجديدة",
    "Swimming in Papua New Guinea": "السباحة في بابوا غينيا الجديدة",
    "Telecommunications in Papua New Guinea": "الاتصالات عن بعد في بابوا غينيا الجديدة",
    "Television episodes set in Papua New Guinea": "حلقات تلفزيونية تقع أحداثها في بابوا غينيا الجديدة",
    "Television in Papua New Guinea": "التلفاز في بابوا غينيا الجديدة",
    "Television in Papua New Guinea by century": "التلفاز في بابوا غينيا الجديدة حسب القرن",
    "Television in Papua New Guinea by decade": "التلفاز في بابوا غينيا الجديدة حسب العقد",
    "Television stations in Papua New Guinea": "محطات تلفزيونية في بابوا غينيا الجديدة",
    "Tennis in Papua New Guinea": "كرة المضرب في بابوا غينيا الجديدة",
    "Theatre in Papua New Guinea": "المسرح في بابوا غينيا الجديدة",
    "Tongan expatriates in Papua New Guinea": "تونغانيون مغتربون في بابوا غينيا الجديدة",
    "Tourism in Papua New Guinea": "سياحة في بابوا غينيا الجديدة",
    "Tourist attractions in Papua New Guinea": "مواقع جذب سياحي في بابوا غينيا الجديدة",
    "Trade unions in Papua New Guinea": "نقابات عمالية في بابوا غينيا الجديدة",
    "Transport buildings and structures in Papua New Guinea": "مبان ومنشآت نقل في بابوا غينيا الجديدة",
    "Transport disasters in Papua New Guinea": "كوارث نقل في بابوا غينيا الجديدة",
    "Transport in Papua New Guinea": "النقل في بابوا غينيا الجديدة",
    "Transport infrastructure in Papua New Guinea": "البنية التحتية للنقل في بابوا غينيا الجديدة",
    "Transport organisations based in Papua New Guinea": "منظمات نقل مقرها في بابوا غينيا الجديدة",
    "Treaties of Papua New Guinea": "معاهدات بابوا غينيا الجديدة",
    "Tropical cyclones in Papua New Guinea": "أعاصير مدارية في بابوا غينيا الجديدة",
    "Tsunamis in Papua New Guinea": "أمواج تسونامي في بابوا غينيا الجديدة",
    "Uninhabited islands of Papua New Guinea": "جزر غير مأهولة في بابوا غينيا الجديدة",
    "United Nations Security Council resolutions concerning Papua New Guinea": "قرارات مجلس الأمن التابع للأمم المتحدة بشأن بابوا غينيا الجديدة",
    "Universities and colleges in Papua New Guinea": "جامعات وكليات في بابوا غينيا الجديدة",
    "Universities in Papua New Guinea": "جامعات في بابوا غينيا الجديدة",
    "University of Papua New Guinea": "جامعة بابوا غينيا الجديدة",
    "University of Papua New Guinea alumni": "خريجو جامعة بابوا غينيا الجديدة",
    "Valleys of Papua New Guinea": "أودية بابوا غينيا الجديدة",
    "Vanuatuan expatriate sportspeople in Papua New Guinea": "رياضيون فانواتيون مغتربون في بابوا غينيا الجديدة",
    "Vanuatuan expatriates in Papua New Guinea": "فانواتيون مغتربون في بابوا غينيا الجديدة",
    "Vertebrates of Papua New Guinea": "فقاريات بابوا غينيا الجديدة",
    "Victims of aviation accidents or incidents in Papua New Guinea": "ضحايا حوادث طيران في بابوا غينيا الجديدة",
    "Video games set in Papua New Guinea": "ألعاب فيديو تقع أحداثها في بابوا غينيا الجديدة",
    "Violence against women in Papua New Guinea": "العنف ضد المرأة في بابوا غينيا الجديدة",
    "Violence in Papua New Guinea": "عنف في بابوا غينيا الجديدة",
    "Violent deaths in Papua New Guinea": "وفيات عنيفة في بابوا غينيا الجديدة",
    "Volcanoes of Papua New Guinea": "براكين بابوا غينيا الجديدة",
    "Volleyball in Papua New Guinea": "كرة الطائرة في بابوا غينيا الجديدة",
    "Wars involving Papua New Guinea": "حروب تشمل بابوا غينيا الجديدة",
    "Water in Papua New Guinea": "مياه في بابوا غينيا الجديدة",
    "Water sports in Papua New Guinea": "رياضات مائية في بابوا غينيا الجديدة",
    "Water transport in Papua New Guinea": "نقل مائي في بابوا غينيا الجديدة",
    "Wetlands of Papua New Guinea": "مناطق رطبة في بابوا غينيا الجديدة",
    "Women in Papua New Guinea": "المرأة في بابوا غينيا الجديدة",
    "Women's soccer players in Papua New Guinea": "لاعبات كرة قدم في بابوا غينيا الجديدة",
    "Women's sport in Papua New Guinea": "رياضة نسائية في بابوا غينيا الجديدة",
    "Works about Papua New Guinea": "أعمال عن بابوا غينيا الجديدة",
    "Works set in Papua New Guinea": "أعمال تقع أحداثها في بابوا غينيا الجديدة",
    "World Heritage Sites in Papua New Guinea": "مواقع التراث العالمي في بابوا غينيا الجديدة",
    "Years in Papua New Guinea": "سنوات في بابوا غينيا الجديدة",
    "Years in Papua New Guinea by month": "سنوات في بابوا غينيا الجديدة حسب الشهر",
    "Years of the 20th century in Papua New Guinea": "سنوات القرن 20 في بابوا غينيا الجديدة",
    "Years of the 21st century in Papua New Guinea": "سنوات القرن 21 في بابوا غينيا الجديدة",
    "Youth in Papua New Guinea": "الشباب في بابوا غينيا الجديدة",
    "Youth organisations based in Papua New Guinea": "منظمات شبابية مقرها في بابوا غينيا الجديدة",
    "Youth sport in Papua New Guinea": "رياضة شبابية في بابوا غينيا الجديدة",
}

data_2 = {
    "Australia–Papua New Guinea relations": "علاقات أستراليا وبابوا غينيا الجديدة",
    "Australia–Papua New Guinea sports relations": "علاقات أستراليا وبابوا غينيا الجديدة الرياضية",
    "Austria–Papua New Guinea relations": "علاقات النمسا وبابوا غينيا الجديدة",
    "Bangladesh–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وبنغلاديش",
    "Belgium–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وبلجيكا",
    "Canada–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وكندا",
    "Chile–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وتشيلي",
    "China–Papua New Guinea relations": "علاقات الصين وبابوا غينيا الجديدة",
    "Cyprus–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وقبرص",
    "Egypt–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة ومصر",
    "Federated States of Micronesia–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وولايات ميكرونيسيا المتحدة",
    "Fiji–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وفيجي",
    "France–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وفرنسا",
    "France–Papua New Guinea sports relations": "علاقات بابوا غينيا الجديدة وفرنسا الرياضية",
    "Germany–Papua New Guinea relations": "علاقات ألمانيا وبابوا غينيا الجديدة",
    "Ghana–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وغانا",
    "Greece–Papua New Guinea relations": "علاقات اليونان وبابوا غينيا الجديدة",
    "Hong Kong–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وهونغ كونغ",
    "Hungary–Papua New Guinea relations": "علاقات المجر وبابوا غينيا الجديدة",
    "India–Papua New Guinea relations": "علاقات الهند وبابوا غينيا الجديدة",
    "Indonesia-Papua New Guinea relations": "علاقات إندونيسيا وبابوا غينيا الجديدة",
    "Indonesia–Papua New Guinea relations": "علاقات إندونيسيا وبابوا غينيا الجديدة",
    "Israel–Papua New Guinea relations": "علاقات إسرائيل وبابوا غينيا الجديدة",
    "Italy–Papua New Guinea relations": "علاقات إيطاليا وبابوا غينيا الجديدة",
    "Japan–Papua New Guinea relations": "علاقات اليابان وبابوا غينيا الجديدة",
    "Malaysia–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وماليزيا",
    "Mexico–Papua New Guinea relations": "علاقات المكسيك وبابوا غينيا الجديدة",
    "Netherlands–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وهولندا",
    "New Zealand–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة ونيوزيلندا",
    "Palestine–Papua New Guinea relations": "علاقات بابوا غينيا الجديدة وفلسطين",
    "Papua New Guinea–Philippines relations": "علاقات الفلبين وبابوا غينيا الجديدة",
    "Papua New Guinea–Poland relations": "علاقات بابوا غينيا الجديدة وبولندا",
    "Papua New Guinea–Singapore relations": "علاقات بابوا غينيا الجديدة وسنغافورة",
    "Papua New Guinea–South Africa relations": "علاقات بابوا غينيا الجديدة وجنوب إفريقيا",
    "Papua New Guinea–South Korea relations": "علاقات بابوا غينيا الجديدة وكوريا الجنوبية",
    "Papua New Guinea–Sri Lanka relations": "علاقات بابوا غينيا الجديدة وسريلانكا",
    "Papua New Guinea–Sweden relations": "علاقات السويد وبابوا غينيا الجديدة",
    "Papua New Guinea–Thailand relations": "علاقات بابوا غينيا الجديدة وتايلاند",
    "Papua New Guinea–Tonga relations": "علاقات بابوا غينيا الجديدة وتونغا",
    "Papua New Guinea–Tuvalu relations": "علاقات بابوا غينيا الجديدة وتوفالو",
    "Papua New Guinea–United Arab Emirates relations": "علاقات الإمارات العربية المتحدة وبابوا غينيا الجديدة",
    "Papua New Guinea–United Arab Emirates sports relations": "علاقات الإمارات العربية المتحدة وبابوا غينيا الجديدة الرياضية",
    "Papua New Guinea–United Kingdom relations": "علاقات المملكة المتحدة وبابوا غينيا الجديدة",
    "Papua New Guinea–United Kingdom sports relations": "علاقات المملكة المتحدة وبابوا غينيا الجديدة الرياضية",
    "Papua New Guinea–United States relations": "علاقات الولايات المتحدة وبابوا غينيا الجديدة",
    "Papua New Guinea–Zimbabwe relations": "علاقات بابوا غينيا الجديدة وزيمبابوي",
    "Australia–Papua New Guinea border": "",
    "Indonesia–Papua New Guinea border": "",
    "Papua New Guinea communications-related lists": "",
    "Papua New Guinea diplomacy-related lists": "",
    "Papua New Guinea football navigational boxes": "",
    "Papua New Guinea football templates": "",
    "Women government ministers of Papua New Guinea": "",
}

to_test = [
    # ("test_papua_new_guinea_0", data_0),
    ("test_papua_new_guinea_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_papua_new_guinea_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
