""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver.nationalities_not_double import (
    two_nationalities_but_not_double_resolver,
)

fast_data_1 = {
    "Bulgarian television series based on South Korean television series": "مسلسلات تلفزيونية بلغارية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Mexican television series based on non-Mexican television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية غير مكسيكية",
    "Non-Argentine television series based on Argentine television series": "مسلسلات تلفزيونية غير أرجنتينية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "American remakes of Argentine films": "أفلام أمريكية مأخوذة من أفلام أرجنتينية",
    "American remakes of Belgian films": "أفلام أمريكية مأخوذة من أفلام بلجيكية",
    "American remakes of Brazilian films": "أفلام أمريكية مأخوذة من أفلام برازيلية",
    "American remakes of British films": "أفلام أمريكية مأخوذة من أفلام بريطانية",
    "American remakes of Canadian films": "أفلام أمريكية مأخوذة من أفلام كندية",
    "American remakes of Danish films": "أفلام أمريكية مأخوذة من أفلام دنماركية",
    "American remakes of Dutch films": "أفلام أمريكية مأخوذة من أفلام هولندية",
    "American remakes of French films": "أفلام أمريكية مأخوذة من أفلام فرنسية",
    "American remakes of German films": "أفلام أمريكية مأخوذة من أفلام ألمانية",
    "American remakes of Hong Kong films": "أفلام أمريكية مأخوذة من أفلام هونغ كونغية",
    "American remakes of Indian films": "أفلام أمريكية مأخوذة من أفلام هندية",
    "American remakes of Israeli films": "أفلام أمريكية مأخوذة من أفلام إسرائيلية",
    "American remakes of Italian films": "أفلام أمريكية مأخوذة من أفلام إيطالية",
    "American remakes of Japanese films": "أفلام أمريكية مأخوذة من أفلام يابانية",
    "American remakes of Mexican films": "أفلام أمريكية مأخوذة من أفلام مكسيكية",
    "American remakes of Norwegian films": "أفلام أمريكية مأخوذة من أفلام نرويجية",
    "American remakes of South Korean films": "أفلام أمريكية مأخوذة من أفلام كورية جنوبية",
    "American remakes of Spanish films": "أفلام أمريكية مأخوذة من أفلام إسبانية",
    "American remakes of Swedish films": "أفلام أمريكية مأخوذة من أفلام سويدية",
    "American remakes of Thai films": "أفلام أمريكية مأخوذة من أفلام تايلندية",
    "Bangladeshi remakes of American films": "أفلام بنغلاديشية مأخوذة من أفلام أمريكية",
    "Bangladeshi remakes of Indian films": "أفلام بنغلاديشية مأخوذة من أفلام هندية",
    "Bangladeshi remakes of Tamil films": "أفلام بنغلاديشية مأخوذة من أفلام تاميلية",
    "British remakes of American films": "أفلام بريطانية مأخوذة من أفلام أمريكية",
    "British remakes of French films": "أفلام بريطانية مأخوذة من أفلام فرنسية",
    "British remakes of German films": "أفلام بريطانية مأخوذة من أفلام ألمانية",
    "Bangladeshi remakes of Telugu films": "أفلام بنغلاديشية مأخوذة من أفلام تيلوغوية",
    "Bengali remakes of English films": "أفلام بنغالية مأخوذة من أفلام إنجليزية",
    "Bengali remakes of Tamil films": "أفلام بنغالية مأخوذة من أفلام تاميلية",
    "Bengali remakes of Telugu films": "أفلام بنغالية مأخوذة من أفلام تيلوغوية",
    "Chinese remakes of American films": "أفلام صينية مأخوذة من أفلام أمريكية",
    "Chinese remakes of Japanese films": "أفلام صينية مأخوذة من أفلام يابانية",
    "Chinese remakes of South Korean films": "أفلام صينية مأخوذة من أفلام كورية جنوبية",
    "Dutch remakes of British films": "أفلام هولندية مأخوذة من أفلام بريطانية",
    "French remakes of American films": "أفلام فرنسية مأخوذة من أفلام أمريكية",
    "Gujarati remakes of Tamil films": "أفلام غجراتية مأخوذة من أفلام تاميلية",
    "Hong Kong remakes of American films": "أفلام هونغ كونغية مأخوذة من أفلام أمريكية",
    "Indian remakes of American films": "أفلام هندية مأخوذة من أفلام أمريكية",
    "Indian remakes of British films": "أفلام هندية مأخوذة من أفلام بريطانية",
    "Indian remakes of French films": "أفلام هندية مأخوذة من أفلام فرنسية",
    "Indian remakes of Hong Kong films": "أفلام هندية مأخوذة من أفلام هونغ كونغية",
    "Indian remakes of Italian films": "أفلام هندية مأخوذة من أفلام إيطالية",
    "Indian remakes of Japanese films": "أفلام هندية مأخوذة من أفلام يابانية",
    "Indian remakes of Pakistani films": "أفلام هندية مأخوذة من أفلام باكستانية",
    "Indian remakes of South Korean films": "أفلام هندية مأخوذة من أفلام كورية جنوبية",
    "Indian remakes of Spanish films": "أفلام هندية مأخوذة من أفلام إسبانية",
    "Indian remakes of Thai films": "أفلام هندية مأخوذة من أفلام تايلندية",
    "Iranian remakes of American films": "أفلام إيرانية مأخوذة من أفلام أمريكية",
    "Italian remakes of French films": "أفلام إيطالية مأخوذة من أفلام فرنسية",
    "Japanese remakes of American films": "أفلام يابانية مأخوذة من أفلام أمريكية",
    "Japanese remakes of South Korean films": "أفلام يابانية مأخوذة من أفلام كورية جنوبية",
    "Maldivian remakes of Indian films": "أفلام مالديفية مأخوذة من أفلام هندية",
    "Pakistani remakes of American films": "أفلام باكستانية مأخوذة من أفلام أمريكية",
    "Pakistani remakes of Indian films": "أفلام باكستانية مأخوذة من أفلام هندية",
    "Philippine remakes of South Korean films": "أفلام فلبينية مأخوذة من أفلام كورية جنوبية",
    "South Korean remakes of Brazilian films": "أفلام كورية جنوبية مأخوذة من أفلام برازيلية",
    "South Korean remakes of Japanese films": "أفلام كورية جنوبية مأخوذة من أفلام يابانية",
    "South Korean remakes of Spanish films": "أفلام كورية جنوبية مأخوذة من أفلام إسبانية",
    "South Korean remakes of Taiwanese films": "أفلام كورية جنوبية مأخوذة من أفلام تايوانية",
    "Spanish remakes of Argentine films": "أفلام إسبانية مأخوذة من أفلام أرجنتينية",
    "Spanish remakes of French films": "أفلام إسبانية مأخوذة من أفلام فرنسية",
    "Spanish remakes of Italian films": "أفلام إسبانية مأخوذة من أفلام إيطالية",
    "Sri Lankan remakes of Indian films": "أفلام سريلانكية مأخوذة من أفلام هندية",
    "Taiwanese remakes of South Korean films": "أفلام تايوانية مأخوذة من أفلام كورية جنوبية",
    "Tamil remakes of Bengali films": "أفلام تاميلية مأخوذة من أفلام بنغالية",
    "Tamil remakes of Telugu films": "أفلام تاميلية مأخوذة من أفلام تيلوغوية",
    "Television remakes of films": "مسلسلات تلفزيونية مأخوذة من أفلام",
    "Telugu remakes of Bengali films": "أفلام تيلوغوية مأخوذة من أفلام بنغالية",
    "Telugu remakes of Gujarati films": "أفلام تيلوغوية مأخوذة من أفلام غجراتية",
    "Telugu remakes of Tamil films": "أفلام تيلوغوية مأخوذة من أفلام تاميلية",
    "Thai remakes of Taiwanese films": "أفلام تايلندية مأخوذة من أفلام تايوانية",
    "Thai remakes of Taiwanese television series": "مسلسلات تلفزيونية تايلندية مأخوذة من مسلسلات تلفزيونية تايوانية",
}

fast_data_2 = {
    "American remakes of Argentine films": "أفلام أمريكية مأخوذة من أفلام أرجنتينية",
    "American television series based on Argentine television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "American television series based on Australian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية أسترالية",
    "American television series based on Belgian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية بلجيكية",
    "American television series based on Brazilian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية برازيلية",
    "American television series based on British television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية بريطانية",
    "American television series based on Canadian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية كندية",
    "American television series based on Chilean television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية تشيلية",
    "American television series based on Colombian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية كولومبية",
    "American television series based on Danish television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية دنماركية",
    "American television series based on Dutch television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية هولندية",
    "American television series based on French television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية فرنسية",
    "American television series based on German television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية ألمانية",
    "American television series based on Israeli television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية إسرائيلية",
    "American television series based on Japanese television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية يابانية",
    "American television series based on Mexican television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية مكسيكية",
    "American television series based on New Zealand television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية نيوزيلندية",
    "American television series based on non-American television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية غير أمريكية",
    "American television series based on Norwegian television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية نرويجية",
    "American television series based on South Korean television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "American television series based on Spanish television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية إسبانية",
    "American television series based on Swedish television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية سويدية",
    "American television series based on Venezuelan television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية فنزويلية",
    "Argentine television series based on American television series": "مسلسلات تلفزيونية أرجنتينية مبنية على مسلسلات تلفزيونية أمريكية",
    "Australian television series based on American television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية أمريكية",
    "Australian television series based on British television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية بريطانية",
    "Australian television series based on Dutch television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية هولندية",
    "Australian television series based on Japanese television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية يابانية",
    "Australian television series based on non-Australian television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية غير أسترالية",
    "Australian television series based on South Korean television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Australian television series based on Swedish television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية سويدية",
    "Austrian television series based on non-Austrian television series": "مسلسلات تلفزيونية نمساوية مبنية على مسلسلات تلفزيونية غير نمساوية",
    "Austrian television series based on South Korean television series": "مسلسلات تلفزيونية نمساوية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Belgian television series based on American television series": "مسلسلات تلفزيونية بلجيكية مبنية على مسلسلات تلفزيونية أمريكية",
    "Belgian television series based on British television series": "مسلسلات تلفزيونية بلجيكية مبنية على مسلسلات تلفزيونية بريطانية",
    "Belgian television series based on non-Belgian television series": "مسلسلات تلفزيونية بلجيكية مبنية على مسلسلات تلفزيونية غير بلجيكية",
    "Belgian television series based on South Korean television series": "مسلسلات تلفزيونية بلجيكية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Brazilian television series based on American television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية أمريكية",
    "Brazilian television series based on Argentine television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "Brazilian television series based on British television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية بريطانية",
    "Brazilian television series based on Dutch television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية هولندية",
    "Brazilian television series based on Israeli television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية إسرائيلية",
    "Brazilian television series based on Mexican television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية مكسيكية",
    "Brazilian television series based on non-Brazilian television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية غير برازيلية",
    "British television series based on American television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية أمريكية",
    "British television series based on Australian television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية أسترالية",
    "British television series based on Dutch television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية هولندية",
    "British television series based on French television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية فرنسية",
    "British television series based on Japanese television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية يابانية",
    "British television series based on non-British television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية غير بريطانية",
    "British television series based on South Korean television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "British television series based on Spanish television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية إسبانية",
    "Bulgarian television series based on British television series": "مسلسلات تلفزيونية بلغارية مبنية على مسلسلات تلفزيونية بريطانية",
    "Bulgarian television series based on non-Bulgarian television series": "مسلسلات تلفزيونية بلغارية مبنية على مسلسلات تلفزيونية غير بلغارية",
    "Bulgarian television series based on South Korean television series": "مسلسلات تلفزيونية بلغارية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Canadian television series based on American television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Canadian television series based on British television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Canadian television series based on Dutch television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية هولندية",
    "Canadian television series based on non-Canadian television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية غير كندية",
    "Canadian television series based on South Korean television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Chilean television series based on American television series": "مسلسلات تلفزيونية تشيلية مبنية على مسلسلات تلفزيونية أمريكية",
    "Chinese television series based on American television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية أمريكية",
    "Chinese television series based on British television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية بريطانية",
    "Chinese television series based on Japanese television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية يابانية",
    "Chinese television series based on non-Chinese television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية غير صينية",
    "Chinese television series based on South Korean television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Chinese television series based on Taiwanese television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية تايوانية",
    "Colombian television series based on American television series": "مسلسلات تلفزيونية كولومبية مبنية على مسلسلات تلفزيونية أمريكية",
    "Croatian television series based on American television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية أمريكية",
    "Croatian television series based on British television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية بريطانية",
    "Croatian television series based on non-Croatian television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية غير كرواتية",
    "Croatian television series based on South Korean television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Croatian television series based on Spanish television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية إسبانية",
    "Czech television series based on British television series": "مسلسلات تلفزيونية تشيكية مبنية على مسلسلات تلفزيونية بريطانية",
    "Czech television series based on non-Czech television series": "مسلسلات تلفزيونية تشيكية مبنية على مسلسلات تلفزيونية غير تشيكية",
    "Danish television series based on American television series": "مسلسلات تلفزيونية دنماركية مبنية على مسلسلات تلفزيونية أمريكية",
    "Danish television series based on British television series": "مسلسلات تلفزيونية دنماركية مبنية على مسلسلات تلفزيونية بريطانية",
    "Dutch television series based on American television series": "مسلسلات تلفزيونية هولندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Dutch television series based on British television series": "مسلسلات تلفزيونية هولندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Dutch television series based on non-Dutch television series": "مسلسلات تلفزيونية هولندية مبنية على مسلسلات تلفزيونية غير هولندية",
    "Dutch television series based on South Korean television series": "مسلسلات تلفزيونية هولندية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Estonian television series based on non-Estonian television series": "مسلسلات تلفزيونية إستونية مبنية على مسلسلات تلفزيونية غير إستونية",
    "Estonian television series based on South Korean television series": "مسلسلات تلفزيونية إستونية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Finnish television series based on American television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Finnish television series based on British television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Finnish television series based on Dutch television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية هولندية",
    "Finnish television series based on non-Finnish television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية غير فنلندية",
    "Finnish television series based on South Korean television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "French television series based on American television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية أمريكية",
    "French television series based on British television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية بريطانية",
    "French television series based on New Zealand television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية نيوزيلندية",
    "French television series based on non-French television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية غير فرنسية",
    "French television series based on South Korean television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "German television series based on American television series": "مسلسلات تلفزيونية ألمانية مبنية على مسلسلات تلفزيونية أمريكية",
    "German television series based on British television series": "مسلسلات تلفزيونية ألمانية مبنية على مسلسلات تلفزيونية بريطانية",
    "German television series based on non-German television series": "مسلسلات تلفزيونية ألمانية مبنية على مسلسلات تلفزيونية غير ألمانية",
    "German television series based on South Korean television series": "مسلسلات تلفزيونية ألمانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Greek television series based on American television series": "مسلسلات تلفزيونية يونانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Greek television series based on British television series": "مسلسلات تلفزيونية يونانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Hungarian television series based on British television series": "مسلسلات تلفزيونية مجرية مبنية على مسلسلات تلفزيونية بريطانية",
    "Hungarian television series based on non-Hungarian television series": "مسلسلات تلفزيونية مجرية مبنية على مسلسلات تلفزيونية غير مجرية",
    "Hungarian television series based on South Korean television series": "مسلسلات تلفزيونية مجرية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Indian television series based on American television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Indian television series based on British television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Indian television series based on non-Indian television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية غير هندية",
    "Indian television series based on South Korean television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Indian television series based on Turkish television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية تركية",
    "Indonesian television series based on American television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية أمريكية",
    "Indonesian television series based on British television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية بريطانية",
    "Indonesian television series based on non-Indonesian television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية غير إندونيسية",
    "Indonesian television series based on Philippine television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية فلبينية",
    "Indonesian television series based on South Korean television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Irish television series based on British television series": "مسلسلات تلفزيونية أيرلندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Irish television series based on non-Irish television series": "مسلسلات تلفزيونية أيرلندية مبنية على مسلسلات تلفزيونية غير أيرلندية",
    "Israeli television series based on American television series": "مسلسلات تلفزيونية إسرائيلية مبنية على مسلسلات تلفزيونية أمريكية",
    "Israeli television series based on British television series": "مسلسلات تلفزيونية إسرائيلية مبنية على مسلسلات تلفزيونية بريطانية",
    "Israeli television series based on non-Israeli television series": "مسلسلات تلفزيونية إسرائيلية مبنية على مسلسلات تلفزيونية غير إسرائيلية",
    "Israeli television series based on South Korean television series": "مسلسلات تلفزيونية إسرائيلية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Italian television series based on American television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية أمريكية",
    "Italian television series based on British television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية بريطانية",
    "Italian television series based on French television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية فرنسية",
    "Italian television series based on non-Italian television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية غير إيطالية",
    "Italian television series based on South Korean television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Italian television series based on Spanish television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية إسبانية",
    "Japanese television series based on American television series": "مسلسلات تلفزيونية يابانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Japanese television series based on Canadian television series": "مسلسلات تلفزيونية يابانية مبنية على مسلسلات تلفزيونية كندية",
    "Japanese television series based on non-Japanese television series": "مسلسلات تلفزيونية يابانية مبنية على مسلسلات تلفزيونية غير يابانية",
    "Japanese television series based on South Korean television series": "مسلسلات تلفزيونية يابانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Lithuanian television series based on non-Lithuanian television series": "مسلسلات تلفزيونية ليتوانية مبنية على مسلسلات تلفزيونية غير ليتوانية",
    "Lithuanian television series based on South Korean television series": "مسلسلات تلفزيونية ليتوانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Malaysian television series based on non-Malaysian television series": "مسلسلات تلفزيونية ماليزية مبنية على مسلسلات تلفزيونية غير ماليزية",
    "Malaysian television series based on South Korean television series": "مسلسلات تلفزيونية ماليزية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Mexican television series based on American television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية أمريكية",
    "Mexican television series based on Argentine television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "Mexican television series based on Brazilian television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية برازيلية",
    "Mexican television series based on British television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية بريطانية",
    "Mexican television series based on Chilean television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية تشيلية",
    "Mexican television series based on Colombian television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية كولومبية",
    "Mexican television series based on Dutch television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية هولندية",
    "Mexican television series based on non-Mexican television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية غير مكسيكية",
    "Mexican television series based on Portuguese television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية برتغالية",
    "Mexican television series based on South Korean television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Mexican television series based on Spanish television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية إسبانية",
    "Mexican television series based on Turkish television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية تركية",
    "Mexican television series based on Venezuelan television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية فنزويلية",
    "New Zealand television series based on American television series": "مسلسلات تلفزيونية نيوزيلندية مبنية على مسلسلات تلفزيونية أمريكية",
    "New Zealand television series based on Australian television series": "مسلسلات تلفزيونية نيوزيلندية مبنية على مسلسلات تلفزيونية أسترالية",
    "New Zealand television series based on British television series": "مسلسلات تلفزيونية نيوزيلندية مبنية على مسلسلات تلفزيونية بريطانية",
    "New Zealand television series based on non-New Zealand television series": "مسلسلات تلفزيونية نيوزيلندية مبنية على مسلسلات تلفزيونية غير نيوزيلندية",
    "Non-American television series based on American television series": "مسلسلات تلفزيونية غير أمريكية مبنية على مسلسلات تلفزيونية أمريكية",
    "Non-Argentine television series based on Argentine television series": "مسلسلات تلفزيونية غير أرجنتينية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "Non-Australian television series based on Australian television series": "مسلسلات تلفزيونية غير أسترالية مبنية على مسلسلات تلفزيونية أسترالية",
    "Non-British television series based on British television series": "مسلسلات تلفزيونية غير بريطانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Non-Canadian television series based on Canadian television series": "مسلسلات تلفزيونية غير كندية مبنية على مسلسلات تلفزيونية كندية",
    "Non-Colombian television series based on Colombian television series": "مسلسلات تلفزيونية غير كولومبية مبنية على مسلسلات تلفزيونية كولومبية",
    "Non-French television series based on French television series": "مسلسلات تلفزيونية غير فرنسية مبنية على مسلسلات تلفزيونية فرنسية",
    "Non-Japanese television series based on Japanese television series": "مسلسلات تلفزيونية غير يابانية مبنية على مسلسلات تلفزيونية يابانية",
    "Non-New Zealand television series based on New Zealand television series": "مسلسلات تلفزيونية غير نيوزيلندية مبنية على مسلسلات تلفزيونية نيوزيلندية",
    "Non-Pakistani television series based on Pakistani television series": "مسلسلات تلفزيونية غير باكستانية مبنية على مسلسلات تلفزيونية باكستانية",
    "Non-South Korean television series based on South Korean television series": "مسلسلات تلفزيونية غير كورية جنوبية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Non-Spanish television series based on Spanish television series": "مسلسلات تلفزيونية غير إسبانية مبنية على مسلسلات تلفزيونية إسبانية",
    "Non-Taiwanese television series based on Taiwanese television series": "مسلسلات تلفزيونية غير تايوانية مبنية على مسلسلات تلفزيونية تايوانية",
    "Non-Turkish television series based on Turkish television series": "مسلسلات تلفزيونية غير تركية مبنية على مسلسلات تلفزيونية تركية",
    "Norwegian television series based on American television series": "مسلسلات تلفزيونية نرويجية مبنية على مسلسلات تلفزيونية أمريكية",
    "Norwegian television series based on British television series": "مسلسلات تلفزيونية نرويجية مبنية على مسلسلات تلفزيونية بريطانية",
    "Pakistani television series based on American television series": "مسلسلات تلفزيونية باكستانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Pakistani television series based on British television series": "مسلسلات تلفزيونية باكستانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Pakistani television series based on non-Pakistani television series": "مسلسلات تلفزيونية باكستانية مبنية على مسلسلات تلفزيونية غير باكستانية",
    "Philippine television series based on American television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية أمريكية",
    "Philippine television series based on Australian television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية أسترالية",
    "Philippine television series based on British television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية بريطانية",
    "Philippine television series based on Colombian television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية كولومبية",
    "Philippine television series based on Dutch television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية هولندية",
    "Philippine television series based on Japanese television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية يابانية",
    "Philippine television series based on Mexican television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية مكسيكية",
    "Philippine television series based on non-Philippine television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية غير فلبينية",
    "Philippine television series based on Philippine television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية فلبينية",
    "Philippine television series based on South Korean television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Philippine television series based on Spanish television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية إسبانية",
    "Polish television series based on American television series": "مسلسلات تلفزيونية بولندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Polish television series based on British television series": "مسلسلات تلفزيونية بولندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Portuguese television series based on American television series": "مسلسلات تلفزيونية برتغالية مبنية على مسلسلات تلفزيونية أمريكية",
    "Portuguese television series based on British television series": "مسلسلات تلفزيونية برتغالية مبنية على مسلسلات تلفزيونية بريطانية",
    "Portuguese television series based on non-Portuguese television series": "مسلسلات تلفزيونية برتغالية مبنية على مسلسلات تلفزيونية غير برتغالية",
    "Portuguese television series based on South Korean television series": "مسلسلات تلفزيونية برتغالية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Romanian television series based on American television series": "مسلسلات تلفزيونية رومانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Romanian television series based on British television series": "مسلسلات تلفزيونية رومانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Romanian television series based on non-Romanian television series": "مسلسلات تلفزيونية رومانية مبنية على مسلسلات تلفزيونية غير رومانية",
    "Romanian television series based on South Korean television series": "مسلسلات تلفزيونية رومانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Russian television series based on American television series": "مسلسلات تلفزيونية روسية مبنية على مسلسلات تلفزيونية أمريكية",
    "Russian television series based on British television series": "مسلسلات تلفزيونية روسية مبنية على مسلسلات تلفزيونية بريطانية",
    "Russian television series based on non-Russian television series": "مسلسلات تلفزيونية روسية مبنية على مسلسلات تلفزيونية غير روسية",
    "Russian television series based on South Korean television series": "مسلسلات تلفزيونية روسية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Singaporean television series based on non-Singaporean television series": "مسلسلات تلفزيونية سنغافورية مبنية على مسلسلات تلفزيونية غير سنغافورية",
    "Singaporean television series based on South Korean television series": "مسلسلات تلفزيونية سنغافورية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Slovak television series based on British television series": "مسلسلات تلفزيونية سلوفاكية مبنية على مسلسلات تلفزيونية بريطانية",
    "South African television series based on American television series": "مسلسلات تلفزيونية جنوب إفريقية مبنية على مسلسلات تلفزيونية أمريكية",
    "South African television series based on British television series": "مسلسلات تلفزيونية جنوب إفريقية مبنية على مسلسلات تلفزيونية بريطانية",
    "South Korean television series based on American television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية أمريكية",
    "South Korean television series based on British television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية بريطانية",
    "South Korean television series based on Japanese television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية يابانية",
    "South Korean television series based on non-South Korean television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية غير كورية جنوبية",
    "South Korean television series based on Taiwanese television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية تايوانية",
    "Spanish television series based on American television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Spanish television series based on British television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Spanish television series based on Colombian television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية كولومبية",
    "Spanish television series based on non-Spanish television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية غير إسبانية",
    "Spanish television series based on South Korean television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Swedish television series based on American television series": "مسلسلات تلفزيونية سويدية مبنية على مسلسلات تلفزيونية أمريكية",
    "Swedish television series based on British television series": "مسلسلات تلفزيونية سويدية مبنية على مسلسلات تلفزيونية بريطانية",
    "Taiwanese television series based on non-Taiwanese television series": "مسلسلات تلفزيونية تايوانية مبنية على مسلسلات تلفزيونية غير تايوانية",
    "Taiwanese television series based on South Korean television series": "مسلسلات تلفزيونية تايوانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Thai television series based on American television series": "مسلسلات تلفزيونية تايلندية مبنية على مسلسلات تلفزيونية أمريكية",
    "Thai television series based on British television series": "مسلسلات تلفزيونية تايلندية مبنية على مسلسلات تلفزيونية بريطانية",
    "Thai television series based on South Korean television series": "مسلسلات تلفزيونية تايلندية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Thai television series based on Taiwanese television series": "مسلسلات تلفزيونية تايلندية مبنية على مسلسلات تلفزيونية تايوانية",
    "Turkish television series based on American television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية أمريكية",
    "Turkish television series based on British television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية بريطانية",
    "Turkish television series based on Japanese television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية يابانية",
    "Turkish television series based on non-Turkish television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية غير تركية",
    "Turkish television series based on South Korean television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Ukrainian television series based on American television series": "مسلسلات تلفزيونية أوكرانية مبنية على مسلسلات تلفزيونية أمريكية",
    "Uruguayan television series based on non-Uruguayan television series": "مسلسلات تلفزيونية أوروغويانية مبنية على مسلسلات تلفزيونية غير أوروغويانية",
    "Uruguayan television series based on South Korean television series": "مسلسلات تلفزيونية أوروغويانية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Vietnamese television series based on American television series": "مسلسلات تلفزيونية فيتنامية مبنية على مسلسلات تلفزيونية أمريكية",
    "Vietnamese television series based on British television series": "مسلسلات تلفزيونية فيتنامية مبنية على مسلسلات تلفزيونية بريطانية",
    "Vietnamese television series based on non-Vietnamese television series": "مسلسلات تلفزيونية فيتنامية مبنية على مسلسلات تلفزيونية غير فيتنامية",
    "Vietnamese television series based on South Korean television series": "مسلسلات تلفزيونية فيتنامية مبنية على مسلسلات تلفزيونية كورية جنوبية",
}

TEMPORAL_CASES = [
    ("test_fast_data_1", fast_data_1, two_nationalities_but_not_double_resolver),
    ("test_fast_data_2", fast_data_2, two_nationalities_but_not_double_resolver),
]


@pytest.mark.parametrize("category, expected", fast_data_2.items(), ids=fast_data_2.keys())
@pytest.mark.fast
def test_politics_and_history(category: str, expected: str) -> None:
    label = two_nationalities_but_not_double_resolver(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", fast_data_1.items(), ids=fast_data_1.keys())
@pytest.mark.fast
def test_politics_and_history2(category: str, expected: str) -> None:
    label = two_nationalities_but_not_double_resolver(category)
    assert label == expected


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: str, callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
