#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

covid_pandemic_data = {
    "Deaths from the COVID-19 pandemic by country subdivision": "وفيات من جائحة فيروس كورونا حسب تقسيم البلد",
    "Deaths from the COVID-19 pandemic in Afghanistan": "وفيات من جائحة فيروس كورونا في أفغانستان",
    "Deaths from the COVID-19 pandemic in Alabama": "وفيات من جائحة فيروس كورونا في ألاباما",
    "Deaths from the COVID-19 pandemic in Alaska": "وفيات من جائحة فيروس كورونا في ألاسكا",
    "Deaths from the COVID-19 pandemic in Albania": "وفيات من جائحة فيروس كورونا في ألبانيا",
    "Deaths from the COVID-19 pandemic in Amapá": "وفيات من جائحة فيروس كورونا في أمابا",
    "Deaths from the COVID-19 pandemic in Ankara": "وفيات من جائحة فيروس كورونا في أنقرة",
    "Deaths from the COVID-19 pandemic in Apulia": "وفيات من جائحة فيروس كورونا في بوليا",
    "Deaths from the COVID-19 pandemic in Arizona": "وفيات من جائحة فيروس كورونا في أريزونا",
    "Deaths from the COVID-19 pandemic in Armenia": "وفيات من جائحة فيروس كورونا في أرمينيا",
    "Deaths from the COVID-19 pandemic in Australia": "وفيات من جائحة فيروس كورونا في أستراليا",
    "Deaths from the COVID-19 pandemic in Austria": "وفيات من جائحة فيروس كورونا في النمسا",
    "Deaths from the COVID-19 pandemic in Bahia": "وفيات من جائحة فيروس كورونا في باهيا",
    "Deaths from the COVID-19 pandemic in Bangladesh": "وفيات من جائحة فيروس كورونا في بنغلاديش",
    "Deaths from the COVID-19 pandemic in Belarus": "وفيات من جائحة فيروس كورونا في روسيا البيضاء",
    "Deaths from the COVID-19 pandemic in Belgium": "وفيات من جائحة فيروس كورونا في بلجيكا",
    "Deaths from the COVID-19 pandemic in Bolivia": "وفيات من جائحة فيروس كورونا في بوليفيا",
    "Deaths from the COVID-19 pandemic in Botswana": "وفيات من جائحة فيروس كورونا في بوتسوانا",
    "Deaths from the COVID-19 pandemic in Brazil by state": "وفيات من جائحة فيروس كورونا في البرازيل حسب الولاية",
    "Deaths from the COVID-19 pandemic in Burundi": "وفيات من جائحة فيروس كورونا في بوروندي",
    "Deaths from the COVID-19 pandemic in Cameroon": "وفيات من جائحة فيروس كورونا في الكاميرون",
    "Deaths from the COVID-19 pandemic in Ceará": "وفيات من جائحة فيروس كورونا في سيارا",
    "Deaths from the COVID-19 pandemic in Chile": "وفيات من جائحة فيروس كورونا في تشيلي",
    "Deaths from the COVID-19 pandemic in Colorado": "وفيات من جائحة فيروس كورونا في كولورادو",
    "Deaths from the COVID-19 pandemic in Croatia": "وفيات من جائحة فيروس كورونا في كرواتيا",
    "Deaths from the COVID-19 pandemic in Cuba": "وفيات من جائحة فيروس كورونا في كوبا",
    "Deaths from the COVID-19 pandemic in Ecuador": "وفيات من جائحة فيروس كورونا في الإكوادور",
    "Deaths from the COVID-19 pandemic in Emilia-Romagna": "وفيات من جائحة فيروس كورونا في إميليا-رومانيا",
    "Deaths from the COVID-19 pandemic in Ethiopia": "وفيات من جائحة فيروس كورونا في إثيوبيا",
    "Deaths from the COVID-19 pandemic in Georgia (country)": "وفيات من جائحة فيروس كورونا في جورجيا",
    "Deaths from the COVID-19 pandemic in Georgia (U.S. state)": "وفيات من جائحة فيروس كورونا في ولاية جورجيا",
    "Deaths from the COVID-19 pandemic in Ghana": "وفيات من جائحة فيروس كورونا في غانا",
    "Deaths from the COVID-19 pandemic in Goiás": "وفيات من جائحة فيروس كورونا في غوياس",
    "Deaths from the COVID-19 pandemic in Greece": "وفيات من جائحة فيروس كورونا في اليونان",
    "Deaths from the COVID-19 pandemic in Guinea": "وفيات من جائحة فيروس كورونا في غينيا",
    "Deaths from the COVID-19 pandemic in Guinea-Bissau": "وفيات من جائحة فيروس كورونا في غينيا بيساو",
    "Deaths from the COVID-19 pandemic in Hawaii": "وفيات من جائحة فيروس كورونا في هاواي",
    "Deaths from the COVID-19 pandemic in Honduras": "وفيات من جائحة فيروس كورونا في هندوراس",
    "Deaths from the COVID-19 pandemic in Idaho": "وفيات من جائحة فيروس كورونا في أيداهو",
    "Deaths from the COVID-19 pandemic in Islamabad": "وفيات من جائحة فيروس كورونا في إسلام آباد",
    "Deaths from the COVID-19 pandemic in Israel": "وفيات من جائحة فيروس كورونا في إسرائيل",
    "Deaths from the COVID-19 pandemic in Italy by region": "وفيات من جائحة فيروس كورونا في إيطاليا حسب المنطقة",
    "Deaths from the COVID-19 pandemic in Ivory Coast": "وفيات من جائحة فيروس كورونا في ساحل العاج",
    "Deaths from the COVID-19 pandemic in Jamaica": "وفيات من جائحة فيروس كورونا في جامايكا",
    "Deaths from the COVID-19 pandemic in Kentucky": "وفيات من جائحة فيروس كورونا في كنتاكي",
    "Deaths from the COVID-19 pandemic in Kenya": "وفيات من جائحة فيروس كورونا في كينيا",
    "Deaths from the COVID-19 pandemic in Latvia": "وفيات من جائحة فيروس كورونا في لاتفيا",
    "Deaths from the COVID-19 pandemic in Lazio": "وفيات من جائحة فيروس كورونا في لاتسيو",
    "Deaths from the COVID-19 pandemic in Libya": "وفيات من جائحة فيروس كورونا في ليبيا",
    "Deaths from the COVID-19 pandemic in Liguria": "وفيات من جائحة فيروس كورونا في ليغوريا",
    "Deaths from the COVID-19 pandemic in Lombardy": "وفيات من جائحة فيروس كورونا في لومبارديا",
    "Deaths from the COVID-19 pandemic in Maine": "وفيات من جائحة فيروس كورونا في مين",
    "Deaths from the COVID-19 pandemic in Malaysia": "وفيات من جائحة فيروس كورونا في ماليزيا",
    "Deaths from the COVID-19 pandemic in Maranhão": "وفيات من جائحة فيروس كورونا في مارانهاو",
    "Deaths from the COVID-19 pandemic in Maryland": "وفيات من جائحة فيروس كورونا في ماريلند",
    "Deaths from the COVID-19 pandemic in Mato Grosso do Sul": "وفيات من جائحة فيروس كورونا في ماتو غروسو دو سول",
    "Deaths from the COVID-19 pandemic in Mato Grosso": "وفيات من جائحة فيروس كورونا في ماتو غروسو",
    "Deaths from the COVID-19 pandemic in Minas Gerais": "وفيات من جائحة فيروس كورونا في ميناس جيرايس",
    "Deaths from the COVID-19 pandemic in Mississippi": "وفيات من جائحة فيروس كورونا في مسيسيبي",
    "Deaths from the COVID-19 pandemic in Missouri": "وفيات من جائحة فيروس كورونا في ميزوري",
    "Deaths from the COVID-19 pandemic in Moldova": "وفيات من جائحة فيروس كورونا في مولدوفا",
    "Deaths from the COVID-19 pandemic in Myanmar": "وفيات من جائحة فيروس كورونا في ميانمار",
    "Deaths from the COVID-19 pandemic in Nepal": "وفيات من جائحة فيروس كورونا في نيبال",
    "Deaths from the COVID-19 pandemic in New Mexico": "وفيات من جائحة فيروس كورونا في نيومكسيكو",
    "Deaths from the COVID-19 pandemic in North Carolina": "وفيات من جائحة فيروس كورونا في كارولاينا الشمالية",
    "Deaths from the COVID-19 pandemic in Northern Ireland": "وفيات من جائحة فيروس كورونا في أيرلندا الشمالية",
    "Deaths from the COVID-19 pandemic in Ohio": "وفيات من جائحة فيروس كورونا في أوهايو",
    "Deaths from the COVID-19 pandemic in Pakistan by administrative unit": "وفيات من جائحة فيروس كورونا في باكستان حسب الوحدة الإدارية",
    "Deaths from the COVID-19 pandemic in Papua New Guinea": "وفيات من جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Deaths from the COVID-19 pandemic in Paraguay": "وفيات من جائحة فيروس كورونا في باراغواي",
    "Deaths from the COVID-19 pandemic in Paraná (state)": "وفيات من جائحة فيروس كورونا في ولاية بارانا",
    "Deaths from the COVID-19 pandemic in Paraíba": "وفيات من جائحة فيروس كورونا في بارايبا",
    "Deaths from the COVID-19 pandemic in Pernambuco": "وفيات من جائحة فيروس كورونا في بيرنامبوكو",
    "Deaths from the COVID-19 pandemic in Piauí": "وفيات من جائحة فيروس كورونا في بياوي",
    "Deaths from the COVID-19 pandemic in Piedmont": "وفيات من جائحة فيروس كورونا في بييمونتي",
    "Deaths from the COVID-19 pandemic in Poland": "وفيات من جائحة فيروس كورونا في بولندا",
    "Deaths from the COVID-19 pandemic in Portugal": "وفيات من جائحة فيروس كورونا في البرتغال",
    "Deaths from the COVID-19 pandemic in Punjab, Pakistan": "وفيات من جائحة فيروس كورونا في البنجاب (باكستان)",
    "Deaths from the COVID-19 pandemic in Rio Grande do Norte": "وفيات من جائحة فيروس كورونا في ريو غراندي دو نورتي",
    "Deaths from the COVID-19 pandemic in Rio Grande do Sul": "وفيات من جائحة فيروس كورونا في ريو غراندي دو سول",
    "Deaths from the COVID-19 pandemic in Romania": "وفيات من جائحة فيروس كورونا في رومانيا",
    "Deaths from the COVID-19 pandemic in Scotland": "وفيات من جائحة فيروس كورونا في إسكتلندا",
    "Deaths from the COVID-19 pandemic in South Carolina": "وفيات من جائحة فيروس كورونا في كارولاينا الجنوبية",
    "Deaths from the COVID-19 pandemic in South Dakota": "وفيات من جائحة فيروس كورونا في داكوتا الجنوبية",
    "Deaths from the COVID-19 pandemic in Sri Lanka": "وفيات من جائحة فيروس كورونا في سريلانكا",
    "Deaths from the COVID-19 pandemic in Sudan": "وفيات من جائحة فيروس كورونا في السودان",
    "Deaths from the COVID-19 pandemic in Switzerland": "وفيات من جائحة فيروس كورونا في سويسرا",
    "Deaths from the COVID-19 pandemic in São Paulo (state)": "وفيات من جائحة فيروس كورونا في ولاية ساو باولو",
    "Deaths from the COVID-19 pandemic in Tajikistan": "وفيات من جائحة فيروس كورونا في طاجيكستان",
    "Deaths from the COVID-19 pandemic in Tanzania": "وفيات من جائحة فيروس كورونا في تنزانيا",
    "Deaths from the COVID-19 pandemic in Texas": "وفيات من جائحة فيروس كورونا في تكساس",
    "Deaths from the COVID-19 pandemic in the Czech Republic": "وفيات من جائحة فيروس كورونا في التشيك",
    "Deaths from the COVID-19 pandemic in the Dominican Republic": "وفيات من جائحة فيروس كورونا في جمهورية الدومينيكان",
    "Deaths from the COVID-19 pandemic in the Federal District (Brazil)": "وفيات من جائحة فيروس كورونا في القطاع الفدرالي (البرازيل)",
    "Deaths from the COVID-19 pandemic in Tuscany": "وفيات من جائحة فيروس كورونا في توسكانا",
    "Deaths from the COVID-19 pandemic in Ukraine": "وفيات من جائحة فيروس كورونا في أوكرانيا",
    "Deaths from the COVID-19 pandemic in Veneto": "وفيات من جائحة فيروس كورونا في فينيتو",
    "Deaths from the COVID-19 pandemic in Venezuela": "وفيات من جائحة فيروس كورونا في فنزويلا",
    "Deaths from the COVID-19 pandemic in Virginia": "وفيات من جائحة فيروس كورونا في فرجينيا",
    "Deaths from the COVID-19 pandemic in Wisconsin": "وفيات من جائحة فيروس كورونا في ويسكونسن",
    "Deaths from the COVID-19 pandemic in Wyoming": "وفيات من جائحة فيروس كورونا في وايومنغ",
    "Deaths from tuberculosis by country subdivision": "وفيات من السل حسب تقسيم البلد",
    "Deaths from tuberculosis by country": "وفيات من السل حسب البلد",
    "Deaths from tuberculosis by former country": "وفيات من السل حسب البلد السابق",
    "Deaths from the COVID-19 pandemic by country": "وفيات من جائحة فيروس كورونا حسب البلد",
    "Deaths from the COVID-19 pandemic in Algeria": "وفيات من جائحة فيروس كورونا في الجزائر",
    "Deaths from the COVID-19 pandemic in Argentina": "وفيات من جائحة فيروس كورونا في الأرجنتين",
    "Deaths from the COVID-19 pandemic in Bosnia and Herzegovina": "وفيات من جائحة فيروس كورونا في البوسنة والهرسك",
    "Deaths from the COVID-19 pandemic in Brazil": "وفيات من جائحة فيروس كورونا في البرازيل",
    "Deaths from the COVID-19 pandemic in Bulgaria": "وفيات من جائحة فيروس كورونا في بلغاريا",
    "Deaths from the COVID-19 pandemic in California": "وفيات من جائحة فيروس كورونا في كاليفورنيا",
    "Deaths from the COVID-19 pandemic in Canada": "وفيات من جائحة فيروس كورونا في كندا",
    "Deaths from the COVID-19 pandemic in China": "وفيات من جائحة فيروس كورونا في الصين",
    "Deaths from the COVID-19 pandemic in Colombia": "وفيات من جائحة فيروس كورونا في كولومبيا",
    "Deaths from the COVID-19 pandemic in Connecticut": "وفيات من جائحة فيروس كورونا في كونيتيكت",
    "Deaths from the COVID-19 pandemic in Egypt": "وفيات من جائحة فيروس كورونا في مصر",
    "Deaths from the COVID-19 pandemic in England": "وفيات من جائحة فيروس كورونا في إنجلترا",
    "Deaths from the COVID-19 pandemic in Florida": "وفيات من جائحة فيروس كورونا في فلوريدا",
    "Deaths from the COVID-19 pandemic in France": "وفيات من جائحة فيروس كورونا في فرنسا",
    "Deaths from the COVID-19 pandemic in Germany": "وفيات من جائحة فيروس كورونا في ألمانيا",
    "Deaths from the COVID-19 pandemic in Hungary": "وفيات من جائحة فيروس كورونا في المجر",
    "Deaths from the COVID-19 pandemic in Illinois": "وفيات من جائحة فيروس كورونا في إلينوي",
    "Deaths from the COVID-19 pandemic in India": "وفيات من جائحة فيروس كورونا في الهند",
    "Deaths from the COVID-19 pandemic in Indonesia": "وفيات من جائحة فيروس كورونا في إندونيسيا",
    "Deaths from the COVID-19 pandemic in Iran": "وفيات من جائحة فيروس كورونا في إيران",
    "Deaths from the COVID-19 pandemic in Iraq": "وفيات من جائحة فيروس كورونا في العراق",
    "Deaths from the COVID-19 pandemic in Italy": "وفيات من جائحة فيروس كورونا في إيطاليا",
    "Deaths from the COVID-19 pandemic in Japan": "وفيات من جائحة فيروس كورونا في اليابان",
    "Deaths from the COVID-19 pandemic in Jordan": "وفيات من جائحة فيروس كورونا في الأردن",
    "Deaths from the COVID-19 pandemic in Kuwait": "وفيات من جائحة فيروس كورونا في الكويت",
    "Deaths from the COVID-19 pandemic in Lebanon": "وفيات من جائحة فيروس كورونا في لبنان",
    "Deaths from the COVID-19 pandemic in Louisiana": "وفيات من جائحة فيروس كورونا في لويزيانا",
    "Deaths from the COVID-19 pandemic in Massachusetts": "وفيات من جائحة فيروس كورونا في ماساتشوستس",
    "Deaths from the COVID-19 pandemic in Mexico": "وفيات من جائحة فيروس كورونا في المكسيك",
    "Deaths from the COVID-19 pandemic in Michigan": "وفيات من جائحة فيروس كورونا في ميشيغان",
    "Deaths from the COVID-19 pandemic in Minnesota": "وفيات من جائحة فيروس كورونا في منيسوتا",
    "Deaths from the COVID-19 pandemic in Morocco": "وفيات من جائحة فيروس كورونا في المغرب",
    "Deaths from the COVID-19 pandemic in Nevada": "وفيات من جائحة فيروس كورونا في نيفادا",
    "Deaths from the COVID-19 pandemic in New Jersey": "وفيات من جائحة فيروس كورونا في نيوجيرسي",
    "Deaths from the COVID-19 pandemic in New York (state)": "وفيات من جائحة فيروس كورونا في ولاية نيويورك",
    "Deaths from the COVID-19 pandemic in New Zealand": "وفيات من جائحة فيروس كورونا في نيوزيلندا",
    "Deaths from the COVID-19 pandemic in Nigeria": "وفيات من جائحة فيروس كورونا في نيجيريا",
    "Deaths from the COVID-19 pandemic in Pakistan": "وفيات من جائحة فيروس كورونا في باكستان",
    "Deaths from the COVID-19 pandemic in Palestine": "وفيات من جائحة فيروس كورونا في فلسطين",
    "Deaths from the COVID-19 pandemic in Pennsylvania": "وفيات من جائحة فيروس كورونا في بنسلفانيا",
    "Deaths from the COVID-19 pandemic in Peru": "وفيات من جائحة فيروس كورونا في بيرو",
    "Deaths from the COVID-19 pandemic in Rio de Janeiro (state)": "وفيات من جائحة فيروس كورونا في ولاية ريو دي جانيرو",
    "Deaths from the COVID-19 pandemic in Russia": "وفيات من جائحة فيروس كورونا في روسيا",
    "Deaths from the COVID-19 pandemic in Senegal": "وفيات من جائحة فيروس كورونا في السنغال",
    "Deaths from the COVID-19 pandemic in Serbia": "وفيات من جائحة فيروس كورونا في صربيا",
    "Deaths from the COVID-19 pandemic in Sindh": "وفيات من جائحة فيروس كورونا في إقليم السند",
    "Deaths from the COVID-19 pandemic in South Korea": "وفيات من جائحة فيروس كورونا في كوريا الجنوبية",
    "Deaths from the COVID-19 pandemic in Spain": "وفيات من جائحة فيروس كورونا في إسبانيا",
    "Deaths from the COVID-19 pandemic in Sweden": "وفيات من جائحة فيروس كورونا في السويد",
    "Deaths from the COVID-19 pandemic in Syria": "وفيات من جائحة فيروس كورونا في سوريا",
    "Deaths from the COVID-19 pandemic in Tennessee": "وفيات من جائحة فيروس كورونا في تينيسي",
    "Deaths from the COVID-19 pandemic in the Netherlands": "وفيات من جائحة فيروس كورونا في هولندا",
    "Deaths from the COVID-19 pandemic in the Philippines": "وفيات من جائحة فيروس كورونا في الفلبين",
    "Deaths from the COVID-19 pandemic in the State of Palestine": "وفيات من جائحة فيروس كورونا في دولة فلسطين",
    "Deaths from the COVID-19 pandemic in the United Arab Emirates": "وفيات من جائحة فيروس كورونا في الإمارات العربية المتحدة",
    "Deaths from the COVID-19 pandemic in the United Kingdom": "وفيات من جائحة فيروس كورونا في المملكة المتحدة",
    "Deaths from the COVID-19 pandemic in the United States by state": "وفيات من جائحة فيروس كورونا في الولايات المتحدة حسب الولاية",
    "Deaths from the COVID-19 pandemic in the United States": "وفيات من جائحة فيروس كورونا في الولايات المتحدة",
    "Deaths from the COVID-19 pandemic in Tunisia": "وفيات من جائحة فيروس كورونا في تونس",
    "Deaths from the COVID-19 pandemic in Turkey": "وفيات من جائحة فيروس كورونا في تركيا",
    "Deaths from the COVID-19 pandemic in Uruguay": "وفيات من جائحة فيروس كورونا في أوروغواي",
    "Deaths from the COVID-19 pandemic in Uzbekistan": "وفيات من جائحة فيروس كورونا في أوزبكستان",
    "Deaths from the COVID-19 pandemic in Wales": "وفيات من جائحة فيروس كورونا في ويلز",
    "Deaths from the COVID-19 pandemic in Washington (state)": "وفيات من جائحة فيروس كورونا في ولاية واشنطن",
    "Deaths from the COVID-19 pandemic in Washington, D.C.": "وفيات من جائحة فيروس كورونا في واشنطن العاصمة",
    "Deaths from the COVID-19 pandemic in Yemen": "وفيات من جائحة فيروس كورونا في اليمن",
    "Deaths from the COVID-19 pandemic in Zimbabwe": "وفيات من جائحة فيروس كورونا في زيمبابوي",
    "Deaths from the COVID-19 pandemic": "وفيات من جائحة فيروس كورونا",
}

airstrikes_data = {
    "Deaths by German airstrikes during The Blitz": "وفيات بضربات جوية ألمانية خلال قصف لندن",
    "Deaths by German airstrikes during World War II": "وفيات بضربات جوية ألمانية خلال الحرب العالمية الثانية",
    "Deaths by Greek airstrikes during World War II": "وفيات بضربات جوية يونانية خلال الحرب العالمية الثانية",
    "Deaths by Turkish airstrikes during the Syrian civil war": "وفيات بضربات جوية تركية خلال الحرب الأهلية السورية",
    "Deaths by Russian airstrikes during the Syrian civil war": "وفيات بضربات جوية روسية خلال الحرب الأهلية السورية",
    "Deaths by Soviet airstrikes during World War II": "وفيات بضربات جوية سوفيتية خلال الحرب العالمية الثانية",
    "Deaths by British airstrikes during World War II": "وفيات بضربات جوية بريطانية خلال الحرب العالمية الثانية",
    "Deaths by New Zealand airstrikes during World War II": "وفيات بضربات جوية نيوزيلندية خلال الحرب العالمية الثانية",
    "Deaths by British airstrikes": "وفيات بضربات جوية بريطانية",
    "Deaths by Colombian airstrikes": "وفيات بضربات جوية كولومبية",
    "Deaths by Russian airstrikes": "وفيات بضربات جوية روسية",
    "Deaths by Saudi Arabian airstrikes": "وفيات بضربات جوية سعودية",
    "Deaths by Greek airstrikes": "وفيات بضربات جوية يونانية",
    "Deaths by German airstrikes": "وفيات بضربات جوية ألمانية",
    "Deaths by French airstrikes": "وفيات بضربات جوية فرنسية",
    "Deaths by Soviet airstrikes": "وفيات بضربات جوية سوفيتية",
    "Deaths by Sudanese airstrikes": "وفيات بضربات جوية سودانية",
    "Deaths by Turkish airstrikes": "وفيات بضربات جوية تركية",
    "Deaths by New Zealand airstrikes": "وفيات بضربات جوية نيوزيلندية",
}

data_test_1 = {
    "Deaths by airstrike during the Syrian civil war": "وفيات بضربات جوية خلال الحرب الأهلية السورية",
    "Deaths by airstrike during World War II": "وفيات بضربات جوية خلال الحرب العالمية الثانية",
    "Deaths by airstrike": "وفيات بضربات جوية",
    "Deaths by firearm in Minnesota": "وفيات بإطلاق النار في منيسوتا",
    "Deaths by firearm in Oregon": "وفيات بإطلاق النار في أوريغن",
    "Deaths by firearm in Uruguay": "وفيات بإطلاق النار في أوروغواي",
    "Deaths by blade weapons": "وفيات بالأسلحة البيضاء",
    "Deaths by country": "وفيات حسب البلد",
    "Deaths by decapitation": "وفيات بقطع الرأس",
    "Deaths by explosive device": "وفيات بعبوة ناسفة",
    "Deaths by improvised explosive device by country": "وفيات بعبوة ناسفة بدائية الصنع حسب البلد",
    "Deaths by improvised explosive device in Afghanistan": "وفيات بعبوة ناسفة بدائية الصنع في أفغانستان",
    "Deaths by improvised explosive device in England": "وفيات بعبوة ناسفة بدائية الصنع في إنجلترا",
    "Deaths by improvised explosive device in Iraq": "وفيات بعبوة ناسفة بدائية الصنع في العراق",
    "Deaths by improvised explosive device in Somalia": "وفيات بعبوة ناسفة بدائية الصنع في الصومال",
    "Deaths by improvised explosive device in the Republic of Ireland": "وفيات بعبوة ناسفة بدائية الصنع في جمهورية أيرلندا",
    "Deaths by improvised explosive device in the United Kingdom": "وفيات بعبوة ناسفة بدائية الصنع في المملكة المتحدة",
    "Deaths by improvised explosive device in the United States": "وفيات بعبوة ناسفة بدائية الصنع في الولايات المتحدة",
    "Deaths by improvised explosive device in Ukraine": "وفيات بعبوة ناسفة بدائية الصنع في أوكرانيا",
    "Deaths by improvised explosive device": "وفيات بعبوة ناسفة بدائية الصنع",
    "Deaths by person in Minnesota": "وفيات حسب الشخص في منيسوتا",
    "Deaths by person in Oregon": "وفيات حسب الشخص في أوريغن",
    "Deaths by stabbing in Algeria": "وفيات بالطعن في الجزائر",
    "Deaths by stabbing in Argentina": "وفيات بالطعن في الأرجنتين",
    "Deaths by stabbing in Arizona": "وفيات بالطعن في أريزونا",
    "Deaths by stabbing in Australia": "وفيات بالطعن في أستراليا",
    "Deaths by stabbing in Azerbaijan": "وفيات بالطعن في أذربيجان",
    "Deaths by stabbing in Belgium": "وفيات بالطعن في بلجيكا",
    "Deaths by stabbing in Brazil": "وفيات بالطعن في البرازيل",
    "Deaths by stabbing in Bulgaria": "وفيات بالطعن في بلغاريا",
    "Deaths by stabbing in California": "وفيات بالطعن في كاليفورنيا",
    "Deaths by stabbing in Canada": "وفيات بالطعن في كندا",
    "Deaths by stabbing in China": "وفيات بالطعن في الصين",
    "Deaths by stabbing in Connecticut": "وفيات بالطعن في كونيتيكت",
    "Deaths by stabbing in Croatia": "وفيات بالطعن في كرواتيا",
    "Deaths by stabbing in Egypt": "وفيات بالطعن في مصر",
    "Deaths by stabbing in England": "وفيات بالطعن في إنجلترا",
    "Deaths by stabbing in Finland": "وفيات بالطعن في فنلندا",
    "Deaths by stabbing in Florida": "وفيات بالطعن في فلوريدا",
    "Deaths by stabbing in France": "وفيات بالطعن في فرنسا",
    "Deaths by stabbing in Germany": "وفيات بالطعن في ألمانيا",
    "Deaths by stabbing in Ghana": "وفيات بالطعن في غانا",
    "Deaths by stabbing in Guatemala": "وفيات بالطعن في غواتيمالا",
    "Deaths by stabbing in Honduras": "وفيات بالطعن في هندوراس",
    "Deaths by stabbing in Hungary": "وفيات بالطعن في المجر",
    "Deaths by stabbing in Illinois": "وفيات بالطعن في إلينوي",
    "Deaths by stabbing in India": "وفيات بالطعن في الهند",
    "Deaths by stabbing in Indiana": "وفيات بالطعن في إنديانا",
    "Deaths by stabbing in Iowa": "وفيات بالطعن في آيوا",
    "Deaths by stabbing in Iran": "وفيات بالطعن في إيران",
    "Deaths by stabbing in Israel": "وفيات بالطعن في إسرائيل",
    "Deaths by stabbing in Italy": "وفيات بالطعن في إيطاليا",
    "Deaths by stabbing in Jamaica": "وفيات بالطعن في جامايكا",
    "Deaths by stabbing in Japan": "وفيات بالطعن في اليابان",
    "Deaths by stabbing in Kansas": "وفيات بالطعن في كانساس",
    "Deaths by stabbing in Kenya": "وفيات بالطعن في كينيا",
    "Deaths by stabbing in Lebanon": "وفيات بالطعن في لبنان",
    "Deaths by stabbing in London": "وفيات بالطعن في لندن",
    "Deaths by stabbing in Massachusetts": "وفيات بالطعن في ماساتشوستس",
    "Deaths by stabbing in Mexico": "وفيات بالطعن في المكسيك",
    "Deaths by stabbing in Michigan": "وفيات بالطعن في ميشيغان",
    "Deaths by stabbing in Mississippi": "وفيات بالطعن في مسيسيبي",
    "Deaths by stabbing in Missouri": "وفيات بالطعن في ميزوري",
    "Deaths by stabbing in Morocco": "وفيات بالطعن في المغرب",
    "Deaths by stabbing in Nevada": "وفيات بالطعن في نيفادا",
    "Deaths by stabbing in New York (state)": "وفيات بالطعن في ولاية نيويورك",
    "Deaths by stabbing in Norway": "وفيات بالطعن في النرويج",
    "Deaths by stabbing in Oregon": "وفيات بالطعن في أوريغن",
    "Deaths by stabbing in Pakistan": "وفيات بالطعن في باكستان",
    "Deaths by stabbing in Paraguay": "وفيات بالطعن في باراغواي",
    "Deaths by stabbing in Pennsylvania": "وفيات بالطعن في بنسلفانيا",
    "Deaths by stabbing in Peru": "وفيات بالطعن في بيرو",
    "Deaths by stabbing in Poland": "وفيات بالطعن في بولندا",
    "Deaths by stabbing in Romania": "وفيات بالطعن في رومانيا",
    "Deaths by stabbing in Rome": "وفيات بالطعن في روما",
    "Deaths by stabbing in Russia": "وفيات بالطعن في روسيا",
    "Deaths by stabbing in Scotland": "وفيات بالطعن في إسكتلندا",
    "Deaths by stabbing in South Korea": "وفيات بالطعن في كوريا الجنوبية",
    "Deaths by stabbing in Spain": "وفيات بالطعن في إسبانيا",
    "Deaths by stabbing in Sweden": "وفيات بالطعن في السويد",
    "Deaths by stabbing in Switzerland": "وفيات بالطعن في سويسرا",
    "Deaths by stabbing in Tennessee": "وفيات بالطعن في تينيسي",
    "Deaths by stabbing in Texas": "وفيات بالطعن في تكساس",
    "Deaths by stabbing in the Dominican Republic": "وفيات بالطعن في جمهورية الدومينيكان",
    "Deaths by stabbing in the Netherlands": "وفيات بالطعن في هولندا",
    "Deaths by stabbing in the Philippines": "وفيات بالطعن في الفلبين",
    "Deaths by stabbing in the United Arab Emirates": "وفيات بالطعن في الإمارات العربية المتحدة",
    "Deaths by stabbing in the United Kingdom": "وفيات بالطعن في المملكة المتحدة",
    "Deaths by stabbing in the United States by state": "وفيات بالطعن في الولايات المتحدة حسب الولاية",
    "Deaths by stabbing in the United States": "وفيات بالطعن في الولايات المتحدة",
    "Deaths by stabbing in Venezuela": "وفيات بالطعن في فنزويلا",
    "Deaths by stabbing in Wales": "وفيات بالطعن في ويلز",
    "Deaths by stabbing": "وفيات بالطعن",
    "Deaths by suicide bomber": "وفيات بتفجير انتحاري",
    "Deaths by United States drone strikes in Afghanistan": "وفيات بهجمات طائرات بدون طيار أمريكية في أفغانستان",
    "Deaths by United States drone strikes in Pakistan": "وفيات بهجمات طائرات بدون طيار أمريكية في باكستان",
    "Deaths by United States drone strikes in Syria": "وفيات بهجمات طائرات بدون طيار أمريكية في سوريا",
    "Deaths by United States drone strikes in Yemen": "وفيات بهجمات طائرات بدون طيار أمريكية في اليمن",
    "Deaths by violence in the United Kingdom": "وفيات بسبب العنف في المملكة المتحدة",
    "Deaths by violence in the United States by state": "وفيات بسبب العنف في الولايات المتحدة حسب الولاية",
    "Deaths by violence in the United States": "وفيات بسبب العنف في الولايات المتحدة",
    "Deaths by violence in Ukraine": "وفيات بسبب العنف في أوكرانيا",
    "Deaths by violence": "وفيات بسبب العنف",
    "Deaths by war": "وفيات حسب الحرب",
    "Deaths from cancer in Minnesota": "وفيات السرطان في منيسوتا",
    "Deaths from cancer in Oregon": "وفيات السرطان في أوريغن",
    "Deaths from cancer in Quebec": "وفيات السرطان في كيبك",
    "Deaths from cancer in West Virginia": "وفيات السرطان في فرجينيا الغربية",
    "Deaths from lung cancer in Delaware": "وفيات سرطان الرئة في ديلاوير",
    "Deaths from lung cancer in Minnesota": "وفيات سرطان الرئة في منيسوتا",
    "Deaths from lung cancer in Oregon": "وفيات سرطان الرئة في أوريغن",
    "Deaths from pneumonia in Delaware": "وفيات الالتهاب الرئوي في ديلاوير",
    "Deaths from pneumonia in Minnesota": "وفيات الالتهاب الرئوي في منيسوتا",
    "Deaths by firearm in Algeria": "وفيات بإطلاق النار في الجزائر",
    "Deaths by firearm in Austria": "وفيات بإطلاق النار في النمسا",
    "Deaths by firearm in Bahrain": "وفيات بإطلاق النار في البحرين",
    "Deaths by firearm in China": "وفيات بإطلاق النار في الصين",
    "Deaths by firearm in France": "وفيات بإطلاق النار في فرنسا",
    "Deaths by firearm in Greece": "وفيات بإطلاق النار في اليونان",
    "Deaths by firearm in Honduras": "وفيات بإطلاق النار في هندوراس",
    "Deaths by firearm in Jordan": "وفيات بإطلاق النار في الأردن",
    "Deaths by firearm in Lebanon": "وفيات بإطلاق النار في لبنان",
    "Deaths by firearm in Syria": "وفيات بإطلاق النار في سوريا",
    "Deaths by firearm in the United States": "وفيات بإطلاق النار في الولايات المتحدة",
    "Deaths by firearm in Tunisia": "وفيات بإطلاق النار في تونس",
    "Deaths by firearm in Turkey": "وفيات بإطلاق النار في تركيا",
    "Deaths by firearm in Venezuela": "وفيات بإطلاق النار في فنزويلا",
    "Deaths by firearm in Yemen": "وفيات بإطلاق النار في اليمن",
    "Deaths by firearm in Balochistan, Pakistan": "وفيات بإطلاق النار في بلوشستان (باكستان)",
    "Deaths by firearm in Florida": "وفيات بإطلاق النار في فلوريدا",
    "Deaths by firearm in Grenada": "وفيات بإطلاق النار في غرينادا",
    "Deaths by firearm in Iran": "وفيات بإطلاق النار في إيران",
    "Deaths by firearm in Iraq": "وفيات بإطلاق النار في العراق",
    "Deaths by firearm in Khyber Pakhtunkhwa": "وفيات بإطلاق النار في خيبر بختونخوا",
    "Deaths by firearm in Manitoba": "وفيات بإطلاق النار في مانيتوبا",
    "Deaths by firearm in Saudi Arabia": "وفيات بإطلاق النار في السعودية",
    "Deaths by firearm in Sudan": "وفيات بإطلاق النار في السودان",
    "Deaths by firearm in Texas": "وفيات بإطلاق النار في تكساس",
    "Deaths by firearm in Thailand": "وفيات بإطلاق النار في تايلاند",
    "Deaths by firearm in the State of Palestine": "وفيات بإطلاق النار في دولة فلسطين",
    "Deaths by firearm in the United States by state": "وفيات بإطلاق النار في الولايات المتحدة حسب الولاية",
    "Deaths by firearm in Wyoming": "وفيات بإطلاق النار في وايومنغ",
    "Deaths by firearm": "وفيات بسلاح ناري",
    "Deaths by former country": "وفيات حسب البلد السابق",
    "Deaths by hanging": "وفيات بالشنق",
    "Deaths by person and city": "وفيات حسب الشخص والمدينة",
    "Deaths by person and populated place": "وفيات حسب الشخص والمكان المأهول",
    "Deaths by person in Palestine": "وفيات حسب الشخص في فلسطين",
    "Deaths by person": "وفيات حسب الشخص",
    "Deaths by populated place": "وفيات حسب المكان المأهول",
    "Deaths by projectile weapons": "وفيات بسلاح القذائف",
    "Deaths by stabbing in ancient Rome": "وفيات بالطعن في روما القديمة",
    "Deaths by stabbing in Bangladesh": "وفيات بالطعن في بنغلاديش",
    "Deaths by stabbing in Colombia": "وفيات بالطعن في كولومبيا",
    "Deaths by stabbing in Idaho": "وفيات بالطعن في أيداهو",
    "Deaths by stabbing in North Carolina": "وفيات بالطعن في كارولاينا الشمالية",
    "Deaths by stabbing in Palestine": "وفيات بالطعن في فلسطين",
    "Deaths by stabbing in the Palestinian territories": "وفيات بالطعن في الضفة الغربية وقطاع غزة",
    "Deaths by stabbing in the State of Palestine": "وفيات بالطعن في دولة فلسطين",
    "Deaths by United States drone strikes in Iraq": "وفيات بهجمات طائرات بدون طيار أمريكية في العراق",
    "Deaths by United States drone strikes": "وفيات بهجمات طائرات بدون طيار أمريكية",
    "Deaths by year": "وفيات حسب السنة",
    "Deaths due to animal attacks": "وفيات ناجمة عن هجمات الحيوانات",
    "Deaths from amyloidosis": "وفيات داء نشواني",
    "Deaths from autoimmune disease": "وفيات أمراض المناعة الذاتية",
    "Deaths from blood disease": "وفيات أمراض الدم",
    "Deaths from cancer by type": "وفيات السرطان حسب الفئة",
    "Deaths from cancer in Colorado": "وفيات السرطان في كولورادو",
    "Deaths from cancer in Georgia (U.S. state)": "وفيات السرطان في ولاية جورجيا",
    "Deaths from cancer in Illinois": "وفيات السرطان في إلينوي",
    "Deaths from cancer in Massachusetts": "وفيات السرطان في ماساتشوستس",
    "Deaths from cancer in Missouri": "وفيات السرطان في ميزوري",
    "Deaths from cancer in New Jersey": "وفيات السرطان في نيوجيرسي",
    "Deaths from cancer in New South Wales": "وفيات السرطان في نيوساوث ويلز",
    "Deaths from cancer in New York (state)": "وفيات السرطان في ولاية نيويورك",
    "Deaths from cancer in North Carolina": "وفيات السرطان في كارولاينا الشمالية",
    "Deaths from cancer in Rhode Island": "وفيات السرطان في رود آيلاند",
    "Deaths from cancer in South Carolina": "وفيات السرطان في كارولاينا الجنوبية",
    "Deaths from cancer in the Palestinian territories": "وفيات السرطان في الضفة الغربية وقطاع غزة",
    "Deaths from cancer in the United States by state or territory": "وفيات السرطان في الولايات المتحدة حسب الولاية أو الإقليم",
    "Deaths from cancer in Uruguay": "وفيات السرطان في أوروغواي",
    "Deaths from cancer in Vatican City": "وفيات السرطان في الفاتيكان",
    "Deaths from cancer in Washington (state)": "وفيات السرطان في ولاية واشنطن",
    "Deaths from cancer": "وفيات السرطان",
    "Deaths from cardiovascular disease": "وفيات أمراض قلبية وعائية",
    "Deaths from digestive disease": "وفيات أمراض الجهاز الهضمي",
    "Deaths from endocrine disease": "وفيات أمراض الغدد الصماء",
    "Deaths from genetic disorders": "وفيات اضطرابات وراثية",
    "Deaths from infectious disease": "وفيات أمراض معدية",
    "Deaths from leishmaniasis": "وفيات من داء الليشمانيات",
    "Deaths from lung cancer in the United States by state or territory": "وفيات سرطان الرئة في الولايات المتحدة حسب الولاية أو الإقليم",
    "Deaths from lung cancer in Uruguay": "وفيات سرطان الرئة في أوروغواي",
    "Deaths from lung cancer": "وفيات سرطان الرئة",
    "Deaths from mastocytosis": "وفيات كثرة الخلايا البدينة",
    "Deaths from mesothelioma": "وفيات من ورم المتوسطة",
    "Deaths from musculoskeletal disorders": "وفيات إصابة الإجهاد المتكرر",
    "Deaths from neurological disease": "وفيات أمراض عصبية",
    "Deaths from organ failure": "وفيات فشل عضوي",
    "Deaths from pneumonia in the United States by state or territory": "وفيات الالتهاب الرئوي في الولايات المتحدة حسب الولاية أو الإقليم",
    "Deaths from pneumonia in Uruguay": "وفيات الالتهاب الرئوي في أوروغواي",
    "Deaths from pneumonia": "وفيات الالتهاب الرئوي",
    "Deaths from reproductive system disease": "وفيات أمراض الجهاز التناسلي",
    "Deaths from respiratory disease": "وفيات أمراض الجهاز التنفسي",
    "Deaths from sickle-cell disease": "وفيات من فقر الدم المنجلي",
    "Deaths from skin disease": "وفيات مرض جلدي",
    "Deaths from tuberculosis by century": "وفيات من السل حسب القرن",
    "Deaths from tuberculosis": "وفيات من السل",
    "Deaths from urologic disease": "وفيات أمراض الجهاز البولي",
}

to_test = [
    ("test_deaths_2_data_1", data_test_1),
    ("test_deaths_2_data_covid_pandemic_data", covid_pandemic_data),
    ("test_deaths_2_data_airstrikes_data", airstrikes_data),
]


@pytest.mark.parametrize("category, expected", airstrikes_data.items(), ids=airstrikes_data.keys())
@pytest.mark.fast
def test_airstrikes_data(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
