"""
"Defunct Canadian football teams": "فرق كرة قدم كندية سابقة",
"LGBTQ players of Canadian football": "لاعبو كرة قدم كندية مثليون",
"""

import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data4 = {
    "Canadian football running backs": "راكضون للخلف كرة القدم الكندية",
    "Canadian football linebackers": "أظهرة كرة القدم الكندية",
    "Canadian football centres": "لاعبو وسط كرة القدم الكندية",
    "Canadian football defensive linemen": "مدافعو خط كرة القدم الكندية",
    "Canadian football defensive backs": "مدافعون خلفيون كرة القدم الكندية",
    "Canadian football fullbacks": "مدافعو كرة القدم الكندية",
    "Canadian football placekickers": "مسددو كرة القدم الكندية",
    "Canadian football scouts": "كشافة كرة القدم الكندية",
    "Canadian football offensive linemen": "مهاجمو خط كرة القدم الكندية",
    "Canadian football tackles": "مصطدمو كرة القدم الكندية",
    "Canadian football wide receivers": "مستقبلون واسعون كرة القدم الكندية",
    "Canadian football guards": "حراس كرة القدم الكندية",
    "Canadian football quarterbacks": "أظهرة رباعيون كرة القدم الكندية",
}

data1 = {
    "Canadian football venues": "ملاعب كرة القدم الكندية",
    "Canadian football templates": "قوالب كرة القدم الكندية",
    "African-American coaches of Canadian football": "مدربو كرة قدم كندية أمريكيون أفارقة",
    "American players of Canadian football by populated place": "لاعبو كرة قدم كندية أمريكيون حسب المكان المأهول",
    "American players of Canadian football by state": "لاعبو كرة قدم كندية أمريكيون حسب الولاية",
    "American players of Canadian football": "لاعبو كرة قدم كندية أمريكيون",
    "Australian players of Canadian football": "لاعبو كرة قدم كندية أستراليون",
    "Bahamian players of Canadian football": "لاعبو كرة قدم كندية بهاميون",
    "Cameroonian players of Canadian football": "لاعبو كرة قدم كندية كاميرونيون",
    "Canadian players of Canadian football by populated place": "لاعبو كرة قدم كندية كنديون حسب المكان المأهول",
    "Coaches of Canadian football": "مدربو كرة قدم كندية",
    "Cuban players of Canadian football": "لاعبو كرة قدم كندية كوبيون",
    "Democratic Republic of the Congo players of Canadian football": "لاعبو كرة قدم كندية كونغويون ديمقراطيون",
    "Dominican Republic players of Canadian football": "لاعبو كرة قدم كندية دومينيكانيون",
    "English players of Canadian football": "لاعبو كرة قدم كندية إنجليز",
    "Guyanese players of Canadian football": "لاعبو كرة قدم كندية غيانيون",
    "Honduran players of Canadian football": "لاعبو كرة قدم كندية هندوراسيون",
    "Jamaican players of Canadian football": "لاعبو كرة قدم كندية جامايكيون",
    "Lebanese players of Canadian football": "لاعبو كرة قدم كندية لبنانيون",
    "Nigerian players of Canadian football": "لاعبو كرة قدم كندية نيجيريون",
    "Panamanian players of Canadian football": "لاعبو كرة قدم كندية بنميون",
    "Players of Canadian football by nationality": "لاعبو كرة قدم كندية حسب الجنسية",
    "Players of Canadian football by position": "لاعبو كرة قدم كندية حسب المركز",
    "Players of Canadian football from Alabama": "لاعبو كرة قدم كندية من ألاباما",
    "Players of Canadian football from Alaska": "لاعبو كرة قدم كندية من ألاسكا",
    "Players of Canadian football from Alberta": "لاعبو كرة قدم كندية من ألبرتا",
    "Players of Canadian football from Arizona": "لاعبو كرة قدم كندية من أريزونا",
    "Players of Canadian football from Arkansas": "لاعبو كرة قدم كندية من أركنساس",
    "Players of Canadian football from Atlanta": "لاعبو كرة قدم كندية من أتلانتا (جورجيا)",
    "Players of Canadian football from Baltimore": "لاعبو كرة قدم كندية من بالتيمور",
    "Players of Canadian football from Birmingham, Alabama": "لاعبو كرة قدم كندية من برمنغهام (ألاباما)",
    "Players of Canadian football from Brampton": "لاعبو كرة قدم كندية من برامبتون (أونتاريو)",
    "Players of Canadian football from British Columbia": "لاعبو كرة قدم كندية من كولومبيا البريطانية",
    "Players of Canadian football from Brooklyn": "لاعبو كرة قدم كندية من بروكلين",
    "Players of Canadian football from California": "لاعبو كرة قدم كندية من كاليفورنيا",
    "Players of Canadian football from Chicago": "لاعبو كرة قدم كندية من شيكاغو",
    "Players of Canadian football from Cincinnati": "لاعبو كرة قدم كندية من سينسيناتي",
    "Players of Canadian football from Cleveland": "لاعبو كرة قدم كندية من كليفلاند",
    "Players of Canadian football from Colorado": "لاعبو كرة قدم كندية من كولورادو",
    "Players of Canadian football from Columbia, South Carolina": "لاعبو كرة قدم كندية من كولومبيا (كارولاينا الجنوبية)",
    "Players of Canadian football from Columbus, Ohio": "لاعبو كرة قدم كندية من كولومبوس (أوهايو)",
    "Players of Canadian football from Connecticut": "لاعبو كرة قدم كندية من كونيتيكت",
    "Players of Canadian football from Dallas": "لاعبو كرة قدم كندية من دالاس",
    "Players of Canadian football from Dayton, Ohio": "لاعبو كرة قدم كندية من دايتون (أوهايو)",
    "Players of Canadian football from Delaware": "لاعبو كرة قدم كندية من ديلاوير",
    "Players of Canadian football from Denver": "لاعبو كرة قدم كندية من دنفر (كولورادو)",
    "Players of Canadian football from Detroit": "لاعبو كرة قدم كندية من ديترويت",
    "Players of Canadian football from Florida": "لاعبو كرة قدم كندية من فلوريدا",
    "Players of Canadian football from Fort Lauderdale, Florida": "لاعبو كرة قدم كندية من فورت لاودردال (فلوريدا)",
    "Players of Canadian football from Georgia (U.S. state)": "لاعبو كرة قدم كندية من ولاية جورجيا",
    "Players of Canadian football from Hawaii": "لاعبو كرة قدم كندية من هاواي",
    "Players of Canadian football from Honolulu": "لاعبو كرة قدم كندية من هونولولو",
    "Players of Canadian football from Houston": "لاعبو كرة قدم كندية من هيوستن",
    "Players of Canadian football from Idaho": "لاعبو كرة قدم كندية من أيداهو",
    "Players of Canadian football from Illinois": "لاعبو كرة قدم كندية من إلينوي",
    "Players of Canadian football from Indiana": "لاعبو كرة قدم كندية من إنديانا",
    "Players of Canadian football from Indianapolis": "لاعبو كرة قدم كندية من إنديانابوليس",
    "Players of Canadian football from Jackson, Mississippi": "لاعبو كرة قدم كندية من جاكسون (مسيسيبي)",
    "Players of Canadian football from Jacksonville, Florida": "لاعبو كرة قدم كندية من جاكسونفيل (فلوريدا)",
    "Players of Canadian football from Kansas City, Missouri": "لاعبو كرة قدم كندية من كانساس سيتي (ميزوري)",
    "Players of Canadian football from Kansas": "لاعبو كرة قدم كندية من كانساس",
    "Players of Canadian football from Kentucky": "لاعبو كرة قدم كندية من كنتاكي",
    "Players of Canadian football from Kingston, Jamaica": "لاعبو كرة قدم كندية من كينغستون",
    "Players of Canadian football from Lagos": "لاعبو كرة قدم كندية من ولاية لاغوس",
    "Players of Canadian football from Las Vegas": "لاعبو كرة قدم كندية من لاس فيغاس (نيفادا)",
    "Players of Canadian football from Long Beach, California": "لاعبو كرة قدم كندية من لونغ بيتش (كاليفورنيا)",
    "Players of Canadian football from Los Angeles": "لاعبو كرة قدم كندية من لوس أنجلوس",
    "Players of Canadian football from Louisiana": "لاعبو كرة قدم كندية من لويزيانا",
    "Players of Canadian football from Louisville, Kentucky": "لاعبو كرة قدم كندية من لويفيل (كنتاكي)",
    "Players of Canadian football from Manitoba": "لاعبو كرة قدم كندية من مانيتوبا",
    "Players of Canadian football from Maryland": "لاعبو كرة قدم كندية من ماريلند",
    "Players of Canadian football from Massachusetts": "لاعبو كرة قدم كندية من ماساتشوستس",
    "Players of Canadian football from Memphis, Tennessee": "لاعبو كرة قدم كندية من ممفيس (تينيسي)",
    "Players of Canadian football from Miami": "لاعبو كرة قدم كندية من ميامي",
    "Players of Canadian football from Michigan": "لاعبو كرة قدم كندية من ميشيغان",
    "Players of Canadian football from Minneapolis": "لاعبو كرة قدم كندية من مينيابوليس",
    "Players of Canadian football from Minnesota": "لاعبو كرة قدم كندية من منيسوتا",
    "Players of Canadian football from Mississippi": "لاعبو كرة قدم كندية من مسيسيبي",
    "Players of Canadian football from Missouri": "لاعبو كرة قدم كندية من ميزوري",
    "Players of Canadian football from Montana": "لاعبو كرة قدم كندية من مونتانا",
    "Players of Canadian football from Nevada": "لاعبو كرة قدم كندية من نيفادا",
    "Players of Canadian football from New Brunswick": "لاعبو كرة قدم كندية من نيو برونزويك",
    "Players of Canadian football from New Jersey": "لاعبو كرة قدم كندية من نيوجيرسي",
    "Players of Canadian football from New Mexico": "لاعبو كرة قدم كندية من نيومكسيكو",
    "Players of Canadian football from New Orleans": "لاعبو كرة قدم كندية من نيو أورلينز",
    "Players of Canadian football from New York (state)": "لاعبو كرة قدم كندية من ولاية نيويورك",
    "Players of Canadian football from New York City": "لاعبو كرة قدم كندية من مدينة نيويورك",
    "Players of Canadian football from Newark, New Jersey": "لاعبو كرة قدم كندية من نيوآرك (نيو جيرسي)",
    "Players of Canadian football from Norfolk, Virginia": "لاعبو كرة قدم كندية من نورفولك (فرجينيا)",
    "Players of Canadian football from North Carolina": "لاعبو كرة قدم كندية من كارولاينا الشمالية",
    "Players of Canadian football from North Dakota": "لاعبو كرة قدم كندية من داكوتا الشمالية",
    "Players of Canadian football from Nova Scotia": "لاعبو كرة قدم كندية من نوفا سكوشا",
    "Players of Canadian football from Oakland, California": "لاعبو كرة قدم كندية من أوكلاند (كاليفورنيا)",
    "Players of Canadian football from Ohio": "لاعبو كرة قدم كندية من أوهايو",
    "Players of Canadian football from Oklahoma City": "لاعبو كرة قدم كندية من أوكلاهوما سيتي",
    "Players of Canadian football from Oklahoma": "لاعبو كرة قدم كندية من أوكلاهوما",
    "Players of Canadian football from Ontario": "لاعبو كرة قدم كندية من أونتاريو",
    "Players of Canadian football from Oregon": "لاعبو كرة قدم كندية من أوريغن",
    "Players of Canadian football from Orlando, Florida": "لاعبو كرة قدم كندية من أورلاندو (فلوريدا)",
    "Players of Canadian football from Pasadena, California": "لاعبو كرة قدم كندية من باسادينا (كاليفورنيا)",
    "Players of Canadian football from Pennsylvania": "لاعبو كرة قدم كندية من بنسلفانيا",
    "Players of Canadian football from Pensacola, Florida": "لاعبو كرة قدم كندية من بينساكولا (فلوريدا)",
    "Players of Canadian football from Philadelphia": "لاعبو كرة قدم كندية من فيلادلفيا",
    "Players of Canadian football from Phoenix, Arizona": "لاعبو كرة قدم كندية من فينيكس (أريزونا)",
    "Players of Canadian football from Pittsburgh": "لاعبو كرة قدم كندية من بيتسبرغ",
    "Players of Canadian football from Quebec": "لاعبو كرة قدم كندية من كيبك",
    "Players of Canadian football from Queens, New York": "لاعبو كرة قدم كندية من كوينز (نيويورك)",
    "Players of Canadian football from Sacramento, California": "لاعبو كرة قدم كندية من ساكرامنتو (كاليفورنيا)",
    "Players of Canadian football from San Antonio": "لاعبو كرة قدم كندية من سان أنطونيو",
    "Players of Canadian football from San Diego": "لاعبو كرة قدم كندية من سان دييغو",
    "Players of Canadian football from San Francisco": "لاعبو كرة قدم كندية من سان فرانسيسكو",
    "Players of Canadian football from San Jose, California": "لاعبو كرة قدم كندية من سان خوسيه (كاليفورنيا)",
    "Players of Canadian football from Saskatchewan": "لاعبو كرة قدم كندية من ساسكاتشوان",
    "Players of Canadian football from Seattle": "لاعبو كرة قدم كندية من سياتل",
    "Players of Canadian football from South Carolina": "لاعبو كرة قدم كندية من كارولاينا الجنوبية",
    "Players of Canadian football from St. Louis": "لاعبو كرة قدم كندية من سينت لويس",
    "Players of Canadian football from St. Petersburg, Florida": "لاعبو كرة قدم كندية من سانت بيترسبرغ (فلوريدا)",
    "Players of Canadian football from Stockton, California": "لاعبو كرة قدم كندية من ستوكتون (كاليفورنيا)",
    "Players of Canadian football from Tampa, Florida": "لاعبو كرة قدم كندية من تامبا (فلوريدا)",
    "Players of Canadian football from Tennessee": "لاعبو كرة قدم كندية من تينيسي",
    "Players of Canadian football from Texas": "لاعبو كرة قدم كندية من تكساس",
    "Players of Canadian football from Utah": "لاعبو كرة قدم كندية من يوتا",
    "Players of Canadian football from Vermont": "لاعبو كرة قدم كندية من فيرمونت",
    "Players of Canadian football from Virginia": "لاعبو كرة قدم كندية من فرجينيا",
    "Players of Canadian football from Washington (state)": "لاعبو كرة قدم كندية من ولاية واشنطن",
    "Players of Canadian football from Washington, D.C.": "لاعبو كرة قدم كندية من واشنطن العاصمة",
    "Players of Canadian football from West Virginia": "لاعبو كرة قدم كندية من فرجينيا الغربية",
    "Players of Canadian football from Wisconsin": "لاعبو كرة قدم كندية من ويسكونسن",
    "Players of Canadian football from Wyoming": "لاعبو كرة قدم كندية من وايومنغ",
    "Players of Canadian football": "لاعبو كرة قدم كندية",
    "Puerto Rican players of Canadian football": "لاعبو كرة قدم كندية بورتوريكيون",
    "Samoan players of Canadian football": "لاعبو كرة قدم كندية سامويون",
    "Sierra Leonean players of Canadian football": "لاعبو كرة قدم كندية سيراليونيون",
    "Venezuelan players of Canadian football": "لاعبو كرة قدم كندية فنزويليون",
}

data2 = {
    "Canadian football media": "إعلام كرة قدم كندية",
    "Canadian football people from Calgary": "أعلام كرة قدم كندية من كالغاري",
    "Canadian football people from Edmonton": "أعلام كرة قدم كندية من إدمونتون",
    "Canadian football people from Greater Sudbury": "أعلام كرة قدم كندية من غريتر سودبوري",
    "Canadian football people from Halifax, Nova Scotia": "أعلام كرة قدم كندية من هاليفاكس (نوفا سكوشيا)",
    "Canadian football people from Hamilton, Ontario": "أعلام كرة قدم كندية من هاميلتون",
    "Canadian football people from London, Ontario": "أعلام كرة قدم كندية من لندن (أونتاريو)",
    "Canadian football people from Mississauga": "أعلام كرة قدم كندية من ميسيسوجا",
    "Canadian football people from Montreal": "أعلام كرة قدم كندية من مونتريال",
    "Canadian football people from New Westminster": "أعلام كرة قدم كندية من نيو ويستمينيستر (كولومبيا البريطانية)",
    "Canadian football people from Ottawa": "أعلام كرة قدم كندية من أوتاوا",
    "Canadian football people from Quebec City": "أعلام كرة قدم كندية من مدينة كيبك",
    "Canadian football people from Regina, Saskatchewan": "أعلام كرة قدم كندية من ريجاينا",
    "Canadian football people from Saskatoon": "أعلام كرة قدم كندية من ساسكاتون",
    "Canadian football people from Toronto": "أعلام كرة قدم كندية من تورونتو",
    "Canadian football people from Vancouver": "أعلام كرة قدم كندية من فانكوفر",
    "Canadian football people from Victoria, British Columbia": "أعلام كرة قدم كندية من فيكتوريا (كولومبيا البريطانية)",
    "Canadian football people from Windsor, Ontario": "أعلام كرة قدم كندية من وندسور (أونتاريو)",
    "Canadian football people from Winnipeg": "أعلام كرة قدم كندية من وينيبيغ",
    "Canadian football terminology": "مصطلحات كرة قدم كندية",
}

data3 = {
    "Canadian football by city": "كرة القدم الكندية حسب المدينة",
    "Canadian football by country": "كرة القدم الكندية حسب البلد",
    "Canadian football by province or territory": "كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Canadian football in Alberta": "كرة القدم الكندية في ألبرتا",
    "Canadian football in British Columbia": "كرة القدم الكندية في كولومبيا البريطانية",
    "Canadian football in Calgary": "كرة القدم الكندية في كالغاري",
    "Canadian football in Canada by city": "كرة القدم الكندية في كندا حسب المدينة",
    "Canadian football in Canada": "كرة القدم الكندية في كندا",
    "Canadian football in Edmonton": "كرة القدم الكندية في إدمونتون",
    "Canadian football in Hamilton, Ontario": "كرة القدم الكندية في هاميلتون",
    "Canadian football in Manitoba": "كرة القدم الكندية في مانيتوبا",
    "Canadian football in Montreal": "كرة القدم الكندية في مونتريال",
    "Canadian football in Nova Scotia": "كرة القدم الكندية في نوفا سكوشا",
    "Canadian football in Ontario": "كرة القدم الكندية في أونتاريو",
    "Canadian football in Ottawa": "كرة القدم الكندية في أوتاوا",
    "Canadian football in Quebec": "كرة القدم الكندية في كيبك",
    "Canadian football in Saskatchewan": "كرة القدم الكندية في ساسكاتشوان",
    "Canadian football in Toronto": "كرة القدم الكندية في تورونتو",
    "Canadian football in Vancouver": "كرة القدم الكندية في فانكوفر",
    "Canadian football in Winnipeg": "كرة القدم الكندية في وينيبيغ",
    "Canadian football teams by city": "فرق كرة القدم الكندية حسب المدينة",
    "Canadian football teams by league": "فرق كرة القدم الكندية حسب الدوري",
    "Canadian football teams by province or territory": "فرق كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Canadian football teams in Alberta": "فرق كرة القدم الكندية في ألبرتا",
    "Canadian football teams in Calgary": "فرق كرة القدم الكندية في كالغاري",
    "Canadian football teams in Edmonton": "فرق كرة القدم الكندية في إدمونتون",
    "Canadian football teams in Manitoba": "فرق كرة القدم الكندية في مانيتوبا",
    "Canadian football teams in Ontario": "فرق كرة القدم الكندية في أونتاريو",
    "Canadian football teams in Ottawa": "فرق كرة القدم الكندية في أوتاوا",
    "Canadian football teams in Saskatchewan": "فرق كرة القدم الكندية في ساسكاتشوان",
    "Canadian football teams in Toronto": "فرق كرة القدم الكندية في تورونتو",
    "Canadian football teams in Vancouver": "فرق كرة القدم الكندية في فانكوفر",
    "Canadian football teams in Winnipeg": "فرق كرة القدم الكندية في وينيبيغ",
    "Canadian football venues in British Columbia": "ملاعب كرة القدم الكندية في كولومبيا البريطانية",
    "Canadian football venues in Manitoba": "ملاعب كرة القدم الكندية في مانيتوبا",
    "Canadian football venues in Ontario": "ملاعب كرة القدم الكندية في أونتاريو",
    "Canadian football venues in Quebec": "ملاعب كرة القدم الكندية في كيبك",
    "Canadian football venues in the United States": "ملاعب كرة القدم الكندية في الولايات المتحدة",
    "Canadian football": "كرة القدم الكندية",
    "Canadian players of Canadian football": "لاعبو كرة قدم كندية كنديون",
}

to_test = [
    ("test_canadian_football_1", data1),
    ("test_canadian_football_2", data2),
    ("test_canadian_football_3", data3),
    ("test_canadian_football_4", data4),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_canadian_football_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_canadian_football_2(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_canadian_football_3(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data4.items(), ids=data4.keys())
def test_canadian_football_4(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
