#!/usr/bin/python3
"""Helper utilities for the translations package.

This module re-exports debugging and data inspection utilities used
throughout the translation modules.
"""

from ..helps import len_print

__all__ = ["len_print"]
