#

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_1 = {
    "1960s in Papua New Guinean sport": "x",
    "1962 in Papua New Guinean sport": "x",
    "1969 in Papua New Guinean sport": "x",
    "1970s in Papua New Guinean sport": "x",
    "1975 in Papua New Guinean sport": "x",
    "1976 in Papua New Guinean sport": "x",
    "1980s in Papua New Guinean sport": "x",
    "1982 in Papua New Guinean sport": "x",
    "1983 in Papua New Guinean sport": "x",
    "1984 in Papua New Guinean sport": "x",
    "1985 in Papua New Guinean sport": "x",
    "1986 in Papua New Guinean sport": "x",
    "1988 in Papua New Guinean rugby league": "x",
    "1988 in Papua New Guinean sport": "x",
    "1989 in Papua New Guinean sport": "x",
    "1990 in Papua New Guinean rugby league": "x",
    "1990 in Papua New Guinean sport": "x",
    "1990s in Papua New Guinean sport": "x",
    "1990s in Papua New Guinean television": "x",
    "1990s Papua New Guinean television series": "x",
    "1991 in Papua New Guinean rugby league": "x",
    "1991 in Papua New Guinean sport": "x",
    "1992 in Papua New Guinean rugby league": "x",
    "1992 in Papua New Guinean sport": "x",
    "1994 in Papua New Guinean rugby league": "x",
    "1994 in Papua New Guinean sport": "x",
    "1996 in Papua New Guinean rugby league": "x",
    "1996 in Papua New Guinean sport": "x",
    "1997 in Papua New Guinean sport": "x",
    "2000 in Papua New Guinean sport": "x",
    "2000s in Papua New Guinean sport": "x",
    "2001 in Papua New Guinean rugby league": "x",
    "2001 in Papua New Guinean soccer": "x",
    "2001 in Papua New Guinean sport": "x",
    "2003 in Papua New Guinean sport": "x",
    "2004 in Papua New Guinean sport": "x",
    "2005 in Papua New Guinean sport": "x",
    "2006 in Papua New Guinean sport": "x",
    "2007 in Papua New Guinean sport": "x",
    "2008 in Papua New Guinean sport": "x",
    "2009 in Papua New Guinean sport": "x",
    "2010 in Papua New Guinean sport": "x",
    "2010s in Papua New Guinean sport": "x",
    "2011 in Papua New Guinean sport": "x",
    "2011–2012 Papua New Guinean constitutional crisis": "x",
    "2012 in Papua New Guinean sport": "x",
    "2013 in Papua New Guinean sport": "x",
    "2014 in Papua New Guinean sport": "x",
    "2015 in Papua New Guinean sport": "x",
    "2016 in Papua New Guinean cricket": "x",
    "2016 in Papua New Guinean sport": "x",
    "2017 in Papua New Guinean cricket": "x",
    "2017 in Papua New Guinean sport": "x",
    "2018 in Papua New Guinean sport": "x",
    "2019 in Papua New Guinean cricket": "x",
    "2019 in Papua New Guinean sport": "x",
    "2020 in Papua New Guinean sport": "x",
    "2020s in Papua New Guinean cricket": "x",
    "2020s in Papua New Guinean sport": "x",
    "2021 in Papua New Guinean cricket": "x",
    "2021 in Papua New Guinean sport": "x",
    "2022 in Papua New Guinean cricket": "x",
    "2022 in Papua New Guinean sport": "x",
    "2023 in Papua New Guinean cricket": "x",
    "2023 in Papua New Guinean sport": "x",
    "2024 in Papua New Guinean cricket": "x",
    "2024 in Papua New Guinean sport": "x",
    "2025 in Papua New Guinean sport": "x",
    "20th century in Papua New Guinean television": "x",
    "20th-century Papua New Guinean businesspeople": "x",
    "20th-century Papua New Guinean painters": "x",
    "20th-century Papua New Guinean people": "x",
    "20th-century Papua New Guinean politicians": "x",
    "20th-century Papua New Guinean sportsmen": "x",
    "20th-century Papua New Guinean sportspeople": "x",
    "20th-century Papua New Guinean sportswomen": "x",
    "20th-century Papua New Guinean television series": "x",
    "21st-century Papua New Guinean people": "x",
    "21st-century Papua New Guinean politicians": "x",
    "21st-century Papua New Guinean sportsmen": "x",
    "21st-century Papua New Guinean sportspeople": "x",
    "21st-century Papua New Guinean sportswomen": "x",
    "Albums by Papua New Guinean artists": "x",
    "Albums by Papua New Guinean artists by genre": "x",
    "Assassinated Papua New Guinean politicians": "x",
    "Australian people of Papua New Guinean descent": "x",
    "British people of Papua New Guinean descent": "x",
    "Fijian people of Papua New Guinean descent": "x",
    "Hip-hop albums by Papua New Guinean artists": "x",
    "Japanese people of Papua New Guinean descent": "x",
    "Lists of Papua New Guinean ambassadors": "x",
    "Lists of Papua New Guinean cricketers": "x",
    "Lists of Papua New Guinean people": "x",
    "Lists of Papua New Guinean sportspeople": "x",
    "New Zealand people of Papua New Guinean descent": "x",
    "Papua New Guinean academics": "x",
    "Papua New Guinean accountants": "x",
    "Papua New Guinean activists": "x",
    "Papua New Guinean actor-politicians": "x",
    "Papua New Guinean actors": "x",
    "Papua New Guinean Anglicans": "x",
    "Papua New Guinean anti-corruption activists": "x",
    "Papua New Guinean anti-war activists": "x",
    "Papua New Guinean archaeologists": "x",
    "Papua New Guinean artists": "x",
    "Papua New Guinean athletes": "x",
    "Papua New Guinean aviators": "x",
    "Papua New Guinean award winners": "x",
    "Papua New Guinean awards": "x",
    "Papua New Guinean badminton players": "x",
    "Papua New Guinean bankers": "x",
    "Papua New Guinean basketball players": "x",
    "Papua New Guinean beatified people": "x",
    "Papua New Guinean biologists": "x",
    "Papua New Guinean bishops": "x",
    "Papua New Guinean bowling players": "x",
    "Papua New Guinean bowls players": "x",
    "Papua New Guinean boxers": "x",
    "Papua New Guinean broadcasters": "x",
    "Papua New Guinean businesspeople": "x",
    "Papua New Guinean businesswomen": "x",
    "Papua New Guinean cardinals": "x",
    "Papua New Guinean chess players": "x",
    "Papua New Guinean Christian missionaries": "x",
    "Papua New Guinean Christians": "x",
    "Papua New Guinean civil servants": "x",
    "Papua New Guinean clergy": "x",
    "Papua New Guinean climate activists": "x",
    "Papua New Guinean Commanders of the Order of the British Empire": "x",
    "Papua New Guinean competitors by sports event": "x",
    "Papua New Guinean cricket captains": "x",
    "Papua New Guinean cricket coaches": "x",
    "Papua New Guinean cricket people": "x",
    "Papua New Guinean cricket tours abroad": "x",
    "Papua New Guinean cricket tours of Australia": "x",
    "Papua New Guinean cricket tours of Hong Kong": "x",
    "Papua New Guinean cricket tours of the United Arab Emirates": "x",
    "Papua New Guinean cricket umpires": "x",
    "Papua New Guinean cricketers": "x",
    "Papua New Guinean criminals": "x",
    "Papua New Guinean cuisine": "x",
    "Papua New Guinean curators": "x",
    "Papua New Guinean dancers": "x",
    "Papua New Guinean decathletes": "x",
    "Papua New Guinean deities": "x",
    "Papua New Guinean designers": "x",
    "Papua New Guinean diaspora": "x",
    "Papua New Guinean diplomats": "x",
    "Papua New Guinean dramatists and playwrights": "x",
    "Papua New Guinean economists": "x",
    "Papua New Guinean editors": "x",
    "Papua New Guinean educators": "x",
    "Papua New Guinean emigrants": "x",
    "Papua New Guinean emigrants to Australia": "x",
    "Papua New Guinean emigrants to Canada": "x",
    "Papua New Guinean emigrants to Japan": "x",
    "Papua New Guinean emigrants to New Zealand": "x",
    "Papua New Guinean environmentalists": "x",
    "Papua New Guinean evangelicals": "x",
    "Papua New Guinean expatriate judges": "x",
    "Papua New Guinean expatriate men's soccer players": "x",
    "Papua New Guinean expatriate rugby league players": "x",
    "Papua New Guinean expatriate rugby league players in Australia": "x",
    "Papua New Guinean expatriate rugby league players in England": "x",
    "Papua New Guinean expatriate rugby union players": "x",
    "Papua New Guinean expatriate soccer players": "x",
    "Papua New Guinean expatriate sportspeople": "x",
    "Papua New Guinean expatriate sportspeople by country of residence": "x",
    "Papua New Guinean expatriate sportspeople in Australia": "x",
    "Papua New Guinean expatriate sportspeople in England": "x",
    "Papua New Guinean expatriate sportspeople in Finland": "x",
    "Papua New Guinean expatriate sportspeople in France": "x",
    "Papua New Guinean expatriate sportspeople in Malaysia": "x",
    "Papua New Guinean expatriate sportspeople in New Zealand": "x",
    "Papua New Guinean expatriate sportspeople in the Netherlands": "x",
    "Papua New Guinean expatriate sportspeople in the Philippines": "x",
    "Papua New Guinean expatriate sportspeople in the Solomon Islands": "x",
    "Papua New Guinean expatriate sportspeople in the United Kingdom": "x",
    "Papua New Guinean expatriate sportspeople in the United States": "x",
    "Papua New Guinean expatriate sportspeople in Wales": "x",
    "Papua New Guinean expatriate women's soccer players": "x",
    "Papua New Guinean expatriates": "x",
    "Papua New Guinean expatriates in Australia": "x",
    "Papua New Guinean expatriates in Belgium": "x",
    "Papua New Guinean expatriates in England": "x",
    "Papua New Guinean expatriates in Fiji": "x",
    "Papua New Guinean expatriates in Finland": "x",
    "Papua New Guinean expatriates in France": "x",
    "Papua New Guinean expatriates in New Zealand": "x",
    "Papua New Guinean expatriates in the Netherlands": "x",
    "Papua New Guinean expatriates in the Solomon Islands": "x",
    "Papua New Guinean expatriates in the United Kingdom": "x",
    "Papua New Guinean expatriates in the United States": "x",
    "Papua New Guinean expatriates in Wales": "x",
    "Papua New Guinean farmers": "x",
    "Papua New Guinean fashion designers": "x",
    "Papua New Guinean female bowls players": "x",
    "Papua New Guinean female freestyle swimmers": "x",
    "Papua New Guinean female martial artists": "x",
    "Papua New Guinean female rugby league players": "x",
    "Papua New Guinean female rugby union players": "x",
    "Papua New Guinean female sailors (sport)": "x",
    "Papua New Guinean female swimmers": "x",
    "Papua New Guinean female taekwondo practitioners": "x",
    "Papua New Guinean female tennis players": "x",
    "Papua New Guinean female weightlifters": "x",
    "Papua New Guinean football managers": "x",
    "Papua New Guinean gospel singers": "x",
    "Papua New Guinean heptathletes": "x",
    "Papua New Guinean high jumpers": "x",
    "Papua New Guinean historians": "x",
    "Papua New Guinean hurdlers": "x",
    "Papua New Guinean javelin throwers": "x",
    "Papua New Guinean journalists": "x",
    "Papua New Guinean judges": "x",
    "Papua New Guinean judges on the courts of Fiji": "x",
    "Papua New Guinean judoka": "x",
    "Papua New Guinean knights": "x",
    "Papua New Guinean Knights Bachelor": "x",
    "Papua New Guinean Knights Commander of the Order of St Michael and St George": "x",
    "Papua New Guinean Knights Commander of the Order of the British Empire": "x",
    "Papua New Guinean lawyers": "x",
    "Papua New Guinean librarians": "x",
    "Papua New Guinean literature": "x",
    "Papua New Guinean long jumpers": "x",
    "Papua New Guinean long-distance runners": "x",
    "Papua New Guinean male bowls players": "x",
    "Papua New Guinean male boxers": "x",
    "Papua New Guinean male judoka": "x",
    "Papua New Guinean male martial artists": "x",
    "Papua New Guinean male sailors (sport)": "x",
    "Papua New Guinean male sport shooters": "x",
    "Papua New Guinean male swimmers": "x",
    "Papua New Guinean male taekwondo practitioners": "x",
    "Papua New Guinean male weightlifters": "x",
    "Papua New Guinean marathon runners": "x",
    "Papua New Guinean martial artists": "x",
    "Papua New Guinean mass media people": "x",
    "Papua New Guinean media personalities": "x",
    "Papua New Guinean members of the Privy Council of the United Kingdom": "x",
    "Papua New Guinean men": "x",
    "Papua New Guinean men athletes": "x",
    "Papua New Guinean men hurdlers": "x",
    "Papua New Guinean men javelin throwers": "x",
    "Papua New Guinean men long-distance runners": "x",
    "Papua New Guinean men marathon runners": "x",
    "Papua New Guinean men middle-distance runners": "x",
    "Papua New Guinean men sprinters": "x",
    "Papua New Guinean men's basketball players": "x",
    "Papua New Guinean men's soccer players": "x",
    "Papua New Guinean middle-distance runners": "x",
    "Papua New Guinean military personnel": "x",
    "Papua New Guinean miners": "x",
    "Papua New Guinean missionaries": "x",
    "Papua New Guinean murder victims": "x",
    "Papua New Guinean murderers": "x",
    "Papua New Guinean musical instruments": "x",
    "Papua New Guinean musicians": "x",
    "Papua New Guinean mythology": "x",
    "Papua New Guinean netball players": "x",
    "Papua New Guinean newspaper editors": "x",
    "Papua New Guinean novelists": "x",
    "Papua New Guinean officials of the United Nations": "x",
    "Papua New Guinean One Day International cricket umpires": "x",
    "Papua New Guinean painters": "x",
    "Papua New Guinean para-badminton players": "x",
    "Papua New Guinean people": "x",
    "Papua New Guinean people by descent": "x",
    "Papua New Guinean people by occupation": "x",
    "Papua New Guinean people by political orientation": "x",
    "Papua New Guinean people by province": "x",
    "Papua New Guinean people by region": "x",
    "Papua New Guinean people by religion": "x",
    "Papua New Guinean people in sports": "x",
    "Papua New Guinean people of Asian descent": "x",
    "Papua New Guinean people of Australian descent": "x",
    "Papua New Guinean people of Austrian descent": "x",
    "Papua New Guinean people of British descent": "x",
    "Papua New Guinean people of Chinese descent": "x",
    "Papua New Guinean people of Cypriot descent": "x",
    "Papua New Guinean people of English descent": "x",
    "Papua New Guinean people of European descent": "x",
    "Papua New Guinean people of Filipino descent": "x",
    "Papua New Guinean people of German descent": "x",
    "Papua New Guinean people of Greek Cypriot descent": "x",
    "Papua New Guinean people of Greek descent": "x",
    "Papua New Guinean people of Irish descent": "x",
    "Papua New Guinean people of Japanese descent": "x",
    "Papua New Guinean people of Lithuanian descent": "x",
    "Papua New Guinean people of Malaysian descent": "x",
    "Papua New Guinean people of Oceanian descent": "x",
    "Papua New Guinean people of Sri Lankan descent": "x",
    "Papua New Guinean people of Tongan descent": "x",
    "Papua New Guinean people of Welsh descent": "x",
    "Papua New Guinean people with disabilities": "x",
    "Papua New Guinean philosophers": "x",
    "Papua New Guinean physicians": "x",
    "Papua New Guinean players of Australian rules football": "x",
    "Papua New Guinean poets": "x",
    "Papua New Guinean police officers": "x",
    "Papua New Guinean political people": "x",
    "Papua New Guinean politicians": "x",
    "Papua New Guinean politicians by party": "x",
    "Papua New Guinean politicians of Chinese descent": "x",
    "Papua New Guinean prisoners and detainees": "x",
    "Papua New Guinean prisoners sentenced to death": "x",
    "Papua New Guinean Protestant missionaries": "x",
    "Papua New Guinean Protestants": "x",
    "Papua New Guinean radio people": "x",
    "Papua New Guinean radio personalities": "x",
    "Papua New Guinean recipients of British honours": "x",
    "Papua New Guinean recipients of British titles": "x",
    "Papua New Guinean recipients of the British Empire Medal": "x",
    "Papua New Guinean records": "x",
    "Papua New Guinean referees and umpires": "x",
    "Papua New Guinean religious leaders": "x",
    "Papua New Guinean Roman Catholic archbishops": "x",
    "Papua New Guinean Roman Catholic bishops": "x",
    "Papua New Guinean Roman Catholic priests": "x",
    "Papua New Guinean Roman Catholics": "x",
    "Papua New Guinean rugby league administrators": "x",
    "Papua New Guinean rugby league coaches": "x",
    "Papua New Guinean rugby league players": "x",
    "Papua New Guinean rugby league players by province": "x",
    "Papua New Guinean rugby league seasons": "x",
    "Papua New Guinean rugby union players": "x",
    "Papua New Guinean runners": "x",
    "Papua New Guinean sailors (sport)": "x",
    "Papua New Guinean schoolteachers": "x",
    "Papua New Guinean scientists": "x",
    "Papua New Guinean Seventh-day Adventists": "x",
    "Papua New Guinean shot putters": "x",
    "Papua New Guinean singers": "x",
    "Papua New Guinean soccer logos": "x",
    "Papua New Guinean soccer players": "x",
    "Papua New Guinean soccer referees": "x",
    "Papua New Guinean social democrats": "x",
    "Papua New Guinean social workers": "x",
    "Papua New Guinean sport by decade": "x",
    "Papua New Guinean sport by year": "x",
    "Papua New Guinean sport shooters": "x",
    "Papua New Guinean sports coaches": "x",
    "Papua New Guinean sportsmen": "x",
    "Papua New Guinean sportspeople": "x",
    "Papua New Guinean sportspeople by province": "x",
    "Papua New Guinean sportspeople by sport": "x",
    "Papua New Guinean sportsperson-politicians": "x",
    "Papua New Guinean sportswomen": "x",
    "Papua New Guinean sprinters": "x",
    "Papua New Guinean steeplechase runners": "x",
    "Papua New Guinean swimmers": "x",
    "Papua New Guinean taekwondo practitioners": "x",
    "Papua New Guinean television series": "x",
    "Papua New Guinean television series by century": "x",
    "Papua New Guinean television series by decade": "x",
    "Papua New Guinean television shows": "x",
    "Papua New Guinean tennis players": "x",
    "Papua New Guinean theatre people": "x",
    "Papua New Guinean trade unionists": "x",
    "Papua New Guinean triple jumpers": "x",
    "Papua New Guinean Twenty20 International cricket umpires": "x",
    "Papua New Guinean victims of crime": "x",
    "Papua New Guinean weightlifters": "x",
    "Papua New Guinean Wikipedians": "x",
    "Papua New Guinean women": "x",
    "Papua New Guinean women academics": "x",
    "Papua New Guinean women activists": "x",
    "Papua New Guinean women artists": "x",
    "Papua New Guinean women athletes": "x",
    "Papua New Guinean women by occupation": "x",
    "Papua New Guinean women civil servants": "x",
    "Papua New Guinean women cricketers": "x",
    "Papua New Guinean women diplomats": "x",
    "Papua New Guinean women environmentalists": "x",
    "Papua New Guinean women fashion designers": "x",
    "Papua New Guinean women hurdlers": "x",
    "Papua New Guinean women in politics": "x",
    "Papua New Guinean women javelin throwers": "x",
    "Papua New Guinean women lawyers": "x",
    "Papua New Guinean women long-distance runners": "x",
    "Papua New Guinean women middle-distance runners": "x",
    "Papua New Guinean women runners": "x",
    "Papua New Guinean women scientists": "x",
    "Papua New Guinean women shot putters": "x",
    "Papua New Guinean women sprinters": "x",
    "Papua New Guinean women writers": "x",
    "Papua New Guinean women's basketball players": "x",
    "Papua New Guinean women's rights activists": "x",
    "Papua New Guinean women's soccer players": "x",
    "Papua New Guinean writers": "x",
    "People of Papua New Guinean descent": "x",
    "Reggae albums by Papua New Guinean artists": "x",
    "Seasons in Papua New Guinean soccer": "x",
    "Seasons in Papua New Guinean sport": "x",
    "Surnames of Papua New Guinean origin": "x",
    "Works by Papua New Guinean people": "x",
}
to_test = [
    ("test_papua_new_guinean_1", data_1),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
