#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data0 = {}

data_1 = {
    "People from the Spanish Netherlands executed for witchcraft": "أشخاص من هولندا الإسبانية أعدموا بتهمة السحر",
    "French people executed by guillotine during the French Revolution": "فرنسيون أعدموا بالمقصلة خلال الثورة الفرنسية",
    "People executed by Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by the House of Lancaster": "أشخاص أعدموا من قبل الهاوس في لانكستر",
    "People executed by the House of York": "أشخاص أعدموا من قبل الهاوس في يورك",
    "People executed by the International Military Tribunal in Nuremberg": "أشخاص أعدموا من قبل المحكمة العسكرية الدولية في نورنبيرغ",
    "People executed by the Jin dynasty (266–420) by decapitation": "أشخاص أعدموا من قبل أسرة جين (266–420) بقطع الرأس",
    "People executed by the Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by the Kingdom of England by decapitation": "أشخاص أعدموا من قبل مملكة إنجلترا بقطع الرأس",
    "People executed by the Kingdom of England by firearm": "أشخاص أعدموا من قبل مملكة إنجلترا بسلاح ناري",
    "People executed by the Kingdom of England by hanging": "أشخاص أعدموا من قبل مملكة إنجلترا بالشنق",
    "People executed by the Kingdom of Ireland by hanging": "أشخاص أعدموا من قبل مملكة أيرلندا بالشنق",
    "People executed by the Kingdom of Scotland by burning": "أشخاص أعدموا من قبل مملكة إسكتلندا بالحرق",
    "People executed by the Kingdom of Scotland by decapitation": "أشخاص أعدموا من قبل مملكة إسكتلندا بقطع الرأس",
    "People executed by the Kingdom of Scotland by hanging": "أشخاص أعدموا من قبل مملكة إسكتلندا بالشنق",
    "National youth sports teams of the United States": "منتخبات رياضية وطنية شبابية في الولايات المتحدة",
    "Women's national sports teams of the United States": "منتخبات رياضية وطنية نسائية في الولايات المتحدة",
    "Women from Dutch Caribbean": "المرأة من كاريبيون هولنديون",
    "Women from Kingdom of Prussia": "المرأة من مملكة بروسيا",
    "Women from Kingdom of Travancore": "المرأة من مملكة ترافنكور",
    "Women from Overseas France": "المرأة من مقاطعات وأقاليم ما وراء البحار الفرنسية",
    "2010s crimes in Europe by city": "جرائم عقد 2010 في أوروبا حسب المدينة",
    "Jews and Judaism in Kingdom of Jerusalem": "اليهود واليهودية في مملكة بيت المقدس",
    "Works about foreign relations of the United States": "أعمال عن علاقات الولايات المتحدة الخارجية",
    "Books about foreign relations of the United States": "كتب عن علاقات الولايات المتحدة الخارجية",
    "Men's national sports teams of the United States": "منتخبات رياضية وطنية رجالية في الولايات المتحدة",
    "wheelchair basketball players in turkey": "لاعبو كرة سلة على كراسي متحركة في تركيا",
    "field hockey players in germany": "لاعبو هوكي ميدان في ألمانيا",
    "baseball players in florida": "لاعبو كرة قاعدة في فلوريدا",
    "baseball players in south korea": "لاعبو كرة قاعدة في كوريا الجنوبية",
    "basketball players in lebanon": "لاعبو كرة سلة في لبنان",
    "sport in khartoum": "الرياضة في الخرطوم",
    "sport in ottoman empire": "الرياضة في الدولة العثمانية",
    "sport in tuzla": "الرياضة في توزلا",
    "sport in veria": "الرياضة في فيريا",
    "sport in álava": "الرياضة في ألافا (مقاطعة)",
    "Defunct political parties of Islamic Republic of Iran": "أحزاب سياسية سابقة في الجمهورية الإسلامية الإيرانية",
    "People executed by hanging by country": "أشخاص أعدموا حرقاً حسب البلد",
    "Cultural depictions of sportspeople": "تصوير ثقافي عن رياضيون",
    "Scheduled sports events": "أحداث رياضية مقررة",
    "ivorian people": "إيفواريون",
    "japanese lgbtq people": "أعلام إل جي بي تي كيو يابانيون",
    "chinese lgbtq people": "أعلام إل جي بي تي كيو صينيون",
    "arab lgbtq people": "أعلام إل جي بي تي كيو عرب",
    "rwandan political people": "ساسة روانديون",
    "maldivian people": "مالديفيون",
    "malian people": "ماليون",
    "maltese lgbtq people": "أعلام إل جي بي تي كيو مالطيون",
    "namibia–russia relations": "العلاقات الروسية الناميبية",
    "morocco–netherlands relations": "العلاقات المغربية الهولندية",
    "morocco–pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco–qatar relations": "العلاقات القطرية المغربية",
    "morocco–russia relations": "العلاقات الروسية المغربية",
    "morocco–united kingdom relations": "العلاقات البريطانية المغربية",
    "mongolia–russia relations": "العلاقات الروسية المنغولية",
    "mauritania–morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania–russia relations": "العلاقات الروسية الموريتانية",
    "south korea–united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "somalia–turkey relations": "العلاقات التركية الصومالية",
    "russia–sudan relations": "العلاقات الروسية السودانية",
    "russia–tunisia relations": "العلاقات التونسية الروسية",
    "russia–united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia–uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "philippine–american war": "الحرب الأمريكية الفلبينية",
    "philippines–saudi arabia relations": "العلاقات السعودية الفلبينية",
    "palestine national basketball team": "منتخب فلسطين لكرة السلة",
    "russia men's national ice hockey team": "منتخب روسيا لهوكي الجليد للرجال",
    "palestine–united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine–united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine–uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "african championships in athletics": "بطولات إفريقية في ألعاب القوى",
    "automotive industry in italy": "صناعة سيارات في إيطاليا",
    "bahrain in the asian para games": "البحرين في الألعاب البارالمبية الآسيوية",
    "field hockey in the 2004 summer olympics": "هوكي الميدان في الألعاب الأولمبية الصيفية 2004",
    "gymnastics in the 2004 summer olympics": "الجمباز في الألعاب الأولمبية الصيفية 2004",
    "history of the petroleum industry in canada": "تاريخ صناعة بترولية في كندا",
    "internet in bahrain": "إنترنت في البحرين",
    "islam in bermuda": "الإسلام في برمودا",
    "kingdom of hungary in the middle ages": "مملكة المجر في العصور الوسطى",
    "kurds in syria": "الأكراد في سوريا",
    "kurds in turkey": "الأكراد في تركيا",
    "protestantism in morocco": "البروتستانتية في المغرب",
    "protestantism in yemen": "البروتستانتية في اليمن",
    "same-sex marriage in the netherlands": "زواج مثلي في هولندا",
    "shia islam in afghanistan": "الشيعة في أفغانستان",
    "shooting in the 2004 summer olympics": "الرماية في الألعاب الأولمبية الصيفية 2004",
    "silver mining in the united states": "التنقيب عن الفضة في الولايات المتحدة",
    "swimming in the 2004 summer olympics": "السباحة في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming in the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "taekwondo in the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "time in azerbaijan": "الزمن في أذربيجان",
    "time in cyprus": "الزمن في قبرص",
    "triathlon in the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "women in niue": "المرأة في نييوي",
    "women in pala": "المرأة في بالاو",
    "women in the cook islands": "المرأة في جزر كوك",
    "women in the federated states of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "women in the federated states-of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "wrestling in the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "wrestling in the 2016 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2016",
    "saudi arabia–ukraine relations": "العلاقات الأوكرانية السعودية",
    "china–sudan relations": "العلاقات السودانية الصينية",
    "china-sudan relations": "العلاقات السودانية الصينية",
    "saudi arabia-ukraine relations": "العلاقات الأوكرانية السعودية",
    "mauritania-morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania-russia relations": "العلاقات الروسية الموريتانية",
    "mongolia-russia relations": "العلاقات الروسية المنغولية",
    "morocco-netherlands relations": "العلاقات المغربية الهولندية",
    "morocco-pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco-qatar relations": "العلاقات القطرية المغربية",
    "morocco-russia relations": "العلاقات الروسية المغربية",
    "morocco-united kingdom relations": "العلاقات البريطانية المغربية",
    "namibia-russia relations": "العلاقات الروسية الناميبية",
    "palestine-united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine-united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine-uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "philippines-saudi arabia relations": "العلاقات السعودية الفلبينية",
    "russia-sudan relations": "العلاقات الروسية السودانية",
    "russia-tunisia relations": "العلاقات التونسية الروسية",
    "russia-united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia-uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "somalia-turkey relations": "العلاقات التركية الصومالية",
    "south korea-united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "lists of populated places in the united states": "قوائم أماكن مأهولة في الولايات المتحدة",
    "populated places in the british virgin islands": "أماكن مأهولة في جزر العذراء البريطانية",
    "soccer in australia": "كرة القدم في أستراليا",
    "soccer in the united states": "كرة القدم في الولايات المتحدة",
    "football in spain": "كرة القدم في إسبانيا",
    "water polo in the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "populated places in tokelau": "أماكن مأهولة في توكيلاو",
    "townships in michigan": "ضواحي مدن في ميشيغان",
    "populated places in christmas island": "أماكن مأهولة في جزيرة عيد الميلاد",
    "cities and towns in india": "مدن وبلدات في الهند",
    "neighbourhoods in rio de janeiro (city)": "أحياء في ريو دي جانيرو",
    "populated places in the cocos (keeling) islands": "أماكن مأهولة في جزر كوكوس",
    "populated places in puebla": "أماكن مأهولة في ولاية بويبلا",
    "populated places in the cook islands": "أماكن مأهولة في جزر كوك",
    "populated places in norfolk island": "أماكن مأهولة في جزيرة نورفولك",
    "cities and towns in moscow oblast": "مدن وبلدات في محافظة موسكو",
    "wheelchair basketball world championship": "بطولة العالم لكرة السلة على الكراسي المتحركة",
    "water polo at the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "portugal national rugby league team": "منتخب البرتغال لدوري الرجبي",
    "new zealand women's national ice hockey team": "منتخب نيوزيلندا لهوكي الجليد للسيدات",
    "new zealand women's national rugby league team": "منتخب نيوزيلندا لدوري الرجبي للسيدات",
    "kazakhstan women's national ice hockey team": "منتخب كازاخستان لهوكي الجليد للسيدات",
    "georgia national rugby union team": "منتخب جورجيا لاتحاد الرجبي",
    "england women's national rugby league team": "منتخب إنجلترا لدوري الرجبي للسيدات",
    "chile national rugby union team": "منتخب تشيلي لاتحاد الرجبي",
    "australia national rugby union team": "منتخب أستراليا لاتحاد الرجبي",
    "algeria national rugby union team": "منتخب الجزائر لاتحاد الرجبي",
    "united states national rugby union team": "منتخب الولايات المتحدة لاتحاد الرجبي",
    "greece national rugby league team": "منتخب اليونان لدوري الرجبي",
    "archery at the 2004 summer olympics": "النبالة في الألعاب الأولمبية الصيفية 2004",
    "wrestling at the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "triathlon at the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming at the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "united states national futsal team": "منتخب الولايات المتحدة لكرة الصالات",
    "thailand women's national basketball team": "منتخب تايلاند لكرة السلة للسيدات",
    "sweden national bandy team": "منتخب السويد للباندي",
    "slovenia women's national football team": "منتخب سلوفينيا لكرة القدم للسيدات",
    "papua new guinea women's national football team": "منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "netherlands men's national basketball team": "منتخب هولندا لكرة السلة للرجال",
    "taekwondo at the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "namibia women's national football team": "منتخب ناميبيا لكرة القدم للسيدات",
    "myanmar women's national football team": "منتخب ميانمار لكرة القدم للسيدات",
    "montenegro women's national football team": "منتخب الجبل الأسود لكرة القدم للسيدات",
    "moldova national rugby league team": "منتخب مولدوفا لدوري الرجبي",
    "moldova women's national football team": "منتخب مولدوفا لكرة القدم للسيدات",
    "philippine football federation": "الاتحاد الفلبيني لكرة القدم",
    "iraq national football team results": "نتائج منتخب العراق لكرة القدم",
    "austria women's national football team": "منتخب النمسا لكرة القدم للسيدات",
    "algeria women's national football team": "منتخب الجزائر لكرة القدم للسيدات",
    "thailand women's national football team": "منتخب تايلاند لكرة القدم للسيدات",
    "switzerland women's national football team": "منتخب سويسرا لكرة القدم للسيدات",
    "portugal women's national football team": "منتخب البرتغال لكرة القدم للسيدات",
    "vietnam national basketball team": "منتخب فيتنام لكرة السلة",
    "uruguay national football team": "منتخب أوروغواي لكرة القدم",
    "bolivia national soccer team": "منتخب بوليفيا لكرة القدم",
}

data_2 = {
    "Austrian Giro d'Italia stage winners": "فائزون في مراحل طواف إيطاليا نمساويون",
    "Azerbaijani men marathon runners": "عداؤو ماراثون أذربيجانيون",
    "Brazilian men sprinters": "عداؤون سريعون برازيليون",
    "Burmese men long-distance runners": "عداؤو مسافات طويلة بورميون",
    "Estonian men long-distance runners": "عداؤو مسافات طويلة إستونيون",
    "Gibraltarian men athletes": "لاعبو قوى جبل طارقيون",
    "Nazis executed by the British military": "نازيون أعدموا من قبل الجيش البريطاني",
    "People executed by the British military": "أشخاص أعدموا من قبل الجيش البريطاني",
    "People executed by the French military": "أشخاص أعدموا من قبل الجيش الفرنسي",
    "women in danish military": "المرأة في الجيش الدنماركي",
    "brazilian women's rights activists": "برازيليون ناشطون في حقوق المرأة",
    "burmese men marathon runners": "عداؤو ماراثون بورميون",
    "canadian men": "رجال كنديون",
    "Men's basketball players from Northern Ireland": "لاعبو كرة سلة من أيرلندا الشمالية",
    "Men's footballers in Papua New Guinea": "لاعبو كرة قدم في بابوا غينيا الجديدة",
    "men's footballers in togo": "لاعبو كرة قدم في توغو",
    "puerto rican men high jumpers": "متسابقو قفز عالي بورتوريكيون",
    "turkish women's rights activists": "أتراك ناشطون في حقوق المرأة",
    "Chilean men shot putters": "لاعبو دفع ثقل تشيليون",
    "Somalian men sprinters": "عداؤون سريعون صوماليون",
    "Sculptures of men in England": "منحوتات في رجال في إنجلترا",
    "Sculptures of men in London": "منحوتات في رجال في لندن",
    "Algerian men middle-distance runners": "عداؤو مسافات متوسطة جزائريون",
    "Guatemalan men middle-distance runners": "عداؤو مسافات متوسطة غواتيماليون",
    "Haitian men athletes": "لاعبو قوى هايتيون",
    "Iranian men athletes": "لاعبو قوى إيرانيون",
    "Iraqi men middle-distance runners": "عداؤو مسافات متوسطة عراقيون",
    "Kyrgyzstani men marathon runners": "عداؤو ماراثون قيرغيزستانيون",
    "Liechtenstein men sprinters": "عداؤون سريعون ليختنشتانيون",
    "Macedonian men sprinters": "عداؤون سريعون مقدونيون",
    "Men discus throwers": "رماة قرص",
    "Men's footballers in Mongolia": "لاعبو كرة قدم في منغوليا",
    "Nicaraguan men high jumpers": "متسابقو قفز عالي نيكاراغويون",
    "Russian men pole vaulters": "قافزون بالزانة روس",
    "Taiwanese men long jumpers": "لاعبو قفز طويل تايوانيون",
    "Trinidad and Tobago men discus throwers": "رماة قرص ترنيداديون",
    "Abolitionists from Wisconsin": "مناهضون للعبودية من ويسكونسن",
    "Albanian women's rights activists": "ألبان ناشطون في حقوق المرأة",
    "Botswana women's rights activists": "بوتسوانيون ناشطون في حقوق المرأة",
    "Venezuelan women's rights activists": "فنزويليون ناشطون في حقوق المرأة",
}

data_3 = {
    "africanamerican–jewish relations": "العلاقات الأمريكية الإفريقية اليهودية",
    "african–native american relations": "العلاقات الأمريكية الأصلية الإفريقية",
    "arab–american relations": "العلاقات الأمريكية العربية",
    "native american–jewish relations": "العلاقات الأمريكية الأصلية اليهودية",
    "roman–iranian relations": "العلاقات الإيرانية الرومانية",
    "1009 works": "أعمال 1009",
    "1013 works": "أعمال 1013",
    "10th-century BC architecture": "عمارة القرن 10 ق م",
    "1239 works": "أعمال 1239",
    "1261 works": "أعمال 1261",
    "1265 works": "أعمال 1265",
    "12th iranian majlis": "المجلس الإيراني الثاني عشر",
    "1370s conflicts": "نزاعات في عقد 1370",
    "13th iranian majlis": "المجلس الإيراني الثالث عشر",
    "13th-century plays": "مسرحيات القرن 13",
    "1429 in law": "القانون في 1429",
    "1483 works": "أعمال 1483",
    "1562 works": "أعمال 1562",
    "15th iranian majlis": "المجلس الإيراني الخامس عشر",
    "1630s natural disasters": "كوارث طبيعية في عقد 1630",
    "1701 in international relations": "علاقات دولية في 1701",
    "1708 in law": "القانون في 1708",
    "1727 in law": "القانون في 1727",
    "1737 in music": "موسيقى في 1737",
    "1752 works": "أعمال 1752",
    "1793 elections": "انتخابات 1793",
    "1795 in mass media": "وسائل إعلام في 1795",
    "17th-century Dutch books": "كتب هولندية في القرن 17",
    "17th-century plays": "مسرحيات القرن 17",
    "1817 treaties": "معاهدات في 1817",
    "1826 murders by continent": "جرائم قتل في 1826 حسب القارة",
    "1830s documents": "وثائق في عقد 1830",
    "1832 works": "أعمال 1832",
    "1833 in mass media": "وسائل إعلام في 1833",
    "1835 meteorology": "الأرصاد الجوية في 1835",
    "1842 in mass media": "وسائل إعلام في 1842",
    "1854 in law": "القانون في 1854",
    "1855 disasters by country": "كوارث في 1855 حسب البلد",
    "1866 asian winter games": "الألعاب الآسيوية الشتوية 1866",
    "1866 european games": "الألعاب الأوروبية 1866",
    "1866 indian general election": "الانتخابات العامة الهندية 1866",
    "1866 pan american games": "دورة الألعاب الأمريكية 1866",
    "1866 parapan american games": "ألعاب بارابان الأمريكية 1866",
    "1866 presidential candidates": "مرشحون رئاسيون في 1866",
    "1866 sea games": "ألعاب البحر 1866",
    "1866 summer olympics": "الألعاب الأولمبية الصيفية 1866",
    "1866 summer paralympics": "الألعاب البارالمبية الصيفية 1866",
    "1866 united states elections": "انتخابات الولايات المتحدة في 1866",
    "1866 united states": "الولايات المتحدة في 1866",
    "1867 in mass media": "وسائل إعلام في 1867",
    "18th-century attacks on Jewish institutions": "هجمات القرن 18 في مؤسسات يهودية",
    "1902 in music by country": "موسيقى في 1902 حسب البلد",
    "1904 murders by country": "جرائم قتل في 1904 حسب البلد",
    "1909 murders by country": "جرائم قتل في 1909 حسب البلد",
    "1910 in international relations": "علاقات دولية في 1910",
    "1917 in music": "موسيقى في 1917",
    "1934 murders": "جرائم قتل في 1934",
    "1948 in law": "القانون في 1948",
    "1948 treaties": "معاهدات في 1948",
    "1965 in music by country": "موسيقى في 1965 حسب البلد",
    "1970s elections": "انتخابات عقد 1970",
    "1971–72 in Northern Ireland association football": "كرة القدم الأيرلندية الشمالية في 1971–72",
    "1972 murders": "جرائم قتل في 1972",
    "1990 in international relations": "علاقات دولية في 1990",
    "1990s television series debuts": "مسلسلات تلفزيونية بدأ عرضها في عقد 1990",
    "1999 disasters by country": "كوارث في 1999 حسب البلد",
    "19th-century books": "كتب القرن 19",
    "1st-century architecture": "عمارة القرن 1",
    "1st-millennium architecture": "عمارة الألفية 1",
    "2021 meteorology": "الأرصاد الجوية في 2021",
    "2024 disasters by country": "كوارث في 2024 حسب البلد",
    "2025–26 in Northern Ireland association football": "كرة القدم الأيرلندية الشمالية في 2025–26",
    "2026 elections by country": "انتخابات 2026 حسب البلد",
    "2026 in music by country": "موسيقى في 2026 حسب البلد",
    "2026 television series debuts": "مسلسلات تلفزيونية بدأ عرضها في 2026",
    "20th-century Anglican archbishops in Ireland": "رؤساء أساقفة أنجليكيون في القرن 20 في أيرلندا",
    "20th-century Anglican archbishops in New Zealand": "رؤساء أساقفة أنجليكيون في القرن 20 في نيوزيلندا",
    "20th-century attacks on Jewish institutions in United States": "هجمات القرن 20 على مؤسسات يهودية في الولايات المتحدة",
    "20th-century attacks on Jewish institutions": "هجمات القرن 20 في مؤسسات يهودية",
    "20th-century executions by Papua New Guinea": "إعدامات في القرن 20 في بابوا غينيا الجديدة",
    "21st-century Anglican archbishops in New Zealand": "رؤساء أساقفة أنجليكيون في القرن 21 في نيوزيلندا",
    "21st-century attacks on Jewish institutions in United States": "هجمات القرن 21 على مؤسسات يهودية في الولايات المتحدة",
    "21st-century attacks on Jewish institutions": "هجمات القرن 21 في مؤسسات يهودية",
    "3rd-century paintings": "لوحات القرن 3",
    "3rd-millennium works": "أعمال الألفية 3",
    "60s conflicts": "نزاعات في عقد 60",
    "April 1959 in sports": "ألعاب رياضية في أبريل 1959",
    "April 2026 in sports": "ألعاب رياضية في أبريل 2026",
    "Attacks on Jewish institutions by century": "هجمات على مؤسسات يهودية حسب القرن",
    "Attacks on Jewish institutions in Poland": "هجمات على مؤسسات يهودية في بولندا",
    "Attacks on Jewish institutions in United States": "هجمات على مؤسسات يهودية في الولايات المتحدة",
    "Attacks on Jewish institutions": "هجمات على مؤسسات يهودية",
    "August 2026 in sports": "ألعاب رياضية في أغسطس 2026",
    "Bishops of Ripon and Leeds": "أساقفة من ريبون (شمال يوركشير) وليدز",
    "british columbia (1866–1866)": "كولومبيا البريطانية (1866–1866)",
    "COVID-19 pandemic in Papua New Guinea templates": "قوالب جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Deaths by airstrike during the Syrian civil war": "وفيات بضربات جوية خلال الحرب الأهلية السورية",
    "Deaths by airstrike during World War II": "وفيات بضربات جوية خلال الحرب العالمية الثانية",
    "Deaths by airstrike": "وفيات بضربات جوية",
    "December 2007 in sports": "ألعاب رياضية في ديسمبر 2007",
    "democratic-republic-of-congo–republic-of ireland relations": "العلاقات الأيرلندية الكونغوية الديمقراطية",
    "Educational institutions established in 2009": "هيئات تعليمية أسست في 2009",
    "February 2026 in sports": "ألعاب رياضية في فبراير 2026",
    "Fiction set in 1716": "أعمال خيالية في 1716",
    "Fiction set in 1790s": "أعمال خيالية في عقد 1790",
    "Fiction set in 1819": "أعمال خيالية في 1819",
    "Fiction set in 27th century": "أعمال خيالية في القرن 27",
    "Healthcare by city of the United States": "الرعاية الصحية حسب المدينة في الولايات المتحدة",
    "January 1901 in sports": "ألعاب رياضية في يناير 1901",
    "January 1952 in sports": "ألعاب رياضية في يناير 1952",
    "January 2026 in sports": "ألعاب رياضية في يناير 2026",
    "July 2026 in sports": "ألعاب رياضية في يوليو 2026",
    "June 1956 in sports": "ألعاب رياضية في يونيو 1956",
    "June 2026 in sports": "ألعاب رياضية في يونيو 2026",
    "Lists of organisations based in Papua New Guinea": "قوائم منظمات مقرها في بابوا غينيا الجديدة",
    "Lists of people executed in the United States by year": "قوائم أشخاص أعدموا في الولايات المتحدة حسب السنة",
    "Lists of people executed in United States by year": "قوائم أشخاص أعدموا في الولايات المتحدة حسب السنة",
    "March 2026 in sports": "ألعاب رياضية في مارس 2026",
    "May 1946 in sports": "ألعاب رياضية في مايو 1946",
    "May 1993 in sports": "ألعاب رياضية في مايو 1993",
    "May 2026 in sports": "ألعاب رياضية في مايو 2026",
    "muslim people templates": "قوالب مسلمون",
    "northern-ireland football cups": "كؤوس كرة القدم الأيرلندية الشمالية",
    "November 2026 in sports": "ألعاب رياضية في نوفمبر 2026",
    "October 1922 in sports": "ألعاب رياضية في أكتوبر 1922",
    "People executed in British North America by hanging": "أشخاص أعدموا في أمريكا الشمالية البريطانية حسب بالشنق",
    "People executed in the Holy Roman Empire by burning": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة حسب بالحرق",
    "People executed in the Holy Roman Empire by decapitation": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة حسب بقطع الرأس",
    "republic of ireland women's national football team": "منتخب جمهورية أيرلندا لكرة القدم للسيدات",
    "republic-of ireland–united kingdom border crossings": "معابر الحدود الأيرلندية البريطانية",
    "republic-of ireland–united kingdom border": "الحدود الأيرلندية البريطانية",
    "second polish republic (1866–1866)": "الجمهورية البولندية الثانية (1866–1866)",
    "September 2024 in sports": "ألعاب رياضية في سبتمبر 2024",
    "September 2026 in sports": "ألعاب رياضية في سبتمبر 2026",
    "south korean presidential election 2017": "انتخابات الرئاسة الكورية الجنوبية 2017",
    "Transport companies established in 1946": "شركات نقل أسست في 1946",
    "Transport infrastructure completed in 1916": "بنية تحتية للنقل اكتملت في 1916",
    "Transport infrastructure completed in 1972": "بنية تحتية للنقل اكتملت في 1972",
    "Transport infrastructure completed in 21st century": "بنية تحتية للنقل اكتملت في القرن 21",
    "uefa euro 1866": "بطولة أمم أوروبا 1866",
    "united kingdom (1866–1866)": "المملكة المتحدة (1866–1866)",
    "war in iraq (1866–1866)": "الحرب في العراق (1866–1866)",
}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("test_1", data_1),
    ("test_2", data_2),
    ("test_3", data_3),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
