"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import resolve_sport_label_unified
from utils.dump_runner import make_dump_test_name_data_callback

test_data_1 = {
    "australian rules football owners and executives": "رؤساء تنفيذيون وملاك كرة قدم أسترالية",
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "canoeing logos": "شعارات ركوب الكنو",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "figure skating media": "إعلام تزلج فني",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "go comics": "قصص مصورة غو",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby union stadiums": "ملاعب اتحاد رجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "tennis logos": "شعارات كرة مضرب",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "wheelchair basketball terminology": "مصطلحات كرة سلة على كراسي متحركة",
}

data_2 = {
    "australian rules football owners and executives": "رؤساء تنفيذيون وملاك كرة قدم أسترالية",
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "canoeing logos": "شعارات ركوب الكنو",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "figure skating media": "إعلام تزلج فني",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "go comics": "قصص مصورة غو",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby union stadiums": "ملاعب اتحاد رجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "tennis logos": "شعارات كرة مضرب",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "wheelchair basketball terminology": "مصطلحات كرة سلة على كراسي متحركة",
    "shooting sports racing organizations": "منظمات سباق رماية",
    "roller hockey (quad) comics": "قصص مصورة هوكي دحرجة",
    "handball racing leagues": "دوريات سباق كرة يد",
    "cross country fan clubs": "أندية معجبي عدو ريفي",
    "track and field video games": "ألعاب فيديو سباقات مضمار وميدان",
    "football racing variants": "أشكال سباق كرة قدم",
    "hurling lists": "قوائم قذف",
    "triple jump racing leagues seasons": "مواسم دوريات سباق قفز ثلاثي",
    "boules songs": "أغاني بوتشي",
    "submission wrestling racing managers": "مدربو سباق مصارعة خضوع",
    "football equipment": "معدات كرة قدم",
    "auto racing bodies": "هيئات سباق سيارات",
    "track and field tactics and skills": "مهارات سباقات مضمار وميدان",
    "soft tennis racing logos": "شعارات سباق كرة مضرب لينة",
    "canadian football racing owners": "ملاك سباق كرة قدم كندية",
    "mixed martial arts racing referees": "حكام سباق فنون قتال مختلطة",
    "baseball racing tactics and skills": "مهارات سباق كرة قاعدة",
    "mountain bike racing films": "أفلام سباق الدراجات الجبلية",
    "sepak takraw manager history": "تاريخ مدربو سيباك تاكرو",
    "sledge hockey manager history": "تاريخ مدربو هوكي مزلجة",
    "snooker racing owners": "ملاك سباق سنوكر",
    "kurash racing commissioners": "مفوضو سباق كوراش",
    "motorcycle racing people": "أعلام سباق دراجات نارية",
    "table tennis racing television series": "مسلسلات تلفزيونية سباق كرة طاولة",
    "go racing managers": "مدربو سباق غو",
    "aquatics racing umpires": "حكام سباق رياضات مائية",
    "pole vault players": "لاعبو قفز بالزانة",
    "archery seasons": "مواسم نبالة",
    "track-and-field athletics racing clubs and teams": "أندية وفرق سباق ألعاب قوى مضمار وميدان",
    "canadian-football commentators": "معلقو كرة قدم كندية",
    "modern pentathlon racing people": "أعلام سباق خماسي حديث",
    "rugby league racing logos": "شعارات سباق دوري رجبي",
    "equestrian racing organizations": "منظمات سباق فروسية",
    "running referees": "حكام ركض",
    "lawn bowls tactics and skills": "مهارات بولينغ عشبي",
    "formula e racing non-playing staff": "طاقم سباق فورمولا إي غير اللاعبين",
    "pentathlon television series": "مسلسلات تلفزيونية خماسي",
    "shooting sport racing variants": "أشكال سباق رماية",
    "boccia racing coaches": "مدربو سباق بوتشيا",
    "single skating owners and executives": "رؤساء تنفيذيون وملاك تزلج فردي على الجليد",
    "javelin throw racing championships": "بطولات سباق رمي رمح",
    "rowing racing people": "أعلام سباق تجديف",
    "snowboarding racing referees": "حكام سباق تزلج على الثلوج",
    "long-distance running racing media": "إعلام سباق ركض مسافات طويلة",
    "wheelchair fencing fan clubs": "أندية معجبي مبارزة سيف شيش على كراسي متحركة",
    "bowls logos": "شعارات بولينج",
    "javelin throw video games": "ألعاب فيديو رمي رمح",
    "middle-distance running clubs and teams": "أندية وفرق ركض مسافات متوسطة",
    "shot put results": "نتائج دفع ثقل",
    "skating non-profit organizations": "منظمات غير ربحية تزلج",
    "cycle manager": "مدربو دراجات",
    "skateboarding owners": "ملاك تزلج على اللوح",
    "track and field bodies": "هيئات سباقات مضمار وميدان",
    "orienteering players": "لاعبو سباق موجه",
    "alpine skiing racing players": "لاعبو سباق تزلج على المنحدرات الثلجية",
    "greco-roman wrestling racing music": "موسيقى سباق مصارعة يونانية رومانية",
    "motocross tactics and skills": "مهارات موتو كروس",
    "pencak silat television series": "مسلسلات تلفزيونية بنكات سيلات",
    "ski jumping racing films": "أفلام سباق قفز تزلجي",
    "darts racing equipment": "معدات سباق سهام مريشة",
    "high school racing personnel": "أفراد سباق مدارس ثانوية",
    "nordic combined lists": "قوائم تزلج نوردي مزدوج",
    "formula racing comics": "قصص مصورة سباقات فورمولا",
    "artistic gymnastics television series": "مسلسلات تلفزيونية جمباز فني",
    "windsurfing racing non-profit organizations": "منظمات غير ربحية سباق ركوب قوارب شراعية",
    "hockey racing equipment": "معدات سباق هوكي",
    "bouldering variants": "أشكال بولدرنق",
    "roller skating players": "لاعبو تزلج بالعجلات",
    "cricket racing video games": "ألعاب فيديو سباق كريكت",
    "shot put racing bodies": "هيئات سباق دفع ثقل",
    "synchronized swimming personnel": "أفراد سباحة متزامنة",
    "cycle racing non-playing staff": "طاقم سباق دراجات غير اللاعبين",
    "aerobics racing manager": "مدربو سباق جمباز أيروبيكس",
    "motorcycle players": "لاعبو دراجات نارية",
    "canadian-football players": "لاعبو كرة قدم كندية",
    "muay thai championships": "بطولات موياي تاي",
    "wheelchair curling logos": "شعارات كيرلنغ على كراسي متحركة",
    "rugby football racing commentators": "معلقو سباق كرة قدم رجبي",
    "road bicycle racing comics": "قصص مصورة سباق دراجات على الطريق",
    "formula one culture": "ثقافة فورمولا ون",
    "skiing logos": "شعارات تزلج",
    "diving racing music": "موسيقى سباق غطس",
    "modern pentathlon racing world competitions": "منافسات سباق خماسي حديث عالمية",
    "bowls executives": "مدراء بولينج",
    "climbing racing terminology": "مصطلحات سباق تسلق",
    "road bicycle racing video games": "ألعاب فيديو سباق دراجات على الطريق",
    "association football racing trainers": "مدربو سباق كرة قدم",
    "pole vault racing logos": "شعارات سباق قفز بالزانة",
    "acrobatic gymnastics racing songs": "أغاني سباق جمباز اكروباتيكي",
    "baseball variants": "أشكال كرة قاعدة",
    "underwater hockey racing referees": "حكام سباق هوكي تحت الماء",
    "cycle racing players": "لاعبو سباق دراجات",
    "motorboat racing organizations": "منظمات سباق زوارق نارية",
    "beach volleyball lists": "قوائم كرة طائرة شاطئية",
    "floorball manager history": "تاريخ مدربو كرة أرض",
    "sumo racing trainers": "مدربو سباق سومو",
    "cricket racing non-profit publishers": "ناشرون غير ربحيون سباق كريكت",
    "boxing media": "إعلام بوكسينغ",
    "biathlon racing non-profit publishers": "ناشرون غير ربحيون سباق بياثلون",
    "beach soccer racing owners and executives": "رؤساء تنفيذيون وملاك سباق كرة قدم شاطئية",
    "ju-jitsu racing manager": "مدربو سباق جوجوتسو",
    "tennis racing footballers": "لاعبو سباق كرة مضرب",
    "track-and-field athletics racing players": "لاعبو سباق ألعاب قوى مضمار وميدان",
    "canoeing racing coaches": "مدربو سباق ركوب الكنو",
    "jujutsu racing music": "موسيقى سباق جوجوتسو",
    "cross country running films": "أفلام عدو ريفي",
    "snowboarding commissioners": "مفوضو تزلج على الثلوج",
    "short track speed skating coaches": "مدربو تزلج على مسار قصير",
    "martial arts racing culture": "ثقافة سباق فنون قتالية",
    "sumo songs": "أغاني سومو",
    "racquetball racing governing bodies": "هيئات تنظيم سباق كرة الراح",
    "equestrianism racing songs": "أغاني سباق فروسية",
    "futsal clubs and teams": "أندية وفرق كرة صالات",
    "go racing executives": "مدراء سباق غو",
    "ju-jitsu racing equipment": "معدات سباق جوجوتسو",
    "cue sports racing teams": "فرق سباق بلياردو",
    "roller skating racing world competitions": "منافسات سباق تزلج بالعجلات عالمية",
    "aerobics logos": "شعارات جمباز أيروبيكس",
    "lawn bowls racing governing bodies": "هيئات تنظيم سباق بولينغ عشبي",
    "high school executives": "مدراء مدارس ثانوية",
    "wheelchair handball results": "نتائج كرة يد على كراسي متحركة",
    "weightlifting clubs and teams": "أندية وفرق رفع أثقال",
    "running logos": "شعارات ركض",
    "pencak silat matches": "مباريات بنكات سيلات",
    "volleyball racing matches": "مباريات سباق كرة طائرة",
    "sumo people": "أعلام سومو",
    "skateboarding records and statistics": "سجلات وإحصائيات تزلج على اللوح",
    "cricket racing umpires": "حكام سباق كريكت",
    "track-and-field athletics manager history": "تاريخ مدربو ألعاب قوى مضمار وميدان",
    "racquetball players": "لاعبو كرة الراح",
    "rally racing rivalries": "دربيات سباق رالي",
    "croquet racing tactics and skills": "مهارات سباق كروكيت",
    "climbing racing personnel": "أفراد سباق تسلق",
    "boules racing results": "نتائج سباق بوتشي",
    "freestyle skiing racing people": "أعلام سباق تزلج حر",
    "curling world competitions": "منافسات كيرلنغ عالمية",
    "synchronized swimming racing players": "لاعبو سباق سباحة متزامنة",
    "skateboarding racing variants": "أشكال سباق تزلج على اللوح",
    "biathlon culture": "ثقافة بياثلون",
    "wrestling racing equipment": "معدات سباق مصارعة",
    "roller skating lists": "قوائم تزلج بالعجلات",
    "wrestling racing awards": "جوائز سباق مصارعة",
    "gaelic football stadiums": "ملاعب كرة قدم غالية",
    "floorball racing comics": "قصص مصورة سباق كرة أرض",
    "roller hockey (quad) world competitions": "منافسات هوكي دحرجة عالمية",
    "long-distance running racing broadcasters": "مذيعو سباق ركض مسافات طويلة",
    "roller hockey media": "إعلام هوكي دحرجة",
    "silat bodies": "هيئات سيلات",
    "hockey commentators": "معلقو هوكي",
    "dressage seasons": "مواسم ترويض خيول",
    "rugby union lists": "قوائم اتحاد رجبي",
    "alpine skiing records and statistics": "سجلات وإحصائيات تزلج على المنحدرات الثلجية",
    "pole vault music": "موسيقى قفز بالزانة",
    "skating people": "أعلام تزلج",
    "weightlifting variants": "أشكال رفع أثقال",
    "hurling records and statistics": "سجلات وإحصائيات قذف",
    "wheelchair handball clubs and teams": "أندية وفرق كرة يد على كراسي متحركة",
    "ski jumping managers": "مدربو قفز تزلجي",
    "rugbyunion results": "نتائج اتحاد رجبي",
    "triple jump racing commentators": "معلقو سباق قفز ثلاثي",
    "kabaddi footballers": "لاعبو كابادي",
    "bobsleigh fan clubs": "أندية معجبي زلاجة جماعية",
    "triathlon manager history": "تاريخ مدربو سباق ثلاثي",
    "triple jump broadcasters": "مذيعو قفز ثلاثي",
    "floorball records and statistics": "سجلات وإحصائيات كرة أرض",
    "muay thai racing governing bodies": "هيئات تنظيم سباق موياي تاي",
    "beach soccer competitions": "منافسات كرة قدم شاطئية",
    "sprinting racing comics": "قصص مصورة سباق جري سريع",
    "skateboarding governing bodies": "هيئات تنظيم تزلج على اللوح",
    "muay thai seasons": "مواسم موياي تاي",
    "kick boxing comics": "قصص مصورة كيك بوكسينغ",
    "tennis racing variants": "أشكال سباق كرة مضرب",
    "kurash organizations": "منظمات كوراش",
    "rugby league racing films": "أفلام سباق دوري رجبي",
    "netball music": "موسيقى كرة شبكة",
    "rugby sevens clubs": "أندية سباعيات رجبي",
    "futsal racing players": "لاعبو سباق كرة صالات",
    "biathlon films": "أفلام بياثلون",
    "sledge hockey video games": "ألعاب فيديو هوكي مزلجة",
    "esports fan clubs": "أندية معجبي رياضة إلكترونية",
    "basketball results": "نتائج كرة سلة",
    "long jump racing fan clubs": "أندية معجبي سباق قفز طويل",
    "kabaddi racing organizations": "منظمات سباق كابادي",
    "artistic swimming racing non-profit publishers": "ناشرون غير ربحيون سباق سباحة فنية",
    "sledge hockey racing non-playing staff": "طاقم سباق هوكي مزلجة غير اللاعبين",
    "ice hockey leagues seasons": "مواسم دوريات هوكي جليد",
    "sports managers": "مدربو رياضية",
    "silat racing seasons": "مواسم سباق سيلات",
    "badminton non-profit organizations": "منظمات غير ربحية تنس ريشة",
    "basque pelota racing media": "إعلام سباق كرة باسك",
    "motocross racing owners": "ملاك سباق موتو كروس",
    "jujutsu racing organizations": "منظمات سباق جوجوتسو",
    "climbing governing bodies": "هيئات تنظيم تسلق",
    "mixed martial arts personnel": "أفراد فنون قتال مختلطة",
    "roller hockey (quad) racing variants": "أشكال سباق هوكي دحرجة",
    "cricket comics": "قصص مصورة كريكت",
    "shooting sports tactics and skills": "مهارات رماية",
    "acrobatic gymnastics racing non-profit publishers": "ناشرون غير ربحيون سباق جمباز اكروباتيكي",
    "wheelchair handball records and statistics": "سجلات وإحصائيات كرة يد على كراسي متحركة",
    "skating racing seasons": "مواسم سباق تزلج",
    "climbing commentators": "معلقو تسلق",
    "shooting sport players": "لاعبو رماية",
    "cross country running racing owners and executives": "رؤساء تنفيذيون وملاك سباق عدو ريفي",
    "water skiing racing leagues": "دوريات سباق تزلج على الماء",
    "long-distance running racing terminology": "مصطلحات سباق ركض مسافات طويلة",
    "triple jump competitions": "منافسات قفز ثلاثي",
    "running racing championships": "بطولات سباق ركض",
    "rally raid footballers": "لاعبو رالي رايد",
    "floorball racing commentators": "معلقو سباق كرة أرض",
    "ski jumping non-playing staff": "طاقم قفز تزلجي غير اللاعبين",
    "motorsport comics": "قصص مصورة رياضة محركات",
    "gridiron football coaches": "مدربو كرة قدم أمريكية شمالية",
    "snooker umpires": "حكام سنوكر",
    "rhythmic gymnastics leagues seasons": "مواسم دوريات جمباز إيقاعي",
    "beach soccer racing trainers": "مدربو سباق كرة قدم شاطئية",
    "wrestling racing commissioners": "مفوضو سباق مصارعة",
    "bowling racing broadcasters": "مذيعو سباق بولينج",
    "australian rules football television series": "مسلسلات تلفزيونية كرة قدم أسترالية",
    "muay thai racing manager history": "تاريخ مدربو سباق موياي تاي",
    "formula e racing stadiums": "ملاعب سباق فورمولا إي",
    "canoeing and kayaking racing non-profit publishers": "ناشرون غير ربحيون سباق كانو-كاياك",
    "ball hockey racing video games": "ألعاب فيديو سباق هوكي كرة",
    "rugby union logos": "شعارات اتحاد رجبي",
    "pencak silat racing coaches": "مدربو سباق بنكات سيلات",
    "rugby music": "موسيقى رجبي",
    "alpine skiing racing video games": "ألعاب فيديو سباق تزلج على المنحدرات الثلجية",
    "sailing (sport) referees": "حكام رياضة إبحار",
    "cross country running referees": "حكام عدو ريفي",
    "kick boxing racing manager": "مدربو سباق كيك بوكسينغ",
    "rallying racing comics": "قصص مصورة سباق راليات",
    "acrobatic gymnastics racing commissioners": "مفوضو سباق جمباز اكروباتيكي",
    "track cycling songs": "أغاني سباق الدراجات على المضمار",
    "pentathlon racing commentators": "معلقو سباق خماسي",
    "wheelchair handball lists": "قوائم كرة يد على كراسي متحركة",
    "wrestling leagues": "دوريات مصارعة",
    "wheelchair beach handball executives": "مدراء كرة يد شاطئية على كراسي متحركة",
    "bmx referees": "حكام سباق بي إم إكس",
    "sport climbing leagues": "دوريات تسلق",
    "equestrian racing terminology": "مصطلحات سباق فروسية",
    "chinese martial arts awards": "جوائز فنون قتالية صينية",
    "climbing racing clubs and teams": "أندية وفرق سباق تسلق",
    "hammer throw organizations": "منظمات رمي مطرقة",
    "sepak takraw executives": "مدراء سيباك تاكرو",
    "shooting sport stadiums": "ملاعب رماية",
    "acrobatic gymnastics racing matches": "مباريات سباق جمباز اكروباتيكي",
    "volleyball racing manager": "مدربو سباق كرة طائرة",
    "weightlifting racing governing bodies": "هيئات تنظيم سباق رفع أثقال",
    "bandy commissioners": "مفوضو باندي",
    "snooker racing executives": "مدراء سباق سنوكر",
    "ski-orienteering competition": "منافسات سباق تزلج موجه",
    "archery racing equipment": "معدات سباق نبالة",
    "soft tennis racing non-playing staff": "طاقم سباق كرة مضرب لينة غير اللاعبين",
    "bmx racing commissioners": "مفوضو سباق بي إم إكس",
    "modern pentathlon media": "إعلام خماسي حديث",
    "relay race non-profit organizations": "منظمات غير ربحية سباق تتابع",
    "pesäpallo racing results": "نتائج سباق بيسبالو",
    "wheelchair basketball broadcasters": "مذيعو كرة سلة على كراسي متحركة",
    "canadian-football racing culture": "ثقافة سباق كرة قدم كندية",
    "volleyball racing variants": "أشكال سباق كرة طائرة",
    "volleyball leagues": "دوريات كرة طائرة",
    "rallying racing executives": "مدراء سباق راليات",
    "pesäpallo referees": "حكام بيسبالو",
    "ice skating results": "نتائج تزلج على الجليد",
    "trampolining racing seasons": "مواسم سباق جمباز قفز",
    "australian rules football racing leagues seasons": "مواسم دوريات سباق كرة قدم أسترالية",
    "modern pentathlon players": "لاعبو خماسي حديث",
    "dragon boat racing commentators": "معلقو سباق قوارب التنين",
    "poker non-profit publishers": "ناشرون غير ربحيون بوكر",
    "motorsport media": "إعلام رياضة محركات",
    "cycle racing personnel": "أفراد سباق دراجات",
    "rugby sevens racing equipment": "معدات سباق سباعيات رجبي",
    "aerobics racing variants": "أشكال سباق جمباز أيروبيكس",
    "road race culture": "ثقافة سباق دراجات على الطريق",
    "formula racing stadiums": "ملاعب سباقات فورمولا",
    "ice hockey bodies": "هيئات هوكي جليد",
    "kick boxing racing stadiums": "ملاعب سباق كيك بوكسينغ",
    "formula one songs": "أغاني فورمولا ون",
    "sepak takraw racing clubs and teams": "أندية وفرق سباق سيباك تاكرو",
    "racingxx trainers": "مدربو سباق سيارات",
    "beach soccer terminology": "مصطلحات كرة قدم شاطئية",
    "boxing trainers": "مدربو بوكسينغ",
    "canoeing films": "أفلام ركوب الكنو",
    "time trial comics": "قصص مصورة سباق دراجات ضد الساعة",
    "long jump racing films": "أفلام سباق قفز طويل",
    "dragon boat comics": "قصص مصورة سباق قوارب التنين",
    "beach handball non-playing staff": "طاقم كرة يد شاطئية غير اللاعبين",
    "pole vault racing organizations": "منظمات سباق قفز بالزانة",
    "table tennis racing fan clubs": "أندية معجبي سباق كرة طاولة",
    "kickboxing racing coaches": "مدربو سباق كيك بوكسينغ",
    "karate stadiums": "ملاعب كاراتيه",
    "bullfighting racing players": "لاعبو سباق مصارعة ثيران",
    "single skating racing owners and executives": "رؤساء تنفيذيون وملاك سباق تزلج فردي على الجليد",
    "automobile racing players": "لاعبو سباق سيارات",
    "canadian-football racing films": "أفلام سباق كرة قدم كندية",
    "rugby football racing manager history": "تاريخ مدربو سباق كرة قدم رجبي",
    "professional wrestling lists": "قوائم مصارعة محترفين",
    "underwater hockey racing songs": "أغاني سباق هوكي تحت الماء",
    "greco-roman wrestling racing managers": "مدربو سباق مصارعة يونانية رومانية",
    "cross country records and statistics": "سجلات وإحصائيات عدو ريفي",
    "bicycle motocross racing fan clubs": "أندية معجبي سباق بي ام اكس",
    "archery records and statistics": "سجلات وإحصائيات نبالة",
    "soccer racing comics": "قصص مصورة سباق كرة قدم",
    "boxing commissioners": "مفوضو بوكسينغ",
    "dragon boat coaches": "مدربو سباق قوارب التنين",
    "cross-country skiing racing manager history": "تاريخ مدربو سباق تزلج ريفي",
    "archery organizations": "منظمات نبالة",
    "trampolining personnel": "أفراد جمباز قفز",
    "track-and-field athletics rivalries": "دربيات ألعاب قوى مضمار وميدان",
    "show jumping racing leagues": "دوريات سباق قفز حواجز",
    "road race broadcasters": "مذيعو سباق دراجات على الطريق",
    "canadian-football songs": "أغاني كرة قدم كندية",
    "track-and-field athletics racing people": "أعلام سباق ألعاب قوى مضمار وميدان",
    "fencing racing footballers": "لاعبو سباق مبارزة سيف شيش",
    "boules racing non-playing staff": "طاقم سباق بوتشي غير اللاعبين",
    "snowboarding racing non-profit organizations": "منظمات غير ربحية سباق تزلج على الثلوج",
    "running non-playing staff": "طاقم ركض غير اللاعبين",
    "canadian football rivalries": "دربيات كرة قدم كندية",
    "water polo racing video games": "ألعاب فيديو سباق كرة ماء",
    "skateboarding racing competition": "منافسات سباق تزلج على اللوح",
    "long jump referees": "حكام قفز طويل",
    "bobsleigh footballers": "لاعبو زلاجة جماعية",
    "cricket racing clubs": "أندية سباق كريكت",
    "alpine skiing racing umpires": "حكام سباق تزلج على المنحدرات الثلجية",
    "canadian football leagues seasons": "مواسم دوريات كرة قدم كندية",
    "orienteering bodies": "هيئات سباق موجه",
    "single skating variants": "أشكال تزلج فردي على الجليد",
    "sepak takraw television series": "مسلسلات تلفزيونية سيباك تاكرو",
    "netball logos": "شعارات كرة شبكة",
    "board games racing rivalries": "دربيات سباق ألعاب طاولة",
    "martial arts culture": "ثقافة فنون قتالية",
    "wushu racing culture": "ثقافة سباق ووشو",
    "bullfighting stadiums": "ملاعب مصارعة ثيران",
    "snowboarding television series": "مسلسلات تلفزيونية تزلج على الثلوج",
    "dressage fan clubs": "أندية معجبي ترويض خيول",
    "dragon boat variants": "أشكال سباق قوارب التنين",
    "biathlon racing broadcasters": "مذيعو سباق بياثلون",
    "sport climbing racing trainers": "مدربو سباق تسلق",
    "artistic swimming racing footballers": "لاعبو سباق سباحة فنية",
    "sailing (sport) racing fan clubs": "أندية معجبي سباق رياضة إبحار",
    "ski jumping racing executives": "مدراء سباق قفز تزلجي",
    "sailing (sport) racing seasons": "مواسم سباق رياضة إبحار",
    "rugby union rivalries": "دربيات اتحاد رجبي",
    "artistic swimming players": "لاعبو سباحة فنية",
    "pair skating organizations": "منظمات تزلج فني على الجليد",
    "rally racing matches": "مباريات سباق رالي",
    "canoeing racing commentators": "معلقو سباق ركوب الكنو",
    "rally world competitions": "منافسات رالي عالمية",
    "bandy competitions": "منافسات باندي",
    "silat racing managers": "مدربو سباق سيلات",
    "chess racing world competitions": "منافسات سباق شطرنج عالمية",
    "greco-roman wrestling racing championships": "بطولات سباق مصارعة يونانية رومانية",
    "gaelic football executives": "مدراء كرة قدم غالية",
    "shooting sports players": "لاعبو رماية",
    "marathon running results": "نتائج سباق ماراثون",
    "association football racing awards": "جوائز سباق كرة قدم",
    "muay thai teams": "فرق موياي تاي",
    "cycling players": "لاعبو سباق دراجات هوائية",
    "ski jumping racing variants": "أشكال سباق قفز تزلجي",
    "table tennis competitions": "منافسات كرة طاولة",
    "floorball comics": "قصص مصورة كرة أرض",
    "rugby league racing video games": "ألعاب فيديو سباق دوري رجبي",
    "luge executives": "مدراء زحف ثلجي",
    "mountain bike champions": "أبطال سباق الدراجات الجبلية",
    "orienteering television series": "مسلسلات تلفزيونية سباق موجه",
    "fencing executives": "مدراء مبارزة سيف شيش",
    "cross country racing managers": "مدربو سباق عدو ريفي",
    "poker commissioners": "مفوضو بوكر",
    "ice skating tactics and skills": "مهارات تزلج على الجليد",
    "athletics lists": "قوائم ألعاب قوى",
    "rugbyunion racing awards": "جوائز سباق اتحاد رجبي",
    "pole vault racing owners": "ملاك سباق قفز بالزانة",
    "sumo media": "إعلام سومو",
    "curling racing films": "أفلام سباق كيرلنغ",
    "ice sledge hockey variants": "أشكال هوكي مزلجة على الجليد",
    "dragon boat racing non-profit organizations": "منظمات غير ربحية سباق قوارب التنين",
    "bullfighting lists": "قوائم مصارعة ثيران",
    "middle-distance running championships": "بطولات ركض مسافات متوسطة",
    "formula one racing seasons": "مواسم سباق فورمولا ون",
    "ice sledge hockey racing owners": "ملاك سباق هوكي مزلجة على الجليد",
    "short track speed skating commissioners": "مفوضو تزلج على مسار قصير",
    "croquet trainers": "مدربو كروكيت",
    "judo coaches": "مدربو جودو",
    "sailing racing umpires": "حكام سباق إبحار",
    "judo racing video games": "ألعاب فيديو سباق جودو",
    "motorboat players": "لاعبو زوارق نارية",
    "curling championships": "بطولات كيرلنغ",
    "karate manager history": "تاريخ مدربو كاراتيه",
    "gaelic football racing films": "أفلام سباق كرة قدم غالية",
    "college seasons": "مواسم كليات",
    "synchronised swimming records and statistics": "سجلات وإحصائيات سباحة متزامنة",
    "tennis racing leagues seasons": "مواسم دوريات سباق كرة مضرب",
    "aerobics competition": "منافسات جمباز أيروبيكس",
    "rowing racing managers": "مدربو سباق تجديف",
    "underwater hockey racing commissioners": "مفوضو سباق هوكي تحت الماء",
    "synchronised swimming players": "لاعبو سباحة متزامنة",
    "eventing racing managers": "مدربو سباق محاكمة خيول",
    "rugby union leagues seasons": "مواسم دوريات اتحاد رجبي",
    "shooting sports executives": "مدراء رماية",
    "freestyle wrestling seasons": "مواسم مصارعة حرة",
    "polo records and statistics": "سجلات وإحصائيات بولو",
    "hockey racing clubs and teams": "أندية وفرق سباق هوكي",
    "triathlon owners": "ملاك سباق ثلاثي",
    "diving racing non-profit publishers": "ناشرون غير ربحيون سباق غطس",
    "motorcycle racing trainers": "مدربو سباق دراجات نارية",
    "shooting players": "لاعبو رماية",
    "track-and-field athletics umpires": "حكام ألعاب قوى مضمار وميدان",
    "bobsleigh terminology": "مصطلحات زلاجة جماعية",
    "ice skating racing clubs and teams": "أندية وفرق سباق تزلج على الجليد",
    "karate racing records and statistics": "سجلات وإحصائيات سباق كاراتيه",
    "biathlon owners": "ملاك بياثلون",
    "ice skating fan clubs": "أندية معجبي تزلج على الجليد",
    "figure skating racing fan clubs": "أندية معجبي سباق تزلج فني",
    "water skiing manager history": "تاريخ مدربو تزلج على الماء",
    "futsal results": "نتائج كرة صالات",
    "wheelchair rugby league organizations": "منظمات دوري رجبي على كراسي متحركة",
    "draughts racing clubs and teams": "أندية وفرق سباق ضامة",
    "fencing songs": "أغاني مبارزة سيف شيش",
    "professional wrestling racing leagues seasons": "مواسم دوريات سباق مصارعة محترفين",
    "sailing (sport) racing clubs and teams": "أندية وفرق سباق رياضة إبحار",
    "sailing (sport) racing songs": "أغاني سباق رياضة إبحار",
    "sailing (sport) racing broadcasters": "مذيعو سباق رياضة إبحار",
    "sports players": "لاعبو رياضية",
    "ski jumping racing media": "إعلام سباق قفز تزلجي",
    "wheelchair beach handball terminology": "مصطلحات كرة يد شاطئية على كراسي متحركة",
    "wheelchair beach handball trainers": "مدربو كرة يد شاطئية على كراسي متحركة",
    "motor racing manager": "مدربو سباق محركات",
    "kurash racing fan clubs": "أندية معجبي سباق كوراش",
    "gymnastics racing organizations": "منظمات سباق جمباز",
    "boxing managers": "مدربو بوكسينغ",
    "aquatics racing managers": "مدربو سباق رياضات مائية",
    "bmx bodies": "هيئات سباق بي إم إكس",
    "bowls racing stadiums": "ملاعب سباق بولينج",
    "sumo racing terminology": "مصطلحات سباق سومو",
    "mixed martial arts music": "موسيقى فنون قتال مختلطة",
    "pair skating players": "لاعبو تزلج فني على الجليد",
    "polo trainers": "مدربو بولو",
    "sambo music": "موسيقى سامبو",
    "gaelic football racing rivalries": "دربيات سباق كرة قدم غالية",
    "bowling awards": "جوائز بولينج",
    "canoeing footballers": "لاعبو ركوب الكنو",
    "darts racing variants": "أشكال سباق سهام مريشة",
    "badminton fan clubs": "أندية معجبي تنس ريشة",
    "racingxx managers": "مدربو سباق سيارات",
    "artistic gymnastics racing coaches": "مدربو سباق جمباز فني",
    "inline hockey results": "نتائج هوكي مضمن",
    "high jump racing terminology": "مصطلحات سباق قفز عالي",
    "artistic gymnastics managers": "مدربو جمباز فني",
    "ice hockey umpires": "حكام هوكي جليد",
    "racquetball clubs": "أندية كرة الراح",
    "equestrianism non-playing staff": "طاقم فروسية غير اللاعبين",
    "hammer throw non-playing staff": "طاقم رمي مطرقة غير اللاعبين",
    "snowboarding manager history": "تاريخ مدربو تزلج على الثلوج",
    "cross country trainers": "مدربو عدو ريفي",
    "wrestling video games": "ألعاب فيديو مصارعة",
    "australian rules football racing clubs and teams": "أندية وفرق سباق كرة قدم أسترالية",
    "motorsports leagues seasons": "مواسم دوريات رياضة محركات",
    "badminton coaches": "مدربو تنس ريشة",
    "skeleton commissioners": "مفوضو زلاجات صدرية",
    "show jumping leagues seasons": "مواسم دوريات قفز حواجز",
    "draughts non-profit organizations": "منظمات غير ربحية ضامة",
    "ice sledge hockey comics": "قصص مصورة هوكي مزلجة على الجليد",
    "formula one racing players": "لاعبو سباق فورمولا ون",
    "single skating racing equipment": "معدات سباق تزلج فردي على الجليد",
    "chess players": "لاعبو شطرنج",
    "aquatics racing terminology": "مصطلحات سباق رياضات مائية",
    "wheelchair basketball people": "أعلام كرة سلة على كراسي متحركة",
    "rowing fan clubs": "أندية معجبي تجديف",
    "motorsports racing competition": "منافسات سباق رياضة محركات",
    "college racing manager history": "تاريخ مدربو سباق كليات",
    "athletics racing footballers": "لاعبو سباق ألعاب قوى",
    "wheelchair fencing non-playing staff": "طاقم مبارزة سيف شيش على كراسي متحركة غير اللاعبين",
    "formula e racing media": "إعلام سباق فورمولا إي",
    "softball players": "لاعبو كرة لينة",
    "motorsports racing matches": "مباريات سباق رياضة محركات",
    "fencing commentators": "معلقو مبارزة سيف شيش",
    "australian rules football racing leagues": "دوريات سباق كرة قدم أسترالية",
    "track-and-field athletics personnel": "أفراد ألعاب قوى مضمار وميدان",
    "sailing (sport) racing governing bodies": "هيئات تنظيم سباق رياضة إبحار",
    "formula one racing executives": "مدراء سباق فورمولا ون",
    "discus throw racing results": "نتائج سباق رمي قرص",
    "equestrian video games": "ألعاب فيديو فروسية",
    "basque pelota racing players": "لاعبو سباق كرة باسك",
    "shooting sports personnel": "أفراد رماية",
    "ice sledge hockey equipment": "معدات هوكي مزلجة على الجليد",
    "track cycling awards": "جوائز سباق الدراجات على المضمار",
    "skateboarding racing terminology": "مصطلحات سباق تزلج على اللوح",
    "floorball films": "أفلام كرة أرض",
    "silat racing non-profit publishers": "ناشرون غير ربحيون سباق سيلات",
    "go personnel": "أفراد غو",
    "fencing racing awards": "جوائز سباق مبارزة سيف شيش",
    "draughts stadiums": "ملاعب ضامة",
    "silat broadcasters": "مذيعو سيلات",
    "hurling organizations": "منظمات قذف",
    "biathlon racing organizations": "منظمات سباق بياثلون",
    "go non-profit organizations": "منظمات غير ربحية غو",
    "rugby sevens non-playing staff": "طاقم سباعيات رجبي غير اللاعبين",
    "inline hockey terminology": "مصطلحات هوكي مضمن",
    "cycling road race records and statistics": "سجلات وإحصائيات سباق دراجات على الطريق",
    "sport climbing leagues seasons": "مواسم دوريات تسلق",
    "sport climbing owners and executives": "رؤساء تنفيذيون وملاك تسلق",
    "boccia racing lists": "قوائم سباق بوتشيا",
    "water skiing non-profit organizations": "منظمات غير ربحية تزلج على الماء",
    "long-distance running video games": "ألعاب فيديو ركض مسافات طويلة",
    "triple jump leagues": "دوريات قفز ثلاثي",
    "racquetball leagues seasons": "مواسم دوريات كرة الراح",
    "shooting sport racing competition": "منافسات سباق رماية",
    "ice sledge hockey racing television series": "مسلسلات تلفزيونية سباق هوكي مزلجة على الجليد",
    "judo stadiums": "ملاعب جودو",
    "equestrianism racing governing bodies": "هيئات تنظيم سباق فروسية",
    "track-and-field athletics racing trainers": "مدربو سباق ألعاب قوى مضمار وميدان",
    "bowling manager history": "تاريخ مدربو بولينج",
    "surfing racing seasons": "مواسم سباق ركمجة",
    "underwater hockey racing television series": "مسلسلات تلفزيونية سباق هوكي تحت الماء",
    "alpine skiing managers": "مدربو تزلج على المنحدرات الثلجية",
    "shooting comics": "قصص مصورة رماية",
    "sailing records and statistics": "سجلات وإحصائيات إبحار",
    "gymnastics racing culture": "ثقافة سباق جمباز",
    "track-and-field athletics equipment": "معدات ألعاب قوى مضمار وميدان",
    "pencak silat racing clubs": "أندية سباق بنكات سيلات",
    "ski flying media": "إعلام تزلج طائر",
    "pole vault awards": "جوائز قفز بالزانة",
    "wheelchair beach handball owners": "ملاك كرة يد شاطئية على كراسي متحركة",
    "rifle shooting racing records and statistics": "سجلات وإحصائيات سباق رماية بندقية",
    "show jumping logos": "شعارات قفز حواجز",
    "wushu executives": "مدراء ووشو",
    "pair skating world competitions": "منافسات تزلج فني على الجليد عالمية",
    "professional wrestling racing rivalries": "دربيات سباق مصارعة محترفين",
    "motor players": "لاعبو محركات",
    "cyclo-cross racing umpires": "حكام سباق سيكلو كروس",
    "bmx commentators": "معلقو سباق بي إم إكس",
    "weightlifting racing clubs and teams": "أندية وفرق سباق رفع أثقال",
    "canoe sprint culture": "ثقافة سباق قوارب",
    "ball hockey media": "إعلام هوكي كرة",
    "canoeing and kayaking racing umpires": "حكام سباق كانو-كاياك",
    "surfing variants": "أشكال ركمجة",
    "discus throw racing people": "أعلام سباق رمي قرص",
    "kurash teams": "فرق كوراش",
    "speed skiing logos": "شعارات تزلج سريع",
    "ice skating racing culture": "ثقافة سباق تزلج على الجليد",
    "canoeing people": "أعلام ركوب الكنو",
    "relay race manager": "مدربو سباق تتابع",
    "track-and-field athletics racing non-playing staff": "طاقم سباق ألعاب قوى مضمار وميدان غير اللاعبين",
    "shooting non-profit publishers": "ناشرون غير ربحيون رماية",
    "show jumping racing media": "إعلام سباق قفز حواجز",
    "croquet culture": "ثقافة كروكيت",
    "figure skating racing trainers": "مدربو سباق تزلج فني",
    "rowing clubs": "أندية تجديف",
    "board games songs": "أغاني ألعاب طاولة",
    "field hockey racing trainers": "مدربو سباق هوكي ميدان",
    "pole vault tactics and skills": "مهارات قفز بالزانة",
    "submission wrestling media": "إعلام مصارعة خضوع",
    "equestrian media": "إعلام فروسية",
    "college music": "موسيقى كليات",
    "squash racing bodies": "هيئات سباق اسكواش",
    "waterskiing racing seasons": "مواسم سباق تزلج على الماء",
    "sumo racing variants": "أشكال سباق سومو",
    "rugbyunion umpires": "حكام اتحاد رجبي",
    "synchronised swimming racing non-profit publishers": "ناشرون غير ربحيون سباق سباحة متزامنة",
    "handball clubs and teams": "أندية وفرق كرة يد",
    "ski flying racing commentators": "معلقو سباق تزلج طائر",
    "curling racing championships": "بطولات سباق كيرلنغ",
    "gridiron football racing films": "أفلام سباق كرة قدم أمريكية شمالية",
    "lacrosse awards": "جوائز لاكروس",
    "pencak silat people": "أعلام بنكات سيلات",
    "sledge hockey racing equipment": "معدات سباق هوكي مزلجة",
    "climbing racing music": "موسيقى سباق تسلق",
    "goalball people": "أعلام كرة هدف",
    "bullfighting racing films": "أفلام سباق مصارعة ثيران",
    "skeleton racing trainers": "مدربو سباق زلاجات صدرية",
    "bouldering video games": "ألعاب فيديو بولدرنق",
    "rally raid racing fan clubs": "أندية معجبي سباق رالي رايد",
    "badminton clubs": "أندية تنس ريشة",
    "taekwondo racing clubs and teams": "أندية وفرق سباق تايكوندو",
    "rugbyunion leagues seasons": "مواسم دوريات اتحاد رجبي",
    "bowling non-profit organizations": "منظمات غير ربحية بولينج",
    "roller skating racing seasons": "مواسم سباق تزلج بالعجلات",
    "pesäpallo television series": "مسلسلات تلفزيونية بيسبالو",
    "lacrosse rivalries": "دربيات لاكروس",
    "waterskiing stadiums": "ملاعب تزلج على الماء",
    "bullfighting racing rivalries": "دربيات سباق مصارعة ثيران",
    "archery clubs": "أندية نبالة",
    "shooting sport manager": "مدربو رماية",
    "powerlifting manager": "مدربو رياضة قوة",
    "board games leagues": "دوريات ألعاب طاولة",
    "sumo films": "أفلام سومو",
    "cross-country skiing players": "لاعبو تزلج ريفي",
    "underwater hockey tactics and skills": "مهارات هوكي تحت الماء",
    "american football culture": "ثقافة كرة قدم أمريكية",
    "acrobatic gymnastics stadiums": "ملاعب جمباز اكروباتيكي",
    "synchronized swimming organizations": "منظمات سباحة متزامنة",
    "chinese martial arts comics": "قصص مصورة فنون قتالية صينية",
    "sprinting racing leagues seasons": "مواسم دوريات سباق جري سريع",
    "speed skating racing lists": "قوائم سباق تزلج سريع",
    "professional wrestling seasons": "مواسم مصارعة محترفين",
    "kabaddi terminology": "مصطلحات كابادي",
    "modern pentathlon television series": "مسلسلات تلفزيونية خماسي حديث",
    "speed skating fan clubs": "أندية معجبي تزلج سريع",
    "american football clubs": "أندية كرة قدم أمريكية",
    "snooker competitions": "منافسات سنوكر",
    "go racing music": "موسيقى سباق غو",
    "ice dancing television series": "مسلسلات تلفزيونية رقص على جليد",
    "long jump rivalries": "دربيات قفز طويل",
    "wheelchair curling rivalries": "دربيات كيرلنغ على كراسي متحركة",
    "canadian-football racing non-profit publishers": "ناشرون غير ربحيون سباق كرة قدم كندية",
    "badminton racing competition": "منافسات سباق تنس ريشة",
    "tennis people": "أعلام كرة مضرب",
    "canoeing and kayaking video games": "ألعاب فيديو كانو-كاياك",
    "formula one governing bodies": "هيئات تنظيم فورمولا ون",
    "soft tennis manager history": "تاريخ مدربو كرة مضرب لينة",
    "soccer coaches": "مدربو كرة قدم",
    "curling racing music": "موسيقى سباق كيرلنغ",
    "wheelchair beach handball world competitions": "منافسات كرة يد شاطئية على كراسي متحركة عالمية",
    "polo rivalries": "دربيات بولو",
    "rugbyunion broadcasters": "مذيعو اتحاد رجبي",
    "bouldering racing matches": "مباريات سباق بولدرنق",
    "motor stadiums": "ملاعب محركات",
    "jujutsu world competitions": "منافسات جوجوتسو عالمية",
    "diving equipment": "معدات غطس",
    "aerobics non-profit publishers": "ناشرون غير ربحيون جمباز أيروبيكس",
    "chess racing television series": "مسلسلات تلفزيونية سباق شطرنج",
    "polo racing tactics and skills": "مهارات سباق بولو",
    "sailing (sport) owners": "ملاك رياضة إبحار",
    "basque pelota racing managers": "مدربو سباق كرة باسك",
    "roller hockey (quad) racing competition": "منافسات سباق هوكي دحرجة",
    "soft tennis managers": "مدربو كرة مضرب لينة",
    "bobsleigh racing fan clubs": "أندية معجبي سباق زلاجة جماعية",
    "sledge hockey racing commissioners": "مفوضو سباق هوكي مزلجة",
    "mixed martial arts racing players": "لاعبو سباق فنون قتال مختلطة",
    "shooting sport organizations": "منظمات رماية",
    "polo racing competition": "منافسات سباق بولو",
    "sepak takraw racing tactics and skills": "مهارات سباق سيباك تاكرو",
    "badminton music": "موسيقى تنس ريشة",
    "speed skiing footballers": "لاعبو تزلج سريع",
    "sledge hockey racing songs": "أغاني سباق هوكي مزلجة",
    "surfing bodies": "هيئات ركمجة",
    "rifle shooting racing umpires": "حكام سباق رماية بندقية",
    "rugby football racing world competitions": "منافسات سباق كرة قدم رجبي عالمية",
    "american-football racing fan clubs": "أندية معجبي سباق كرة قدم أمريكية",
    "climbing coaches": "مدربو تسلق",
    "ju-jitsu racing footballers": "لاعبو سباق جوجوتسو",
    "swimming racing leagues": "دوريات سباق سباحة",
    "climbing songs": "أغاني تسلق",
    "hurling governing bodies": "هيئات تنظيم قذف",
    "triathlon television series": "مسلسلات تلفزيونية سباق ثلاثي",
    "draughts championships": "بطولات ضامة",
    "australian rules football clubs and teams": "أندية وفرق كرة قدم أسترالية",
    "american-football non-profit publishers": "ناشرون غير ربحيون كرة قدم أمريكية",
    "skiing television series": "مسلسلات تلفزيونية تزلج",
    "wheelchair curling results": "نتائج كيرلنغ على كراسي متحركة",
    "tennis results": "نتائج كرة مضرب",
    "formula one racing non-profit publishers": "ناشرون غير ربحيون سباق فورمولا ون",
    "skeleton racing terminology": "مصطلحات سباق زلاجات صدرية",
    "goalball equipment": "معدات كرة هدف",
    "muay thai owners": "ملاك موياي تاي",
    "gridiron football leagues seasons": "مواسم دوريات كرة قدم أمريكية شمالية",
    "motocross terminology": "مصطلحات موتو كروس",
    "volleyball lists": "قوائم كرة طائرة",
    "boxing racing governing bodies": "هيئات تنظيم سباق بوكسينغ",
    "gridiron football racing results": "نتائج سباق كرة قدم أمريكية شمالية",
    "acrobatic gymnastics racing fan clubs": "أندية معجبي سباق جمباز اكروباتيكي",
    "rally raid racing umpires": "حكام سباق رالي رايد",
    "wheelchair curling footballers": "لاعبو كيرلنغ على كراسي متحركة",
    "nordic combined rivalries": "دربيات تزلج نوردي مزدوج",
    "time trial world competitions": "منافسات سباق دراجات ضد الساعة عالمية",
    "pentathlon racing matches": "مباريات سباق خماسي",
    "poker films": "أفلام بوكر",
    "draughts racing records and statistics": "سجلات وإحصائيات سباق ضامة",
    "middle-distance running racing logos": "شعارات سباق ركض مسافات متوسطة",
    "cue sports variants": "أشكال بلياردو",
    "surfing players": "لاعبو ركمجة",
    "sport climbing racing personnel": "أفراد سباق تسلق",
    "motorboat lists": "قوائم زوارق نارية",
    "aquatic sports video games": "ألعاب فيديو رياضات مائية",
    "gymnastics records and statistics": "سجلات وإحصائيات جمباز",
    "racquets video games": "ألعاب فيديو لعبة الراح",
    "football racing stadiums": "ملاعب سباق كرة قدم",
    "esports racing manager history": "تاريخ مدربو سباق رياضة إلكترونية",
    "rugby racing terminology": "مصطلحات سباق رجبي",
    "motor umpires": "حكام محركات",
    "sepak takraw racing world competitions": "منافسات سباق سيباك تاكرو عالمية",
    "diving racing seasons": "مواسم سباق غطس",
    "skeleton racing coaches": "مدربو سباق زلاجات صدرية",
    "american football fan clubs": "أندية معجبي كرة قدم أمريكية",
    "shooting sport racing players": "لاعبو سباق رماية",
    "croquet owners and executives": "رؤساء تنفيذيون وملاك كروكيت",
    "aquatics racing championships": "بطولات سباق رياضات مائية",
    "sailing racing video games": "ألعاب فيديو سباق إبحار",
    "tennis racing television series": "مسلسلات تلفزيونية سباق كرة مضرب",
    "wheelchair curling world competitions": "منافسات كيرلنغ على كراسي متحركة عالمية",
    "cue sports players": "لاعبو بلياردو",
    "martial arts umpires": "حكام فنون قتالية",
    "ball hockey lists": "قوائم هوكي كرة",
    "wheelchair rugby league stadiums": "ملاعب دوري رجبي على كراسي متحركة",
    "motorsport racing commissioners": "مفوضو سباق رياضة محركات",
    "cricket racing executives": "مدراء سباق كريكت",
    "motocross racing manager history": "تاريخ مدربو سباق موتو كروس",
    "rifle shooting racing films": "أفلام سباق رماية بندقية",
    "muay thai racing clubs": "أندية سباق موياي تاي",
    "pair skating personnel": "أفراد تزلج فني على الجليد",
    "boules organizations": "منظمات بوتشي",
    "shooting chairmen and investors": "رؤساء ومسيرو رماية",
    "professional wrestling racing players": "لاعبو سباق مصارعة محترفين",
    "shot put players": "لاعبو دفع ثقل",
    "pair skating racing music": "موسيقى سباق تزلج فني على الجليد",
    "automobile racing variants": "أشكال سباق سيارات",
    "rugbyunion racing films": "أفلام سباق اتحاد رجبي",
    "croquet racing leagues": "دوريات سباق كروكيت",
    "gridiron football racing fan clubs": "أندية معجبي سباق كرة قدم أمريكية شمالية",
    "boxing world competitions": "منافسات بوكسينغ عالمية",
    "rugby racing tactics and skills": "مهارات سباق رجبي",
    "polo video games": "ألعاب فيديو بولو",
    "cross-country skiing racing films": "أفلام سباق تزلج ريفي",
    "ju-jitsu trainers": "مدربو جوجوتسو",
    "rally racing variants": "أشكال سباق رالي",
    "badminton commentators": "معلقو تنس ريشة",
    "water skiing racing footballers": "لاعبو سباق تزلج على الماء",
    "wheelchair fencing seasons": "مواسم مبارزة سيف شيش على كراسي متحركة",
    "motorboat results": "نتائج زوارق نارية",
    "track-and-field athletics culture": "ثقافة ألعاب قوى مضمار وميدان",
    "darts songs": "أغاني سهام مريشة",
    "football racing films": "أفلام سباق كرة قدم",
    "pole vault racing competition": "منافسات سباق قفز بالزانة",
    "archery racing footballers": "لاعبو سباق نبالة",
    "mountain bike seasons": "مواسم سباق الدراجات الجبلية",
    "bmx racing players": "لاعبو سباق بي إم إكس",
    "soccer racing executives": "مدراء سباق كرة قدم",
    "beach soccer organizations": "منظمات كرة قدم شاطئية",
    "taekwondo racing bodies": "هيئات سباق تايكوندو",
    "bouldering logos": "شعارات بولدرنق",
    "boccia competition": "منافسات بوتشيا",
    "silat stadiums": "ملاعب سيلات",
    "rallying non-profit organizations": "منظمات غير ربحية راليات",
    "track-and-field athletics songs": "أغاني ألعاب قوى مضمار وميدان",
    "formula racing players": "لاعبو سباقات فورمولا",
    "beach soccer racing video games": "ألعاب فيديو سباق كرة قدم شاطئية",
    "speed skating players": "لاعبو تزلج سريع",
    "high school racing logos": "شعارات سباق مدارس ثانوية",
    "cycle trainers": "مدربو دراجات",
    "college television series": "مسلسلات تلفزيونية كليات",
    "basque pelota racing executives": "مدراء سباق كرة باسك",
    "soccer stadiums": "ملاعب كرة قدم",
    "college racing umpires": "حكام سباق كليات",
    "ice dancing commissioners": "مفوضو رقص على جليد",
    "eventing referees": "حكام محاكمة خيول",
    "powerlifting racing records and statistics": "سجلات وإحصائيات سباق رياضة قوة",
    "submission wrestling broadcasters": "مذيعو مصارعة خضوع",
    "sport climbing racing results": "نتائج سباق تسلق",
    "rallying governing bodies": "هيئات تنظيم راليات",
    "kick boxing lists": "قوائم كيك بوكسينغ",
    "lacrosse clubs and teams": "أندية وفرق لاكروس",
    "gridiron football racing logos": "شعارات سباق كرة قدم أمريكية شمالية",
    "figure skating racing equipment": "معدات سباق تزلج فني",
    "rugby football comics": "قصص مصورة كرة قدم رجبي",
    "pentathlon racing competition": "منافسات سباق خماسي",
    "trampolining songs": "أغاني جمباز قفز",
    "formula e players": "لاعبو فورمولا إي",
    "ball hockey racing tactics and skills": "مهارات سباق هوكي كرة",
    "greco-roman wrestling personnel": "أفراد مصارعة يونانية رومانية",
    "cycle race competition": "منافسات سباق دراجات",
    "xiangqi racing culture": "ثقافة سباق شطرنج صيني",
    "canoe sprint commentators": "معلقو سباق قوارب",
    "esports racing manager": "مدربو سباق رياضة إلكترونية",
    "nordic combined racing lists": "قوائم سباق تزلج نوردي مزدوج",
    "ski jumping rivalries": "دربيات قفز تزلجي",
    "go culture": "ثقافة غو",
    "canoeing championships": "بطولات ركوب الكنو",
    "field hockey leagues seasons": "مواسم دوريات هوكي ميدان",
    "pencak silat racing music": "موسيقى سباق بنكات سيلات",
    "wheelchair beach handball governing bodies": "هيئات تنظيم كرة يد شاطئية على كراسي متحركة",
    "long-distance running non-playing staff": "طاقم ركض مسافات طويلة غير اللاعبين",
    "synchronised swimming racing songs": "أغاني سباق سباحة متزامنة",
    "show jumping racing logos": "شعارات سباق قفز حواجز",
    "basque pelota racing lists": "قوائم سباق كرة باسك",
    "formula racing logos": "شعارات سباقات فورمولا",
    "badminton racing executives": "مدراء سباق تنس ريشة",
    "association football films": "أفلام كرة قدم",
    "diving trainers": "مدربو غطس",
    "ju-jitsu leagues seasons": "مواسم دوريات جوجوتسو",
    "aerobics films": "أفلام جمباز أيروبيكس",
    "pair skating racing players": "لاعبو سباق تزلج فني على الجليد",
    "baseball racing broadcasters": "مذيعو سباق كرة قاعدة",
    "skateboarding people": "أعلام تزلج على اللوح",
    "skeleton racing players": "لاعبو سباق زلاجات صدرية",
    "rugby governing bodies": "هيئات تنظيم رجبي",
    "auto racing fan clubs": "أندية معجبي سباق سيارات",
    "athletics personnel": "أفراد ألعاب قوى",
    "squash seasons": "مواسم اسكواش",
    "hockey equipment": "معدات هوكي",
    "wheelchair handball referees": "حكام كرة يد على كراسي متحركة",
    "formula e racing players": "لاعبو سباق فورمولا إي",
    "mountain bike racing competitions": "منافسات سباق الدراجات الجبلية",
    "racewalking fan clubs": "أندية معجبي سباق جري",
    "cycle variants": "أشكال دراجات",
    "greco-roman wrestling racing commentators": "معلقو سباق مصارعة يونانية رومانية",
    "sprinting trainers": "مدربو جري سريع",
    "rally raid media": "إعلام رالي رايد",
    "rowing lists": "قوائم تجديف",
    "pole vault racing rivalries": "دربيات سباق قفز بالزانة",
    "taekwondo racing lists": "قوائم سباق تايكوندو",
    "ice dancing racing leagues": "دوريات سباق رقص على جليد",
    "biathlon racing clubs": "أندية سباق بياثلون",
    "lacrosse media": "إعلام لاكروس",
    "trampolining matches": "مباريات جمباز قفز",
    "bouldering racing seasons": "مواسم سباق بولدرنق",
    "racquets music": "موسيقى لعبة الراح",
    "shooting sport racing organizations": "منظمات سباق رماية",
    "long-distance running referees": "حكام ركض مسافات طويلة",
    "dragon boat racing manager history": "تاريخ مدربو سباق قوارب التنين",
    "karate governing bodies": "هيئات تنظيم كاراتيه",
    "hockey commissioners": "مفوضو هوكي",
    "table tennis fan clubs": "أندية معجبي كرة طاولة",
    "golf organizations": "منظمات غولف",
    "association football logos": "شعارات كرة قدم",
    "synchronized swimming songs": "أغاني سباحة متزامنة",
    "single skating video games": "ألعاب فيديو تزلج فردي على الجليد",
    "association football racing lists": "قوائم سباق كرة قدم",
    "korfball racing coaches": "مدربو سباق كورفبال",
    "karate championships": "بطولات كاراتيه",
    "wushu television series": "مسلسلات تلفزيونية ووشو",
    "cricket owners and executives": "رؤساء تنفيذيون وملاك كريكت",
    "acrobatic gymnastics racing manager history": "تاريخ مدربو سباق جمباز اكروباتيكي",
    "formula e music": "موسيقى فورمولا إي",
    "cricket racing referees": "حكام سباق كريكت",
    "association football media": "إعلام كرة قدم",
    "shooting results": "نتائج رماية",
    "bicycle motocross manager history": "تاريخ مدربو بي ام اكس",
    "ski flying executives": "مدراء تزلج طائر",
    "bmx racing culture": "ثقافة سباق بي إم إكس",
    "polo owners and executives": "رؤساء تنفيذيون وملاك بولو",
    "gaelic football songs": "أغاني كرة قدم غالية",
    "javelin throw racing broadcasters": "مذيعو سباق رمي رمح",
    "american football commissioners": "مفوضو كرة قدم أمريكية",
    "pair skating television series": "مسلسلات تلفزيونية تزلج فني على الجليد",
    "shooting umpires": "حكام رماية",
    "weightlifting racing commissioners": "مفوضو سباق رفع أثقال",
    "formula one racing competition": "منافسات سباق فورمولا ون",
    "dragon boat awards": "جوائز سباق قوارب التنين",
    "college racing executives": "مدراء سباق كليات",
    "motocross racing leagues": "دوريات سباق موتو كروس",
    "kickboxing racing governing bodies": "هيئات تنظيم سباق كيك بوكسينغ",
    "badminton broadcasters": "مذيعو تنس ريشة",
    "sumo racing fan clubs": "أندية معجبي سباق سومو",
    "formula one manager": "مدربو فورمولا ون",
    "badminton songs": "أغاني تنس ريشة",
    "lawn bowls racing seasons": "مواسم سباق بولينغ عشبي",
    "swimming comics": "قصص مصورة سباحة",
    "wheelchair handball championships": "بطولات كرة يد على كراسي متحركة",
    "triple jump racing logos": "شعارات سباق قفز ثلاثي",
    "wheelchair basketball logos": "شعارات كرة سلة على كراسي متحركة",
    "ice dancing racing culture": "ثقافة سباق رقص على جليد",
    "rifle shooting racing trainers": "مدربو سباق رماية بندقية",
    "cricket trainers": "مدربو كريكت",
    "roller hockey (quad) non-profit organizations": "منظمات غير ربحية هوكي دحرجة",
    "badminton racing owners": "ملاك سباق تنس ريشة",
    "skeleton owners and executives": "رؤساء تنفيذيون وملاك زلاجات صدرية",
    "pair skating racing lists": "قوائم سباق تزلج فني على الجليد",
    "track cycling comics": "قصص مصورة سباق الدراجات على المضمار",
    "swimming racing video games": "ألعاب فيديو سباق سباحة",
    "ju-jitsu matches": "مباريات جوجوتسو",
    "beach volleyball rivalries": "دربيات كرة طائرة شاطئية",
    "sport climbing racing manager": "مدربو سباق تسلق",
    "wushu personnel": "أفراد ووشو",
    "relay race stadiums": "ملاعب سباق تتابع",
    "pole vault racing broadcasters": "مذيعو سباق قفز بالزانة",
    "volleyball fan clubs": "أندية معجبي كرة طائرة",
    "formula one racing world competitions": "منافسات سباق فورمولا ون عالمية",
    "silat leagues": "دوريات سيلات",
    "rugby football racing coaches": "مدربو سباق كرة قدم رجبي",
    "kickboxing racing players": "لاعبو سباق كيك بوكسينغ",
    "lacrosse racing players": "لاعبو سباق لاكروس",
    "basque pelota racing leagues seasons": "مواسم دوريات سباق كرة باسك",
    "modern pentathlon racing coaches": "مدربو سباق خماسي حديث",
    "basque pelota racing non-profit publishers": "ناشرون غير ربحيون سباق كرة باسك",
    "sledge hockey racing championships": "بطولات سباق هوكي مزلجة",
    "field hockey coaches": "مدربو هوكي ميدان",
    "shot put manager": "مدربو دفع ثقل",
    "middle-distance running racing non-profit publishers": "ناشرون غير ربحيون سباق ركض مسافات متوسطة",
    "long-distance running racing television series": "مسلسلات تلفزيونية سباق ركض مسافات طويلة",
    "canoeing executives": "مدراء ركوب الكنو",
    "nordic combined racing clubs and teams": "أندية وفرق سباق تزلج نوردي مزدوج",
    "powerlifting culture": "ثقافة رياضة قوة",
    "mountain bike commentators": "معلقو سباق الدراجات الجبلية",
    "long jump people": "أعلام قفز طويل",
    "show jumping racing songs": "أغاني سباق قفز حواجز",
    "goalball racing commissioners": "مفوضو سباق كرة هدف",
    "sledge hockey racing tactics and skills": "مهارات سباق هوكي مزلجة",
    "high jump racing manager history": "تاريخ مدربو سباق قفز عالي",
    "boules racing lists": "قوائم سباق بوتشي",
    "basketball non-profit organizations": "منظمات غير ربحية كرة سلة",
    "underwater hockey racing leagues": "دوريات سباق هوكي تحت الماء",
    "baseball racing footballers": "لاعبو سباق كرة قاعدة",
    "cross-country skiing songs": "أغاني تزلج ريفي",
    "figure skating racing clubs and teams": "أندية وفرق سباق تزلج فني",
    "yacht racing umpires": "حكام سباقات يخوت",
    "freestyle wrestling racing comics": "قصص مصورة سباق مصارعة حرة",
    "boccia racing managers": "مدربو سباق بوتشيا",
    "pesäpallo racing manager": "مدربو سباق بيسبالو",
    "field hockey racing commissioners": "مفوضو سباق هوكي ميدان",
    "boxing chairmen and investors": "رؤساء ومسيرو بوكسينغ",
    "basketball chairmen and investors": "رؤساء ومسيرو كرة سلة",
    "water polo racing chairmen and investors": "رؤساء ومسيرو سباق كرة ماء",
    "curling racing chairmen and investors": "رؤساء ومسيرو سباق كيرلنغ",
    "marathon running chairmen and investors": "رؤساء ومسيرو سباق ماراثون",
    "beach volleyball chairmen and investors": "رؤساء ومسيرو كرة طائرة شاطئية",
    "chinese martial arts racing chairmen and investors": "رؤساء ومسيرو سباق فنون قتالية صينية",
    "bodybuilding racing chairmen and investors": "رؤساء ومسيرو سباق كمال أجسام",
    "go racing chairmen and investors": "رؤساء ومسيرو سباق غو",
    "high jump racing chairmen and investors": "رؤساء ومسيرو سباق قفز عالي",
    "eventing chairmen and investors": "رؤساء ومسيرو محاكمة خيول",
    "submission wrestling chairmen and investors": "رؤساء ومسيرو مصارعة خضوع",
    "croquet chairmen and investors": "رؤساء ومسيرو كروكيت",
    "rowing chairmen and investors": "رؤساء ومسيرو تجديف",
    "roller skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج بالعجلات",
    "speed skiing racing chairmen and investors": "رؤساء ومسيرو سباق تزلج سريع",
    "polo racing chairmen and investors": "رؤساء ومسيرو سباق بولو",
    "soccer chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "single skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج فردي على الجليد",
    "association football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري الرجبي",
    "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي",
    "roller skating champions": "أبطال التزلج بالعجلات",
    "cross country running racing champions": "أبطال سباق العدو الريفي",
    "basketball champions": "أبطال كرة السلة",
    "archery racing champions": "أبطال سباق النبالة",
    "skateboarding racing champions": "أبطال سباق التزلج على اللوح",
    "basque pelota champions": "أبطال كرة الباسك",
    "fencing racing champions": "أبطال سباق مبارزة سيف الشيش",
    "shooting champions": "أبطال الرماية",
    "nordic combined racing champions": "أبطال سباق التزلج النوردي المزدوج",
    "triathlon champions": "أبطال السباق الثلاثي",
    "kick boxing racing champions": "أبطال سباق الكيك بوكسينغ",
    "speed skating champions": "أبطال التزلج السريع",
    "karate champions": "أبطال الكاراتيه",
    "wheelchair fencing champions": "أبطال مبارزة سيف الشيش على الكراسي المتحركة",
}

data_3 = {
    "boxing chairmen and investors": "رؤساء ومسيرو بوكسينغ",
    "basketball chairmen and investors": "رؤساء ومسيرو كرة سلة",
    "water polo racing chairmen and investors": "رؤساء ومسيرو سباق كرة ماء",
    "curling racing chairmen and investors": "رؤساء ومسيرو سباق كيرلنغ",
    "marathon running chairmen and investors": "رؤساء ومسيرو سباق ماراثون",
    "beach volleyball chairmen and investors": "رؤساء ومسيرو كرة طائرة شاطئية",
    "chinese martial arts racing chairmen and investors": "رؤساء ومسيرو سباق فنون قتالية صينية",
    "bodybuilding racing chairmen and investors": "رؤساء ومسيرو سباق كمال أجسام",
    "go racing chairmen and investors": "رؤساء ومسيرو سباق غو",
    "high jump racing chairmen and investors": "رؤساء ومسيرو سباق قفز عالي",
    "eventing chairmen and investors": "رؤساء ومسيرو محاكمة خيول",
    "submission wrestling chairmen and investors": "رؤساء ومسيرو مصارعة خضوع",
    "croquet chairmen and investors": "رؤساء ومسيرو كروكيت",
    "rowing chairmen and investors": "رؤساء ومسيرو تجديف",
    "roller skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج بالعجلات",
    "speed skiing racing chairmen and investors": "رؤساء ومسيرو سباق تزلج سريع",
    "polo racing chairmen and investors": "رؤساء ومسيرو سباق بولو",
    "soccer chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "single skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج فردي على الجليد",
    "association football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري الرجبي",
    "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي",
    # "rugby league chairmen and investors": "رؤساء ومسيرو دوري رجبي",
    # "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد رجبي",
    "roller skating champions": "أبطال التزلج بالعجلات",
    "cross country running racing champions": "أبطال سباق العدو الريفي",
    "basketball champions": "أبطال كرة السلة",
    "archery racing champions": "أبطال سباق النبالة",
    "skateboarding racing champions": "أبطال سباق التزلج على اللوح",
    "basque pelota champions": "أبطال كرة الباسك",
    "fencing racing champions": "أبطال سباق مبارزة سيف الشيش",
    "shooting champions": "أبطال الرماية",
    "nordic combined racing champions": "أبطال سباق التزلج النوردي المزدوج",
    "triathlon champions": "أبطال السباق الثلاثي",
    "kick boxing racing champions": "أبطال سباق الكيك بوكسينغ",
    "speed skating champions": "أبطال التزلج السريع",
    "karate champions": "أبطال الكاراتيه",
    "wheelchair fencing champions": "أبطال مبارزة سيف الشيش على الكراسي المتحركة",
}


@pytest.mark.parametrize("category, expected_key", test_data_1.items(), ids=test_data_1.keys())
@pytest.mark.fast
def test_resolve_team_suffix_1(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_resolve_team_suffix_2(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_resolve_team_suffix_3(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


all_test_data = test_data_1 | data_2 | data_3

to_test = [
    ("test_resolve_sport_label_by_jobs_key", all_test_data, resolve_sport_label_unified),
]

test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)
