#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_empty_value = {
    "Scheduled multi-sport events": "أحداث رياضية متعددة مقررة",
    "Defunct multi-sport events": "أحداث رياضية متعددة سابقة",
    "Disabled multi-sport events": "أحداث رياضية متعددة معاقون",
    "Timor-Leste at multi-sport events": "أحداث رياضية متعددة في تيمور الشرقية",
    "Wikipedia categories named after multi-sport events": "تصنيفات سميت بأسماء أحداث رياضية متعددة",
    "Youth multi-sport events": "أحداث رياضية متعددة شبابية",
}

data_0 = {
    "1896 in multi-sport events": "الأحداث الرياضية المتعددة في 1896",
    "1900 in multi-sport events": "الأحداث الرياضية المتعددة في 1900",
    "1904 in multi-sport events": "الأحداث الرياضية المتعددة في 1904",
    "1906 in multi-sport events": "الأحداث الرياضية المتعددة في 1906",
    "1908 in multi-sport events": "الأحداث الرياضية المتعددة في 1908",
    "1912 in multi-sport events": "الأحداث الرياضية المتعددة في 1912",
    "1916 in multi-sport events": "الأحداث الرياضية المتعددة في 1916",
    "1920 in multi-sport events": "الأحداث الرياضية المتعددة في 1920",
    "1924 in multi-sport events": "الأحداث الرياضية المتعددة في 1924",
    "1926 in multi-sport events": "الأحداث الرياضية المتعددة في 1926",
    "1928 in multi-sport events": "الأحداث الرياضية المتعددة في 1928",
    "1930 in multi-sport events": "الأحداث الرياضية المتعددة في 1930",
    "1932 in multi-sport events": "الأحداث الرياضية المتعددة في 1932",
    "1933 in multi-sport events": "الأحداث الرياضية المتعددة في 1933",
    "1934 in multi-sport events": "الأحداث الرياضية المتعددة في 1934",
    "1935 in multi-sport events": "الأحداث الرياضية المتعددة في 1935",
    "1936 in multi-sport events": "الأحداث الرياضية المتعددة في 1936",
    "1938 in multi-sport events": "الأحداث الرياضية المتعددة في 1938",
    "1940 in multi-sport events": "الأحداث الرياضية المتعددة في 1940",
    "1944 in multi-sport events": "الأحداث الرياضية المتعددة في 1944",
    "1946 in multi-sport events": "الأحداث الرياضية المتعددة في 1946",
    "1948 in multi-sport events": "الأحداث الرياضية المتعددة في 1948",
    "1950 in multi-sport events": "الأحداث الرياضية المتعددة في 1950",
    "1951 in multi-sport events": "الأحداث الرياضية المتعددة في 1951",
    "1952 in multi-sport events": "الأحداث الرياضية المتعددة في 1952",
    "1953 in multi-sport events": "الأحداث الرياضية المتعددة في 1953",
    "1954 in multi-sport events": "الأحداث الرياضية المتعددة في 1954",
    "1955 in multi-sport events": "الأحداث الرياضية المتعددة في 1955",
    "1956 in multi-sport events": "الأحداث الرياضية المتعددة في 1956",
    "1957 in multi-sport events": "الأحداث الرياضية المتعددة في 1957",
    "1958 in multi-sport events": "الأحداث الرياضية المتعددة في 1958",
    "1959 in multi-sport events": "الأحداث الرياضية المتعددة في 1959",
    "1960 in multi-sport events": "الأحداث الرياضية المتعددة في 1960",
    "1961 in multi-sport events": "الأحداث الرياضية المتعددة في 1961",
    "1962 in multi-sport events": "الأحداث الرياضية المتعددة في 1962",
    "1963 in multi-sport events": "الأحداث الرياضية المتعددة في 1963",
    "1964 in multi-sport events": "الأحداث الرياضية المتعددة في 1964",
    "1965 in multi-sport events": "الأحداث الرياضية المتعددة في 1965",
    "1966 in multi-sport events": "الأحداث الرياضية المتعددة في 1966",
    "1967 in multi-sport events": "الأحداث الرياضية المتعددة في 1967",
    "1968 in multi-sport events": "الأحداث الرياضية المتعددة في 1968",
    "1969 in multi-sport events": "الأحداث الرياضية المتعددة في 1969",
    "1970 in multi-sport events": "الأحداث الرياضية المتعددة في 1970",
    "1971 in multi-sport events": "الأحداث الرياضية المتعددة في 1971",
    "1972 in multi-sport events": "الأحداث الرياضية المتعددة في 1972",
    "1973 in multi-sport events": "الأحداث الرياضية المتعددة في 1973",
    "1974 in multi-sport events": "الأحداث الرياضية المتعددة في 1974",
    "1975 in multi-sport events": "الأحداث الرياضية المتعددة في 1975",
    "1976 in multi-sport events": "الأحداث الرياضية المتعددة في 1976",
    "1977 in multi-sport events": "الأحداث الرياضية المتعددة في 1977",
    "1978 in multi-sport events": "الأحداث الرياضية المتعددة في 1978",
    "1979 in multi-sport events": "الأحداث الرياضية المتعددة في 1979",
    "1980 in multi-sport events": "الأحداث الرياضية المتعددة في 1980",
    "1981 in multi-sport events": "الأحداث الرياضية المتعددة في 1981",
    "1982 in multi-sport events": "الأحداث الرياضية المتعددة في 1982",
    "1983 in multi-sport events": "الأحداث الرياضية المتعددة في 1983",
    "1984 in multi-sport events": "الأحداث الرياضية المتعددة في 1984",
    "1985 in multi-sport events": "الأحداث الرياضية المتعددة في 1985",
    "1986 in multi-sport events": "الأحداث الرياضية المتعددة في 1986",
    "1987 in multi-sport events": "الأحداث الرياضية المتعددة في 1987",
    "1988 in multi-sport events": "الأحداث الرياضية المتعددة في 1988",
    "1989 in multi-sport events": "الأحداث الرياضية المتعددة في 1989",
    "1990 in multi-sport events": "الأحداث الرياضية المتعددة في 1990",
    "1991 in multi-sport events": "الأحداث الرياضية المتعددة في 1991",
    "1992 in multi-sport events": "الأحداث الرياضية المتعددة في 1992",
    "1993 in multi-sport events": "الأحداث الرياضية المتعددة في 1993",
    "1994 in multi-sport events": "الأحداث الرياضية المتعددة في 1994",
    "1995 in multi-sport events": "الأحداث الرياضية المتعددة في 1995",
    "1996 in multi-sport events": "الأحداث الرياضية المتعددة في 1996",
    "1997 in multi-sport events": "الأحداث الرياضية المتعددة في 1997",
    "1998 in multi-sport events": "الأحداث الرياضية المتعددة في 1998",
    "1999 in multi-sport events": "الأحداث الرياضية المتعددة في 1999",
    "2000 in multi-sport events": "الأحداث الرياضية المتعددة في 2000",
    "2001 in multi-sport events": "الأحداث الرياضية المتعددة في 2001",
    "2002 in multi-sport events": "الأحداث الرياضية المتعددة في 2002",
    "2003 in multi-sport events": "الأحداث الرياضية المتعددة في 2003",
    "2004 in multi-sport events": "الأحداث الرياضية المتعددة في 2004",
    "2005 in multi-sport events": "الأحداث الرياضية المتعددة في 2005",
    "2006 in multi-sport events": "الأحداث الرياضية المتعددة في 2006",
    "2007 in multi-sport events": "الأحداث الرياضية المتعددة في 2007",
    "2008 in multi-sport events": "الأحداث الرياضية المتعددة في 2008",
    "2009 in multi-sport events": "الأحداث الرياضية المتعددة في 2009",
    "2010 in multi-sport events": "الأحداث الرياضية المتعددة في 2010",
    "2011 in multi-sport events": "الأحداث الرياضية المتعددة في 2011",
    "2012 in multi-sport events": "الأحداث الرياضية المتعددة في 2012",
    "2013 in multi-sport events": "الأحداث الرياضية المتعددة في 2013",
    "2014 in multi-sport events": "الأحداث الرياضية المتعددة في 2014",
    "2015 in multi-sport events": "الأحداث الرياضية المتعددة في 2015",
    "2016 in multi-sport events": "الأحداث الرياضية المتعددة في 2016",
    "2017 in multi-sport events": "الأحداث الرياضية المتعددة في 2017",
    "2018 in multi-sport events": "الأحداث الرياضية المتعددة في 2018",
    "2019 in multi-sport events": "الأحداث الرياضية المتعددة في 2019",
    "2020 in multi-sport events": "الأحداث الرياضية المتعددة في 2020",
    "2021 in multi-sport events": "الأحداث الرياضية المتعددة في 2021",
    "2022 in multi-sport events": "الأحداث الرياضية المتعددة في 2022",
    "2024 in multi-sport events": "الأحداث الرياضية المتعددة في 2024",
    "2025 in multi-sport events": "الأحداث الرياضية المتعددة في 2025",
    "2026 in multi-sport events": "الأحداث الرياضية المتعددة في 2026",
    "2028 in multi-sport events": "الأحداث الرياضية المتعددة في 2028",
}


data_1 = {
    "Competitors at multi-sport events by country": "منافسون في أحداث رياضية متعددة حسب البلد",
    "Competitors at multi-sport events by sport": "منافسون في أحداث رياضية متعددة حسب الرياضة",
    "Competitors at multi-sport events by year": "منافسون في أحداث رياضية متعددة حسب السنة",
    "Medalists at multi-sport events by year": "فائزون بميداليات في أحداث رياضية متعددة حسب السنة",
    "Nations at multi-sport events by country": "بلدان في أحداث رياضية متعددة حسب البلد",
    "Albania at winter multi-sport events": "ألبانيا في أحداث رياضية متعددة شتوية",
    "Algeria at winter multi-sport events": "الجزائر في أحداث رياضية متعددة شتوية",
    "American Samoa at winter multi-sport events": "ساموا الأمريكية في أحداث رياضية متعددة شتوية",
    "Argentina at winter multi-sport events": "الأرجنتين في أحداث رياضية متعددة شتوية",
    "Australia at winter multi-sport events": "أستراليا في أحداث رياضية متعددة شتوية",
    "Austria at winter multi-sport events": "النمسا في أحداث رياضية متعددة شتوية",
    "Brazil at winter multi-sport events": "البرازيل في أحداث رياضية متعددة شتوية",
    "Canada at winter multi-sport events": "كندا في أحداث رياضية متعددة شتوية",
    "China at winter multi-sport events": "الصين في أحداث رياضية متعددة شتوية",
    "Czech Republic at winter multi-sport events": "التشيك في أحداث رياضية متعددة شتوية",
    "East Germany at winter multi-sport events": "ألمانيا الشرقية في أحداث رياضية متعددة شتوية",
    "France at winter multi-sport events": "فرنسا في أحداث رياضية متعددة شتوية",
    "Germany at winter multi-sport events": "ألمانيا في أحداث رياضية متعددة شتوية",
    "Hong Kong at winter multi-sport events": "هونغ كونغ في أحداث رياضية متعددة شتوية",
    "India at winter multi-sport events": "الهند في أحداث رياضية متعددة شتوية",
    "Iran at winter multi-sport events": "إيران في أحداث رياضية متعددة شتوية",
    "Israel at winter multi-sport events": "إسرائيل في أحداث رياضية متعددة شتوية",
    "Italy at winter multi-sport events": "إيطاليا في أحداث رياضية متعددة شتوية",
    "Japan at winter multi-sport events": "اليابان في أحداث رياضية متعددة شتوية",
    "Kazakhstan at winter multi-sport events": "كازاخستان في أحداث رياضية متعددة شتوية",
    "Kyrgyzstan at winter multi-sport events": "قيرغيزستان في أحداث رياضية متعددة شتوية",
    "Lebanon at winter multi-sport events": "لبنان في أحداث رياضية متعددة شتوية",
    "Lithuania at winter multi-sport events": "ليتوانيا في أحداث رياضية متعددة شتوية",
    "Malaysia at winter multi-sport events": "ماليزيا في أحداث رياضية متعددة شتوية",
    "Mongolia at winter multi-sport events": "منغوليا في أحداث رياضية متعددة شتوية",
    "Multi-sport events": "أحداث رياضية متعددة",
    "Multi-sport events-related lists": "قوائم متعلقة بأحداث رياضية متعددة",
    "Multi-sport events bids": "ترشيحات أحداث رياضية متعددة",
    "Multi-sport events by country": "أحداث رياضية متعددة حسب البلد",
    "Multi-sport events by year": "أحداث رياضية متعددة حسب السنة",
    "Multi-sport events cancelled due to the COVID-19 pandemic": "أحداث رياضية متعددة ألغيت بسبب جائحة فيروس كورونا",
    "Multi-sport events in Africa by country": "أحداث رياضية متعددة في إفريقيا حسب البلد",
    "Multi-sport events in Andorra": "أحداث رياضية متعددة في أندورا",
    "Multi-sport events in Argentina": "أحداث رياضية متعددة في الأرجنتين",
    "Multi-sport events in Asia": "أحداث رياضية متعددة في آسيا",
    "Multi-sport events in Asia by country": "أحداث رياضية متعددة في آسيا حسب البلد",
    "Multi-sport events in Australia": "أحداث رياضية متعددة في أستراليا",
    "Multi-sport events in Austria": "أحداث رياضية متعددة في النمسا",
    "Multi-sport events in Azerbaijan": "أحداث رياضية متعددة في أذربيجان",
    "Multi-sport events in Bahrain": "أحداث رياضية متعددة في البحرين",
    "Multi-sport events in Belgium": "أحداث رياضية متعددة في بلجيكا",
    "Multi-sport events in Bolivia": "أحداث رياضية متعددة في بوليفيا",
    "Multi-sport events in Brazil": "أحداث رياضية متعددة في البرازيل",
    "Multi-sport events in Bulgaria": "أحداث رياضية متعددة في بلغاريا",
    "Multi-sport events in Canada": "أحداث رياضية متعددة في كندا",
    "Multi-sport events in Chile": "أحداث رياضية متعددة في تشيلي",
    "Multi-sport events in China": "أحداث رياضية متعددة في الصين",
    "Multi-sport events in Colombia": "أحداث رياضية متعددة في كولومبيا",
    "Multi-sport events in Croatia": "أحداث رياضية متعددة في كرواتيا",
    "Multi-sport events in Cuba": "أحداث رياضية متعددة في كوبا",
    "Multi-sport events in Cyprus": "أحداث رياضية متعددة في قبرص",
    "Multi-sport events in Czechoslovakia": "أحداث رياضية متعددة في تشيكوسلوفاكيا",
    "Multi-sport events in Denmark": "أحداث رياضية متعددة في الدنمارك",
    "Multi-sport events in East Germany": "أحداث رياضية متعددة في ألمانيا الشرقية",
    "Multi-sport events in Ecuador": "أحداث رياضية متعددة في الإكوادور",
    "Multi-sport events in El Salvador": "أحداث رياضية متعددة في السلفادور",
    "Multi-sport events in Europe": "أحداث رياضية متعددة في أوروبا",
    "Multi-sport events in Europe by country": "أحداث رياضية متعددة في أوروبا حسب البلد",
    "Multi-sport events in Finland": "أحداث رياضية متعددة في فنلندا",
    "Multi-sport events in France": "أحداث رياضية متعددة في فرنسا",
    "Multi-sport events in Germany": "أحداث رياضية متعددة في ألمانيا",
    "Multi-sport events in Greece": "أحداث رياضية متعددة في اليونان",
    "Multi-sport events in Hungary": "أحداث رياضية متعددة في المجر",
    "Multi-sport events in Iceland": "أحداث رياضية متعددة في آيسلندا",
    "Multi-sport events in India": "أحداث رياضية متعددة في الهند",
    "Multi-sport events in Indonesia": "أحداث رياضية متعددة في إندونيسيا",
    "Multi-sport events in insular areas of the United States": "أحداث رياضية متعددة في المناطق المعزولة في الولايات المتحدة",
    "Multi-sport events in Iran": "أحداث رياضية متعددة في إيران",
    "Multi-sport events in Israel": "أحداث رياضية متعددة في إسرائيل",
    "Multi-sport events in Italy": "أحداث رياضية متعددة في إيطاليا",
    "Multi-sport events in Jamaica": "أحداث رياضية متعددة في جامايكا",
    "Multi-sport events in Japan": "أحداث رياضية متعددة في اليابان",
    "Multi-sport events in Jordan": "أحداث رياضية متعددة في الأردن",
    "Multi-sport events in Kazakhstan": "أحداث رياضية متعددة في كازاخستان",
    "Multi-sport events in Kenya": "أحداث رياضية متعددة في كينيا",
    "Multi-sport events in Kuwait": "أحداث رياضية متعددة في الكويت",
    "Multi-sport events in Lebanon": "أحداث رياضية متعددة في لبنان",
    "Multi-sport events in Liechtenstein": "أحداث رياضية متعددة في ليختنشتاين",
    "Multi-sport events in Luxembourg": "أحداث رياضية متعددة في لوكسمبورغ",
    "Multi-sport events in Macau": "أحداث رياضية متعددة في ماكاو",
    "Multi-sport events in Malaysia": "أحداث رياضية متعددة في ماليزيا",
    "Multi-sport events in Malta": "أحداث رياضية متعددة في مالطا",
    "Multi-sport events in Mexico": "أحداث رياضية متعددة في المكسيك",
    "Multi-sport events in Monaco": "أحداث رياضية متعددة في موناكو",
    "Multi-sport events in Mongolia": "أحداث رياضية متعددة في منغوليا",
    "Multi-sport events in Montenegro": "أحداث رياضية متعددة في الجبل الأسود",
    "Multi-sport events in Mozambique": "أحداث رياضية متعددة في موزمبيق",
    "Multi-sport events in New Zealand": "أحداث رياضية متعددة في نيوزيلندا",
    "Multi-sport events in Nigeria": "أحداث رياضية متعددة في نيجيريا",
    "Multi-sport events in North America": "أحداث رياضية متعددة في أمريكا الشمالية",
    "Multi-sport events in North Korea": "أحداث رياضية متعددة في كوريا الشمالية",
    "Multi-sport events in Norway": "أحداث رياضية متعددة في النرويج",
    "Multi-sport events in Oceania": "أحداث رياضية متعددة في أوقيانوسيا",
    "Multi-sport events in Oman": "أحداث رياضية متعددة في سلطنة عمان",
    "Multi-sport events in Panama": "أحداث رياضية متعددة في بنما",
    "Multi-sport events in Peru": "أحداث رياضية متعددة في بيرو",
    "Multi-sport events in Poland": "أحداث رياضية متعددة في بولندا",
    "Multi-sport events in Puerto Rico": "أحداث رياضية متعددة في بورتوريكو",
    "Multi-sport events in Qatar": "أحداث رياضية متعددة في قطر",
    "Multi-sport events in Romania": "أحداث رياضية متعددة في رومانيا",
    "Multi-sport events in Russia": "أحداث رياضية متعددة في روسيا",
    "Multi-sport events in Samoa": "أحداث رياضية متعددة في ساموا",
    "Multi-sport events in San Marino": "أحداث رياضية متعددة في سان مارينو",
    "Multi-sport events in Serbia": "أحداث رياضية متعددة في صربيا",
    "Multi-sport events in Singapore": "أحداث رياضية متعددة في سنغافورة",
    "Multi-sport events in Slovakia": "أحداث رياضية متعددة في سلوفاكيا",
    "Multi-sport events in South America": "أحداث رياضية متعددة في أمريكا الجنوبية",
    "Multi-sport events in South Korea": "أحداث رياضية متعددة في كوريا الجنوبية",
    "Multi-sport events in Spain": "أحداث رياضية متعددة في إسبانيا",
    "Multi-sport events in Sweden": "أحداث رياضية متعددة في السويد",
    "Multi-sport events in Switzerland": "أحداث رياضية متعددة في سويسرا",
    "Multi-sport events in Syria": "أحداث رياضية متعددة في سوريا",
    "Multi-sport events in Taiwan": "أحداث رياضية متعددة في تايوان",
    "Multi-sport events in Thailand": "أحداث رياضية متعددة في تايلاند",
    "Multi-sport events in the Netherlands": "أحداث رياضية متعددة في هولندا",
    "Multi-sport events in the Republic of the Congo": "أحداث رياضية متعددة في جمهورية الكونغو",
    "Multi-sport events in the Soviet Union": "أحداث رياضية متعددة في الاتحاد السوفيتي",
    "Multi-sport events in the United Kingdom": "أحداث رياضية متعددة في المملكة المتحدة",
    "Multi-sport events in the United States": "أحداث رياضية متعددة في الولايات المتحدة",
    "Multi-sport events in Turkey": "أحداث رياضية متعددة في تركيا",
    "Multi-sport events in Turkmenistan": "أحداث رياضية متعددة في تركمانستان",
    "Multi-sport events in Venezuela": "أحداث رياضية متعددة في فنزويلا",
    "Multi-sport events in Vietnam": "أحداث رياضية متعددة في فيتنام",
    "Multi-sport events in West Germany": "أحداث رياضية متعددة في ألمانيا الغربية",
    "Multi-sport events in Yugoslavia": "أحداث رياضية متعددة في يوغسلافيا",
    "Multi-sport events in Zimbabwe": "أحداث رياضية متعددة في زيمبابوي",
    "Multi-sport events templates": "قوالب أحداث رياضية متعددة",
    "Multi-sport events venues": "ملاعب أحداث رياضية متعددة",
    "National multi-sport events": "أحداث رياضية متعددة وطنية",
    "Nations at winter multi-sport events": "بلدان في أحداث رياضية متعددة شتوية",
    "Nepal at winter multi-sport events": "نيبال في أحداث رياضية متعددة شتوية",
    "New Zealand at winter multi-sport events": "نيوزيلندا في أحداث رياضية متعددة شتوية",
    "North Korea at winter multi-sport events": "كوريا الشمالية في أحداث رياضية متعددة شتوية",
    "Pakistan at winter multi-sport events": "باكستان في أحداث رياضية متعددة شتوية",
    "Philippines at winter multi-sport events": "الفلبين في أحداث رياضية متعددة شتوية",
    "Singapore at winter multi-sport events": "سنغافورة في أحداث رياضية متعددة شتوية",
    "South Korea at winter multi-sport events": "كوريا الجنوبية في أحداث رياضية متعددة شتوية",
    "Spain at winter multi-sport events": "إسبانيا في أحداث رياضية متعددة شتوية",
    "Summer multi-sport events": "أحداث رياضية متعددة صيفية",
    "Tajikistan at winter multi-sport events": "طاجيكستان في أحداث رياضية متعددة شتوية",
    "Thailand at winter multi-sport events": "تايلاند في أحداث رياضية متعددة شتوية",
    "Turkey at winter multi-sport events": "تركيا في أحداث رياضية متعددة شتوية",
    "Ukraine at winter multi-sport events": "أوكرانيا في أحداث رياضية متعددة شتوية",
    "United States at winter multi-sport events": "الولايات المتحدة في أحداث رياضية متعددة شتوية",
    "Uzbekistan at winter multi-sport events": "أوزبكستان في أحداث رياضية متعددة شتوية",
    "West Germany at winter multi-sport events": "ألمانيا الغربية في أحداث رياضية متعددة شتوية",
    "Winter multi-sport events by country": "أحداث رياضية متعددة شتوية حسب البلد",
    "Winter multi-sport events in Germany": "أحداث رياضية متعددة شتوية في ألمانيا",
    "Winter multi-sport events in Norway": "أحداث رياضية متعددة شتوية في النرويج",
    "Winter multi-sport events in Russia": "أحداث رياضية متعددة شتوية في روسيا",
    "Winter multi-sport events in the United States": "أحداث رياضية متعددة شتوية في الولايات المتحدة",
    "Multi-sport clubs in Egypt": "أندية متعددة الرياضات في مصر",
    "Multi-sport clubs in Finland": "أندية متعددة الرياضات في فنلندا",
    "Multi-sport clubs in France": "أندية متعددة الرياضات في فرنسا",
    "Multi-sport clubs in Germany": "أندية متعددة الرياضات في ألمانيا",
    "Multi-sport clubs in Greece": "أندية متعددة الرياضات في اليونان",
    "Multi-sport clubs in Iceland": "أندية متعددة الرياضات في آيسلندا",
    "Multi-sport clubs in India": "أندية متعددة الرياضات في الهند",
    "Soviet Union at multi-sport events": "الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Swaziland at multi-sport events": "سوازيلاند في الأحداث الرياضية المتعددة",
    "Wheelchair tennis at multi-sport events": "كرة المضرب على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "soviet union in multi-sport events": "الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Afghanistan at multi-sport events": "أفغانستان في الأحداث الرياضية المتعددة",
    "Algeria at multi-sport events": "الجزائر في الأحداث الرياضية المتعددة",
    "Angola at multi-sport events": "أنغولا في الأحداث الرياضية المتعددة",
    "Antigua and Barbuda at multi-sport events": "أنتيغوا وباربودا في الأحداث الرياضية المتعددة",
    "Bahamas at multi-sport events": "باهاماس في الأحداث الرياضية المتعددة",
    "Bahrain at multi-sport events": "البحرين في الأحداث الرياضية المتعددة",
    "Barbados at multi-sport events": "بربادوس في الأحداث الرياضية المتعددة",
    "Belarus at multi-sport events": "روسيا البيضاء في الأحداث الرياضية المتعددة",
    "Belize at multi-sport events": "بليز في الأحداث الرياضية المتعددة",
    "Benin at multi-sport events": "بنين في الأحداث الرياضية المتعددة",
    "Bermuda at multi-sport events": "برمودا في الأحداث الرياضية المتعددة",
    "Bhutan at multi-sport events": "بوتان في الأحداث الرياضية المتعددة",
    "Burkina Faso at multi-sport events": "بوركينا فاسو في الأحداث الرياضية المتعددة",
    "Burundi at multi-sport events": "بوروندي في الأحداث الرياضية المتعددة",
    "Cambodia at multi-sport events": "كمبوديا في الأحداث الرياضية المتعددة",
    "Cameroon at multi-sport events": "الكاميرون في الأحداث الرياضية المتعددة",
    "Cape Verde at multi-sport events": "الرأس الأخضر في الأحداث الرياضية المتعددة",
    "Central African Republic at multi-sport events": "جمهورية إفريقيا الوسطى في الأحداث الرياضية المتعددة",
    "Chad at multi-sport events": "تشاد في الأحداث الرياضية المتعددة",
    "Chess at multi-sport events": "الشطرنج في الأحداث الرياضية المتعددة",
    "Comoros at multi-sport events": "جزر القمر في الأحداث الرياضية المتعددة",
    "Competitors at multi-sport events": "منافسون في الأحداث الرياضية المتعددة",
    "Czech Republic at multi-sport events": "التشيك في الأحداث الرياضية المتعددة",
    "Dependent territories of the United Kingdom at multi-sport events": "أقاليم ما وراء البحار البريطانية في الأحداث الرياضية المتعددة",
    "Djibouti at multi-sport events": "جيبوتي في الأحداث الرياضية المتعددة",
    "Dominica at multi-sport events": "دومينيكا في الأحداث الرياضية المتعددة",
    "Dominican Republic at multi-sport events": "جمهورية الدومينيكان في الأحداث الرياضية المتعددة",
    "Egypt at multi-sport events": "مصر في الأحداث الرياضية المتعددة",
    "Equatorial Guinea at multi-sport events": "غينيا الاستوائية في الأحداث الرياضية المتعددة",
    "Equestrian sports at multi-sport events": "رياضات فروسية في الأحداث الرياضية المتعددة",
    "Eritrea at multi-sport events": "إرتريا في الأحداث الرياضية المتعددة",
    "Eswatini at multi-sport events": "إسواتيني في الأحداث الرياضية المتعددة",
    "Ethiopia at multi-sport events": "إثيوبيا في الأحداث الرياضية المتعددة",
    "Fiji at multi-sport events": "فيجي في الأحداث الرياضية المتعددة",
    "Gabon at multi-sport events": "الغابون في الأحداث الرياضية المتعددة",
    "Ghana at multi-sport events": "غانا في الأحداث الرياضية المتعددة",
    "Gibraltar at multi-sport events": "جبل طارق في الأحداث الرياضية المتعددة",
    "Go at multi-sport events": "غو في الأحداث الرياضية المتعددة",
    "Grenada at multi-sport events": "غرينادا في الأحداث الرياضية المتعددة",
    "Guinea-Bissau at multi-sport events": "غينيا بيساو في الأحداث الرياضية المتعددة",
    "Guinea at multi-sport events": "غينيا في الأحداث الرياضية المتعددة",
    "Guyana at multi-sport events": "غيانا في الأحداث الرياضية المتعددة",
    "Haiti at multi-sport events": "هايتي في الأحداث الرياضية المتعددة",
    "Insular areas of the United States at multi-sport events": "المناطق المعزولة في الولايات المتحدة في الأحداث الرياضية المتعددة",
    "Iraq at multi-sport events": "العراق في الأحداث الرياضية المتعددة",
    "Ivory Coast at multi-sport events": "ساحل العاج في الأحداث الرياضية المتعددة",
    "Ju-jitsu at multi-sport events": "جوجوتسو في الأحداث الرياضية المتعددة",
    "Judo at multi-sport events": "الجودو في الأحداث الرياضية المتعددة",
    "Kiribati at multi-sport events": "كيريباتي في الأحداث الرياضية المتعددة",
    "Kosovo at multi-sport events": "كوسوفو في الأحداث الرياضية المتعددة",
    "Lesotho at multi-sport events": "ليسوتو في الأحداث الرياضية المتعددة",
    "Liberia at multi-sport events": "ليبيريا في الأحداث الرياضية المتعددة",
    "Libya at multi-sport events": "ليبيا في الأحداث الرياضية المتعددة",
    "Malawi at multi-sport events": "ملاوي في الأحداث الرياضية المتعددة",
    "Maldives at multi-sport events": "جزر المالديف في الأحداث الرياضية المتعددة",
    "Mali at multi-sport events": "مالي في الأحداث الرياضية المتعددة",
    "Marshall Islands at multi-sport events": "جزر مارشال في الأحداث الرياضية المتعددة",
    "Mauritania at multi-sport events": "موريتانيا في الأحداث الرياضية المتعددة",
    "Mauritius at multi-sport events": "موريشيوس في الأحداث الرياضية المتعددة",
    "Modern pentathlon at multi-sport events": "الخماسي الحديث في الأحداث الرياضية المتعددة",
    "Moldova at multi-sport events": "مولدوفا في الأحداث الرياضية المتعددة",
    "Morocco at multi-sport events": "المغرب في الأحداث الرياضية المتعددة",
    "Multi-sport events by continent": "أحداث رياضية متعددة حسب القارة",
    "Multi-sport events in Africa": "أحداث رياضية متعددة في إفريقيا",
    "Multi-sport events in Algeria": "أحداث رياضية متعددة في الجزائر",
    "Multi-sport events in Egypt": "أحداث رياضية متعددة في مصر",
    "Multi-sport events in Morocco": "أحداث رياضية متعددة في المغرب",
    "Multi-sport events in Saudi Arabia": "أحداث رياضية متعددة في السعودية",
    "Multi-sport events in Tunisia": "أحداث رياضية متعددة في تونس",
    "Multi-sport events navigational boxes": "صناديق تصفح أحداث رياضية متعددة",
    "Namibia at multi-sport events": "ناميبيا في الأحداث الرياضية المتعددة",
    "Nations at multi-sport events": "بلدان في الأحداث الرياضية المتعددة",
    "Netherlands Antilles at multi-sport events": "جزر الأنتيل الهولندية في الأحداث الرياضية المتعددة",
    "North Macedonia at multi-sport events": "مقدونيا الشمالية في الأحداث الرياضية المتعددة",
    "Palestine at multi-sport events": "فلسطين في الأحداث الرياضية المتعددة",
    "Papua New Guinea at multi-sport events": "بابوا غينيا الجديدة في الأحداث الرياضية المتعددة",
    "Paraguay at multi-sport events": "باراغواي في الأحداث الرياضية المتعددة",
    "Philippines at multi-sport events": "الفلبين في الأحداث الرياضية المتعددة",
    "Rwanda at multi-sport events": "رواندا في الأحداث الرياضية المتعددة",
    "Saint Kitts and Nevis at multi-sport events": "سانت كيتس ونيفيس في الأحداث الرياضية المتعددة",
    "Saint Lucia at multi-sport events": "سانت لوسيا في الأحداث الرياضية المتعددة",
    "Saint Vincent and the Grenadines at multi-sport events": "سانت فنسنت وجزر غرينادين في الأحداث الرياضية المتعددة",
    "Senegal at multi-sport events": "السنغال في الأحداث الرياضية المتعددة",
    "Seychelles at multi-sport events": "سيشل في الأحداث الرياضية المتعددة",
    "Skeleton at multi-sport events": "الزلاجات الصدرية في الأحداث الرياضية المتعددة",
    "Slovenia at multi-sport events": "سلوفينيا في الأحداث الرياضية المتعددة",
    "Snooker at multi-sport events": "السنوكر في الأحداث الرياضية المتعددة",
    "Solomon Islands at multi-sport events": "جزر سليمان في الأحداث الرياضية المتعددة",
    "Somalia at multi-sport events": "الصومال في الأحداث الرياضية المتعددة",
    "South Sudan at multi-sport events": "جنوب السودان في الأحداث الرياضية المتعددة",
    "Sport climbing at multi-sport events": "التسلق في الأحداث الرياضية المتعددة",
    "Sudan at multi-sport events": "السودان في الأحداث الرياضية المتعددة",
    "Surfing at multi-sport events": "الركمجة في الأحداث الرياضية المتعددة",
    "Suriname at multi-sport events": "سورينام في الأحداث الرياضية المتعددة",
    "São Tomé and Príncipe at multi-sport events": "ساو تومي وبرينسيب في الأحداث الرياضية المتعددة",
    "Tanzania at multi-sport events": "تنزانيا في الأحداث الرياضية المتعددة",
    "Tennis at multi-sport events": "كرة المضرب في الأحداث الرياضية المتعددة",
    "The Gambia at multi-sport events": "غامبيا في الأحداث الرياضية المتعددة",
    "Togo at multi-sport events": "توغو في الأحداث الرياضية المتعددة",
    "Tonga at multi-sport events": "تونغا في الأحداث الرياضية المتعددة",
    "Trinidad and Tobago at multi-sport events": "ترينيداد وتوباغو في الأحداث الرياضية المتعددة",
    "Tunisia at multi-sport events": "تونس في الأحداث الرياضية المتعددة",
    "Tuvalu at multi-sport events": "توفالو في الأحداث الرياضية المتعددة",
    "Uganda at multi-sport events": "أوغندا في الأحداث الرياضية المتعددة",
    "Ukraine at multi-sport events": "أوكرانيا في الأحداث الرياضية المتعددة",
    "United Arab Emirates at multi-sport events": "الإمارات العربية المتحدة في الأحداث الرياضية المتعددة",
    "Vanuatu at multi-sport events": "فانواتو في الأحداث الرياضية المتعددة",
    "Wheelchair basketball at multi-sport events": "كرة السلة على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "Winter multi-sport events": "أحداث رياضية متعددة شتوية",
    "Winter multi-sport events in Austria": "أحداث رياضية متعددة شتوية في النمسا",
    "Winter multi-sport events in Canada": "أحداث رياضية متعددة شتوية في كندا",
    "Xiangqi at multi-sport events": "الشطرنج الصيني في الأحداث الرياضية المتعددة",
}

to_test = [
    ("test_multi_sport_0", data_0),
    ("test_multi_sport_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_multi_sport_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
