#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

empty_data = {
    "Abandoned military aircraft projects of Russia": "",
    "Abandoned military projects of Russia": "",
    "Academicians of the National Academy of Motion Picture Arts and Sciences of Russia": "",
    "Academic staff of the D. Mendeleev University of Chemical Technology of Russia": "",
    "Academic staff of the Peoples' Friendship University of Russia": "",
    "Academies of Russia": "",
    "Acting heads of the federal subjects of Russia": "",
    "Administrative divisions of Russia": "",
    "Administrative divisions of the federal subjects of Russia": "",
    "Advisers to the president of Russia": "",
    "Aerial bombs of Russia": "",
    "Aerospace companieszz of Russia": "",
    "Agricultural machinery manufacturers of Russia": "",
    "Aides to the president of Russia": "",
    "Airborne divisions of Russia": "",
    "Airborne infantry brigades of Russia": "",
    "Airborne units and formations of Russia": "",
    "Aircraft engine manufacturers of Russia": "",
    "Aircraft industry of Russia": "",
    "Aircraft manufacturers of Russia": "",
    "Air guns of Russia": "",
    "Airport operators of Russia": "",
    "Airships of Russia": "",
    "Air-to-air missile manufacturers of Russia": "",
    "Air-to-air missiles of Russia": "",
    "Air-to-surface missiles of Russia": "",
    "Alexis of Russia": "",
    "Amendments to the Constitution of Russia": "",
    "Ancient peoples of Russia": "",
    "Anna of Russia": "",
    "Anti-aircraft weapons of Russia": "",
    "Anti-ballistic missiles of Russia": "",
    "Anti-ship cruise missiles of Russia": "",
    "Anti-ship missiles of Russia": "",
    "Anti-submarine missiles of Russia": "",
    "Anti-tank guided missiles of Russia": "",
    "Armoured fighting vehicles of Russia": "",
    "Armoured personnel carriers of Russia": "",
    "Armoured units and formations of Russia": "",
    "Arms industry of Russia": "",
    "Arms trading companieszz of Russia": "",
    "Army training units and formations of Russia": "",
    "Army units and formations of Russia": "",
    "Artillery units and formations of Russia": "",
    "Assault rifles of Russia": "",
    "Audio equipment manufacturers of Russia": "",
    "Autonomous okrugs of Russia": "",
    "Auto parts suppliers of Russia": "",
    "Aviation history of Russia": "",
    "Ballistic missiles of Russia": "",
    "Barges of Russia": "",
    "Battalions of Russia": "",
    "Bilateral sports relations of Russia": "",
    "Bilateral treaties of Russia": "",
    "Biosphere reserves of Russia": "",
    "Bishops of the Russian Orthodox Church Outside of Russia": "",
    "Bolt-action rifles of Russia": "",
    "Book publishing companieszz of Russia": "",
    "Books by publishing company of Russia": "",
    "Bookstores of Russia": "",
    "Boycotts of Russia": "",
    "Brigades of Russia": "",
    "Bullion coins of Russia": "",
    "Buses of Russia": "",
    "Cable television companieszz of Russia": "",
    "Calderas of Russia": "",
    "Capitals of republics of Russia": "",
    "Car manufacturers of Russia": "",
    "Categories by federal subject of Russia": "",
    "Central Bank of Russia": "",
    "Ceramics manufacturers of Russia": "",
    "Chief Muftis of Russia": "",
    "Chief rabbis of Russia": "",
    "Circassian people of Russia": "",
    "City districts of Russia": "",
    "Client states of Russia": "",
    "Climbing areas of Russia": "",
    "Clothing brands of Russia": "",
    "Coins of Russia": "",
    "Combat helmets of Russia": "",
    "Comic book publishing companieszz of Russia": "",
    "Communications satellites of Russia": "",
    "Concert tours of Russia": "",
    "Constitutional history of Russia": "",
    "Constitutions and charters of federal subjects of Russia": "",
    "Construction equipment manufacturers of Russia": "",
    "Continental shelves of Russia": "",
    "Copper mining companieszz of Russia": "",
    "Corps of Russia": "",
    "Country data templates of former subdivisions of Russia": "",
    "Country data templates of Russia": "",
    "Country data templates of subdivisions of Russia": "",
    "Court of Elizabeth of Russia": "",
    "Crewed space program of Russia": "",
    "Cruise missiles of Russia": "",
    "Cultural heritage of Russia": "",
    "Defunct aircraft manufacturers of Russia": "",
    "Defunct diplomatic missions of Russia": "",
    "Defunct federal ministries of Russia": "",
    "Defunct government agencies of Russia": "",
    "Defunct law enforcement agencies of Russia": "",
    "Defunct motorcycle manufacturers of Russia": "",
    "Department stores of Russia": "",
    "Deputy defence ministers of Russia": "",
    "Deputy foreign ministers of Russia": "",
    "Deputy ministers of Russia": "",
    "Diatremes of Russia": "",
    "Diesel–electric locomotives of Russia": "",
    "Diesel locomotives of Russia": "",
    "Diesel multiple units of Russia": "",
    "Divisions of Russia": "",
    "D. Mendeleev University of Chemical Technology of Russia": "",
    "Double-barreled shotguns of Russia": "",
    "Earth observation satellites of Russia": "",
    "Economic regions of Russia": "",
    "Electric locomotives of Russia": "",
    "Electric multiple units of Russia": "",
    "Electric vehicle manufacturers of Russia": "",
    "Emperors of Russia": "",
    "Empresses consort of Russia": "",
    "Empresses of Russia": "",
    "Empresses regnant of Russia": "",
    "Endemic birds of Russia": "",
    "Endemic fauna of Russia": "",
    "Endemic flora of Russia": "",
    "Energy policy of Russia": "",
    "Engine manufacturers of Russia": "",
    "Estuaries of Russia": "",
    "Eurovision songs of Russia": "",
    "Event management companieszz of Russia": "",
    "Extinct animals of Russia": "",
    "Extreme points of Russia": "",
    "Federal cities of Russia": "",
    "Federal districts of Russia": "",
    "Federal executive bodies of Russia": "",
    "Federal law enforcement agencies of Russia": "",
    "Federal ministries of Russia": "",
    "Federal State Unitary Enterprises of Russia": "",
    "Ferns of Russia": "",
    "Ferry companieszz of Russia": "",
    "Fertilizer companieszz of Russia": "",
    "Field marshals of Russia": "",
    "Film production companieszz of Russia": "",
    "Financial regulatory authorities of Russia": "",
    "Firearm manufacturers of Russia": "",
    "Firearms of Russia": "",
    "Fjords of Russia": "",
    "Food provision ministers of Russia": "",
    "Food retailers of Russia": "",
    "Foreign trade of Russia": "",
    "Former administrative units of Russia": "",
    "Former federal subjects of Russia": "",
    "Former islands of Russia": "",
    "Former subdivisions of Russia": "",
    "Fossils of Russia": "",
    "Geologic formations of Russia": "",
    "Geologic history of Russia": "",
    "Geysers of Russia": "",
    "Glacial lakes of Russia": "",
    "Gold mining companieszz of Russia": "",
    "Government-owned banks of Russia": "",
    "Government spokespersons of Russia": "",
    "Governors of the Central Bank of Russia": "",
    "Grand duchesses of Russia": "",
    "Grand dukes of Russia": "",
    "Grasses of Russia": "",
    "Grenade launchers of Russia": "",
    "Guided missiles of Russia": "",
    "Heads of former federal subjects of Russia": "",
    "Heavy machine guns of Russia": "",
    "Helicopter manufacturers of Russia": "",
    "Helicopter regiments of Russia": "",
    "High-speed trains of Russia": "",
    "Historical ethnic groups of Russia": "",
    "Historical geography of Russia": "",
    "History of the administrative divisions of Russia": "",
    "Home appliance manufacturers of Russia": "",
    "Honorary titles of Russia": "",
    "Howitzers of Russia": "",
    "Hydroelectric power companieszz of Russia": "",
    "Icebreakers of Russia": "",
    "Ice caps of Russia": "",
    "Identified objects of cultural heritage of Russia": "",
    "Impact craters of Russia": "",
    "Important Bird Areas of Russia": "",
    "Independent Psychiatric Association of Russia": "",
    "Indigenous languages of Russia": "",
    "Infantry brigades of Russia": "",
    "Infantry divisions of Russia": "",
    "Infantry fighting vehicles of Russia": "",
    "Infantry units and formations of Russia": "",
    "Information technology consulting firms of Russia": "",
    "Intercontinental ballistic missiles of Russia": "",
    "Intermediate-range ballistic missiles of Russia": "",
    "Internet technology companieszz of Russia": "",
    "Investment management companieszz of Russia": "",
    "Isthmuses of Russia": "",
    "Judges of the Constitutional Court of Russia": "",
    "Krais of Russia": "",
    "Krivak-class frigates of the Border Guard Service of Russia": "",
    "Lagoons of Russia": "",
    "Lake groups of Russia": "",
    "Lake islands of Russia": "",
    "Land cultivation ministers of Russia": "",
    "Law enforcement agencies of the republics of Russia": "",
    "Liberal Democratic Party of Russia": "",
    "Light tanks of Russia": "",
    "Liquefied natural gas plants of Russia": "",
    "Lists of commemorative coins of Russia": "",
    "Lists of moths of Russia": "",
    "Lithostratigraphy of Russia": "",
    "Locomotives of Russia": "",
    "Lost submarines of Russia": "",
    "Machine guns of Russia": "",
    "Main battle tanks of Russia": "",
    "Maps of Russia": "",
    "Mechanical engineering companieszz of Russia": "",
    "Mechanised infantry brigades of Russia": "",
    "Medical technology companieszz of Russia": "",
    "Medieval history of Russia": "",
    "Members of the Supreme Soviet of Russia": "",
    "Merchant ships of Russia": "",
    "Metallurgical industry of Russia": "",
    "Metropolitan areas of Russia": "",
    "Military aircraft procurement programs of Russia": "",
    "Military awards and decorations of Russia": "",
    "Military electronics of Russia": "",
    "Military locations of Russia": "",
    "Military satellites of Russia": "",
    "Military vehicles of Russia": "",
    "Model manufacturers of Russia": "",
    "Modern anti-tank rockets of Russia": "",
    "Modern incendiary weapons of Russia": "",
    "Modern military equipment of Russia": "",
    "Modern thermobaric weapons of Russia": "",
    "Monasteries of the Russian Orthodox Church Outside of Russia": "",
    "Monitors of Russia": "",
    "Motorcycle manufacturers of Russia": "",
    "Motorcycles of Russia": "",
    "Multilateral relations of Russia": "",
    "Multiple units of Russia": "",
    "Municipal districts of Russia": "",
    "Municipal divisions of the federal subjects of Russia": "",
    "Museums-Reserves of Russia": "",
    "Musical instrument manufacturing companieszz of Russia": "",
    "Named passenger trains of Russia": "",
    "Nanotechnology companieszz of Russia": "",
    "National orchestras of Russia": "",
    "Natural monuments of Russia": "",
    "Natural Resources and environment ministers of Russia": "",
    "Naval guns of Russia": "",
    "Naval infantry brigades of Russia": "",
    "Naval weapons of Russia": "",
    "Navigation satellites of Russia": "",
    "Nicholas I of Russia": "",
    "Night trains of Russia": "",
    "Noble titles of Russia": "",
    "Non-lethal firearms of Russia": "",
    "Nuclear cruise missiles of Russia": "",
    "Nuclear power companieszz of Russia": "",
    "Nuclear technology companieszz of Russia": "",
    "Nuclear weapons program of Russia": "",
    "Oblasts of Russia": "",
    "Online companieszz of Russia": "",
    "Online dating services of Russia": "",
    "Online financial services companieszz of Russia": "",
    "Online gambling companieszz of Russia": "",
    "Online marketplaces of Russia": "",
    "Online music stores of Russia": "",
    "Online retailers of Russia": "",
    "Optics manufacturing companieszz of Russia": "",
    "Orchids of Russia": "",
    "Orders of chivalry of Russia": "",
    "Pacific Coast of Russia": "",
    "Parties affiliated with the Liberal Democratic Party of Russia": "",
    "People's Artists of Russia": "",
    "Peoples' Friendship University of Russia": "",
    "Philately of Russia": "",
    "Photography companieszz of Russia": "",
    "Photography equipment manufacturers of Russia": "",
    "Pistols of Russia": "",
    "Political divisions of Russia": "",
    "Political families of Russia": "",
    "Postage stamps of Russia": "",
    "Postal history of Russia": "",
    "Postal system of Russia": "",
    "Post–Cold War weapons of Russia": "",
    "Presidential Administration of Russia": "",
    "Presidents of the Constitutional Court of Russia": "",
    "Presidents of the Handball Union of Russia": "",
    "Priests of the Russian Orthodox Church Outside of Russia": "",
    "Private equity firms of Russia": "",
    "Proposed aircraft of Russia": "",
    "Proposed military aircraft of Russia": "",
    "Prosecutors-general of Russia": "",
    "Railcars of Russia": "",
    "Rail transport navigational boxes of Russia": "",
    "Rail vehicle manufacturers of Russia": "",
    "Railway coaches of Russia": "",
    "Reconnaissance satellites of Russia": "",
    "Regalia of Russia": "",
    "Regents of Russia": "",
    "Republics of Russia": "",
    "Research vessels of Russia": "",
    "Revolvers of Russia": "",
    "Rifles of Russia": "",
    "River islands of Russia": "",
    "Road-inaccessible communities of Russia": "",
    "Robots of Russia": "",
    "Rocket divisions of Russia": "",
    "Rocket engine manufacturers of Russia": "",
    "Rocket-propelled grenade launchers of Russia": "",
    "Rural settlements of Russia": "",
    "Russian Orthodox Church Outside of Russia": "",
    "Russo-Japanese War battleships of Russia": "",
    "Russo-Japanese War cruisers of Russia": "",
    "Russo-Japanese War naval ships of Russia": "",
    "Russo-Japanese war weapons of Russia": "",
    "Sacred lakes of Russia": "",
    "Sberbank of Russia": "",
    "Sedimentary basins of Russia": "",
    "Self-propelled anti-aircraft weapons of Russia": "",
    "Self-propelled artillery of Russia": "",
    "Semi-automatic pistols of Russia": "",
    "Semi-automatic rifles of Russia": "",
    "Semi-automatic shotguns of Russia": "",
    "Semiconductor companieszz of Russia": "",
    "Shield volcanoes of Russia": "",
    "Ships of the Border Guard Service of Russia": "",
    "Ships of the line of Russia": "",
    "Shotguns of Russia": "",
    "Single-shot shotguns of Russia": "",
    "Sniper rifles of Russia": "",
    "Sounding rockets of Russia": "",
    "Space industry companieszz of Russia": "",
    "Space launch vehicles of Russia": "",
    "Space program of Russia": "",
    "Special Economic Zones of Russia": "",
    "Special envoys of the president of Russia": "",
    "Special forces of Russia": "",
    "Specialist law enforcement agencies of Russia": "",
    "Specialist police agencies of Russia": "",
    "Spetsnaz brigades of Russia": "",
    "Spits of Russia": "",
    "Sports titles of Russia": "",
    "Standards of Russia": "",
    "State controllers of Russia": "",
    "Steam locomotives of Russia": "",
    "Steamships of Russia": "",
    "Steel companieszz of Russia": "",
    "Submachine guns of Russia": "",
    "Submarine-launched ballistic missiles of Russia": "",
    "Submarine-launched cruise missiles of Russia": "",
    "Supreme Soviet of Russia": "",
    "Surface-to-air missiles of Russia": "",
    "Surface-to-surface missiles of Russia": "",
    "Tank brigades of Russia": "",
    "Tank divisions of Russia": "",
    "Tankers of Russia": "",
    "Tank regiments of Russia": "",
    "Tatar people of Russia": "",
    "Telecommunications companieszz of Russia": "",
    "Television production companieszz of Russia": "",
    "Templates by federal subject of Russia": "",
    "Territorial disputes of Russia": "",
    "Textile arts of Russia": "",
    "Theatre rocket brigades of Russia": "",
    "Third-level administrative divisions of Russia": "",
    "Toy companieszz of Russia": "",
    "Tractor manufacturers of Russia": "",
    "Trading companieszz of Russia": "",
    "Tram vehicles of Russia": "",
    "Trees of Russia": "",
    "Trial and research firearms of Russia": "",
    "Tsareviches of Russia": "",
    "Tsarevnas of Russia": "",
    "Tsarinas of Russia": "",
    "Tsars of Russia": "",
    "Tsesarevichs of Russia": "",
    "Unitary Enterprises of Russia": "",
    "Units and formations of the National Guard of Russia": "",
    "Uranium mining companieszz of Russia": "",
    "Urban okrugs of Russia": "",
    "Urban settlements of Russia": "",
    "Vasili IV of Russia": "",
    "Venture capital firms of Russia": "",
    "Volcanism of Russia": "",
    "Watch manufacturing companieszz of Russia": "",
    "Weapons of Russia": "",
    "Weather satellites of Russia": "",
    "Wikipedia categories named after companieszz of Russia": "",
    "Wikipedia categories named after manufacturing companieszz of Russia": "",
    "Wikipedia categories named after presidents of Russia": "",
    "Wikipedia featured topics Battlecruisers of Russia": "",
    "Wikipedia requested images of people of Russia": "",
    "Wikipedias by languages of Russia": "",
    "Wine regions of Russia": "",
    "Wineries of Russia": "",
    "Women heads of federal subjects of Russia": "",
    "Wooden architecture of Russia": "",
    "World War I armoured fighting vehicles of Russia": "",
    "World War I artillery of Russia": "",
    "World War I battlecruisers of Russia": "",
    "World War I battleships of Russia": "",
    "World War I cruisers of Russia": "",
    "World War I destroyers of Russia": "",
    "World War I merchant ships of Russia": "",
    "World War I military equipment of Russia": "",
    "World War I mortars of Russia": "",
    "World War I naval ships of Russia": "",
    "World War I passenger ships of Russia": "",
    "World War I ships of Russia": "",
    "World War I submarines of Russia": "",
    "World War I tanks of Russia": "",
    "World War I torpedo boats of Russia": "",
    "World War I weapons of Russia": "",
}

data1 = {
    "Works about the French invasion of Russia": "أعمال عن الغزو الفرنسي لروسيا",
    "Films about the French invasion of Russia": "أفلام عن الغزو الفرنسي لروسيا",
    "National youth sports teams of Russia": "منتخبات رياضية وطنية شبابية في روسيا",
    "National sports teams of Russia": "منتخبات رياضية وطنية في روسيا",
    "Women's national sports teams of Russia": "منتخبات رياضية وطنية نسائية في روسيا",
    "Agriculture ministers of Russia": "وزراء زراعة روسيا",
    "Culture ministers of Russia": "وزراء ثقافة روسيا",
    "Economy ministers of Russia": "وزراء اقتصاد روسيا",
    "Education ministers of Russia": "وزراء تعليم روسيا",
    "Energy ministers of Russia": "وزراء طاقة روسيا",
    "Finance ministers of Russia": "وزراء مالية روسيا",
    "Health ministers of Russia": "وزراء صحة روسيا",
    "Justice ministers of Russia": "وزراء عدل روسيا",
    "Military personnel of the Tsardom of Russia": "أفراد عسكريون من روسيا القيصرية",
    "Immigrants to the Tsardom of Russia": "مهاجرون إلى روسيا القيصرية",
    "Generals of the Tsardom of Russia": "جنرالات روسيا القيصرية",
    "Foreign relations of the Tsardom of Russia": "علاقات روسيا القيصرية الخارجية",
    "Foreign ministers of the Tsardom of Russia": "وزراء خارجية روسيا القيصرية",
    "Battles involving the Tsardom of Russia": "معارك تشمل روسيا القيصرية",
    "Battles of the French invasion of Russia": "معارك الغزو الفرنسي لروسيا",
    "Rebels from the Tsardom of Russia": "متمردون من روسيا القيصرية",
    "People from the Tsardom of Russia": "أشخاص من روسيا القيصرية",
    "Nuns from the Tsardom of Russia": "راهبات من روسيا القيصرية",
    "Nobility from the Tsardom of Russia": "نبلاء من روسيا القيصرية",
    "English expatriates in the Tsardom of Russia": "إنجليز مغتربون في روسيا القيصرية",
    "Expatriates in the Tsardom of Russia": "مغتربون في روسيا القيصرية",
    "Expatriates from the Dutch Republic in the Tsardom of Russia": "مغتربون من جمهورية هولندا في روسيا القيصرية",
    "Artists from the Tsardom of Russia": "فنانون من روسيا القيصرية",
    "Writers from the Tsardom of Russia": "كتاب من روسيا القيصرية",
    "Ambassadors of Safavid Iran to the Tsardom of Russia": "سفراء إيران الصفوية لدى روسيا القيصرية",
    "Ambassadors of Sweden to the Tsardom of Russia": "سفراء السويد لدى روسيا القيصرية",
    "Ambassadors of the Tsardom of Russia": "سفراء روسيا القيصرية",
    "Ambassadors to the Tsardom of Russia": "سفراء لدى روسيا القيصرية",
    "15th-century military history of Russia": "تاريخ روسيا العسكري في القرن 15",
    "16th-century military history of Russia": "تاريخ روسيا العسكري في القرن 16",
    "17th-century military history of Russia": "تاريخ روسيا العسكري في القرن 17",
    "20th-century military history of Russia": "تاريخ روسيا العسكري في القرن 20",
    "21st-century military history of Russia": "تاريخ روسيا العسكري في القرن 21",
    "Accidents and incidents by airline of Russia": "حوادث حسب شركة الطيران في روسيا",
    "Acting presidents of Russia": "رؤساء روسيا بالإنابة",
    "Aircraft carriers of Russia": "حاملات طائرات في روسيا",
    "Air defence units and formations of Russia": "وحدات وتشكيلات دفاع جوي في روسيا",
    "Airlines of Russia": "شركات طيران في روسيا",
    "Ambassadors of Russia": "سفراء روسيا",
    "Amphibians of Russia": "برمائيات روسيا",
    "Amphibious warfare vessels of Russia": "سفن حربية برمائية في روسيا",
    "Archaeology of Russia": "علم الآثار في روسيا",
    "Archipelagoes of Russia": "أرخبيلات روسيا",
    "Architecture firms of Russia": "شركات هندسة معمارية في روسيا",
    "Arthropods of Russia": "مفصليات روسيا",
    "Artificial islands of Russia": "جزر اصطناعية في روسيا",
    "Artillery of Russia": "مدفعية في روسيا",
    "Auxiliary ships of Russia": "سفن مساعدة في روسيا",
    "Banks of Russia": "بنوك روسيا",
    "Battlecruisers of Russia": "طرادات معركة في روسيا",
    "Battleships of Russia": "بوارج في روسيا",
    "Bays of Russia": "خلجان روسيا",
    "Beaches of Russia": "شواطئ روسيا",
    "Bibliographies of Russia": "ببليوجرافيات روسيا",
    "Bilateral military relations of Russia": "علاقات روسيا الثنائية العسكرية",
    "Bilateral relations of Russia": "علاقات روسيا الثنائية",
    "Biota of Russia": "حيويات روسيا",
    "Birds of Russia": "طيور روسيا",
    "Bodies of ice of Russia": "هيئات جليد في روسيا",
    "Bodies of water of Russia": "مسطحات مائية في روسيا",
    "Border crossings of Russia": "معابر حدودية في روسيا",
    "Borders of Russia": "حدود روسيا",
    "Bus manufacturers of Russia": "مصانع الباصات في روسيا",
    "Candidates for President of Russia": "مرشحون لمنصب رئيس روسيا",
    "Canyons and gorges of Russia": "أخاديد في روسيا",
    "Cargo airlines of Russia": "شحن جوي في روسيا",
    "Cargo ships of Russia": "سفن بضائع روسيا",
    "Cars of Russia": "سيارات في روسيا",
    "Caves of Russia": "كهوف روسيا",
    "Charter airlines of Russia": "طيران عارض في روسيا",
    "Chief justices of Russia": "رؤساء قضاء روسيا",
    "Children of presidents of Russia": "أبناء رؤساء روسيا",
    "Children of prime ministers of Russia": "أبناء رؤساء وزراء روسيا",
    "Cinema of Russia": "سينما في روسيا",
    "Citizenship of Russia": "المواطنة في روسيا",
    "Civil awards and decorations of Russia": "جوائز وأوسمة مدنية في روسيا",
    "Climate of Russia": "مناخ روسيا",
    "Coasts of Russia": "سواحل روسيا",
    "Constitutions of Russia": "دساتير في روسيا",
    "Construction industry of Russia": "صناعة بناء في روسيا",
    "Corvettes of Russia": "فرقيطات في روسيا",
    "Cruisers of Russia": "طرادات في روسيا",
    "Crustaceans of Russia": "قشريات روسيا",
    "Cultural depictions of presidents of Russia": "تصوير ثقافي عن رؤساء روسيا",
    "Cultural history of Russia": "تاريخ روسيا الثقافي",
    "Culture of Russia": "ثقافة روسيا",
    "Currencies of Russia": "عملات في روسيا",
    "Defence agencies of Russia": "وكالات دفاع في روسيا",
    "Defunct airlines of Russia": "شركات طيران سابقة في روسيا",
    "Defunct banks of Russia": "بنوك سابقة في روسيا",
    "Defunct motor vehicle manufacturers of Russia": "مصانع سيارات سابقة في روسيا",
    "Demographics of Russia": "التركيبة السكانية في روسيا",
    "Depressions of Russia": "منخفضات روسيا",
    "Deserts of Russia": "صحاري روسيا",
    "Destroyers of Russia": "مدمرات في روسيا",
    "Dinosaurs of Russia": "ديناصورات في روسيا",
    "Diplomatic missions of Russia": "بعثات روسيا الدبلوماسية",
    "Districts of Russia": "مديريات روسيا",
    "Drainage basins of Russia": "أحواض تصريف في روسيا",
    "Drug policy of Russia": "سياسة المخدرات في روسيا",
    "Dunes of Russia": "كثبان رملية في روسيا",
    "Early modern history of Russia": "تاريخ روسيا الحديث المبكر",
    "Economic history of Russia": "تاريخ روسيا الاقتصادي",
    "Economy of Russia": "اقتصاد روسيا",
    "Ecoregions of Russia": "مناطق بيئية في روسيا",
    "Elizabeth of Russia": "إليزابيث إمبراطورة روسيا",
    "Environment of Russia": "بيئة روسيا",
    "Escort ships of Russia": "سفن مرافقة في روسيا",
    "Fast-food chains of Russia": "سلاسل وجبات سريعة في روسيا",
    "Fauna of Russia": "حيوانات روسيا",
    "Featured pictures of Russia": "صور مميزة عن روسيا",
    "Federal subjects of Russia": "كيانات روسيا الاتحادية",
    "Federal universities of Russia": "جامعات فيدرالية في روسيا",
    "Female candidates for President of Russia": "مرشحات لمنصب رئيس روسيا",
    "Ferries of Russia": "عبارات في روسيا",
    "First ladies of Russia": "السيدات الأولى في روسيا",
    "Fish of Russia": "أسماك روسيا",
    "Flags of Russia": "أعلام روسيا",
    "Flags of the federal subjects of Russia": "أعلام كيانات روسيا الاتحادية",
    "Flora of Russia": "نباتات روسيا",
    "Folklore of Russia": "فلكور في روسيا",
    "Forests of Russia": "غابات روسيا",
    "French invasion of Russia": "الغزو الفرنسي لروسيا",
    "Frigates of Russia": "فرقاطات في روسيا",
    "Fungi of Russia": "فطريات روسيا",
    "Geography of Russia": "جغرافيا روسيا",
    "Geology of Russia": "جيولوجيا روسيا",
    "Glaciers of Russia": "أنهار جليدية في روسيا",
    "Golden Ring of Russia": "الجولدن رنج في روسيا",
    "Government agencies of Russia": "وكالات حكومية في روسيا",
    "Government ministers of Russia": "وزراء روسيا",
    "Government ministries of federal subjects of Russia": "وزارات حكومة كيانات روسيا الاتحادية",
    "Government of Russia": "حكومة روسيا",
    "Grand Duchess Anastasia Nikolaevna of Russia": "الدوقة الكبرى أناستاسيا نيكولايفنا من روسيا",
    "Grasslands of Russia": "أراضي عشبية في روسيا",
    "Gulfs of Russia": "خلجان روسيا",
    "Headlands of Russia": "أراضي رأسية في روسيا",
    "Heads of government of Russia": "قادة حكومة روسيا",
    "Heads of state of Russia": "قادة روسيا",
    "Heads of the federal subjects of Russia": "قادة كيانات روسيا الاتحادية",
    "Hills of Russia": "تلال روسيا",
    "Historians of Russia": "مؤرخو روسيا",
    "Historiography of Russia": "تأريخ روسيا",
    "History of Russia": "تاريخ روسيا",
    "Hot springs of Russia": "ينابيع حارة في روسيا",
    "Images of Russia": "صور من روسيا",
    "Indigenous peoples of Russia": "شعوب أصلية في روسيا",
    "Insects of Russia": "حشرات روسيا",
    "Internet service providers of Russia": "تزويد خدمة الإنترنت في روسيا",
    "Invasions of Russia": "غزوات في روسيا",
    "Invertebrates of Russia": "لافقاريات روسيا",
    "Islands of Russia": "جزر روسيا",
    "Judiciary of Russia": "النظام القضائي روسيا",
    "Lakes of Russia": "بحيرات روسيا",
    "Landforms of Russia": "تضاريس روسيا",
    "Languages of Russia": "لغات روسيا",
    "Law enforcement agencies of Russia": "وكالات تطبيق القانون في روسيا",
    "Law of Russia": "قانون في روسيا",
    "Learned societies of Russia": "جمعيات علمية في روسيا",
    "Legal history of Russia": "تاريخ روسيا القانوني",
    "Legislatures of the federal subjects of Russia": "هيئات تشريعية في كيانات روسيا الاتحادية",
    "Lists of ambassadors of Russia": "قوائم سفراء روسيا",
    "Lists of biota of Russia": "قوائم حيويات روسيا",
    "Lists of candidates for President of Russia": "قوائم مرشحون لمنصب رئيس روسيا",
    "Lists of flags of Russia": "قوائم أعلام روسيا",
    "Lists of government ministers of Russia": "قوائم وزراء روسيا",
    "Lists of heads of the federal subjects of Russia": "قوائم قادة كيانات روسيا الاتحادية",
    "Lists of indigenous peoples of Russia": "قوائم شعوب أصلية في روسيا",
    "Lists of landforms of Russia": "قوائم تضاريس روسيا",
    "Lists of ships of Russia": "قوائم سفن روسيا",
    "Lists of subdivisions of Russia": "قوائم تقسيمات روسيا",
    "Locomotive manufacturers of Russia": "مصانع القاطرات في روسيا",
    "Mammals of Russia": "ثدييات روسيا",
    "Maritime history of Russia": "تاريخ روسيا البحري",
    "Military academies of Russia": "أكاديميات عسكرية في روسيا",
    "Military communications of Russia": "اتصالات عسكرية في روسيا",
    "Military equipment of Russia": "عتاد روسيا العسكري",
    "Military history of Russia": "تاريخ روسيا العسكري",
    "Military installations of Russia": "منشآت روسيا العسكرية",
    "Military logistics of Russia": "لوجستية عسكرية في روسيا",
    "Military of Russia": "عسكرية روسيا",
    "Military ranks of Russia": "رتب عسكرية في روسيا",
    "Military research facilities of Russia": "مرافق بحثية عسكرية في روسيا",
    "Military research of Russia": "أبحاث عسكرية في روسيا",
    "Military units and formations of Russia": "وحدات وتشكيلات روسيا العسكرية",
    "Minesweepers of Russia": "كاسحات ألغام في روسيا",
    "Mine warfare vessels of Russia": "سفن حرب ألغام في روسيا",
    "Ministers of defence of Russia": "وزراء دفاع روسيا",
    "Ministers of foreign affairs of Russia": "وزراء شؤون خارجية روسيا",
    "Ministers of internal affairs of Russia": "وزراء شؤون داخلية روسيا",
    "Missile boats of Russia": "قوارب صواريخ في روسيا",
    "Modern history of Russia": "تاريخ روسيا الحديث",
    "Motor vehicle manufacturers of Russia": "مصانع السيارات في روسيا",
    "Mountain passes of Russia": "ممرات جبلية في روسيا",
    "Mountain ranges of Russia": "سلاسل جبلية في روسيا",
    "Mountains of Russia": "جبال روسيا",
    "Municipalities of Russia": "بلديات روسيا",
    "Music of Russia": "موسيقى روسيا",
    "Muslim communities of Russia": "مجتمعات إسلامية في روسيا",
    "National Guard of Russia": "الحرس الوطني في روسيا",
    "National parks of Russia": "متنزهات وطنية في روسيا",
    "National trade union centers of Russia": "مراكز نقابية وطنية في روسيا",
    "Natural history of Russia": "تاريخ روسيا الطبيعي",
    "Naturalized citizens of Russia": "متجنسون في روسيا",
    "Naval history of Russia": "تاريخ روسيا العسكري البحري",
    "Naval ships of Russia": "سفن قوات بحرية في روسيا",
    "Naval units and formations of Russia": "وحدات وتشكيلات روسيا البحرية",
    "Nuclear history of Russia": "تاريخ روسيا النووي",
    "Nuclear missiles of Russia": "صواريخ نووية في روسيا",
    "Nuclear weapons of Russia": "أسلحة نووية في روسيا",
    "Oil fields of Russia": "حقول نفط في روسيا",
    "Orders, decorations, and medals of Russia": "مراتب تشريفية وأوسمة وميداليات روسيا",
    "Passenger ships of Russia": "سفن ركاب في روسيا",
    "Patrol vessels of Russia": "سفن دورية في روسيا",
    "Peace treaties of Russia": "معاهدات سلام روسيا",
    "Peninsulas of Russia": "أشباه جزر في روسيا",
    "People of Russia": "أشخاص من روسيا",
    "Plains of Russia": "سهول روسيا",
    "Plateaus of Russia": "هضاب روسيا",
    "Political history of Russia": "تاريخ روسيا السياسي",
    "Politics of Russia": "سياسة روسيا",
    "Ports and harbours of Russia": "مرافئ وموانئ روسيا",
    "Presidency of Russia": "رئاسة روسيا",
    "Presidents of Russia": "رؤساء روسيا",
    "Prisoners and detainees of Russia": "سجناء ومعتقلون في روسيا",
    "Protected areas of Russia": "مناطق محمية في روسيا",
    "Regions of Russia": "مناطق روسيا",
    "Reptiles of Russia": "زواحف روسيا",
    "Ridges of Russia": "نتوئات جبلية في روسيا",
    "Rivers of Russia": "أنهار روسيا",
    "Rocket engines of Russia": "محركات صواريخ في روسيا",
    "Rock formations of Russia": "تكوينات صخرية في روسيا",
    "Rolling stock of Russia": "القطارات في روسيا",
    "Satellites of Russia": "أقمار صناعية تتبع روسيا",
    "Seas of Russia": "بحار روسيا",
    "Service vessels of Russia": "سفن خدمة في روسيا",
    "Ships of Russia": "سفن روسيا",
    "Shipwrecks of Russia": "حطام سفن في روسيا",
    "Shipyards of Russia": "حوض بناء سفن في روسيا",
    "Social groups of Russia": "مجموعات اجتماعية في روسيا",
    "Social history of Russia": "تاريخ روسيا الاجتماعي",
    "Society of Russia": "مجتمع روسيا",
    "Spiders of Russia": "عناكب في روسيا",
    "Sports organisations of Russia": "منظمات رياضية في روسيا",
    "Sports organizations of Russia": "منظمات رياضية في روسيا",
    "Springs of Russia": "ينابيع روسيا",
    "Straits of Russia": "مضائق روسيا",
    "Stratovolcanoes of Russia": "براكين طبقية في روسيا",
    "Submarines of Russia": "غواصات روسيا",
    "Supermarkets of Russia": "محلات سوبر ماركت في روسيا",
    "Swamps of Russia": "مستنقعات في روسيا",
    "Tall ships of Russia": "سفن طويلة في روسيا",
    "Tanks of Russia": "دبابات روسيا",
    "Territorial evolution of Russia": "الحركة الاستعمارية الروسية",
    "Torpedoes of Russia": "الطوربيدات في روسيا",
    "Training units and formations of Russia": "وحدات وتشكيلات تدريبية في روسيا",
    "Treaties of Russia": "معاهدات روسيا",
    "Truck manufacturers of Russia": "مصانع الشاحنات في روسيا",
    "Uninhabited islands of Russia": "جزر غير مأهولة في روسيا",
    "Unmanned aerial vehicles of Russia": "طائرات بدون طيار روسية",
    "Unmanned military aircraft of Russia": "طائرات عسكرية بدون طيار روسية",
    "Valleys of Russia": "أودية روسيا",
    "Vehicles of Russia": "مركبات روسيا",
    "Vertebrates of Russia": "فقاريات روسيا",
    "Vice presidents of Russia": "نواب رؤساء روسيا",
    "Volcanoes of Russia": "براكين روسيا",
    "Waterfalls of Russia": "شلالات روسيا",
    "Wetlands of Russia": "مناطق رطبة في روسيا",
    "Women government ministers of Russia": "وزيرات روسيات",
    "Members of learned societies of Russia": "أعضاء جمعيات علمية في روسيا",
    "Members of legislatures of the federal subjects of Russia": "أعضاء هيئات تشريعية في كيانات روسيا الاتحادية",
    "Men's national sports teams of Russia": "منتخبات رياضية وطنية رجالية في روسيا",
    "History books about the Tsardom of Russia": "كتب تاريخ عن روسيا القيصرية",
    "Books about presidents of Russia": "كتب عن رؤساء روسيا",
    "Mass media by language of Russia": "وسائل إعلام حسب لغة روسيا",
    "Categories by language of Russia": "تصنيفات حسب لغة روسيا",
}

companies_test_data = {
    "Agriculture companies of Russia": "شركات زراعة في روسيا",
    "Aluminium companies of Russia": "شركات ألومنيوم في روسيا",
    "Automotive companies of Russia": "شركات سيارات في روسيا",
    "Biotechnology companies of Russia": "شركات تقانة حيوية في روسيا",
    "Building materials companies of Russia": "شركات مواد بناء في روسيا",
    "Bus companies of Russia": "شركات الباصات في روسيا",
    "Cement companies of Russia": "شركات أسمنت في روسيا",
    "Chemical companies of Russia": "شركات كيميائية في روسيا",
    "Clothing companies of Russia": "شركات ملابس في روسيا",
    "Coal companies of Russia": "شركات فحم في روسيا",
    "companies of Russia": "شركات في روسيا",
    "Computer companies of Russia": "شركات حوسبة في روسيا",
    "Conglomerate companies of Russia": "تكتل شركات في روسيا",
    "Construction and civil engineering companies of Russia": "شركات بناء وهندسة مدنية في روسيا",
    "Cosmetics companies of Russia": "شركات مستحضرات التجميل في روسيا",
    "Defence companies of Russia": "شركات دفاعية في روسيا",
    "Defunct companies of Russia": "شركات سابقة في روسيا",
    "Defunct electric power companies of Russia": "شركات طاقة كهربائية سابقة في روسيا",
    "Defunct energy companies of Russia": "شركات طاقة سابقة في روسيا",
    "Defunct manufacturing companies of Russia": "شركات تصنيع سابقة في روسيا",
    "Defunct oil companies of Russia": "شركات زيت الوقود سابقة في روسيا",
    "Defunct shipping companies of Russia": "شركات نقل بحري سابقة في روسيا",
    "Defunct transport companies of Russia": "شركات نقل سابقة في روسيا",
    "Defunct video game companies of Russia": "شركات ألعاب فيديو سابقة في روسيا",
    "Design companies of Russia": "شركات تصميم في روسيا",
    "Drink companies of Russia": "شركات مشروبات في روسيا",
    "Electrical engineering companies of Russia": "شركات هندسة كهربائية في روسيا",
    "Electric power companies of Russia": "شركات طاقة كهربائية في روسيا",
    "Electronics companies of Russia": "شركات إلكترونيات في روسيا",
    "Energy companies of Russia": "شركات طاقة في روسيا",
    "Engineering companies of Russia": "شركات هندسية في روسيا",
    "Entertainment companies of Russia": "شركات ترفيه في روسيا",
    "Financial services companies of Russia": "شركات خدمات مالية في روسيا",
    "Food and drink companies of Russia": "شركات أطعمة ومشروبات في روسيا",
    "Government-owned companies of Russia": "شركات مملوكة للحكومة في روسيا",
    "Holding companies of Russia": "شركات قابضة في روسيا",
    "Information technology companies of Russia": "شركات تقانة المعلومات في روسيا",
    "Insurance companies of Russia": "شركات تأمين في روسيا",
    "Investment companies of Russia": "شركات استثمارية في روسيا",
    "Jewellery companies of Russia": "شركات مجوهرات في روسيا",
    "Lists of companies of Russia": "قوائم شركات في روسيا",
    "Manufacturing companies of Russia": "شركات تصنيع في روسيا",
    "Mass media companies of Russia": "شركات وسائل إعلام في روسيا",
    "Metal companies of Russia": "شركات معادن في روسيا",
    "Mining companies of Russia": "شركات تعدين في روسيا",
    "Mobile phone companies of Russia": "شركات هاتف محمول في روسيا",
    "Natural gas companies of Russia": "شركات غاز طبيعي في روسيا",
    "Nuclear companies of Russia": "شركات نووية في روسيا",
    "Oil and gas companies of Russia": "شركات النفط والغاز في روسيا",
    "Oil companies of Russia": "شركات زيت الوقود في روسيا",
    "Pharmaceutical companies of Russia": "شركات أدوية في روسيا",
    "Privately held companies of Russia": "شركات خاصة في روسيا",
    "Publishing companies of Russia": "شركات نشر في روسيا",
    "Pulp and paper companies of Russia": "شركات اللب والورق في روسيا",
    "Railway companies of Russia": "شركات سكك حديدية في روسيا",
    "Real estate companies of Russia": "شركات عقارية في روسيا",
    "Retail companies of Russia": "شركات تجارة التجزئة في روسيا",
    "Security companies of Russia": "شركات أمن في روسيا",
    "Service companies of Russia": "شركات خدمات في روسيا",
    "Shipbuilding companies of Russia": "شركات سفن في روسيا",
    "Shipping companies of Russia": "شركات نقل بحري في روسيا",
    "Software companies of Russia": "شركات برمجيات في روسيا",
    "Technology companies of Russia": "شركات تقانة في روسيا",
    "Television companies of Russia": "شركات تلفاز في روسيا",
    "Transport companies of Russia": "شركات نقل في روسيا",
    "Travel and holiday companies of Russia": "شركات السفر والعطلات في روسيا",
    "Vehicle manufacturing companies of Russia": "شركات تصنيع مركبات في روسيا",
    "Video game companies of Russia": "شركات ألعاب فيديو في روسيا",
    "Water companies of Russia": "شركات مياه في روسيا",
}

to_test = [
    ("test_all_russia", data1),
    ("test_companies_russia", companies_test_data),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.slow
def test_all_russia(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
