#

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_skip = {
    "Antigua and Barbuda and the Commonwealth of Nations": "x",
    "Antigua and Barbuda articles by importance": "x",
    "Antigua and Barbuda articles by quality": "x",
    "Antigua and Barbuda at the Junior Pan American Games": "x",
    "Antigua and Barbuda aviation law": "x",
    "Antigua and Barbuda beauty pageant winners": "x",
    "Antigua and Barbuda calypsonians": "x",
    "Antigua and Barbuda court system": "x",
    "Antigua and Barbuda dressage riders": "x",
    "Antigua and Barbuda evangelicals": "x",
    "Antigua and Barbuda geography-related lists": "x",
    "Antigua and Barbuda judges on the courts of Anguilla": "x",
    "Antigua and Barbuda judges on the courts of Belize": "x",
    "Antigua and Barbuda judges on the courts of Grenada": "x",
    "Antigua and Barbuda judges on the courts of Montserrat": "x",
    "Antigua and Barbuda judges on the courts of Saint Lucia": "x",
    "Antigua and Barbuda knights": "x",
    "Antigua and Barbuda Labour Party politicians": "x",
    "Antigua and Barbuda location map modules": "x",
    "Antigua and Barbuda masters athletes": "x",
    "Antigua and Barbuda modules": "x",
    "Antigua and Barbuda people of Saint Kitts and Nevis descent": "x",
    "Antigua and Barbuda Protestants": "x",
    "Antigua and Barbuda records": "x",
    "Antigua and Barbuda religion-related lists": "x",
    "Antigua and Barbuda Salvationists": "x",
    "Antigua and Barbuda Seventh-day Adventists": "x",
    "Antigua and Barbuda slave owners": "x",
    "Antigua and Barbuda social democrats": "x",
    "Antigua and Barbuda stub templates": "x",
    "Antigua and Barbuda transport-related lists": "x",
    "Antigua and Barbuda user categories": "x",
    "Antigua and Barbuda user templates": "x",
    "Antigua and Barbuda Wikipedians": "x",
    "Antigua and Barbuda–Holy See relations": "x",
    "Apostolic nuncios to Antigua and Barbuda": "x",
    "Australian judges on the courts of Antigua and Barbuda": "x",
    "Baroque architecture in Antigua and Barbuda": "x",
    "Beauty pageants in Antigua and Barbuda": "x",
    "Bilateral sports relations of Antigua and Barbuda": "x",
    "Bird family (Antigua and Barbuda)": "x",
    "British judges on the courts of Antigua and Barbuda": "x",
    "British Virgin Islands expatriates in Antigua and Barbuda": "x",
    "British Virgin Islands judges on the courts of Antigua and Barbuda": "x",
    "Buildings and structures in Saint John Parish, Antigua and Barbuda": "x",
    "By-elections in Antigua and Barbuda": "x",
    "Catholic Church in Antigua and Barbuda": "x",
    "Catholic secondary schools in Antigua and Barbuda": "x",
    "Constitution of Antigua and Barbuda": "x",
    "Country data templates of Antigua and Barbuda": "x",
    "Cricket grounds in Antigua and Barbuda": "x",
    "Dominica expatriate sportspeople in Antigua and Barbuda": "x",
    "Dominica expatriates in Antigua and Barbuda": "x",
    "Dominica judges on the courts of Antigua and Barbuda": "x",
    "Dominica people of Antigua and Barbuda descent": "x",
    "Education, sports and creative industries ministers of Antigua and Barbuda": "x",
    "Emergency services in Antigua and Barbuda": "x",
    "Endemic birds of Antigua and Barbuda": "x",
    "Endemic fauna of Antigua and Barbuda": "x",
    "Expatriate judges on the courts of Antigua and Barbuda": "x",
    "Federalism in Antigua and Barbuda": "x",
    "Folk festivals in Antigua and Barbuda": "x",
    "Ghanaian judges on the courts of Antigua and Barbuda": "x",
    "Girls' schools in Antigua and Barbuda": "x",
    "Guyanese judges on the courts of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda to Canada": "x",
    "High commissioners of Antigua and Barbuda to Saint Kitts and Nevis": "x",
    "High commissioners of Antigua and Barbuda to the United Kingdom": "x",
    "High commissioners of Australia to Antigua and Barbuda": "x",
    "High commissioners of Canada to Antigua and Barbuda": "x",
    "High commissioners of India to Antigua and Barbuda": "x",
    "High commissioners of South Africa to Antigua and Barbuda": "x",
    "High commissioners of the United Kingdom to Antigua and Barbuda": "x",
    "High schools and secondary schools in Antigua and Barbuda": "x",
    "History of sport in Antigua and Barbuda": "x",
    "Hurricanes in Antigua and Barbuda": "x",
    "Important Bird Areas of Antigua and Barbuda": "x",
    "Jamaican judges on the courts of Antigua and Barbuda": "x",
    "John Hughes, Antigua and Barbuda": "x",
    "Judicial Committee of the Privy Council cases on appeal from Antigua and Barbuda": "x",
    "Major divisions of Antigua and Barbuda": "x",
    "Members of the 14th legislature of Antigua and Barbuda": "x",
    "Members of the 15th legislature of Antigua and Barbuda": "x",
    "Members of the 16th legislature of Antigua and Barbuda": "x",
    "Members of the House of Representatives (Antigua and Barbuda)": "x",
    "Merchant ships of Antigua and Barbuda": "x",
    "Micronations in Antigua and Barbuda": "x",
    "Monarchy of Antigua and Barbuda": "x",
    "National Cultural Heritage of Antigua and Barbuda": "x",
    "National Security Council (Antigua and Barbuda)": "x",
    "Parades in Antigua and Barbuda": "x",
    "Parliaments of Antigua and Barbuda": "x",
    "People from Saint George, Antigua and Barbuda": "x",
    "People from Saint John, Antigua and Barbuda": "x",
    "People from Saint Mary, Antigua and Barbuda": "x",
    "People from Saint Paul, Antigua and Barbuda": "x",
    "People from Saint Peter, Antigua and Barbuda": "x",
    "People from Saint Philip, Antigua and Barbuda": "x",
    "Permanent representatives of Antigua and Barbuda to the World Trade Organization": "x",
    "Places in Saint John Parish, Antigua and Barbuda": "x",
    "Private islands of Antigua and Barbuda": "x",
    "Ramsar sites in Antigua and Barbuda": "x",
    "Recipients of the Order of the Nation (Antigua and Barbuda)": "x",
    "Recipients of the Order of the National Hero (Antigua and Barbuda)": "x",
    "Republicanism in Antigua and Barbuda": "x",
    "Saint George, Antigua and Barbuda": "x",
    "Saint John, Antigua and Barbuda": "x",
    "Saint Kitts and Nevis expatriates in Antigua and Barbuda": "x",
    "Saint Kitts and Nevis judges on the courts of Antigua and Barbuda": "x",
    "Saint Kitts and Nevis people of Antigua and Barbuda descent": "x",
    "Saint Lucian expatriates in Antigua and Barbuda": "x",
    "Saint Lucian judges on the courts of Antigua and Barbuda": "x",
    "Saint Lucian people of Antigua and Barbuda descent": "x",
    "Saint Mary, Antigua and Barbuda": "x",
    "Saint Paul, Antigua and Barbuda": "x",
    "Saint Peter, Antigua and Barbuda": "x",
    "Saint Philip, Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriate sportspeople in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriates in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines judges on the courts of Antigua and Barbuda": "x",
    "Scouting and Guiding in Antigua and Barbuda": "x",
    "Serbia and Montenegro expatriate sportspeople in Antigua and Barbuda": "x",
    "Socialism in Antigua and Barbuda": "x",
    "Speakers of the House of Representatives (Antigua and Barbuda)": "x",
    "United States Virgin Islands people of Antigua and Barbuda descent": "x",
    "Women ambassadors of Antigua and Barbuda": "x",
    "World Athletics Championships athletes for Antigua and Barbuda": "x",
}

to_test = [("test_antigua_and_barbuda_data_skip", data_skip)]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
