#
from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_1 = {
    "Non-fiction books about Indigenous peoples of the Americas": "كتب غير خيالية عن شعوب أصلية في الأمريكتين",
    "19th-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 19 حسب الجنسية",
    "19th-century non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 19",
    "20th-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 20 حسب الجنسية",
    "21st-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 21 حسب الجنسية",
    "African-American non-fiction writers": "كتاب غير روائيين أمريكيون أفارقة",
    "Cameroonian non-fiction writers": "كتاب غير روائيين كاميرونيون",
    "Canadian non-fiction writers in French": "كتاب غير روائيين كنديون في فرنسيون",
    "Non-fiction writers about organized crime in Italy": "كتاب غير روائيين عن جريمة منظمة في إيطاليا",
    "Non-fiction writers about organized crime in the United States": "كتاب غير روائيين عن جريمة منظمة في الولايات المتحدة",
    "Paraguayan non-fiction writers": "كتاب غير روائيين بارغوايانيون",
    "Togolese non-fiction writers": "كتاب غير روائيين توغويون",
    "Zimbabwean non-fiction writers": "كتاب غير روائيين زيمبابويون",
    "10th-century non-fiction writers": "كتاب غير روائيين في القرن 10",
    "11th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 11",
    "11th-century non-fiction writers": "كتاب غير روائيين في القرن 11",
    "12th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 12",
    "12th-century non-fiction writers": "كتاب غير روائيين في القرن 12",
    "13th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 13",
    "13th-century non-fiction writers": "كتاب غير روائيين في القرن 13",
    "14th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 14",
    "14th-century non-fiction writers": "كتاب غير روائيين في القرن 14",
    "15th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 15",
    "15th-century non-fiction writers": "كتاب غير روائيين في القرن 15",
    "16th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 16",
    "16th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 16",
    "16th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 16",
    "16th-century non-fiction writers": "كتاب غير روائيين في القرن 16",
    "17th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 17",
    "17th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 17",
    "17th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 17",
    "17th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 17",
    "17th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 17",
    "17th-century non-fiction writers": "كتاب غير روائيين في القرن 17",
    "18th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 18",
    "18th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 18",
    "18th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 18",
    "18th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 18",
    "18th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 18",
    "18th-century non-fiction writers": "كتاب غير روائيين في القرن 18",
    "19th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 19",
    "19th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 19",
    "19th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 19",
    "19th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 19",
    "19th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 19",
    "19th-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 19",
    "19th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 19",
    "19th-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 19",
    "19th-century non-fiction writers": "كتاب غير روائيين في القرن 19",
    "20th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 20",
    "20th-century Australian non-fiction writers": "كتاب غير روائيين أستراليون في القرن 20",
    "20th-century Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون في القرن 20",
    "20th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 20",
    "20th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 20",
    "20th-century Chilean non-fiction writers": "كتاب غير روائيين تشيليون في القرن 20",
    "20th-century Croatian non-fiction writers": "كتاب غير روائيين كروات في القرن 20",
    "20th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 20",
    "20th-century Dutch non-fiction writers": "كتاب غير روائيين هولنديون في القرن 20",
    "20th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 20",
    "20th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 20",
    "20th-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 20",
    "20th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 20",
    "20th-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 20",
    "20th-century Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون في القرن 20",
    "20th-century Italian non-fiction writers": "كتاب غير روائيين إيطاليون في القرن 20",
    "20th-century Lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون في القرن 20",
    "20th-century Norwegian non-fiction writers": "كتاب غير روائيين نرويجيون في القرن 20",
    "20th-century Polish non-fiction writers": "كتاب غير روائيين بولنديون في القرن 20",
    "20th-century Russian non-fiction writers": "كتاب غير روائيين روس في القرن 20",
    "20th-century Swedish non-fiction writers": "كتاب غير روائيين سويديون في القرن 20",
    "20th-century Swiss non-fiction writers": "كتاب غير روائيين سويسريون في القرن 20",
    "20th-century non-fiction writers": "كتاب غير روائيين في القرن 20",
    "21st-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 21",
    "21st-century Australian non-fiction writers": "كتاب غير روائيين أستراليون في القرن 21",
    "21st-century Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون في القرن 21",
    "21st-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 21",
    "21st-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 21",
    "21st-century Chilean non-fiction writers": "كتاب غير روائيين تشيليون في القرن 21",
    "21st-century Croatian non-fiction writers": "كتاب غير روائيين كروات في القرن 21",
    "21st-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 21",
    "21st-century Dutch non-fiction writers": "كتاب غير روائيين هولنديون في القرن 21",
    "21st-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 21",
    "21st-century Finnish non-fiction writers": "كتاب غير روائيين فنلنديون في القرن 21",
    "21st-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 21",
    "21st-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 21",
    "21st-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 21",
    "21st-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 21",
    "21st-century Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون في القرن 21",
    "21st-century Italian non-fiction writers": "كتاب غير روائيين إيطاليون في القرن 21",
    "21st-century Polish non-fiction writers": "كتاب غير روائيين بولنديون في القرن 21",
    "21st-century Russian non-fiction writers": "كتاب غير روائيين روس في القرن 21",
    "21st-century Scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون في القرن 21",
    "21st-century Spanish non-fiction writers": "كتاب غير روائيين إسبان في القرن 21",
    "21st-century Swiss non-fiction writers": "كتاب غير روائيين سويسريون في القرن 21",
    "21st-century non-fiction writers": "كتاب غير روائيين في القرن 21",
    "21st-century non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 21",
    "2nd-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 2",
    "2nd-century non-fiction writers": "كتاب غير روائيين في القرن 2",
    "3rd-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 3",
    "3rd-century non-fiction writers": "كتاب غير روائيين في القرن 3",
    "4th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 4",
    "4th-century non-fiction writers": "كتاب غير روائيين في القرن 4",
    "5th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 5",
    "5th-century non-fiction writers": "كتاب غير روائيين في القرن 5",
    "6th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 6",
    "6th-century non-fiction writers": "كتاب غير روائيين في القرن 6",
    "7th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 7",
    "7th-century non-fiction writers": "كتاب غير روائيين في القرن 7",
    "8th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 8",
    "8th-century non-fiction writers": "كتاب غير روائيين في القرن 8",
    "9th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 9",
    "9th-century non-fiction writers": "كتاب غير روائيين في القرن 9",
    "Albanian non-fiction writers": "كتاب غير روائيين ألبان",
    "American male non-fiction writers": "كتاب غير روائيين ذكور أمريكيون",
    "American non-fiction crime writers": "كتاب جريمة غير روائيين أمريكيون",
    "American non-fiction environmental writers": "كتاب بيئة غير روائيين أمريكيون",
    "American non-fiction writers": "كتاب غير روائيين أمريكيون",
    "American non-fiction writers by century": "كتاب غير روائيين أمريكيون حسب القرن",
    "Angolan non-fiction writers": "كتاب غير روائيين أنغوليون",
    "Arab non-fiction writers": "كتاب غير روائيين عرب",
    "Argentine non-fiction writers": "كتاب غير روائيين أرجنتينيون",
    "Armenian non-fiction writers": "كتاب غير روائيين أرمن",
    "Australian male non-fiction writers": "كتاب غير روائيين ذكور أستراليون",
    "Australian non-fiction crime writers": "كتاب جريمة غير روائيين أستراليون",
    "Australian non-fiction writers": "كتاب غير روائيين أستراليون",
    "Austrian non-fiction writers": "كتاب غير روائيين نمساويون",
    "Azerbaijani non-fiction writers": "كتاب غير روائيين أذربيجانيون",
    "Bangladeshi non-fiction writers": "كتاب غير روائيين بنغلاديشيون",
    "Belarusian non-fiction writers": "كتاب غير روائيين بيلاروسيون",
    "Belgian male non-fiction writers": "كتاب غير روائيين ذكور بلجيكيون",
    "Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون",
    "Belgian non-fiction writers by century": "كتاب غير روائيين بلجيكيون حسب القرن",
    "Beninese non-fiction writers": "كتاب غير روائيين بنينيون",
    "Bermudian non-fiction writers": "كتاب غير روائيين برموديون",
    "Bolivian non-fiction writers": "كتاب غير روائيين بوليفيون",
    "Bosnia and Herzegovina non-fiction writers": "كتاب غير روائيين بوسنيون",
    "Botswana non-fiction writers": "كتاب غير روائيين بوتسوانيون",
    "Brazilian non-fiction writers": "كتاب غير روائيين برازيليون",
    "British male non-fiction writers": "كتاب غير روائيين ذكور بريطانيون",
    "British non-fiction crime writers": "كتاب جريمة غير روائيين بريطانيون",
    "British non-fiction writers": "كتاب غير روائيين بريطانيون",
    "British non-fiction writers by century": "كتاب غير روائيين بريطانيون حسب القرن",
    "Burkinabe non-fiction writers": "كتاب غير روائيين بوركينابيون",
    "Burkinabé non-fiction writers": "كتاب غير روائيين بوركينابيون",
    "Burmese non-fiction writers": "كتاب غير روائيين بورميون",
    "Canadian male non-fiction writers": "كتاب غير روائيين ذكور كنديون",
    "Canadian non-fiction writers": "كتاب غير روائيين كنديون",
    "Canadian non-fiction writers by century": "كتاب غير روائيين كنديون حسب القرن",
    "Central African Republic non-fiction writers": "كتاب غير روائيين أفارقة أوسطيون",
    "Chadian non-fiction writers": "كتاب غير روائيين تشاديون",
    "Chilean non-fiction writers": "كتاب غير روائيين تشيليون",
    "Chinese non-fiction writers": "كتاب غير روائيين صينيون",
    "Colombian non-fiction writers": "كتاب غير روائيين كولومبيون",
    "Croatian non-fiction writers by century": "كتاب غير روائيين كروات حسب القرن",
    "Cuban non-fiction writers": "كتاب غير روائيين كوبيون",
    "Cypriot non-fiction writers": "كتاب غير روائيين قبرصيون",
    "Czech non-fiction writers": "كتاب غير روائيين تشيكيون",
    "Danish male non-fiction writers": "كتاب غير روائيين ذكور دنماركيون",
    "Danish non-fiction writers": "كتاب غير روائيين دنماركيون",
    "Danish non-fiction writers by century": "كتاب غير روائيين دنماركيون حسب القرن",
    "Democratic republic of congo non-fiction writers": "كتاب غير روائيين كونغويون ديمقراطيون",
    "Dutch non-fiction writers": "كتاب غير روائيين هولنديون",
    "Dutch non-fiction writers by century": "كتاب غير روائيين هولنديون حسب القرن",
    "Egyptian non-fiction writers": "كتاب غير روائيين مصريون",
    "Emirati non-fiction writers": "كتاب غير روائيين إماراتيون",
    "English male non-fiction writers": "كتاب غير روائيين ذكور إنجليز",
    "English non-fiction crime writers": "كتاب جريمة غير روائيين إنجليز",
    "English non-fiction writers by century": "كتاب غير روائيين إنجليز حسب القرن",
    "Eritrean non-fiction writers": "كتاب غير روائيين إريتريون",
    "Estonian non-fiction writers": "كتاب غير روائيين إستونيون",
    "Ethiopian non-fiction writers": "كتاب غير روائيين إثيوبيون",
    "Filipino non-fiction writers": "كتاب غير روائيين فلبينيون",
    "Finnish non-fiction writers": "كتاب غير روائيين فنلنديون",
    "Finnish non-fiction writers by century": "كتاب غير روائيين فنلنديون حسب القرن",
    "French male non-fiction writers": "كتاب غير روائيين ذكور فرنسيون",
    "French non-fiction writers": "كتاب غير روائيين فرنسيون",
    "French non-fiction writers by century": "كتاب غير روائيين فرنسيون حسب القرن",
    "Gambian non-fiction writers": "كتاب غير روائيين غامبيون",
    "German male non-fiction writers": "كتاب غير روائيين ذكور ألمان",
    "German non-fiction writers": "كتاب غير روائيين ألمان",
    "German non-fiction writers by century": "كتاب غير روائيين ألمان حسب القرن",
    "Ghanaian non-fiction writers": "كتاب غير روائيين غانيون",
    "Greek non-fiction writers": "كتاب غير روائيين يونانيون",
    "Guadeloupean non-fiction writers": "كتاب غير روائيين غواديلوبيون",
    "Guyanese non-fiction writers": "كتاب غير روائيين غيانيون",
    "Haitian non-fiction writers": "كتاب غير روائيين هايتيون",
    "Hungarian non-fiction writers": "كتاب غير روائيين مجريون",
    "Icelandic non-fiction writers": "كتاب غير روائيين آيسلنديون",
    "Indian male non-fiction writers": "كتاب غير روائيين ذكور هنود",
    "Indian non-fiction environmental writers": "كتاب بيئة غير روائيين هنود",
    "Indian non-fiction writers": "كتاب غير روائيين هنود",
    "Indian non-fiction writers by century": "كتاب غير روائيين هنود حسب القرن",
    "Indonesian non-fiction writers": "كتاب غير روائيين إندونيسيون",
    "Iranian non-fiction writers": "كتاب غير روائيين إيرانيون",
    "Iraqi non-fiction writers": "كتاب غير روائيين عراقيون",
    "Irish male non-fiction writers": "كتاب غير روائيين ذكور أيرلنديون",
    "Irish non-fiction writers": "كتاب غير روائيين أيرلنديون",
    "Irish non-fiction writers by century": "كتاب غير روائيين أيرلنديون حسب القرن",
    "Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون",
    "Israeli non-fiction writers by century": "كتاب غير روائيين إسرائيليون حسب القرن",
    "Italian male non-fiction writers": "كتاب غير روائيين ذكور إيطاليون",
    "Italian non-fiction writers": "كتاب غير روائيين إيطاليون",
    "Italian non-fiction writers by century": "كتاب غير روائيين إيطاليون حسب القرن",
    "Jamaican non-fiction writers": "كتاب غير روائيين جامايكيون",
    "Japanese non-fiction writers": "كتاب غير روائيين يابانيون",
    "Japanese non-fiction writers by century": "كتاب غير روائيين يابانيون حسب القرن",
    "Jewish American non-fiction writers": "كتاب غير روائيين أمريكيون يهود",
    "Jewish non-fiction writers": "كتاب غير روائيين يهود",
    "Kenyan non-fiction writers": "كتاب غير روائيين كينيون",
    "Korean non-fiction writers": "كتاب غير روائيين كوريون",
    "Kosovan non-fiction writers": "كتاب غير روائيين كوسوفيون",
    "Kuwaiti non-fiction writers": "كتاب غير روائيين كويتيون",
    "Latvian non-fiction writers": "كتاب غير روائيين لاتفيون",
    "Lebanese non-fiction writers": "كتاب غير روائيين لبنانيون",
    "Liberian non-fiction writers": "كتاب غير روائيين ليبيريون",
    "Libyan non-fiction writers": "كتاب غير روائيين ليبيون",
    "Lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون",
    "Luxembourgian non-fiction writers": "كتاب غير روائيين لوكسمبورغيون",
    "Macedonian non-fiction writers": "كتاب غير روائيين مقدونيون",
    "Malawian non-fiction writers": "كتاب غير روائيين ملاويون",
    "Malaysian non-fiction writers": "كتاب غير روائيين ماليزيون",
    "Male non-fiction writers": "كتاب غير روائيين ذكور",
    "Male non-fiction writers by nationality": "كتاب غير روائيين ذكور حسب الجنسية",
    "Male non-fiction writers from Northern Ireland": "كتاب غير روائيين ذكور من أيرلندا الشمالية",
    "Malian non-fiction writers": "كتاب غير روائيين ماليون",
    "Maltese non-fiction writers": "كتاب غير روائيين مالطيون",
    "Mauritian non-fiction writers": "كتاب غير روائيين موريشيوسيون",
    "Mexican non-fiction writers": "كتاب غير روائيين مكسيكيون",
    "Moroccan non-fiction writers": "كتاب غير روائيين مغاربة",
    "Mozambican non-fiction writers": "كتاب غير روائيين موزمبيقيون",
    "Namibian non-fiction writers": "كتاب غير روائيين ناميبيون",
    "Nigerian non-fiction writers": "كتاب غير روائيين نيجيريون",
    "Non-fiction crime writers": "كتاب جريمة غير روائيين",
    "Non-fiction environmental writers": "كتاب بيئة غير روائيين",
    "Non-fiction writers": "كتاب غير روائيين",
    "Non-fiction writers by century": "كتاب غير روائيين حسب القرن",
    "Non-fiction writers by century and nationality": "كتاب غير روائيين حسب القرن والجنسية",
    "Non-fiction writers by nationality": "كتاب غير روائيين حسب الجنسية",
    "Non-fiction writers by nationality and century": "كتاب غير روائيين حسب الجنسية والقرن",
    "Non-fiction writers from Cornwall": "كتاب غير روائيين من كورنوال",
    "Non-fiction writers from Georgia (country)": "كتاب غير روائيين من جورجيا",
    "Non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية",
    "Non-fiction writers from the Ottoman Empire": "كتاب غير روائيين من الدولة العثمانية",
    "Non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية",
    "Norwegian non-fiction writers": "كتاب غير روائيين نرويجيون",
    "Norwegian non-fiction writers by century": "كتاب غير روائيين نرويجيون حسب القرن",
    "Pakistani non-fiction writers": "كتاب غير روائيين باكستانيون",
    "Pakistani non-fiction writers by century": "كتاب غير روائيين باكستانيون حسب القرن",
    "Palestinian non-fiction writers": "كتاب غير روائيين فلسطينيون",
    "Peruvian non-fiction writers": "كتاب غير روائيين بيرويون",
    "Polish male non-fiction writers": "كتاب غير روائيين ذكور بولنديون",
    "Polish non-fiction writers": "كتاب غير روائيين بولنديون",
    "Portuguese non-fiction writers": "كتاب غير روائيين برتغاليون",
    "Puerto Rican non-fiction writers": "كتاب غير روائيين بورتوريكيون",
    "Qatari non-fiction writers": "كتاب غير روائيين قطريون",
    "Romanian non-fiction writers": "كتاب غير روائيين رومان",
    "Russian non-fiction writers": "كتاب غير روائيين روس",
    "Russian non-fiction writers by century": "كتاب غير روائيين روس حسب القرن",
    "Rwandan non-fiction writers": "كتاب غير روائيين روانديون",
    "Sahrawi non-fiction writers": "كتاب غير روائيين صحراويون",
    "Saudi Arabian non-fiction writers": "كتاب غير روائيين سعوديون",
    "Scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون",
    "Scottish non-fiction writers by century": "كتاب غير روائيين إسكتلنديون حسب القرن",
    "Senegalese non-fiction writers": "كتاب غير روائيين سنغاليون",
    "Serbian non-fiction writers": "كتاب غير روائيين صرب",
    "Sierra Leonean non-fiction writers": "كتاب غير روائيين سيراليونيون",
    "Singaporean non-fiction writers": "كتاب غير روائيين سنغافوريون",
    "Slovak non-fiction writers": "كتاب غير روائيين سلوفاكيون",
    "Slovenian non-fiction writers": "كتاب غير روائيين سلوفينيون",
    "Somalian non-fiction writers": "كتاب غير روائيين صوماليون",
    "South Korean non-fiction writers": "كتاب غير روائيين كوريون جنوبيون",
    "Soviet non-fiction writers": "كتاب غير روائيين سوفيت",
    "Spanish male non-fiction writers": "كتاب غير روائيين ذكور إسبان",
    "Spanish non-fiction writers": "كتاب غير روائيين إسبان",
    "Spanish non-fiction writers by century": "كتاب غير روائيين إسبان حسب القرن",
    "Sri Lankan non-fiction writers": "كتاب غير روائيين سريلانكيون",
    "Sudanese non-fiction writers": "كتاب غير روائيين سودانيون",
    "Swedish male non-fiction writers": "كتاب غير روائيين ذكور سويديون",
    "Swedish non-fiction writers": "كتاب غير روائيين سويديون",
    "Swedish non-fiction writers by century": "كتاب غير روائيين سويديون حسب القرن",
    "Swiss non-fiction writers": "كتاب غير روائيين سويسريون",
    "Swiss non-fiction writers by century": "كتاب غير روائيين سويسريون حسب القرن",
    "Syrian non-fiction writers": "كتاب غير روائيين سوريون",
    "Taiwanese non-fiction writers": "كتاب غير روائيين تايوانيون",
    "Tajikistani non-fiction writers": "كتاب غير روائيين طاجيك",
    "Tanzanian non-fiction writers": "كتاب غير روائيين تنزانيون",
    "Thai non-fiction writers": "كتاب غير روائيين تايلنديون",
    "Trinidad and Tobago non-fiction writers": "كتاب غير روائيين ترنيداديون",
    "Tunisian non-fiction writers": "كتاب غير روائيين تونسيون",
    "Turkish Cypriot non-fiction writers": "كتاب غير روائيين قبرصيون شماليون",
    "Turkish non-fiction writers": "كتاب غير روائيين أتراك",
    "Ugandan non-fiction writers": "كتاب غير روائيين أوغنديون",
    "Ukrainian non-fiction writers": "كتاب غير روائيين أوكرانيون",
    "Uruguayan non-fiction writers": "كتاب غير روائيين أوروغويانيون",
    "Venezuelan non-fiction writers": "كتاب غير روائيين فنزويليون",
    "Vietnamese non-fiction writers": "كتاب غير روائيين فيتناميون",
    "Yemeni non-fiction writers": "كتاب غير روائيين يمنيون",
    "Yugoslav non-fiction writers": "كتاب غير روائيين يوغسلافيون",
    "Zambian non-fiction writers": "كتاب غير روائيين زامبيون",
}

to_test = [
    ("text_non_fiction", data_1),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
