#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data1 = {}

data2 = {
    "1964 in American women's sports": "رياضات نسائية أمريكية في 1964",
    "1972 in American women's sports": "رياضات نسائية أمريكية في 1972",
    "2003 in Canadian women's sports": "رياضات نسائية كندية في 2003",
    "2026 in American women's sports": "رياضات نسائية أمريكية في 2026",
    "american women's sports": "رياضات نسائية أمريكية",
    "canadian women's sports": "رياضات نسائية كندية",
    "mexican women's sports": "رياضات نسائية مكسيكية",
    "1550 in sports": "ألعاب رياضية في 1550",
    "december 1550 in sports": "ألعاب رياضية في ديسمبر 1550",
    "june 1550 in sports": "ألعاب رياضية في يونيو 1550",
    "Sports leagues in Papua New Guinea": "دوريات رياضية في بابوا غينيا الجديدة",
    "honduran people in sports": "هندوراسيون في ألعاب رياضية",
    "Jewish sports": "ألعاب رياضية يهودية",
    "surinamese sports federation": "الاتحاد السورينامي للرياضة",
    "zaïrean wheelchair sports federation": "الاتحاد الزائيري للرياضة على الكراسي المتحركة",
    "American women's sports by year": "رياضات نسائية أمريكية حسب السنة",
    "American women's sports by decade": "رياضات نسائية أمريكية حسب العقد",
    "1887 in American women's sports": "رياضات نسائية أمريكية في 1887",
    "1889 in American women's sports": "رياضات نسائية أمريكية في 1889",
    "1930 in American women's sports": "رياضات نسائية أمريكية في 1930",
    "1931 in American women's sports": "رياضات نسائية أمريكية في 1931",
    "1934 in American women's sports": "رياضات نسائية أمريكية في 1934",
    "1938 in American women's sports": "رياضات نسائية أمريكية في 1938",
    "1945 in American women's sports": "رياضات نسائية أمريكية في 1945",
    "1946 in American women's sports": "رياضات نسائية أمريكية في 1946",
    "1947 in American women's sports": "رياضات نسائية أمريكية في 1947",
    "1948 in American women's sports": "رياضات نسائية أمريكية في 1948",
    "1950 in American women's sports": "رياضات نسائية أمريكية في 1950",
    "1951 in American women's sports": "رياضات نسائية أمريكية في 1951",
    "1953 in American women's sports": "رياضات نسائية أمريكية في 1953",
    "1954 in American women's sports": "رياضات نسائية أمريكية في 1954",
    "1955 in American women's sports": "رياضات نسائية أمريكية في 1955",
    "1956 in American women's sports": "رياضات نسائية أمريكية في 1956",
    "1959 in American women's sports": "رياضات نسائية أمريكية في 1959",
    "1961 in American women's sports": "رياضات نسائية أمريكية في 1961",
    "1963 in American women's sports": "رياضات نسائية أمريكية في 1963",
    "1966 in American women's sports": "رياضات نسائية أمريكية في 1966",
    "1967 in American women's sports": "رياضات نسائية أمريكية في 1967",
    "1968 in American women's sports": "رياضات نسائية أمريكية في 1968",
    "1970 in American women's sports": "رياضات نسائية أمريكية في 1970",
    "1971 in American women's sports": "رياضات نسائية أمريكية في 1971",
    "1973 in American women's sports": "رياضات نسائية أمريكية في 1973",
    "1974 in American women's sports": "رياضات نسائية أمريكية في 1974",
    "1975 in American women's sports": "رياضات نسائية أمريكية في 1975",
    "1978 in American women's sports": "رياضات نسائية أمريكية في 1978",
    "1979 in American women's sports": "رياضات نسائية أمريكية في 1979",
    "1980 in American women's sports": "رياضات نسائية أمريكية في 1980",
    "1982 in American women's sports": "رياضات نسائية أمريكية في 1982",
    "1983 in American women's sports": "رياضات نسائية أمريكية في 1983",
    "1984 in American women's sports": "رياضات نسائية أمريكية في 1984",
    "1985 in American women's sports": "رياضات نسائية أمريكية في 1985",
    "1986 in American women's sports": "رياضات نسائية أمريكية في 1986",
    "1987 in American women's sports": "رياضات نسائية أمريكية في 1987",
    "1989 in American women's sports": "رياضات نسائية أمريكية في 1989",
    "1990 in American women's sports": "رياضات نسائية أمريكية في 1990",
    "1991 in American women's sports": "رياضات نسائية أمريكية في 1991",
    "1992 in American women's sports": "رياضات نسائية أمريكية في 1992",
    "1993 in American women's sports": "رياضات نسائية أمريكية في 1993",
    "1995 in American women's sports": "رياضات نسائية أمريكية في 1995",
    "1996 in American women's sports": "رياضات نسائية أمريكية في 1996",
    "1998 in American women's sports": "رياضات نسائية أمريكية في 1998",
    "2000 in American women's sports": "رياضات نسائية أمريكية في 2000",
    "2001 in American women's sports": "رياضات نسائية أمريكية في 2001",
    "2004 in American women's sports": "رياضات نسائية أمريكية في 2004",
    "2005 in American women's sports": "رياضات نسائية أمريكية في 2005",
    "2006 in American women's sports": "رياضات نسائية أمريكية في 2006",
    "2007 in American women's sports": "رياضات نسائية أمريكية في 2007",
    "2009 in American women's sports": "رياضات نسائية أمريكية في 2009",
    "2010 in American women's sports": "رياضات نسائية أمريكية في 2010",
    "2011 in American women's sports": "رياضات نسائية أمريكية في 2011",
    "2012 in American women's sports": "رياضات نسائية أمريكية في 2012",
    "2013 in American women's sports": "رياضات نسائية أمريكية في 2013",
    "2014 in American women's sports": "رياضات نسائية أمريكية في 2014",
    "2015 in American women's sports": "رياضات نسائية أمريكية في 2015",
    "2016 in American women's sports": "رياضات نسائية أمريكية في 2016",
    "2017 in American women's sports": "رياضات نسائية أمريكية في 2017",
    "2018 in American women's sports": "رياضات نسائية أمريكية في 2018",
    "2021 in American women's sports": "رياضات نسائية أمريكية في 2021",
    "2022 in American women's sports": "رياضات نسائية أمريكية في 2022",
    "2023 in American women's sports": "رياضات نسائية أمريكية في 2023",
    "2024 in American women's sports": "رياضات نسائية أمريكية في 2024",
    "2025 in American women's sports": "رياضات نسائية أمريكية في 2025",
    "1880s in American women's sports": "رياضات نسائية أمريكية في عقد 1880",
    "1930s in American women's sports": "رياضات نسائية أمريكية في عقد 1930",
    "1940s in American women's sports": "رياضات نسائية أمريكية في عقد 1940",
    "1950s in American women's sports": "رياضات نسائية أمريكية في عقد 1950",
    "1960s in American women's sports": "رياضات نسائية أمريكية في عقد 1960",
    "1970s in American women's sports": "رياضات نسائية أمريكية في عقد 1970",
    "1980s in American women's sports": "رياضات نسائية أمريكية في عقد 1980",
    "1990s in American women's sports": "رياضات نسائية أمريكية في عقد 1990",
    "2010s in American women's sports": "رياضات نسائية أمريكية في عقد 2010",
    "2020s in American women's sports": "رياضات نسائية أمريكية في عقد 2020",
    "Canadian women's sports by year": "رياضات نسائية كندية حسب السنة",
    "Canadian women's sports by decade": "رياضات نسائية كندية حسب العقد",
    "1983 in Canadian women's sports": "رياضات نسائية كندية في 1983",
    "2004 in Canadian women's sports": "رياضات نسائية كندية في 2004",
    "2007 in Canadian women's sports": "رياضات نسائية كندية في 2007",
    "2011 in Canadian women's sports": "رياضات نسائية كندية في 2011",
    "2012 in Canadian women's sports": "رياضات نسائية كندية في 2012",
    "2023 in Canadian women's sports": "رياضات نسائية كندية في 2023",
    "1980s in Canadian women's sports": "رياضات نسائية كندية في عقد 1980",
    "1990s in Canadian women's sports": "رياضات نسائية كندية في عقد 1990",
    "2000s in Canadian women's sports": "رياضات نسائية كندية في عقد 2000",
    "2010s in Canadian women's sports": "رياضات نسائية كندية في عقد 2010",
    "2020s in Canadian women's sports": "رياضات نسائية كندية في عقد 2020",
    "Mexican women's sports by year": "رياضات نسائية مكسيكية حسب السنة",
    "Mexican women's sports by decade": "رياضات نسائية مكسيكية حسب العقد",
    "1971 in Mexican women's sports": "رياضات نسائية مكسيكية في 1971",
    "1974 in Mexican women's sports": "رياضات نسائية مكسيكية في 1974",
    "2010 in Mexican women's sports": "رياضات نسائية مكسيكية في 2010",
    "1970s in Mexican women's sports": "رياضات نسائية مكسيكية في عقد 1970",
    "2010s in Mexican women's sports": "رياضات نسائية مكسيكية في عقد 2010",
}

data3 = {
    "Women's sports by dependent territory": "رياضات نسائية حسب الأقاليم التابعة",
    "Women's sports by populated place": "رياضات نسائية حسب المكان المأهول",
    "Women's sports by sport and country": "رياضات نسائية حسب الرياضة والبلد",
    "Women's sports by year": "رياضات نسائية حسب السنة",
    "Women's sports in American Samoa": "رياضات نسائية في ساموا الأمريكية",
    "Women's sports in Arizona": "رياضات نسائية في أريزونا",
    "Women's sports in Atlanta": "رياضات نسائية في أتلانتا (جورجيا)",
    "Women's sports in Boston": "رياضات نسائية في بوسطن",
    "Women's sports in Botswana": "رياضات نسائية في بوتسوانا",
    "Women's sports in British Columbia": "رياضات نسائية في كولومبيا البريطانية",
    "Women's sports in California": "رياضات نسائية في كاليفورنيا",
    "Women's sports in Canada": "رياضات نسائية في كندا",
    "Women's sports in Charlotte, North Carolina": "رياضات نسائية في تشارلوت (كارولاينا الشمالية)",
    "Women's sports in Chicago": "رياضات نسائية في شيكاغو",
    "Women's sports in Cleveland": "رياضات نسائية في كليفلاند",
    "Women's sports in Connecticut": "رياضات نسائية في كونيتيكت",
    "Women's sports in Dallas": "رياضات نسائية في دالاس",
    "Women's sports in Detroit": "رياضات نسائية في ديترويت",
    "Women's sports in Florida": "رياضات نسائية في فلوريدا",
    "Women's sports in Georgia (U.S. state)": "رياضات نسائية في ولاية جورجيا",
    "Women's sports in Guam": "رياضات نسائية في غوام",
    "Women's sports in Haryana": "رياضات نسائية في هاريانا",
    "Women's sports in Houston": "رياضات نسائية في هيوستن",
    "Women's sports in Illinois": "رياضات نسائية في إلينوي",
    "Women's sports in Indiana": "رياضات نسائية في إنديانا",
    "Women's sports in insular areas of the United States": "رياضات نسائية في المناطق المعزولة في الولايات المتحدة",
    "Women's sports in Iowa": "رياضات نسائية في آيوا",
    "Women's sports in Istanbul": "رياضات نسائية في إسطنبول",
    "Women's sports in Kansas": "رياضات نسائية في كانساس",
    "Women's sports in Kansas City, Missouri": "رياضات نسائية في كانساس سيتي (ميزوري)",
    "Women's sports in Kentucky": "رياضات نسائية في كنتاكي",
    "Women's sports in Lebanon": "رياضات نسائية في لبنان",
    "Women's sports in Los Angeles": "رياضات نسائية في لوس أنجلوس",
    "Women's sports in Louisiana": "رياضات نسائية في لويزيانا",
    "Women's sports in Manitoba": "رياضات نسائية في مانيتوبا",
    "Women's sports in Maryland": "رياضات نسائية في ماريلند",
    "Women's sports in Massachusetts": "رياضات نسائية في ماساتشوستس",
    "Women's sports in Miami": "رياضات نسائية في ميامي",
    "Women's sports in Michigan": "رياضات نسائية في ميشيغان",
    "Women's sports in Minnesota": "رياضات نسائية في منيسوتا",
    "Women's sports in Missouri": "رياضات نسائية في ميزوري",
    "Women's sports in Nevada": "رياضات نسائية في نيفادا",
    "Women's sports in New Jersey": "رياضات نسائية في نيوجيرسي",
    "Women's sports in New York (state)": "رياضات نسائية في ولاية نيويورك",
    "Women's sports in New York City": "رياضات نسائية في مدينة نيويورك",
    "Women's sports in North America": "رياضات نسائية في أمريكا الشمالية",
    "Women's sports in North Carolina": "رياضات نسائية في كارولاينا الشمالية",
    "Women's sports in Nova Scotia": "رياضات نسائية في نوفا سكوشا",
    "Women's sports in Oceania": "رياضات نسائية في أوقيانوسيا",
    "Women's sports in Ohio": "رياضات نسائية في أوهايو",
    "Women's sports in Oklahoma": "رياضات نسائية في أوكلاهوما",
    "Women's sports in Pennsylvania": "رياضات نسائية في بنسلفانيا",
    "Women's sports in Philadelphia": "رياضات نسائية في فيلادلفيا",
    "Women's sports in Puerto Rico": "رياضات نسائية في بورتوريكو",
    "Women's sports in Quebec": "رياضات نسائية في كيبك",
    "Women's sports in Quebec City": "رياضات نسائية في مدينة كيبك",
    "Women's sports in Rhode Island": "رياضات نسائية في رود آيلاند",
    "Women's sports in San Diego": "رياضات نسائية في سان دييغو",
    "Women's sports in Seattle": "رياضات نسائية في سياتل",
    "Women's sports in South Carolina": "رياضات نسائية في كارولاينا الجنوبية",
    "Women's sports in Texas": "رياضات نسائية في تكساس",
    "Women's sports in the Philippines": "رياضات نسائية في الفلبين",
    "Women's sports in the United States": "رياضات نسائية في الولايات المتحدة",
    "Women's sports in Utah": "رياضات نسائية في يوتا",
    "Women's sports in Vancouver": "رياضات نسائية في فانكوفر",
    "Women's sports in West Germany": "رياضات نسائية في ألمانيا الغربية",
    "Women's sports in Wisconsin": "رياضات نسائية في ويسكونسن",
    "1884 in women's sport": "رياضة نسائية في 1884",
    "1885 in women's sport": "رياضة نسائية في 1885",
    "1886 in women's sport": "رياضة نسائية في 1886",
    "1887 in women's sport": "رياضة نسائية في 1887",
    "1888 in women's sport": "رياضة نسائية في 1888",
    "1891 in women's sport": "رياضة نسائية في 1891",
    "1892 in women's sport": "رياضة نسائية في 1892",
    "1893 in women's sport": "رياضة نسائية في 1893",
    "1894 in women's sport": "رياضة نسائية في 1894",
    "1895 in women's sport": "رياضة نسائية في 1895",
    "1896 in women's sport": "رياضة نسائية في 1896",
    "1897 in women's sport": "رياضة نسائية في 1897",
    "1901 in women's sport": "رياضة نسائية في 1901",
    "1902 in women's sport": "رياضة نسائية في 1902",
    "1903 in women's sport": "رياضة نسائية في 1903",
    "1904 in women's sport": "رياضة نسائية في 1904",
    "1905 in women's sport": "رياضة نسائية في 1905",
    "1906 in women's sport": "رياضة نسائية في 1906",
    "1907 in women's sport": "رياضة نسائية في 1907",
    "1908 in women's sport": "رياضة نسائية في 1908",
    "1909 in women's sport": "رياضة نسائية في 1909",
    "1910 in women's sport": "رياضة نسائية في 1910",
    "1911 in women's sport": "رياضة نسائية في 1911",
    "1912 in women's sport": "رياضة نسائية في 1912",
    "1913 in women's sport": "رياضة نسائية في 1913",
    "1914 in women's sport": "رياضة نسائية في 1914",
    "1919 in women's sport": "رياضة نسائية في 1919",
    "1920 in women's sport": "رياضة نسائية في 1920",
    "1921 in women's sport": "رياضة نسائية في 1921",
    "1922 in women's sport": "رياضة نسائية في 1922",
    "1923 in women's sport": "رياضة نسائية في 1923",
    "1924 in women's sport": "رياضة نسائية في 1924",
    "1926 in women's sport": "رياضة نسائية في 1926",
    "1927 in women's sport": "رياضة نسائية في 1927",
    "1928 in women's sport": "رياضة نسائية في 1928",
    "1929 in women's sport": "رياضة نسائية في 1929",
    "1930 in women's sport": "رياضة نسائية في 1930",
    "1932 in women's sport": "رياضة نسائية في 1932",
    "1933 in women's sport": "رياضة نسائية في 1933",
    "1934 in women's sport": "رياضة نسائية في 1934",
    "1936 in women's sport": "رياضة نسائية في 1936",
    "1937 in women's sport": "رياضة نسائية في 1937",
    "1946 in women's sport": "رياضة نسائية في 1946",
    "1947 in women's sport": "رياضة نسائية في 1947",
    "1948 in women's sport": "رياضة نسائية في 1948",
    "1949 in women's sport": "رياضة نسائية في 1949",
    "1950 in women's sport": "رياضة نسائية في 1950",
    "1952 in women's sport": "رياضة نسائية في 1952",
    "1953 in women's sport": "رياضة نسائية في 1953",
    "1954 in women's sport": "رياضة نسائية في 1954",
    "1956 in women's sport": "رياضة نسائية في 1956",
    "1957 in women's sport": "رياضة نسائية في 1957",
    "1959 in women's sport": "رياضة نسائية في 1959",
    "1961 in women's sport": "رياضة نسائية في 1961",
    "1963 in women's sport": "رياضة نسائية في 1963",
    "1964 in women's sport": "رياضة نسائية في 1964",
    "1965 in women's sport": "رياضة نسائية في 1965",
    "1969 in women's sport": "رياضة نسائية في 1969",
    "1970 in women's sport": "رياضة نسائية في 1970",
    "1971 in women's sport": "رياضة نسائية في 1971",
    "1972 in women's sport": "رياضة نسائية في 1972",
    "1973 in women's sport": "رياضة نسائية في 1973",
    "1974 in women's sport": "رياضة نسائية في 1974",
    "1974 in women's sport by country": "رياضة نسائية في 1974 حسب البلد",
    "1975 in women's sport": "رياضة نسائية في 1975",
    "1976 in women's sport": "رياضة نسائية في 1976",
    "1977 in women's sport": "رياضة نسائية في 1977",
    "1978 in women's sport": "رياضة نسائية في 1978",
    "1986 in women's sport by country": "رياضة نسائية في 1986 حسب البلد",
    "1987 in women's sport by country": "رياضة نسائية في 1987 حسب البلد",
    "1988 in women's sport": "رياضة نسائية في 1988",
    "1988 in women's sport by country": "رياضة نسائية في 1988 حسب البلد",
    "1989 in women's sport by country": "رياضة نسائية في 1989 حسب البلد",
    "1990 in women's sport by country": "رياضة نسائية في 1990 حسب البلد",
    "1991 in women's sport by country": "رياضة نسائية في 1991 حسب البلد",
    "1992 in women's sport": "رياضة نسائية في 1992",
    "1992 in women's sport by country": "رياضة نسائية في 1992 حسب البلد",
    "1993 in women's sport by country": "رياضة نسائية في 1993 حسب البلد",
    "1994 in women's sport by country": "رياضة نسائية في 1994 حسب البلد",
    "1995 in women's sport by country": "رياضة نسائية في 1995 حسب البلد",
    "1996 in women's sport by country": "رياضة نسائية في 1996 حسب البلد",
    "1998 in women's sport by country": "رياضة نسائية في 1998 حسب البلد",
    "1999 in women's sport by country": "رياضة نسائية في 1999 حسب البلد",
    "2000 in women's sport by country": "رياضة نسائية في 2000 حسب البلد",
    "2001 in women's sport by country": "رياضة نسائية في 2001 حسب البلد",
    "2003 in women's sport by country": "رياضة نسائية في 2003 حسب البلد",
    "2004 in women's sport by country": "رياضة نسائية في 2004 حسب البلد",
    "2005 in women's sport by country": "رياضة نسائية في 2005 حسب البلد",
    "2006 in women's sport by country": "رياضة نسائية في 2006 حسب البلد",
    "2008 in women's sport by country": "رياضة نسائية في 2008 حسب البلد",
    "2009 in women's sport by country": "رياضة نسائية في 2009 حسب البلد",
    "2010 in women's sport": "رياضة نسائية في 2010",
    "2010 in women's sport by country": "رياضة نسائية في 2010 حسب البلد",
    "2013 in women's sport by country": "رياضة نسائية في 2013 حسب البلد",
    "2014 in women's sport": "رياضة نسائية في 2014",
    "2014 in women's sport by country": "رياضة نسائية في 2014 حسب البلد",
    "2015 in women's sport": "رياضة نسائية في 2015",
    "2015 in women's sport by country": "رياضة نسائية في 2015 حسب البلد",
    "2017 in women's sport by country": "رياضة نسائية في 2017 حسب البلد",
    "2018 in women's sport": "رياضة نسائية في 2018",
    "2018 in women's sport by country": "رياضة نسائية في 2018 حسب البلد",
    "2019 in women's sport by country": "رياضة نسائية في 2019 حسب البلد",
    "Women's sport-related lists": "قوائم متعلقة برياضة نسائية",
    "Women's sport by country and year": "رياضة نسائية حسب البلد والسنة",
    "Women's sport by year and country": "رياضة نسائية حسب السنة والبلد",
    "Women's sport in Afghanistan": "رياضة نسائية في أفغانستان",
    "Women's sport in Albania": "رياضة نسائية في ألبانيا",
    "Women's sport in Algeria": "رياضة نسائية في الجزائر",
    "Women's sport in Amsterdam": "رياضة نسائية في أمستردام",
    "Women's sport in Andorra": "رياضة نسائية في أندورا",
    "Women's sport in Angola": "رياضة نسائية في أنغولا",
    "Women's sport in Antigua and Barbuda": "رياضة نسائية في أنتيغوا وباربودا",
    "Women's sport in Argentina": "رياضة نسائية في الأرجنتين",
    "Women's sport in Armenia": "رياضة نسائية في أرمينيا",
    "Women's sport in Aruba": "رياضة نسائية في أروبا",
    "Women's sport in Australia": "رياضة نسائية في أستراليا",
    "Women's sport in Austria": "رياضة نسائية في النمسا",
    "Women's sport in Azerbaijan": "رياضة نسائية في أذربيجان",
    "Women's sport in Bangladesh": "رياضة نسائية في بنغلاديش",
    "Women's sport in Barbados": "رياضة نسائية في بربادوس",
    "Women's sport in Belarus": "رياضة نسائية في روسيا البيضاء",
    "Women's sport in Belgium": "رياضة نسائية في بلجيكا",
    "Women's sport in Belize": "رياضة نسائية في بليز",
    "Women's sport in Benin": "رياضة نسائية في بنين",
    "Women's sport in Bermuda": "رياضة نسائية في برمودا",
    "Women's sport in Bhutan": "رياضة نسائية في بوتان",
    "Women's sport in Bolivia": "رياضة نسائية في بوليفيا",
    "Women's sport in Bosnia and Herzegovina": "رياضة نسائية في البوسنة والهرسك",
    "Women's sport in Botswana": "رياضة نسائية في بوتسوانا",
    "Women's sport in Brazil": "رياضة نسائية في البرازيل",
    "Women's sport in Brunei": "رياضة نسائية في بروناي",
    "Women's sport in Bulgaria": "رياضة نسائية في بلغاريا",
    "Women's sport in Cambodia": "رياضة نسائية في كمبوديا",
    "Women's sport in Cameroon": "رياضة نسائية في الكاميرون",
    "Women's sport in Central America": "رياضة نسائية في أمريكا الوسطى",
    "Women's sport in Chile": "رياضة نسائية في تشيلي",
    "Women's sport in China": "رياضة نسائية في الصين",
    "Women's sport in Costa Rica": "رياضة نسائية في كوستاريكا",
    "Women's sport in Croatia": "رياضة نسائية في كرواتيا",
    "Women's sport in Cuba": "رياضة نسائية في كوبا",
    "Women's sport in Cyprus": "رياضة نسائية في قبرص",
    "Women's sport in Czechoslovakia": "رياضة نسائية في تشيكوسلوفاكيا",
    "Women's sport in dependent territories of the United Kingdom": "رياضة نسائية في أقاليم ما وراء البحار البريطانية",
    "Women's sport in Djibouti": "رياضة نسائية في جيبوتي",
    "Women's sport in East Germany": "رياضة نسائية في ألمانيا الشرقية",
    "Women's sport in Ecuador": "رياضة نسائية في الإكوادور",
    "Women's sport in Egypt": "رياضة نسائية في مصر",
    "Women's sport in El Salvador": "رياضة نسائية في السلفادور",
    "Women's sport in England": "رياضة نسائية في إنجلترا",
    "Women's sport in Equatorial Guinea": "رياضة نسائية في غينيا الاستوائية",
    "Women's sport in Estonia": "رياضة نسائية في إستونيا",
    "Women's sport in Ethiopia": "رياضة نسائية في إثيوبيا",
    "Women's sport in Fiji": "رياضة نسائية في فيجي",
    "Women's sport in Finland": "رياضة نسائية في فنلندا",
    "Women's sport in France": "رياضة نسائية في فرنسا",
    "Women's sport in French Guiana": "رياضة نسائية في غويانا الفرنسية",
    "Women's sport in Gabon": "رياضة نسائية في الغابون",
    "Women's sport in Georgia (country)": "رياضة نسائية في جورجيا",
    "Women's sport in Germany": "رياضة نسائية في ألمانيا",
    "Women's sport in Ghana": "رياضة نسائية في غانا",
    "Women's sport in Gibraltar": "رياضة نسائية في جبل طارق",
    "Women's sport in Greenland": "رياضة نسائية في جرينلاند",
    "Women's sport in Grenada": "رياضة نسائية في غرينادا",
    "Women's sport in Guadeloupe": "رياضة نسائية في غوادلوب",
    "Women's sport in Guatemala": "رياضة نسائية في غواتيمالا",
    "Women's sport in Guinea": "رياضة نسائية في غينيا",
    "Women's sport in Guyana": "رياضة نسائية في غيانا",
    "Women's sport in Haiti": "رياضة نسائية في هايتي",
    "Women's sport in Hong Kong": "رياضة نسائية في هونغ كونغ",
    "Women's sport in Hungary": "رياضة نسائية في المجر",
    "Women's sport in Iceland": "رياضة نسائية في آيسلندا",
    "Women's sport in India": "رياضة نسائية في الهند",
    "Women's sport in Indonesia": "رياضة نسائية في إندونيسيا",
    "Women's sport in Iran": "رياضة نسائية في إيران",
    "Women's sport in Iraq": "رياضة نسائية في العراق",
    "Women's sport in Ireland": "رياضة نسائية في أيرلندا",
    "Women's sport in Ireland by sport": "رياضة نسائية في أيرلندا حسب الرياضة",
    "Women's sport in Israel": "رياضة نسائية في إسرائيل",
    "Women's sport in Italy": "رياضة نسائية في إيطاليا",
    "Women's sport in Ivory Coast": "رياضة نسائية في ساحل العاج",
    "Women's sport in Jamaica": "رياضة نسائية في جامايكا",
    "Women's sport in Japan": "رياضة نسائية في اليابان",
    "Women's sport in Jordan": "رياضة نسائية في الأردن",
    "Women's sport in Kazakhstan": "رياضة نسائية في كازاخستان",
    "Women's sport in Kenya": "رياضة نسائية في كينيا",
    "Women's sport in Korea": "رياضة نسائية في كوريا",
    "Women's sport in Kosovo": "رياضة نسائية في كوسوفو",
    "Women's sport in Kuwait": "رياضة نسائية في الكويت",
    "Women's sport in Kyrgyzstan": "رياضة نسائية في قيرغيزستان",
    "Women's sport in Laos": "رياضة نسائية في لاوس",
    "Women's sport in Latvia": "رياضة نسائية في لاتفيا",
    "Women's sport in Lebanon": "رياضة نسائية في لبنان",
    "Women's sport in Lesotho": "رياضة نسائية في ليسوتو",
    "Women's sport in Liberia": "رياضة نسائية في ليبيريا",
    "Women's sport in Libya": "رياضة نسائية في ليبيا",
    "Women's sport in Liechtenstein": "رياضة نسائية في ليختنشتاين",
    "Women's sport in Lithuania": "رياضة نسائية في ليتوانيا",
    "Women's sport in London": "رياضة نسائية في لندن",
    "Women's sport in Luxembourg": "رياضة نسائية في لوكسمبورغ",
    "Women's sport in Macau": "رياضة نسائية في ماكاو",
    "Women's sport in Madagascar": "رياضة نسائية في مدغشقر",
    "Women's sport in Malawi": "رياضة نسائية في ملاوي",
    "Women's sport in Malaysia": "رياضة نسائية في ماليزيا",
    "Women's sport in Mali": "رياضة نسائية في مالي",
    "Women's sport in Malta": "رياضة نسائية في مالطا",
    "Women's sport in Mauritius": "رياضة نسائية في موريشيوس",
    "Women's sport in Mexico": "رياضة نسائية في المكسيك",
    "Women's sport in Moldova": "رياضة نسائية في مولدوفا",
    "Women's sport in Monaco": "رياضة نسائية في موناكو",
    "Women's sport in Mongolia": "رياضة نسائية في منغوليا",
    "Women's sport in Montenegro": "رياضة نسائية في الجبل الأسود",
    "Women's sport in Morocco": "رياضة نسائية في المغرب",
    "Women's sport in Mozambique": "رياضة نسائية في موزمبيق",
    "Women's sport in Myanmar": "رياضة نسائية في ميانمار",
    "Women's sport in Namibia": "رياضة نسائية في ناميبيا",
    "Women's sport in Nepal": "رياضة نسائية في نيبال",
    "Women's sport in New Zealand": "رياضة نسائية في نيوزيلندا",
    "Women's sport in Nicaragua": "رياضة نسائية في نيكاراغوا",
    "Women's sport in Niger": "رياضة نسائية في النيجر",
    "Women's sport in Nigeria": "رياضة نسائية في نيجيريا",
    "Women's sport in North Korea": "رياضة نسائية في كوريا الشمالية",
    "Women's sport in North Macedonia": "رياضة نسائية في مقدونيا الشمالية",
    "Women's sport in Northern Ireland": "رياضة نسائية في أيرلندا الشمالية",
    "Women's sport in Norway": "رياضة نسائية في النرويج",
    "Women's sport in Oman": "رياضة نسائية في سلطنة عمان",
    "Women's sport in Pakistan": "رياضة نسائية في باكستان",
    "Women's sport in Palestine": "رياضة نسائية في فلسطين",
    "Women's sport in Panama": "رياضة نسائية في بنما",
    "Women's sport in Papua New Guinea": "رياضة نسائية في بابوا غينيا الجديدة",
    "Women's sport in Paraguay": "رياضة نسائية في باراغواي",
    "Women's sport in Peru": "رياضة نسائية في بيرو",
    "Women's sport in Poland": "رياضة نسائية في بولندا",
    "Women's sport in Portugal": "رياضة نسائية في البرتغال",
    "Women's sport in Qatar": "رياضة نسائية في قطر",
    "Women's sport in Romania": "رياضة نسائية في رومانيا",
    "Women's sport in Russia": "رياضة نسائية في روسيا",
    "Women's sport in Rwanda": "رياضة نسائية في رواندا",
    "Women's sport in Samoa": "رياضة نسائية في ساموا",
    "Women's sport in San Marino": "رياضة نسائية في سان مارينو",
    "Women's sport in Scotland": "رياضة نسائية في إسكتلندا",
    "Women's sport in Senegal": "رياضة نسائية في السنغال",
    "Women's sport in Serbia": "رياضة نسائية في صربيا",
    "Women's sport in Seychelles": "رياضة نسائية في سيشل",
    "Women's sport in Singapore": "رياضة نسائية في سنغافورة",
    "Women's sport in Slovakia": "رياضة نسائية في سلوفاكيا",
    "Women's sport in Slovenia": "رياضة نسائية في سلوفينيا",
    "Women's sport in Somalia": "رياضة نسائية في الصومال",
    "Women's sport in South Africa": "رياضة نسائية في جنوب إفريقيا",
    "Women's sport in South Korea": "رياضة نسائية في كوريا الجنوبية",
    "Women's sport in South Sudan": "رياضة نسائية في جنوب السودان",
    "Women's sport in Southeast Asia": "رياضة نسائية في جنوب شرق آسيا",
    "Women's sport in Spain": "رياضة نسائية في إسبانيا",
    "Women's sport in Sri Lanka": "رياضة نسائية في سريلانكا",
    "Women's sport in Sudan": "رياضة نسائية في السودان",
    "Women's sport in Switzerland": "رياضة نسائية في سويسرا",
    "Women's sport in Syria": "رياضة نسائية في سوريا",
    "Women's sport in Taiwan": "رياضة نسائية في تايوان",
    "Women's sport in Tajikistan": "رياضة نسائية في طاجيكستان",
    "Women's sport in Tanzania": "رياضة نسائية في تنزانيا",
    "Women's sport in Thailand": "رياضة نسائية في تايلاند",
    "Women's sport in the Bahamas": "رياضة نسائية في باهاماس",
    "Women's sport in the Caribbean": "رياضة نسائية في الكاريبي",
    "Women's sport in the Cayman Islands": "رياضة نسائية في جزر كايمان",
    "Women's sport in the Central African Republic": "رياضة نسائية في جمهورية إفريقيا الوسطى",
    "Women's sport in the Comoros": "رياضة نسائية في جزر القمر",
    "Women's sport in the Czech Republic": "رياضة نسائية في التشيك",
    "Women's sport in the Democratic Republic of the Congo": "رياضة نسائية في جمهورية الكونغو الديمقراطية",
    "Women's sport in the Dominican Republic": "رياضة نسائية في جمهورية الدومينيكان",
    "Women's sport in the Faroe Islands": "رياضة نسائية في جزر فارو",
    "Women's sport in the Republic of Ireland": "رياضة نسائية في جمهورية أيرلندا",
    "Women's sport in the Republic of the Congo": "رياضة نسائية في جمهورية الكونغو",
    "Women's sport in the Soviet Union": "رياضة نسائية في الاتحاد السوفيتي",
    "Women's sport in the United Arab Emirates": "رياضة نسائية في الإمارات العربية المتحدة",
    "Women's sport in the United Kingdom": "رياضة نسائية في المملكة المتحدة",
    "Women's sport in Togo": "رياضة نسائية في توغو",
    "Women's sport in Trinidad and Tobago": "رياضة نسائية في ترينيداد وتوباغو",
    "Women's sport in Tunisia": "رياضة نسائية في تونس",
    "Women's sport in Turkey": "رياضة نسائية في تركيا",
    "Women's sport in Turkmenistan": "رياضة نسائية في تركمانستان",
    "Women's sport in Uganda": "رياضة نسائية في أوغندا",
    "Women's sport in Ukraine": "رياضة نسائية في أوكرانيا",
    "Women's sport in Uruguay": "رياضة نسائية في أوروغواي",
    "Women's sport in Uzbekistan": "رياضة نسائية في أوزبكستان",
    "Women's sport in Vanuatu": "رياضة نسائية في فانواتو",
    "Women's sport in Venezuela": "رياضة نسائية في فنزويلا",
    "Women's sport in Vietnam": "رياضة نسائية في فيتنام",
    "Women's sport in Wales": "رياضة نسائية في ويلز",
    "Women's sport in West Germany": "رياضة نسائية في ألمانيا الغربية",
    "Women's sport in Yemen": "رياضة نسائية في اليمن",
    "Women's sport in Yugoslavia": "رياضة نسائية في يوغسلافيا",
    "Women's sport in Zambia": "رياضة نسائية في زامبيا",
    "Women's sport in Zimbabwe": "رياضة نسائية في زيمبابوي",
    "Women's sport navigational boxes": "صناديق تصفح رياضة نسائية",
    "Women's sport templates": "قوالب رياضة نسائية",
    "Women's sports clubs and teams in Afghanistan": "أندية وفرق رياضية نسائية في أفغانستان",
    "Women's sports clubs and teams in Albania": "أندية وفرق رياضية نسائية في ألبانيا",
    "Women's sports clubs and teams in Andorra": "أندية وفرق رياضية نسائية في أندورا",
    "Women's sports clubs and teams in Armenia": "أندية وفرق رياضية نسائية في أرمينيا",
    "Women's sports clubs and teams in Azerbaijan": "أندية وفرق رياضية نسائية في أذربيجان",
    "Women's sports clubs and teams in Bangladesh": "أندية وفرق رياضية نسائية في بنغلاديش",
    "Women's sports clubs and teams in Botswana": "أندية وفرق رياضية نسائية في بوتسوانا",
    "Women's sports clubs and teams in Denmark": "أندية وفرق رياضية نسائية في الدنمارك",
    "Women's sports clubs and teams in Fiji": "أندية وفرق رياضية نسائية في فيجي",
    "Women's sports clubs and teams in Gabon": "أندية وفرق رياضية نسائية في الغابون",
    "Women's sports clubs and teams in Georgia (country)": "أندية وفرق رياضية نسائية في جورجيا",
    "Women's sports clubs and teams in Guatemala": "أندية وفرق رياضية نسائية في غواتيمالا",
    "Women's sports clubs and teams in Guyana": "أندية وفرق رياضية نسائية في غيانا",
    "Women's sports clubs and teams in Haiti": "أندية وفرق رياضية نسائية في هايتي",
    "Women's sports clubs and teams in Hong Kong": "أندية وفرق رياضية نسائية في هونغ كونغ",
    "Women's sports clubs and teams in Ivory Coast": "أندية وفرق رياضية نسائية في ساحل العاج",
    "Women's sports clubs and teams in Kenya": "أندية وفرق رياضية نسائية في كينيا",
    "Women's sports clubs and teams in Kosovo": "أندية وفرق رياضية نسائية في كوسوفو",
    "Women's sports clubs and teams in Laos": "أندية وفرق رياضية نسائية في لاوس",
    "Women's sports clubs and teams in Lebanon": "أندية وفرق رياضية نسائية في لبنان",
    "Women's sports clubs and teams in Lesotho": "أندية وفرق رياضية نسائية في ليسوتو",
    "Women's sports clubs and teams in Malawi": "أندية وفرق رياضية نسائية في ملاوي",
    "Women's sports clubs and teams in Malaysia": "أندية وفرق رياضية نسائية في ماليزيا",
    "Women's sports clubs and teams in Moldova": "أندية وفرق رياضية نسائية في مولدوفا",
    "Women's sports clubs and teams in Montenegro": "أندية وفرق رياضية نسائية في الجبل الأسود",
    "Women's sports clubs and teams in Morocco": "أندية وفرق رياضية نسائية في المغرب",
    "Women's sports clubs and teams in Niger": "أندية وفرق رياضية نسائية في النيجر",
    "Women's sports clubs and teams in Pakistan": "أندية وفرق رياضية نسائية في باكستان",
    "Women's sports clubs and teams in Paraguay": "أندية وفرق رياضية نسائية في باراغواي",
    "Women's sports clubs and teams in Rwanda": "أندية وفرق رياضية نسائية في رواندا",
    "Women's sports clubs and teams in Singapore": "أندية وفرق رياضية نسائية في سنغافورة",
    "Women's sports clubs and teams in Sri Lanka": "أندية وفرق رياضية نسائية في سريلانكا",
    "Women's sports clubs and teams in Syria": "أندية وفرق رياضية نسائية في سوريا",
    "Women's sports clubs and teams in Tajikistan": "أندية وفرق رياضية نسائية في طاجيكستان",
    "Women's sports clubs and teams in the Cayman Islands": "أندية وفرق رياضية نسائية في جزر كايمان",
    "Women's sports clubs and teams in the Central African Republic": "أندية وفرق رياضية نسائية في جمهورية إفريقيا الوسطى",
    "Women's sports clubs and teams in the Dominican Republic": "أندية وفرق رياضية نسائية في جمهورية الدومينيكان",
    "Women's sports clubs and teams in the Philippines": "أندية وفرق رياضية نسائية في الفلبين",
    "Women's sports clubs and teams in Togo": "أندية وفرق رياضية نسائية في توغو",
    "Women's sports clubs and teams in Trinidad and Tobago": "أندية وفرق رياضية نسائية في ترينيداد وتوباغو",
    "Women's sports clubs and teams in Uganda": "أندية وفرق رياضية نسائية في أوغندا",
    "Women's sports clubs and teams in Venezuela": "أندية وفرق رياضية نسائية في فنزويلا",
    "Women's sports clubs and teams in Zambia": "أندية وفرق رياضية نسائية في زامبيا",
    "Women's sports clubs and teams in Zimbabwe": "أندية وفرق رياضية نسائية في زيمبابوي",
    "Women's sports in Indianapolis": "رياضات نسائية في إنديانابوليس",
    "Women's sports in Minneapolis": "رياضات نسائية في مينيابوليس",
    "Women's sports in Oregon": "رياضات نسائية في أوريغن",
    "Women's sports in Palau": "رياضات نسائية في بالاو",
    "Women's sports in Vienna": "رياضات نسائية في فيينا",
}

to_test = [
    ("test_sports_data_1", data1),
    ("test_sports_data_2", data2),
    ("test_sports_data_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_sports_data_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_sports_data_2(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_sports_data_3(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
