"""
pytest tests_require_fixes/test_skip_data_all.py -m dump
"""

import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

test_data_1 = {
    "American wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة أمريكيون",
    "Canadian wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة كنديون",
    "Finnish wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة فنلنديون",
    "Scottish wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة إسكتلنديون",
    "Superhero television characters by franchise": "أبطال خارقون تلفازيون حسب حق الامتياز",
    "Swedish wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة سويديون",
    "Swiss wheelchair curling champions": "أبطال الكيرلنغ على الكراسي المتحركة سويسريون",
    "DC Comics superhero teams": "فرق أبطال دي سي كومكس",
    "Superheroes": "أبطال خارقون",
    "Superheroes in anime and manga": "أنمي ومانغا أبطال خارقين",
    "Superheroes by publisher": "أبطال خارقون حسب الناشر",
    "Superheroes by type": "أبطال خارقون حسب النوع",
    "Animal superheroes": "حيوانات أبطال خارقين",
    "Child superheroes": "أبطال خارقون أطفال",
    "Comics superheroes": "قصص مصورة حول أبطال خارقون",
    "DC Comics female superheroes": "بطلات دي سي كومكس الخارقات",
    "DC Comics superheroes": "أبطال دي سي كومكس",
    "Egyptian superheroes": "أبطال خارقون مصريون",
    "Golden Age superheroes": "أبطال العصر الذهبي",
    "Marvel Comics female superheroes": "بطلات مارفل كومكس الخارقات",
    "Marvel Comics superheroes": "أبطال خارقون في مارفل كومكس",
    "Muslim superheroes": "أبطال خارقون مسلمون",
    "Papua New Guinea and the United Nations": "بابوا غينيا الجديدة والأمم المتحدة",
    "qatar and united nations": "قطر والأمم المتحدة",
    "Turkey and United Nations": "تركيا والأمم المتحدة",
    "united kingdom–asian relations": "العلاقات الآسيوية البريطانية",
    "united kingdom–middle eastern relations": "العلاقات البريطانية الشرقية الأوسطية",
    "united kingdom–oceanian relations": "العلاقات الأوقيانوسية البريطانية",
    "united states–asian relations": "العلاقات الآسيوية الأمريكية",
    "united states–central american relations": "العلاقات الأمريكية الأمريكية الأوسطية",
    "united states–european relations": "العلاقات الأمريكية الأوروبية",
    "united states–middle eastern relations": "العلاقات الأمريكية الشرقية الأوسطية",
    "united states–north american relations": "العلاقات الأمريكية الأمريكية الشمالية",
    "united states–oceanian relations": "العلاقات الأمريكية الأوقيانوسية",
    "united states–south american relations": "العلاقات الأمريكية الأمريكية الجنوبية",
    "russian empire-united states relations": "العلاقات بين الإمبراطورية الروسية والولايات المتحدة",
    "german–romania military relations": "العلاقات الألمانية الرومانية العسكرية",
    "canada–oceanian relations": "العلاقات الأوقيانوسية الكندية",
    "American expatriate men's soccer players": "لاعبو كرة قدم أمريكيون مغتربون",
    "American rock music": "موسيقى الروك أمريكي",
    "Ancient Christian female saints": "قديسات مسيحيات قدماء",
    "Ancient Christians": "مسيحيون قدماء",
    "Ancient Jewish physicians": "أطباء يهود قدماء",
    "Ancient Jewish scholars": "دارسون يهود قدماء",
    "Ancient Jewish women": "يهوديات قدماء",
    "Ancient Jewish writers": "كتاب يهود قدماء",
    "Association football competitions in Africa for men's national teams": "منافسات كرة قدم في إفريقيا في منتخبات وطنية رجالية",
    "Association football competitions in Asia for men's national teams": "منافسات كرة قدم في آسيا في منتخبات وطنية رجالية",
    "Association football competitions in Europe for men's national teams": "منافسات كرة قدم في أوروبا في منتخبات وطنية رجالية",
    "Association football competitions in North America for men's national teams": "منافسات كرة قدم في أمريكا الشمالية في منتخبات وطنية رجالية",
    "Association football competitions in North America for national youth teams": "منافسات كرة قدم في أمريكا الشمالية في منتخبات وطنية شبابية",
    "australian electronic dance music": "موسيقى الرقص الإلكترونية الأسترالية",
    "austrian rock": "روك نمساوي",
    "Bengali folk songs": "أغاني فولك بنغالي",
    "Buddhist comics": "قصص مصورة بوذيون",
    "Buddhist media in Taiwan": "إعلام بوذيون في تايوان",
    "Buddhist media": "إعلام بوذيون",
    "Buddhist music": "موسيقى بوذيون",
    "Buddhist video games": "ألعاب فيديو بوذيون",
    "by benjamin britten": "بواسطة بنجامين بريتن",
    "by james cameron": "بواسطة جيمس كاميرون",
    "by raphael": "بواسطة رافاييل",
    "by vaikom muhammad basheer": "بواسطة محمد بشير",
    "Byzantine female saints": "قديسات بيزنطيات",
    "chinese professional baseball league awards": "جوائز دوري كرة القاعدة الصيني للمحترفين",
    "Christian country music": "كانتري مسيحي",
    "Christian electronic dance music songs": "أغاني موسيقى الرقص الإلكترونية مسيحي",
    "Christian electronic dance music": "موسيقى الرقص الإلكترونية مسيحي",
    "Christian hip-hop songs": "أغاني هيب هوب مسيحي",
    "Christian hip-hop": "هيب هوب مسيحي",
    "Christian R&B": "ريذم أند بلوز مسيحي",
    "CONCACAF competitions for men's national teams": "منافسات الكونكاكاف في منتخبات وطنية رجالية",
    "CONCACAF competitions for national youth teams": "منافسات الكونكاكاف في منتخبات وطنية شبابية",
    "czech deaf people": "أعلام تشيكيون صم",
    "Danish country music": "كانتري دنماركي",
    "danish dance songs": "أغاني رقص دنماركي",
    "deaf culture": "ثقافة صم",
    "Deaths by American drone strikes in Afghanistan": "وفيات بضربات طائرات مسيرة أمريكية في أفغانستان",
    "Deaths by American drone strikes in Pakistan": "وفيات بضربات طائرات مسيرة أمريكية في باكستان",
    "Deaths by American drone strikes in Syria": "وفيات بضربات طائرات مسيرة أمريكية في سوريا",
    "Deaths by American drone strikes in Yemen": "وفيات بهجمات طائرات بدون طيار أمريكية في اليمن",
    "Deaths by American drone strikes": "وفيات بضربات طائرات مسيرة نفذتها الولايات المتحدة",
    "Deaths by arrow wounds": "وفيات بسبب طعنات رماح",
    "Deaths by beating in the United States": "وفيات بسبب الضرب في الولايات المتحدة",
    "Deaths by beating": "وفيات بسبب الضرب",
    "Deaths by car bomb": "وفيات بسيارة مفخخة",
    "Deaths by cause": "وفيات حسب السبب",
    "Deaths by dehydration": "وفيات بسبب جفاف",
    "Deaths by drone strikes of the Central Intelligence Agency in Pakistan": "وفيات بضربات طائرات مسيرة في عمليات وكالة المخابرات المركزية في باكستان",
    "Deaths by drone strikes of the Central Intelligence Agency in Yemen": "وفيات بهجمات طائرات بدون طيار في عمليات وكالة المخابرات المركزية في اليمن",
    "Deaths by drone strikes of the Central Intelligence Agency": "وفيات بضربات طائرات مسيرة في عمليات وكالة المخابرات المركزية",
    "Deaths by drowning": "وفيات بسبب الغرق",
    "Deaths by electrocution": "وفيات بسبب الكهرباء",
    "Deaths by euthanasia": "وفيات بسبب القتل الرحيم",
    "Deaths by execution in the United States by state": "وفيات بالإعدام في الولايات المتحدة حسب الولاية",
    "Deaths by firearm in international waters": "وفيات بإطلاق النار في مياه دولية",
    "Deaths by firearm in Timor-Leste": "وفيات بإطلاق النار في تيمور الشرقية",
    "Deaths by firearm in Victoria (state)": "وفيات بإطلاق النار في فيكتوريا (أستراليا)",
    "Deaths by horse-riding accident": "وفيات بسبب حادث السقوط عن الحصان",
    "Deaths by poisoning": "وفيات بسبب السم",
    "Deaths by smoke inhalation": "وفيات بسبب استنشاق الدخان",
    "Deaths by starvation": "وفيات بسبب الجوع",
    "Deaths by strangulation in the United States": "وفيات بالخنق في الولايات المتحدة",
    "Deaths by type of illness": "وفيات حسب المرض",
    "Deaths due to dog attacks": "وفيات بسبب هجمات الكلاب",
    "Deaths due to fish attacks": "وفيات بسبب هجمات الأسماك",
    "Deaths due to hippopotamus attacks": "وفيات بسبب هجمات فرس النهر",
    "Deaths due to injuries sustained in boxing": "وفيات بسبب إصابات أثناء الملاكمة",
    "Deaths due to shipwreck": "وفيات بسبب غرق سفن",
    "Deaths due to snake bites": "وفيات بسبب لدغات الثعابين",
    "Deaths due to wolf attacks": "وفيات بسبب هجمات الذئب",
    "Deaths during the Bahraini uprising of 2011": "وفيات خلال الاحتجاجات البحرينية 2011",
    "Deaths from abdominal aortic aneurysm": "وفيات بسبب تمدد الشريان الأبهر البطني",
    "Deaths from actinomycosis": "وفيات بسبب داء الشعيات",
    "Deaths from adenoid cystic carcinoma": "وفيات بسبب سرطانة غدانية كيسية",
    "Deaths from African trypanosomiasis": "وفيات بسبب داء المثقبيات الإفريقي",
    "Deaths from AIDS-related illness": "وفيات بسبب الإيدز",
    "Deaths from Alzheimer's disease by country": "وفيات ناجمة عن مرض آلزهايمر حسب البلد",
    "Deaths from Alzheimer's disease in the United States": "وفيات ناجمة عن مرض آلزهايمر في الولايات المتحدة",
    "Deaths from Alzheimer's disease": "وفيات بسبب مرض آلزهايمر",
    "Deaths from anal cancer": "وفيات بسبب سرطان الشرج",
    "Deaths from anemia": "وفيات بسبب فقر الدم",
    "Deaths from aneurysm": "وفيات بسبب أم الدم",
    "Deaths from angiosarcoma": "وفيات من ساركومة وعائية",
    "Deaths from anorexia nervosa": "وفيات بسبب فقدان الشهية العصابي",
    "Deaths from anthrax": "وفيات بسبب جمرة خبيثة",
    "Deaths from aortic aneurysm": "وفيات بسبب أم الدم الأبهرية",
    "Deaths from aortic dissection": "وفيات بسبب تسلخ الأبهر",
    "Deaths from appendicitis": "وفيات بسبب التهاب الزائدة الدودية",
    "Deaths from arteriosclerosis": "وفيات بسبب تصلب الشرايين",
    "Deaths from arthritis": "وفيات بسبب التهاب المفاصل",
    "Deaths from asphyxiation": "وفيات بسبب الاختناق",
    "Deaths from asthma": "وفيات بسبب الربو",
    "Deaths from bladder cancer": "وفيات بسبب سرطان المثانة",
    "Deaths from bleeding": "وفيات بسبب النزف",
    "Deaths from bone cancer": "وفيات بسبب سرطان العظام",
    "Deaths from brain tumor": "وفيات بسبب ورم الدماغ",
    "Deaths from breast cancer": "وفيات بسبب سرطان الثدي",
    "Deaths from bronchitis": "وفيات بسبب التهاب القصبات",
    "Deaths from bronchopneumonia": "وفيات بسبب ذات الرئة القصبية",
    "Deaths from cancer in Victoria (state)": "وفيات السرطان في فيكتوريا (أستراليا)",
    "Deaths from carbon monoxide poisoning": "وفيات بسبب التسمم بأحادي أكسيد الكربون",
    "Deaths from cardiomyopathy": "وفيات بسبب اعتلال عضلة القلب",
    "Deaths from cervical cancer": "وفيات بسبب سرطان عنق الرحم",
    "Deaths from choking": "وفيات بسبب الشرقة",
    "Deaths from cholangiocarcinoma": "وفيات بسبب سرطانة الأقنية الصفراوية",
    "Deaths from cholera": "وفيات بسبب الكوليرا",
    "Deaths from cirrhosis": "وفيات بسبب التشمع",
    "Deaths from colorectal cancer": "وفيات بسبب سرطان القولون",
    "Deaths from coronary thrombosis": "وفيات بسبب خثار تاجي",
    "Deaths from Crohn's disease": "وفيات بسبب داء كرون",
    "Deaths from cystic fibrosis": "وفيات بسبب التليف الكيسي",
    "Deaths from dementia by country": "وفيات ناجمة عن الخرف حسب البلد",
    "Deaths from dementia in the United States": "وفيات من الخرف في الولايات المتحدة",
    "Deaths from dementia": "وفيات بسبب الخرف",
    "Deaths from dengue fever": "وفيات من حمى الضنك",
    "Deaths from diabetes": "وفيات بسبب مرض السكري",
    "Deaths from diphtheria": "وفيات بسبب الخناق",
    "Deaths from disease": "وفيات بسبب الأمراض",
    "Deaths from dysentery": "وفيات بسبب الزحار",
    "Deaths from Ebola": "وفيات بسبب الإيبولا",
    "Deaths from edema": "وفيات بسبب وذمة",
    "Deaths from embolism": "وفيات بسبب انسداد وعائي",
    "Deaths from emphysema": "وفيات بسبب داء الانسداد الرئوي المزمن",
    "Deaths from endocarditis": "وفيات بسبب التهاب الشغاف",
    "Deaths from epilepsy": "وفيات بسبب الصرع",
    "Deaths from esophageal cancer by country": "وفيات بسبب سرطان المريء حسب البلد",
    "Deaths from esophageal cancer in Australia": "وفيات بسبب سرطان المريء في أستراليا",
    "Deaths from esophageal cancer in Belgium": "وفيات بسبب سرطان المريء في بلجيكا",
    "Deaths from esophageal cancer in California": "وفيات بسبب سرطان المريء في كاليفورنيا",
    "Deaths from esophageal cancer in Canada": "وفيات بسبب سرطان المريء في كندا",
    "Deaths from esophageal cancer in Denmark": "وفيات بسبب سرطان المريء في الدنمارك",
    "Deaths from esophageal cancer in England": "وفيات بسبب سرطان المريء في إنجلترا",
    "Deaths from esophageal cancer in Finland": "وفيات بسبب سرطان المريء في فنلندا",
    "Deaths from esophageal cancer in Florida": "وفيات بسبب سرطان المريء في فلوريدا",
    "Deaths from esophageal cancer in France": "وفيات بسبب سرطان المريء في فرنسا",
    "Deaths from esophageal cancer in Germany": "وفيات بسبب سرطان المريء في ألمانيا",
    "Deaths from esophageal cancer in Japan": "وفيات بسبب سرطان المريء في اليابان",
    "Deaths from esophageal cancer in New York (state)": "وفيات بسبب سرطان المريء في نيويورك",
    "Deaths from esophageal cancer in Texas": "وفيات بسبب سرطان المريء في تكساس",
    "Deaths from esophageal cancer in the Netherlands": "وفيات بسبب سرطان المريء في هولندا",
    "Deaths from esophageal cancer in the United Kingdom": "وفيات بسبب سرطان المريء في المملكة المتحدة",
    "Deaths from esophageal cancer in the United States": "وفيات بسبب سرطان المريء في الولايات المتحدة",
    "Deaths from esophageal cancer": "وفيات بسبب سرطان المريء",
    "Deaths from falls": "وفيات بسبب السقوط",
    "Deaths from gallbladder cancer": "وفيات بسبب سرطان الحويصلة الصفراوية",
    "Deaths from gangrene": "وفيات بسبب الغنغرينا",
    "Deaths from gastritis": "وفيات بسبب التهاب المعدة",
    "Deaths from head injury": "وفيات بسبب إصابات الرأس",
    "Deaths from heart cancer": "وفيات بسبب سرطان القلب",
    "Deaths from hepatitis": "وفيات بسبب التهاب الكبد",
    "Deaths from hernias": "وفيات بسبب فتوق",
    "Deaths from hypertension": "وفيات بسبب ارتفاع ضغط الدم",
    "Deaths from hyperthermia": "وفيات بسبب فرط الحرارة",
    "Deaths from hypothermia": "وفيات بسبب انخفاض الحرارة",
    "Deaths from hypoxia": "وفيات بسبب نقص التأكسج",
    "Deaths from influenza": "وفيات بسبب الإنفلونزا",
    "Deaths from intracranial aneurysm": "وفيات بسبب أم الدم داخل القحف",
    "Deaths from kidney cancer": "وفيات بسبب سرطان الكلية",
    "Deaths from kidney disease": "وفيات بسبب أمراض الكلى",
    "Deaths from kidney failure": "وفيات بسبب الفشل الكلوي",
    "Deaths from laryngeal cancer": "وفيات بسبب سرطان الحنجرة",
    "Deaths from laughter": "وفيات بسبب الضحك",
    "Deaths from leiomyosarcoma": "وفيات بسبب الساركومة العضلية الملساء",
    "Deaths from leprosy": "وفيات بسبب الجذام",
    "Deaths from leukemia by country": "وفيات بسبب سرطان الدم حسب البلد",
    "Deaths from leukemia in Jamaica": "وفيات بسبب سرطان الدم في جامايكا",
    "Deaths from leukemia": "وفيات بسبب سرطان الدم",
    "Deaths from Lewy body dementia": "وفيات بسبب خرف أجسام ليوي",
    "Deaths from liposarcoma": "وفيات بسبب الساركومة الشحمية",
    "Deaths from liver cancer": "وفيات بسبب سرطان الكبد",
    "Deaths from liver disease": "وفيات بسبب أمراض الكبد",
    "Deaths from lung disease": "وفيات بسبب أمراض الرئة",
    "Deaths from lupus": "وفيات بسبب الذئبة الحمراء",
    "Deaths from lymphoma": "وفيات بسبب اللمفوما",
    "Deaths from malaria": "وفيات بسبب الملاريا",
    "Deaths from measles": "وفيات بسبب مرض الحصبة",
    "Deaths from melanoma": "وفيات بسبب الورم الميلانيني",
    "Deaths from meningitis": "وفيات بسبب التهاب السحايا",
    "Deaths from methicillin-resistant Staphylococcus aureus": "وفيات بسبب المكورات العنقودية الذهبية المقاومة للميثيسيلين",
    "Deaths from motor neuron disease": "وفيات بسبب مرض العصبون الحركي",
    "Deaths from multiple myeloma": "وفيات بسبب ورم نخاعي متعدد",
    "Deaths from multiple organ failure": "وفيات بسبب متلازمة الاختلال العضوي المتعدد",
    "Deaths from multiple sclerosis": "وفيات بسبب التصلب المتعدد",
    "Deaths from multiple system atrophy": "وفيات بسبب الضمور الجهازي المتعدد",
    "Deaths from myasthenia gravis": "وفيات بسبب الوهن العضلي الوبيل",
    "Deaths from myelodysplastic syndrome": "وفيات بسبب متلازمة خلل التنسج النخاعي",
    "Deaths from nephritis": "وفيات بسبب التهاب الكلى",
    "Deaths from neurodegenerative disease": "وفيات بسبب مرض تحللي عصبي",
    "Deaths from neuromuscular disease": "وفيات بسبب مرض عصبي عضلي",
    "Deaths from osteomyelitis": "وفيات بسبب التهاب العظم والنقي",
    "Deaths from ovarian cancer": "وفيات بسبب سرطان المبيض",
    "Deaths from pancreatic cancer in Japan": "وفيات سرطان البنكرياس في اليابان",
    "Deaths from pancreatic cancer": "وفيات بسبب سرطان البنكرياس",
    "Deaths from pancreatitis": "وفيات بسبب التهاب البنكرياس",
    "Deaths from Parkinson's disease": "وفيات بسبب مرض باركنسون",
    "Deaths from peritoneal cancer": "وفيات بسبب سرطان البريتون",
    "Deaths from peritonitis": "وفيات بسبب التهاب البريتون",
    "Deaths from peritonsillar abscess": "وفيات بسبب خراج مجاورات اللوزة",
    "Deaths from pernicious anemia": "وفيات بسبب فقر الدم الخبيث",
    "Deaths from plague (disease)": "وفيات بسبب طاعون",
    "Deaths from pneumonia in Victoria (state)": "وفيات الالتهاب الرئوي في فيكتوريا (أستراليا)",
    "Deaths from pneumothorax": "وفيات بسبب استرواح الصدر",
    "Deaths from progressive supranuclear palsy": "وفيات بسبب الشلل فوق النوى المترقي",
    "Deaths from prostate cancer": "وفيات بسبب سرطان البروستات",
    "Deaths from pulmonary embolism": "وفيات بسبب انصمام رئوي",
    "Deaths from pulmonary fibrosis": "وفيات بسبب التليف الرئوي",
    "Deaths from respiratory failure": "وفيات بسبب الفشل التنفسي",
    "Deaths from scurvy": "وفيات بسبب نقص فيتامين سي",
    "Deaths from sepsis": "وفيات بسبب خمج الدم",
    "Deaths from skeletal disease": "وفيات بسبب مرض عظمي",
    "Deaths from skin cancer": "وفيات بسبب سرطان الجلد",
    "Deaths from small intestine cancer": "وفيات بسبب السرطان المعوي",
    "Deaths from smallpox": "وفيات بسبب الجدري",
    "Deaths from Spanish flu": "وفيات بسبب الإنفلونزا الإسبانية",
    "Deaths from spinal cancer": "وفيات بسبب سرطان العمود الفقري",
    "Deaths from staphylococcal infection": "وفيات بسبب البكتيريا العنقودية",
    "Deaths from stomach cancer": "وفيات بسبب سرطان المعدة",
    "Deaths from streptococcus infection": "وفيات بسبب عدوى المكورة العقدية",
    "Deaths from subarachnoid hemorrhage": "وفيات بسبب نزف تحت العنكبوتية",
    "Deaths from surgical complications": "وفيات بسبب مضاعفات جراحية",
    "Deaths from sweating sickness": "وفيات بسبب التعرق",
    "Deaths from syphilis": "وفيات بسبب الزهري",
    "Deaths from testicular cancer": "وفيات بسبب سرطان الخصية",
    "Deaths from tetanus": "وفيات بسبب الكزاز",
    "Deaths from the Spanish flu pandemic": "وفيات بسبب الإنفلونزا الإسبانية",
    "Deaths from throat cancer": "وفيات بسبب سرطان الرأس والعنق",
    "Deaths from thrombosis": "وفيات بسبب الجلطات",
    "Deaths from thyroid cancer": "وفيات بسبب سرطان الغدة الدرقية",
    "Deaths from typhoid fever": "وفيات بسبب حمى التيفوئيد",
    "Deaths from typhus": "وفيات بسبب التيفوس",
    "Deaths from uterine cancer": "وفيات بسبب سرطان الرحم",
    "Deaths from varicella zoster infection": "وفيات بعدوى فيروس جدري الماء النطاقي",
    "Deaths from vasculitis": "وفيات بسبب التهاب الوعائي",
    "Deaths from whooping cough": "وفيات بسبب السعال الديكي",
    "Deaths from yellow fever": "وفيات بسبب الحمى الصفراء",
    "defunct amusement parks": "متنزهات ملاهي سابقة",
    "defunct asian restaurants": "مطاعم آسيوية سابقة",
    "Defunct Christian organizations based in United States": "منظمات مسيحية سابقة مقرها في الولايات المتحدة",
    "Defunct Christian schools in Canada": "مدارس مسيحية سابقة في كندا",
    "Defunct Christian schools in United States": "مدارس مسيحية سابقة في الولايات المتحدة",
    "defunct comedy clubs": "أندية كوميدية سابقة",
    "defunct communist parties": "أحزاب شيوعية سابقة",
    "defunct cycling races": "سباقات سباق دراجات هوائية سابقة",
    "defunct elementary schools": "مدارس إبتدائية سابقة",
    "defunct european restaurants": "مطاعم أوروبية سابقة",
    "defunct far-right political parties": "أحزاب اليمين المتطرف سابقة",
    "defunct feminist organizations": "منظمات نسوية سابقة",
    "defunct french restaurants": "مطاعم فرنسية سابقة",
    "defunct high schools": "مدارس ثانوية سابقة",
    "Defunct Islamic organizations based in United States": "منظمات إسلامية سابقة مقرها في الولايات المتحدة",
    "defunct italian restaurants": "مطاعم إيطالية سابقة",
    "defunct japanese restaurants": "مطاعم يابانية سابقة",
    "Defunct Jewish organizations based in United States": "منظمات يهودية سابقة مقرها في الولايات المتحدة",
    "defunct liberal parties": "أحزاب ليبرالية سابقة",
    "defunct lower houses": "المجالس الدنيا سابقة",
    "defunct mexican restaurants": "مطاعم مكسيكية سابقة",
    "defunct middle schools": "مدارس إعدادية سابقة",
    "defunct multi-national basketball leagues": "دوريات كرة سلة متعددة الجنسيات سابقة",
    "defunct private schools": "مدارس خاصة سابقة",
    "defunct professional sports leagues": "دوريات رياضية للمحترفين سابقة",
    "defunct public high schools": "مدارس ثانوية عامة سابقة",
    "defunct radio networks": "شبكات مذياع سابقة",
    "defunct radio stations": "محطات إذاعية سابقة",
    "defunct railway stations": "محطات السكك الحديدية سابقة",
    "defunct right-wing parties": "أحزاب يمينية سابقة",
    "defunct socialist parties": "أحزاب اشتراكية سابقة",
    "defunct sports governing bodies": "هيئات تنظيم رياضية سابقة",
    "defunct television channels": "قنوات تلفزيونية سابقة",
    "defunct television networks": "شبكات تلفزيونية سابقة",
    "defunct tourist attractions": "مواقع جذب سياحي سابقة",
    "defunct trade unions": "نقابات عمالية سابقة",
    "defunct women's basketball competitions": "منافسات كرة سلة نسائية سابقة",
    "defunct women's basketball leagues": "دوريات كرة سلة نسائية سابقة",
    "defunct women's football clubs": "أندية كرة قدم نسائية سابقة",
    "defunct women's soccer leagues": "دوريات كرة قدم نسائية سابقة",
    "english country music": "كانتري إنجليزي",
    "Estonian rock music": "موسيقى الروك إستوني",
    "Expatriate men's footballers in Papua New Guinea": "لاعبو كرة قدم مغتربون في بابوا غينيا الجديدة",
    "expatriate men's footballers": "لاعبو كرة قدم مغتربون",
    "expatriate men's soccer players": "لاعبو كرة قدم مغتربون",
    "Fictional people executed for murder": "أشخاص خياليون أعدموا بتهمة قتل",
    "Fictional people executed for treason": "أشخاص خياليون أعدموا بتهمة خيانة",
    "French electronic songs": "أغاني إليكترونيك فرنسي",
    "Hindu music": "موسيقى هندوس",
    "Holocaust literature": "أدب هولوكوست",
    "hong kong rock songs": "أغاني روك هونغ كونغي",
    "Icelandic deaf people": "أعلام آيسلنديون صم",
    "Indian folk songs": "أغاني فولك هندي",
    "irish pop songs": "أغاني بوب أيرلندي",
    "Islamic media in India": "إعلام إسلاميون في الهند",
    "Islamic media": "إعلام إسلاميون",
    "Islamic music": "موسيقى إسلاميون",
    "Jewish dance": "رقص يهودي",
    "Jewish folk songs": "أغاني فولك يهودي",
    "Jewish hip-hop": "هيب هوب يهودي",
    "Jewish rock songs": "أغاني روك يهودي",
    "Jewish rock": "روك يهودي",
    "korean traditional music": "موسيقى تقليدية كوري",
    "Members of the Communist Party of the Soviet Union executed by the Soviet Union": "أعضاء الحزب الشيوعي في الاتحاد السوفيتي أعدموا من قبل الاتحاد السوفيتي",
    "Members of the Riksdag 2010–2010": "أعضاء البرلمان السويدي 2010–2010",
    "mexican revolution films": "أفلام الثورة المكسيكية",
    "Mexican television awards": "جوائز التلفزة المكسيكية",
    "middle eastern traditional music": "موسيقى تقليدية شرق أوسطي",
    "Mongolian traditional music": "موسيقى تقليدية منغولي",
    "Murdered American Jews": "أمريكيون يهود قتلوا",
    "Nazi culture": "ثقافة نازيون",
    "Nazi songs": "أغاني نازيون",
    "Non-fiction writers about the French Connection": "كتاب غير روائيين عن الرابط الفرنسي",
    "north american television awards": "جوائز التلفزة الأمريكية الشمالية",
    "paralympics people": "أشخاص في الألعاب البارالمبية",
    "People executed in the Philippines during World War II": "أشخاص أعدموا في الفلبين خلال الحرب العالمية الثانية",
    "People from Baden-Württemberg executed by Nazi Germany": "أشخاص من بادن-فورتمبيرغ أعدموا من قبل ألمانيا النازية",
    "People from Bavaria executed by Nazi Germany": "أشخاص من بافاريا أعدموا من قبل ألمانيا النازية",
    "People from Berlin executed by Nazi Germany": "أشخاص من برلين أعدموا من قبل ألمانيا النازية",
    "People from Brandenburg executed by Nazi Germany": "أشخاص من براندنبورغ أعدموا من قبل ألمانيا النازية",
    "People from Bremen (state) executed by Nazi Germany": "أشخاص من ولاية بريمن أعدموا من قبل ألمانيا النازية",
    "People from Georgia (country) executed by the Soviet Union": "أشخاص من جورجيا أعدموا من قبل الاتحاد السوفيتي",
    "People from Hamburg executed by Nazi Germany": "أشخاص من هامبورغ أعدموا من قبل ألمانيا النازية",
    "People from Hesse executed by Nazi Germany": "أشخاص من هسن أعدموا من قبل ألمانيا النازية",
    "People from Lower Saxony executed by Nazi Germany": "أشخاص من سكسونيا السفلى أعدموا من قبل ألمانيا النازية",
    "People from Mecklenburg-Vorpommern executed by Nazi Germany": "أشخاص من مكلنبورغ فوربومرن أعدموا من قبل ألمانيا النازية",
    "People from North Rhine-Westphalia executed by Nazi Germany": "أشخاص من شمال الراين-وستفاليا أعدموا من قبل ألمانيا النازية",
    "People from Rhineland-Palatinate executed by Nazi Germany": "أشخاص من راينلند بالاتينات أعدموا من قبل ألمانيا النازية",
    "People from Saxony executed by Nazi Germany": "أشخاص من ساكسونيا أعدموا من قبل ألمانيا النازية",
    "People from Saxony-Anhalt executed by Nazi Germany": "أشخاص من ساكسونيا أنهالت أعدموا من قبل ألمانيا النازية",
    "People from Schleswig-Holstein executed by Nazi Germany": "أشخاص من شليسفيغ هولشتاين أعدموا من قبل ألمانيا النازية",
    "People from Thuringia executed by Nazi Germany": "أشخاص من تورينغن أعدموا من قبل ألمانيا النازية",
    "Romanian football clubs in international competitions": "أندية كرة القدم الرومانية في منافسات دولية",
    "Romantic composers": "ملحنون رومانسيون",
    "russian blind people": "أعلام روس مكفوفون",
    "Serbian hip-hop": "هيب هوب صربي",
    "singaporean blind people": "أعلام سنغافوريون مكفوفون",
    "slovenian deaf people": "أعلام سلوفينيون صم",
    "taiwanese hip hop": "هيب هوب تايواني",
    "ukrainian deaf people": "أعلام أوكرانيون صم",
}

test_data_empty = {
    "2021 Tamil-language television series endings": "x",
    "2024–2026 ICC Cricket World Cup League 2": "x",
    "2026 All Elite Wrestling pay-per-view events": "x",
    "2026 All-Ireland Senior Football Championship": "x",
    "2026 anime": "x",
    "2026 beauty pageants": "x",
    "2026 Canadian Football League season by team": "x",
    "2026 CONCACAF Champions Cup participants seasons": "x",
    "2026 CONCACAF Champions Cup": "x",
    "2026 concert residencies": "x",
    "2026 concert tours": "x",
    "2026 debut works": "x",
    "2026 directorial debut films": "x",
    "2026 FIA World Endurance Championship season": "x",
    "2026 FIBA 3x3 World Cup": "x",
    "2026 FIFA World Cup qualification (CONCACAF)": "x",
    "2026 FIFA World Cup qualification (UEFA)": "x",
    "2026 FIFA World Cup qualification templates": "x",
    "2026 IIHF Men's World Ice Hockey Championships": "x",
    "2026 IIHF U18 Women's World Championships": "x",
    "2026 in 3x3 basketball": "x",
    "2026 in Asian international football": "x",
    "2026 in Asian men's football": "x",
    "2026 in Asian men's international football": "x",
    "2026 in Asian women's international football": "x",
    "2026 in Asian youth football": "x",
    "2026 in Catalan sport": "x",
    "2026 in computing": "x",
    "2026 in disability sport": "x",
    "2026 in European international football": "x",
    "2026 in European men's football": "x",
    "2026 in European men's international football": "x",
    "2026 in European women's international football": "x",
    "2026 in European youth football": "x",
    "2026 in Formula Three": "x",
    "2026 in Ladies' Gaelic football": "x",
    "2026 in LGBTQ history": "x",
    "2026 in men's international sport": "x",
    "2026 in North Macedonia sport": "x",
    "2026 in OFC football": "x",
    "2026 in ski mountaineering": "x",
    "2026 in speedway": "x",
    "2026 in strength athletics": "x",
    "2026 in the sport of athletics": "x",
    "2026 in track racing": "x",
    "2026 in UFC": "x",
    "2026 in West Indian cricket": "x",
    "2026 in women's international sport": "x",
    "2026 London Borough council elections": "x",
    "2026 Major League Baseball season": "x",
    "2026 Men's FIH Hockey World Cup qualification": "x",
    "2026 Men's FIH Hockey World Cup Qualifying Tournaments": "x",
    "2026 Men's FIH Hockey World Cup": "x",
    "2026 Men's T20 World Cup qualification": "x",
    "2026 Men's T20 World Cup templates": "x",
    "2026 Men's T20 World Cup": "x",
    "2026 multiplayer online battle arena tournaments": "x",
    "2026 National Football League (Ireland)": "x",
    "2026 NFL season": "x",
    "2026 Ontario municipal elections": "x",
    "2026 political party leadership elections": "x",
    "2026 song contests": "x",
    "2026 Speedway Grand Prix": "x",
    "2026 State Assembly elections in India": "x",
    "2026 state constitutional officer elections in the United States": "x",
    "2026 state legislature special elections in the United States": "x",
    "2026 television specials": "x",
    "2026 U.S. legislative sessions": "x",
    "2026 UEFA European Under-17 Championship": "x",
    "2026 UEFA European Under-19 Championship": "x",
    "2026 Under-19 Men's Cricket World Cup": "x",
    "2026 United States county executive elections": "x",
    "2026 United States judicial elections": "x",
    "2026 United States lieutenant gubernatorial elections": "x",
    "2026 United States mayoral elections": "x",
    "2026 United States state attorney general elections": "x",
    "2026 United States state auditor elections": "x",
    "2026 United States state secretary of state elections": "x",
    "2026 United States state superintendent of public instruction elections": "x",
    "2026 United States state treasurer elections": "x",
    "2026 WAFF Championship": "x",
    "2026 Women's FIH Hockey World Cup qualification": "x",
    "2026 Women's FIH Hockey World Cup Qualifying Tournaments": "x",
    "2026 Women's FIH Hockey World Cup": "x",
    "2026 Women's T20 World Cup qualification": "x",
    "2026 Women's T20 World Cup templates": "x",
    "2026 Women's T20 World Cup": "x",
    "2026 World Rally Championship season": "x",
    "2026 WWE Network events": "x",
    "2026 WWE pay-per-view events": "x",
    "2026–27 Australian cricket season": "x",
    "2026–27 in European international football": "x",
    "2026–27 in European men's field hockey": "x",
    "2026–27 in European men's football": "x",
    "2026–27 in European men's international football": "x",
    "2026–27 U Sports season": "x",
    "2026–27 UEFA Conference League": "x",
    "20th-century American newspaper publishers (people)": "x",
    "21st-century Moroccan LGBTQ people": "x",
    "Abortion in non-fiction": "x",
    "Academic staff of Süleyman Demirel University": "x",
    "Academicians of non-governmental academies based in Russia": "x",
    "Advisory non-departmental public bodies of the Scottish Government": "x",
    "AfC submissions declined as a non-notable academic topic": "x",
    "AfC submissions declined as a non-notable athletic topic": "x",
    "AfC submissions declined as a non-notable biography": "x",
    "AfC submissions declined as a non-notable book": "x",
    "AfC submissions declined as a non-notable event": "x",
    "AfC submissions declined as a non-notable film": "x",
    "AfC submissions declined as a non-notable musical topic": "x",
    "AfC submissions declined as a non-notable organization": "x",
    "AfC submissions declined as non-notable web content": "x",
    "AfC submissions declined as non-notable": "x",
    "AfC submissions rejected as non-notable": "x",
    "Africa territory (non-sovereign) templates": "x",
    "Akron Firestone Non-Skids coaches": "x",
    "Akron Firestone Non-Skids players": "x",
    "Akron Firestone Non-Skids seasons": "x",
    "Akron Firestone Non-Skids": "x",
    "Album articles with non-standard infoboxes": "x",
    "All articles with improper non-free content": "x",
    "All non-free logos": "x",
    "All non-free media": "x",
    "Alumni of Teesside University": "x",
    "American non-commissioned personnel": "x",
    "American non-fiction children's writers": "x",
    "American non-fiction literary awards": "x",
    "American non-fiction outdoors writers": "x",
    "American soccer clubs 2026 season": "x",
    "Amusement rides planned to open in 2026": "x",
    "Animal testing on non-human primates": "x",
    "Anthems of non-sovereign states": "x",
    "Antiquities in Pushkin Museum": "x",
    "Arabic non-fiction books": "x",
    "Arabic non-fiction literature": "x",
    "Aromanian non-fiction writers": "x",
    "Articles containing Bantayanon-language text": "x",
    "Articles containing Bantoanon-language text": "x",
    "Articles containing Butuanon-language text": "x",
    "Articles containing Capiznon-language text": "x",
    "Articles containing Cuyonon-language text": "x",
    "Articles containing Higaonon-language text": "x",
    "Articles containing Hiligaynon-language text": "x",
    "Articles containing Malaynon-language text": "x",
    "Articles containing non-English-language text": "x",
    "Articles containing Northern Sorsoganon-language text": "x",
    "Articles containing potentially dated statements from April 2014": "x",
    "Articles containing potentially dated statements from February 2024": "x",
    "Articles containing Ratagnon-language text": "x",
    "Articles containing Romblomanon-language text": "x",
    "Articles containing Southern Sorsoganon-language text": "x",
    "Articles containing Surigaonon-language text": "x",
    "Articles containing Tandaganon-language text": "x",
    "Articles containing Western Subanon-language text": "x",
    "Articles lacking reliable references from February 2013": "x",
    "Articles needing non-English script or text": "x",
    "Articles with dead external links from June 2017": "x",
    "Articles with excessive non-free audio content": "x",
    "Articles with improper non-free content": "x",
    "Articles with non-English-language CS1 sources": "x",
    "Articles with non-English-language sources": "x",
    "Articles with non-HTML file bare URLs for citations": "x",
    "Asia territory (non-sovereign) templates": "x",
    "Assam MLAs 2021–2026": "x",
    "Association football player non-biographical articles": "x",
    "Australian non-commissioned personnel": "x",
    "Australian non-fiction book awards": "x",
    "Azad Kashmir MLAs 2021–2026": "x",
    "Battle of Greece": "x",
    "Bisexual non-fiction books": "x",
    "Bollywood Hungama movie template using non-numeric ID": "x",
    "Bollywood Hungama person template using non-numeric ID": "x",
    "Bosnia and Herzegovina non-alcoholic drinks": "x",
    "Bosnian War in non-fiction": "x",
    "British non-commissioned personnel": "x",
    "British non-fiction literary awards": "x",
    "British non-fiction outdoors writers": "x",
    "Buddhism articles needing non-English scripting support & specialist attention": "x",
    "Canadian non-fiction literary awards": "x",
    "Candidates for speedy deletion as dependent on a non-existent page": "x",
    "Cannon-launched guided projectiles": "x",
    "Chairpersons of non-governmental organizations": "x",
    "Children's non-fiction books": "x",
    "Children's non-fiction writers": "x",
    "Chinese people by non-city prefecture-level division": "x",
    "Christian non-aligned Scouting organizations": "x",
    "Citation Style 1 templates using non-standard parameters": "x",
    "Class masks with non-standard classes": "x",
    "Closed non-builders": "x",
    "Club of Committed Non-Party Members politicians": "x",
    "Coats of arms of non-metropolitan district councils": "x",
    "Collaborative non-fiction books": "x",
    "Collaborative non-fiction": "x",
    "Cometary object redirects (non-primary)": "x",
    "Completed non-free use rationale logo transclusions": "x",
    "Conversion of non-Christian religious buildings and structures into churches": "x",
    "Countries in the Eurovision Song Contest 2026": "x",
    "Cue sports articles with good non-English versions": "x",
    "Deaths from non-Hodgkin lymphoma": "x",
    "Defunct non-departmental public bodies of the United Kingdom government": "x",
    "Defunct non-English-language newspapers published in the United States": "x",
    "Drugs with non-standard legal status": "x",
    "Drugs with non-standard pregnancy category": "x",
    "Dutch-language non-fiction books": "x",
    "Editnotices with unsalted non-existent targets": "x",
    "Educational technology non-profits": "x",
    "English non-fiction outdoors writers": "x",
    "English non-league football articles by importance": "x",
    "English non-league football articles by quality": "x",
    "English non-League football club squad templates": "x",
    "English non-league football task force articles": "x",
    "English non-league football task force": "x",
    "English non-league team of the year navigational boxes": "x",
    "English-language non-fiction books": "x",
    "Environmental non-fiction books": "x",
    "Episode lists with a non-matching set of numbered parameters": "x",
    "Episode lists with non-compliant line colors": "x",
    "Europe territory (non-sovereign) templates": "x",
    "Eurovision Song Contest 2026": "x",
    "Executive non-departmental public bodies of the Scottish Government": "x",
    "Experimental drugs developed for non-alcoholic fatty liver disease": "x",
    "Experimental non-hallucinogens": "x",
    "Fiction redirect categories with non-existent parent categories": "x",
    "Fictional non-commissioned officers": "x",
    "Fictional United States Army non-commissioned officers": "x",
    "First secretaries in non-national subdivisions of the Soviet Union": "x",
    "FootballFacts.ru template using non-numeric ID": "x",
    "Former evangelical non-denominational churches": "x",
    "Former non-metropolitan counties": "x",
    "Former non-metropolitan district councils of England": "x",
    "Former non-metropolitan districts of Avon": "x",
    "Former non-metropolitan districts of Bedfordshire": "x",
    "Former non-metropolitan districts of Buckinghamshire": "x",
    "Former non-metropolitan districts of Cheshire": "x",
    "Former non-metropolitan districts of Cornwall": "x",
    "Former non-metropolitan districts of Cumbria": "x",
    "Former non-metropolitan districts of Dorset": "x",
    "Former non-metropolitan districts of Durham": "x",
    "Former non-metropolitan districts of East Sussex": "x",
    "Former non-metropolitan districts of Hereford and Worcester": "x",
    "Former non-metropolitan districts of Humberside": "x",
    "Former non-metropolitan districts of Kent": "x",
    "Former non-metropolitan districts of North Yorkshire": "x",
    "Former non-metropolitan districts of Northamptonshire": "x",
    "Former non-metropolitan districts of Northumberland": "x",
    "Former non-metropolitan districts of Shropshire": "x",
    "Former non-metropolitan districts of Somerset": "x",
    "Former non-metropolitan districts of Suffolk": "x",
    "Former non-metropolitan districts of the Isle of Wight": "x",
    "Former non-metropolitan districts of Wiltshire": "x",
    "Former non-metropolitan districts": "x",
    "Formula One non-championship races": "x",
    "Founders of Sciences Po": "x",
    "French non-fiction outdoors writers": "x",
    "French-language Canadian non-fiction writers": "x",
    "French-language non-fiction books": "x",
    "Gay non-fiction books": "x",
    "German non-fiction literary awards": "x",
    "German-language non-fiction books": "x",
    "Governor General's Award–winning non-fiction books": "x",
    "Governor General's Award–winning non-fiction writers": "x",
    "Great Britain national baseball team": "x",
    "Hash function (non-cryptographic)": "x",
    "Heads of government of non-sovereign entities": "x",
    "High-importance English non-league football articles": "x",
    "High-importance Non-tropical storm articles": "x",
    "Hockey Australia template using non-numeric ID": "x",
    "Hugo Award for Best Non-Fiction Book–winning works": "x",
    "Idioms from non-English cultures": "x",
    "India Meteorological Department": "x",
    "Infobox drug articles with non-default infobox title": "x",
    "Infobox rugby biography with non-numeric numeric parameters": "x",
    "Infobox U.S. county using a non-standard time zone": "x",
    "Infobox U.S. county using a non-standard timezone": "x",
    "International Emmy Award for Best Non-Scripted Entertainment winners": "x",
    "Intersex non-fiction": "x",
    "Irish non-subscribing Presbyterian ministers": "x",
    "Japan in non-Japanese culture": "x",
    "Jctint template using non-numeric parameter values": "x",
    "Justice ministers of Andalusia": "x",
    "Kerala MLAs 2021–2026": "x",
    "Law enforcement non-governmental organizations in the United States": "x",
    "LDS non-fiction": "x",
    "Leaders of the Non-Partisan Solidarity Union": "x",
    "Lesbian non-fiction books": "x",
    "LGBTQ non-fiction books": "x",
    "LGBTQ rights in South Africa": "x",
    "Lists by population (non-human)": "x",
    "Lists of aircraft in non-standard formats": "x",
    "Lists of non-sovereign nations": "x",
    "Low-importance English non-league football articles": "x",
    "Low-importance Non-tropical storm articles": "x",
    "Major League Volleyball (2026)": "x",
    "Mass media occupations": "x",
    "Members of the Election Committee of Hong Kong": "x",
    "Members of the Folketing 2022–2026": "x",
    "Members of the House of Keys 2021–2026": "x",
    "Metropolitan and non-metropolitan counties": "x",
    "Mid-importance English non-league football articles": "x",
    "Mid-importance Non-tropical storm articles": "x",
    "Minor planet object redirects (non-primary)": "x",
    "Monthly clean-up category (Articles with improper non-free content) counter": "x",
    "Montreal Shamrocks (non-NHA) players": "x",
    "New Zealand non-fiction literary awards": "x",
    "Non-Aggression Pact (band) albums": "x",
    "Non-aggression pacts": "x",
    "Non-alcoholic drink logos": "x",
    "Non-alcoholic drinks": "x",
    "Non-alcoholic fatty liver disease": "x",
    "Non-alcoholic mixed drinks": "x",
    "Non-Aligned Movement people": "x",
    "Non-Aligned Movement Summits": "x",
    "Non-Aligned Movement": "x",
    "Non-aligned Scouting organizations in Canada": "x",
    "Non-aligned Scouting organizations in the United States": "x",
    "Non-aligned Scouting organizations": "x",
    "Non-alternating knots and links": "x",
    "Non-Arab companions of the Prophet": "x",
    "Non-Arabic-language mass media in Algeria": "x",
    "Non-Arabic-language mass media in Egypt": "x",
    "Non-Arabic-language mass media in Lebanon": "x",
    "Non-Arabic-language mass media in Morocco": "x",
    "Non-Arabic-language mass media in Tunisia": "x",
    "Non-Arabic-language newspapers published in Algeria": "x",
    "Non-Arabic-language newspapers published in Egypt": "x",
    "Non-Arabic-language newspapers published in Lebanon": "x",
    "Non-Arabic-language newspapers published in Morocco": "x",
    "Non-Arabic-language newspapers published in Tunisia": "x",
    "Non-articles using infobox website with unknown parameters": "x",
    "Non-associative algebra": "x",
    "Non-associative algebras": "x",
    "Non-benzenoid aromatic carbocycles": "x",
    "Non-British Royal Air Force personnel of World War II": "x",
    "Non-cabinet ministers of Sri Lanka": "x",
    "Non-canon Doctor Who episodes": "x",
    "Non-cardinals elected pope": "x",
    "Non-Chalcedonian Christians": "x",
    "Non-Chalcedonianism": "x",
    "Non-cinematic Western (genre) films": "x",
    "Non-citizen suffrage": "x",
    "Non-clerical religious clothing": "x",
    "Non-coding DNA": "x",
    "Non-coding RNA": "x",
    "Non-combat internal explosions on warships": "x",
    "Non-combat naval accidents of the United States": "x",
    "Non-combat naval accidents": "x",
    "Non-combatant evacuation operations": "x",
    "Non-combatant military personnel of the American Civil War": "x",
    "Non-combatant military personnel": "x",
    "Non-commercial": "x",
    "Non-commissioned air force personnel": "x",
    "Non-commissioned army personnel": "x",
    "Non-commissioned officers": "x",
    "Non-commissioned personnel": "x",
    "Non-conformist Sunni jurisprudence": "x",
    "Non-conformists of the 1550s": "x",
    "Non-conformists": "x",
    "Non-cooperative games": "x",
    "Non-coordinating anions": "x",
    "Non-dairy yogurts": "x",
    "Non-Darwinian evolution": "x",
    "Non-deaf sign languages": "x",
    "Non-denominational Evangelical churches in the United States": "x",
    "Non-denominational Evangelical churches": "x",
    "Non-denominational Evangelical multisite churches in the United States": "x",
    "Non-denominational Evangelical multisite churches": "x",
    "Non-denominational Evangelical unions": "x",
    "Non-denominational Judaism": "x",
    "Non-departmental public bodies of the Northern Ireland Executive": "x",
    "Non-departmental public bodies of the United Kingdom government": "x",
    "Non-diocesan Anglican bishops": "x",
    "Non-Disney Mickey Mouse-media": "x",
    "Non-dynastic kings of Macedonia (ancient kingdom)": "x",
    "Non-dynastic pharaohs": "x",
    "Non-empty disambiguation categories": "x",
    "Non-English user warning templates": "x",
    "Non-English welcome messages": "x",
    "Non-English works based on the Encyclopædia Britannica": "x",
    "Non-English-based programming languages": "x",
    "Non-English-language broadcasting in the United States": "x",
    "Non-English-language magazines published in the United Kingdom": "x",
    "Non-English-language magazines published in the United States": "x",
    "Non-English-language mass media in Alabama": "x",
    "Non-English-language mass media in Arizona": "x",
    "Non-English-language mass media in Arkansas": "x",
    "Non-English-language mass media in California": "x",
    "Non-English-language mass media in Colorado": "x",
    "Non-English-language mass media in Connecticut": "x",
    "Non-English-language mass media in Delaware": "x",
    "Non-English-language mass media in Florida": "x",
    "Non-English-language mass media in Georgia (U.S. state)": "x",
    "Non-English-language mass media in Hawaii": "x",
    "Non-English-language mass media in Illinois": "x",
    "Non-English-language mass media in Indiana": "x",
    "Non-English-language mass media in Iowa": "x",
    "Non-English-language mass media in Kansas": "x",
    "Non-English-language mass media in Kentucky": "x",
    "Non-English-language mass media in Louisiana": "x",
    "Non-English-language mass media in Maine": "x",
    "Non-English-language mass media in Maryland": "x",
    "Non-English-language mass media in Massachusetts": "x",
    "Non-English-language mass media in Michigan": "x",
    "Non-English-language mass media in Minnesota": "x",
    "Non-English-language mass media in Missouri": "x",
    "Non-English-language mass media in Nebraska": "x",
    "Non-English-language mass media in Nevada": "x",
    "Non-English-language mass media in New Jersey": "x",
    "Non-English-language mass media in New Mexico": "x",
    "Non-English-language mass media in New York (state)": "x",
    "Non-English-language mass media in North Carolina": "x",
    "Non-English-language mass media in North Dakota": "x",
    "Non-English-language mass media in Ohio": "x",
    "Non-English-language mass media in Oklahoma": "x",
    "Non-English-language mass media in Oregon": "x",
    "Non-English-language mass media in Pennsylvania": "x",
    "Non-English-language mass media in Rhode Island": "x",
    "Non-English-language mass media in South Carolina": "x",
    "Non-English-language mass media in South Dakota": "x",
    "Non-English-language mass media in Tennessee": "x",
    "Non-English-language mass media in Texas": "x",
    "Non-English-language mass media in the United Kingdom": "x",
    "Non-English-language mass media in the United States by state": "x",
    "Non-English-language mass media in the United States": "x",
    "Non-English-language mass media in Utah": "x",
    "Non-English-language mass media in Virginia": "x",
    "Non-English-language mass media in Washington (state)": "x",
    "Non-English-language mass media in Wisconsin": "x",
    "Non-English-language newspapers published in Arizona": "x",
    "Non-English-language newspapers published in Australia": "x",
    "Non-English-language newspapers published in California": "x",
    "Non-English-language newspapers published in Colorado": "x",
    "Non-English-language newspapers published in Connecticut": "x",
    "Non-English-language newspapers published in Florida": "x",
    "Non-English-language newspapers published in Georgia (U.S. state)": "x",
    "Non-English-language newspapers published in Illinois": "x",
    "Non-English-language newspapers published in Iowa": "x",
    "Non-English-language newspapers published in Kansas": "x",
    "Non-English-language newspapers published in Louisiana": "x",
    "Non-English-language newspapers published in Maine": "x",
    "Non-English-language newspapers published in Maryland": "x",
    "Non-English-language newspapers published in Massachusetts": "x",
    "Non-English-language newspapers published in Michigan": "x",
    "Non-English-language newspapers published in Minnesota": "x",
    "Non-English-language newspapers published in Missouri": "x",
    "Non-English-language newspapers published in Nebraska": "x",
    "Non-English-language newspapers published in Nevada": "x",
    "Non-English-language newspapers published in New Jersey": "x",
    "Non-English-language newspapers published in New Mexico": "x",
    "Non-English-language newspapers published in New York (state)": "x",
    "Non-English-language newspapers published in North Carolina": "x",
    "Non-English-language newspapers published in North Dakota": "x",
    "Non-English-language newspapers published in Ohio": "x",
    "Non-English-language newspapers published in Oregon": "x",
    "Non-English-language newspapers published in Pennsylvania": "x",
    "Non-English-language newspapers published in South Dakota": "x",
    "Non-English-language newspapers published in Texas": "x",
    "Non-English-language newspapers published in the United States by state": "x",
    "Non-English-language newspapers published in the United States": "x",
    "Non-English-language newspapers published in Washington (state)": "x",
    "Non-English-language newspapers published in Wisconsin": "x",
    "Non-English-language radio stations in Alabama": "x",
    "Non-English-language radio stations in Arizona": "x",
    "Non-English-language radio stations in Arkansas": "x",
    "Non-English-language radio stations in California": "x",
    "Non-English-language radio stations in Colorado": "x",
    "Non-English-language radio stations in Connecticut": "x",
    "Non-English-language radio stations in Delaware": "x",
    "Non-English-language radio stations in Florida": "x",
    "Non-English-language radio stations in Georgia (U.S. state)": "x",
    "Non-English-language radio stations in Hawaii": "x",
    "Non-English-language radio stations in Illinois": "x",
    "Non-English-language radio stations in Indiana": "x",
    "Non-English-language radio stations in Kansas": "x",
    "Non-English-language radio stations in Kentucky": "x",
    "Non-English-language radio stations in Louisiana": "x",
    "Non-English-language radio stations in Maryland": "x",
    "Non-English-language radio stations in Massachusetts": "x",
    "Non-English-language radio stations in Minnesota": "x",
    "Non-English-language radio stations in Missouri": "x",
    "Non-English-language radio stations in New Jersey": "x",
    "Non-English-language radio stations in New Mexico": "x",
    "Non-English-language radio stations in New York (state)": "x",
    "Non-English-language radio stations in North Carolina": "x",
    "Non-English-language radio stations in Ohio": "x",
    "Non-English-language radio stations in Oklahoma": "x",
    "Non-English-language radio stations in Oregon": "x",
    "Non-English-language radio stations in Pennsylvania": "x",
    "Non-English-language radio stations in Rhode Island": "x",
    "Non-English-language radio stations in South Carolina": "x",
    "Non-English-language radio stations in Tennessee": "x",
    "Non-English-language radio stations in Texas": "x",
    "Non-English-language radio stations in the United States by state": "x",
    "Non-English-language radio stations in Utah": "x",
    "Non-English-language radio stations in Washington (state)": "x",
    "Non-English-language radio stations in Wisconsin": "x",
    "Non-English-language television stations in California": "x",
    "Non-English-language television stations in Florida": "x",
    "Non-Euclidean geometry": "x",
    "Non-fatal shootings": "x",
    "Non-ferrous metallurgical works in the United Kingdom": "x",
    "Non-fiction book stub templates": "x",
    "Non-fiction books about American prostitution": "x",
    "Non-fiction books about American slavery": "x",
    "Non-fiction books about artificial intelligence": "x",
    "Non-fiction books about autism": "x",
    "Non-fiction books about British prostitution": "x",
    "Non-fiction books about Canadian prostitution": "x",
    "Non-fiction books about cannibalism": "x",
    "Non-fiction books about Colombian drug cartels": "x",
    "Non-fiction books about consumerism": "x",
    "Non-fiction books about contract killers": "x",
    "Non-fiction books about elephants": "x",
    "Non-fiction books about gangsters": "x",
    "Non-fiction books about geisha": "x",
    "Non-fiction books about guerrilla warfare": "x",
    "Non-fiction books about horror": "x",
    "Non-fiction books about jihadism": "x",
    "Non-fiction books about MDMA": "x",
    "Non-fiction books about Mexican drug cartels": "x",
    "Non-fiction books about mobsters": "x",
    "Non-fiction books about musical theatre": "x",
    "Non-fiction books about outlaws of the American Old West": "x",
    "Non-fiction books about piracy": "x",
    "Non-fiction books about prostitution": "x",
    "Non-fiction books about public relations": "x",
    "Non-fiction books about same-sex sexuality": "x",
    "Non-fiction books about Soviet repression": "x",
    "Non-fiction books about submarine warfare": "x",
    "Non-fiction books about the 1550 Bangladesh genocide": "x",
    "Non-fiction books about the Armenian genocide": "x",
    "Non-fiction books about the Central Intelligence Agency": "x",
    "Non-fiction books about the French Connection": "x",
    "Non-fiction books about the Great Depression": "x",
    "Non-fiction books about the Great Game": "x",
    "Non-fiction books about the Great Recession": "x",
    "Non-fiction books about the Holodomor": "x",
    "Non-fiction books about the illegal drug trade": "x",
    "Non-fiction books about The Simpsons": "x",
    "Non-fiction books about the subprime mortgage crisis": "x",
    "Non-fiction books about the United States Marine Corps": "x",
    "Non-fiction books about United States intelligence agencies": "x",
    "Non-fiction books by discipline": "x",
    "Non-fiction books by Norman Mailer": "x",
    "Non-fiction books by William Boyd (writer)": "x",
    "Non-fiction by Walter Scott": "x",
    "Non-fiction Cyberpunk media": "x",
    "Non-fiction genres": "x",
    "Non-fiction literary awards": "x",
    "Non-fiction literature about abortion": "x",
    "Non-fiction literature by country": "x",
    "Non-fiction literature from Georgia (country)": "x",
    "Non-fiction literature from Northern Ireland": "x",
    "Non-fiction literature": "x",
    "Non-fiction novels of investigative journalism": "x",
    "Non-fiction outdoors writers": "x",
    "Non-fiction works about the Bosnian genocide": "x",
    "Non-fiction works about the United States Marine Corps": "x",
    "Non-fiction works by creator": "x",
    "Non-fiction works by Elizabeth Gaskell": "x",
    "Non-fiction writers about the French Connection": "x",
    "Non-fiction": "x",
    "Non-FIFA football competitions": "x",
    "Non-food crop diseases": "x",
    "Non-food crops": "x",
    "Non-free Analog Science Fiction and Fact magazine covers": "x",
    "Non-free architectural works": "x",
    "Non-free audio samples by artist": "x",
    "Non-free bandy logos": "x",
    "Non-free Black Mask magazine covers": "x",
    "Non-free character artwork": "x",
    "Non-free computer icons": "x",
    "Non-free destroyed architecture": "x",
    "Non-free Disney logos": "x",
    "Non-free Dragon magazine covers": "x",
    "Non-free Dungeon magazine covers": "x",
    "Non-free Entertainment Weekly magazine covers": "x",
    "Non-free Esquire magazine covers": "x",
    "Non-free Fantastic Universe magazine covers": "x",
    "Non-free Far Eastern Economic Review magazine covers": "x",
    "Non-free former or old logos": "x",
    "Non-free Fortune magazine covers": "x",
    "Non-free Galaxy Science Fiction magazine covers": "x",
    "Non-free GQ magazine covers": "x",
    "Non-free graffiti with NFUR stated": "x",
    "Non-free graffiti": "x",
    "Non-free Heavy Metal magazine covers": "x",
    "Non-free Life magazine covers": "x",
    "Non-free logos": "x",
    "Non-free Maclean's magazine covers": "x",
    "Non-free Mad magazine covers": "x",
    "Non-free magazine covers by title": "x",
    "Non-free magazine covers": "x",
    "Non-free media with non-commercial and no derivative works licenses": "x",
    "Non-free Men's Health magazine covers": "x",
    "Non-free music samples": "x",
    "Non-free musical interface audio": "x",
    "Non-free Mystery Scene magazine covers": "x",
    "Non-free National Geographic magazine covers": "x",
    "Non-free newspaper covers": "x",
    "Non-free Newsweek magazine covers": "x",
    "Non-free Penthouse magazine covers": "x",
    "Non-free People magazine covers": "x",
    "Non-free pictures of tornadoes": "x",
    "Non-free Playbill magazine covers": "x",
    "Non-free Playboy magazine covers": "x",
    "Non-free Popular Electronics magazine covers": "x",
    "Non-free posters": "x",
    "Non-free proposed architecture": "x",
    "Non-free Radio Times magazine covers": "x",
    "Non-free rationale as na": "x",
    "Non-free Redbook magazine covers": "x",
    "Non-free Rolling Stone magazine covers": "x",
    "Non-free school logos": "x",
    "Non-free screenshots": "x",
    "Non-free sheet music": "x",
    "Non-free Sports Illustrated magazine covers": "x",
    "Non-free Startling Stories magazine covers": "x",
    "Non-free SVGs requiring file size reduction": "x",
    "Non-free symbols": "x",
    "Non-free The Atlantic magazine covers": "x",
    "Non-free The Economist magazine covers": "x",
    "Non-free The Magazine of Fantasy & Science Fiction magazine covers": "x",
    "Non-free The New York Times Magazine magazine covers": "x",
    "Non-free The New Yorker magazine covers": "x",
    "Non-free The Saturday Evening Post magazine covers": "x",
    "Non-free The Shadow magazine covers": "x",
    "Non-free The Strand Magazine magazine covers": "x",
    "Non-free Time magazine covers": "x",
    "Non-free TV Guide magazine covers": "x",
    "Non-free university technical college logos": "x",
    "Non-free Unknown magazine covers": "x",
    "Non-free use rationale templates": "x",
    "Non-free Vanity Fair magazine covers": "x",
    "Non-free Venture Science Fiction magazine covers": "x",
    "Non-free video samples": "x",
    "Non-free Vogue magazine covers": "x",
    "Non-free Wired magazine covers": "x",
    "Non-freeway toll roads": "x",
    "Non-French-language magazines published in France": "x",
    "Non-French-language newspapers published in France": "x",
    "Non-fungible tokens": "x",
    "Non-games": "x",
    "Non-German units of the Wehrmacht": "x",
    "Non-governmental academies based in Russia": "x",
    "Non-governmental elections": "x",
    "Non-governmental organizations": "x",
    "Non-hallucinogenic 5-HT2A receptor agonists": "x",
    "Non-Hebrew-language mass media in Israel": "x",
    "Non-Hebrew-language newspapers published in Israel": "x",
    "Non-Hodgkin lymphoma": "x",
    "Non-human celestial navigation": "x",
    "Non-human primate astronauts of the American space program": "x",
    "Non-hunting areas of Thailand": "x",
    "Non-idiophonic interruptive free aerophones": "x",
    "Non-impact printing": "x",
    "Non-Inscrits MEPs": "x",
    "Non-institutional bodies of the European Union": "x",
    "Non-international England cricketers": "x",
    "Non-invented electrical components": "x",
    "Non-ionic surfactants": "x",
    "Non-Islamic Islam studies literature": "x",
    "Non-ISO Language user templates": "x",
    "Non-jamming knots": "x",
    "Non-League football": "x",
    "Non-lethal firearms of Russia": "x",
    "Non-lethal firearms": "x",
    "Non-lethal projectiles": "x",
    "Non-lethal weapons": "x",
    "Non-mainspace quotation templates": "x",
    "Non-metropolitan district councils of England": "x",
    "Non-military counterinsurgency organizations": "x",
    "Non-military counterterrorist organizations": "x",
    "Non-military rank insignia": "x",
    "Non-ministerial departments of the Government of the United Kingdom": "x",
    "Non-ministerial departments of the Scottish Government": "x",
    "Non-ministerial departments of the Welsh Government": "x",
    "Non-native Tamil poets": "x",
    "Non-Neutral Independents politicians": "x",
    "Non-Newtonian fluids": "x",
    "Non-nucleophilic bases": "x",
    "Non-nucleoside reverse transcriptase inhibitors": "x",
    "Non-operating common carrier freight railroads in the United States": "x",
    "Non-oxide glasses": "x",
    "Non-Pama-Nyungan languages": "x",
    "Non-parametric statistics": "x",
    "Non-Partisan Association councillors": "x",
    "Non-partisan elections": "x",
    "Non-Partisan Solidarity Union Members of the Legislative Yuan": "x",
    "Non-Partisan Solidarity Union politicians": "x",
    "Non-Partisan Solidarity Union": "x",
    "Non-passenger multiple units": "x",
    "Non-periodic comets": "x",
    "Non-petroleum based lubricants": "x",
    "Non-plant crops": "x",
    "Non-practicing entities": "x",
    "Non-profit academic publishers": "x",
    "Non-profit architecture organizations based in the United States": "x",
    "Non-profit corporations": "x",
    "Non-profit executives": "x",
    "Non-profit institutes based in the United States": "x",
    "Non-profit microfinance organizations based in North America": "x",
    "Non-profit microfinance organizations": "x",
    "Non-profit organisations based in Victoria (state)": "x",
    "Non-profit organizations based in the New Orleans metropolitan area": "x",
    "Non-profit organizations listed in Russia as foreign agents": "x",
    "Non-profit youth organizations based in the United States": "x",
    "Non-proliferation treaties": "x",
    "Non-proportional multi-winner electoral systems": "x",
    "Non-protein ion channel toxins": "x",
    "Non-proteinogenic amino acids": "x",
    "Non-public museums in the United States": "x",
    "Non-public museums": "x",
    "Non-pulmonic consonants": "x",
    "Non-railway predecessors of railway companies": "x",
    "Non-receptor tyrosine kinase inhibitors": "x",
    "Non-registered political parties in Romania": "x",
    "Non-religious Israeli communities": "x",
    "Non-religious Israeli settlements": "x",
    "Non-renewable resources": "x",
    "Non-rocket spacelaunch": "x",
    "Non-Romanian-language newspapers published in Romania": "x",
    "Non-School institutions of the University of Cambridge": "x",
    "Non-sexuality": "x",
    "Non-SI metric units": "x",
    "Non-sovereign monarchy": "x",
    "Non-Spanish classical guitars": "x",
    "Non-standard discography infoboxes": "x",
    "Non-standard positional numeral systems": "x",
    "Non-Status Indians": "x",
    "Non-stoichiometric compounds": "x",
    "Non-store retailing": "x",
    "Non-subject-matter-related article-talk header templates": "x",
    "Non-Summit": "x",
    "Non-tariff barriers to trade": "x",
    "Non-terminally differentiated (blast) cells": "x",
    "Non-theatrical film production companies": "x",
    "Non-Thoroughbred racehorses": "x",
    "Non-timber forest products": "x",
    "Non-tobacco nicotine products": "x",
    "Non-tonal languages in tonal families": "x",
    "Non-tricolorable knots and links": "x",
    "Non-tropical storm articles by importance": "x",
    "Non-tropical storm articles by quality": "x",
    "Non-tropical storms articles needing expert attention": "x",
    "Non-tropical storms templates": "x",
    "Non-U.S. alumni of the Command and General Staff College": "x",
    "Non-uniform random numbers": "x",
    "North America territory (non-sovereign) templates": "x",
    "Observances on non-Gregorian calendars": "x",
    "Obsessive–compulsive disorder in non-fiction literature": "x",
    "Oceania territory (non-sovereign) templates": "x",
    "OlyCatMenWomen on non-category page": "x",
    "OlyCatMenWomen on non-Olympic page": "x",
    "One Piece non-free media": "x",
    "Open non-builders": "x",
    "Out of copyright in 2026": "x",
    "People from Thonon-les-Bains": "x",
    "People from Tournon-sur-Rhône": "x",
    "People with non-domiciled status in the United Kingdom": "x",
    "Personnel of the Non-Combatant Corps": "x",
    "Planning ministers of Puntland": "x",
    "Probability distributions with non-finite variance": "x",
    "Puducherry MLAs 2021–2026": "x",
    "Railway stations scheduled to open in 2026": "x",
    "Regulation of non-governmental organizations": "x",
    "Restricted titles (non-leading number sign)": "x",
    "Rodez AF": "x",
    "Rohingya people": "x",
    "Scottish Parliament constituencies and regions from 2026": "x",
    "Screenshots of films out of copyright in 2026": "x",
    "Secretaries-general of the Non-Aligned Movement": "x",
    "Senescence in non-human organisms": "x",
    "Ships sunk by non-combat internal explosions": "x",
    "Siege of Sarajevo in non-fiction": "x",
    "Singaporean Non-constituency Members of Parliament": "x",
    "Ski mountaineering at the 2026 Winter Olympics": "x",
    "Snooker non-ranking competitions": "x",
    "Soccerbase template using non-numeric ID": "x",
    "Song articles with infoboxes with non-standard extra track listings": "x",
    "Songs written by Marla Cannon-Goodman": "x",
    "south african anti–world-war-ii activists": "x",
    "South African military memorials and cemeteries": "x",
    "South America territory (non-sovereign) templates": "x",
    "Spanish-language non-fiction books": "x",
    "sports-people from Thonon-les-Bains": "x",
    "Sri Lankan non-commissioned personnel": "x",
    "SS non-commissioned officers": "x",
    "Swedish non-commissioned personnel": "x",
    "Sámi non-fiction writers": "x",
    "Tamil Nadu MLAs 2021–2026": "x",
    "Tamil scholars of non-Tamil background": "x",
    "Television non-maintenance tracking categories": "x",
    "Tennessee Technological University": "x",
    "Texas A&M University faculty": "x",
    "Theories of non-biological ageing": "x",
    "Timelines of historically non-Chinese states in China": "x",
    "Tonal languages in non-tonal families": "x",
    "Top-importance English non-league football articles": "x",
    "Top-importance Non-tropical storm articles": "x",
    "Train-related introductions in 2026": "x",
    "Transgender non-fiction books": "x",
    "Tribute albums to non-musicians": "x",
    "Turkish non-commissioned personnel": "x",
    "UK councillors 2022–2026": "x",
    "Unassessed English non-league football articles": "x",
    "Unassessed Non-tropical storm articles": "x",
    "Union army non-commissioned officers": "x",
    "United States Air Force non-commissioned officers": "x",
    "United States Army Air Forces non-commissioned officers": "x",
    "United States Army non-commissioned officers": "x",
    "United States Coast Guard non-commissioned officers": "x",
    "United States Marine Corps non-commissioned officers": "x",
    "United States Navy non-commissioned officers": "x",
    "Unknown-importance English non-league football articles": "x",
    "Unknown-importance Non-tropical storm articles": "x",
    "Urdu-language non-fiction literature": "x",
    "Usage of portal image for non-existent portal": "x",
    "Video games featuring non-playable protagonists": "x",
    "Violent non-state actor incidents by country": "x",
    "Violent non-state actor incidents in Africa": "x",
    "Violent non-state actor incidents in Asia": "x",
    "Violent non-state actor incidents in Europe": "x",
    "Violent non-state actor incidents in Italy": "x",
    "Violent non-state actor incidents in Mexico": "x",
    "Violent non-state actor incidents in Nigeria": "x",
    "Violent non-state actor incidents in North America": "x",
    "Violent non-state actor incidents in South America": "x",
    "Violent non-state actor incidents in the United Kingdom": "x",
    "Violent non-state actor incidents in the United States": "x",
    "Violent non-state actor incidents": "x",
    "Violent non-state actors": "x",
    "Wales MSs 2021–2026": "x",
    "West Bengal MLAs 2021–2026": "x",
    "West Coast hip-hop musicians": "x",
    "Winter Olympics by year category navigation — non-matching parameters": "x",
    "Women heads of government of non-sovereign entities": "x",
    "Writers by non-fiction genre": "x",
    "Writers by non-fiction subject area": "x",
    "Yi people": "x",
}

to_test = [
    ("test_skip_data_all_1", test_data_1),
    ("test_skip_data_all_2", test_data_empty),
]


@pytest.mark.parametrize("category, expected", test_data_1.items(), ids=test_data_1.keys())
@pytest.mark.skip2
def test_skip_data_all_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
