#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data_callback

data_1 = {
    "animated television series debuts": "مسلسلات تلفزيونية رسوم متحركة بدأ عرضها",
    "animated television series endings": "مسلسلات تلفزيونية رسوم متحركة انتهت",
    "animated television series-endings": "مسلسلات تلفزيونية رسوم متحركة انتهت",
    "anime television films": "أفلام أنمي متلفزة",
    "anime television series": "مسلسلات أنمي متلفزة",
    "anime television series debuts": "مسلسلات أنمي متلفزة بدأ عرضها",
    "comics debuts": "قصص مصورة بدأ عرضها",
    "comics endings": "قصص مصورة انتهت",
    "comics-endings": "قصص مصورة انتهت",
    "martial arts comics": "قصص مصورة فنون قتالية",
    "martial arts television series": "مسلسلات تلفزيونية فنون قتالية",
    "martial arts video games": "ألعاب فيديو فنون قتالية",
    "science fiction film series debuts": "سلاسل أفلام خيال علمي بدأ عرضها",
    "science fiction film series-endings": "سلاسل أفلام خيال علمي انتهت",
    "television series debuts": "مسلسلات تلفزيونية بدأ عرضها",
    "television series endings": "مسلسلات تلفزيونية انتهت",
    "television series-endings": "مسلسلات تلفزيونية انتهت",
    "web series debuts": "مسلسلات ويب بدأ عرضها",
    "web series endings": "مسلسلات ويب انتهت",
    "web series-endings": "مسلسلات ويب انتهت",
}

data_2 = {
    "action comedy television series": "مسلسلات تلفزيونية حركة كوميدية",
    "action comedy web series": "مسلسلات ويب حركة كوميدية",
    "action comics": "قصص مصورة حركة",
    "action film series": "سلاسل أفلام حركة",
    "action television characters": "شخصيات تلفزيونية حركة",
    "action television films": "أفلام تلفزيونية حركة",
    "action television series": "مسلسلات تلفزيونية حركة",
    "action web series": "مسلسلات ويب حركة",
    "adult animated drama television series": "مسلسلات تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated supernatural television series": "مسلسلات تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated television series": "مسلسلات تلفزيونية رسوم متحركة للكبار",
    "adult animated web series": "مسلسلات ويب رسوم متحركة للكبار",
    "adventure comics": "قصص مصورة مغامرات",
    "adventure film series": "سلاسل أفلام مغامرات",
    "adventure television films": "أفلام تلفزيونية مغامرات",
    "adventure television series": "مسلسلات تلفزيونية مغامرات",
    "adventure web series": "مسلسلات ويب مغامرات",
    "animated film series": "سلاسل أفلام رسوم متحركة",
    "animated short film series": "سلاسل أفلام رسوم متحركة قصيرة",
    "animated television characters": "شخصيات تلفزيونية رسوم متحركة",
    "animated television episodes": "حلقات تلفزيونية رسوم متحركة",
    "animated television films": "أفلام تلفزيونية رسوم متحركة",
    "animated television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة",
    "animated television series": "مسلسلات تلفزيونية رسوم متحركة",
    "animated web series": "مسلسلات ويب رسوم متحركة",
    "anime film series": "سلاسل أفلام أنمي",
    "anthology comics": "قصص مصورة أنثولوجيا",
    "anthology film series": "سلاسل أفلام أنثولوجيا",
    "anthology television series": "مسلسلات تلفزيونية أنثولوجيا",
    "anthology web series": "مسلسلات ويب أنثولوجيا",
    "apocalyptic comics": "قصص مصورة نهاية العالم",
    "apocalyptic television episodes": "حلقات تلفزيونية نهاية العالم",
    "apocalyptic television series": "مسلسلات تلفزيونية نهاية العالم",
    "apocalyptic video games": "ألعاب فيديو نهاية العالم",
    "aviation comics": "قصص مصورة طيران",
    "aviation television series": "مسلسلات تلفزيونية طيران",
    "biographical comics": "قصص مصورة سير ذاتية",
    "biographical television films": "أفلام تلفزيونية سير ذاتية",
    "biographical television series": "مسلسلات تلفزيونية سير ذاتية",
    "black comedy comics": "قصص مصورة كوميدية سوداء",
    "black comedy television episodes": "حلقات تلفزيونية كوميدية سوداء",
    "black comedy television series": "مسلسلات تلفزيونية كوميدية سوداء",
    "black comedy web series": "مسلسلات ويب كوميدية سوداء",
    "black television series": "مسلسلات تلفزيونية سوداء",
    "black-and-white television episodes": "حلقات تلفزيونية أبيض وأسود",
    "cancelled video games": "ألعاب فيديو ملغية",
    "children's animated television series": "مسلسلات تلفزيونية رسوم متحركة أطفال",
    "children's comedy television series": "مسلسلات تلفزيونية أطفال كوميدية",
    "children's film series": "سلاسل أفلام أطفال",
    "children's television characters": "شخصيات تلفزيونية أطفال",
    "children's television series": "مسلسلات تلفزيونية أطفال",
    "children's web series": "مسلسلات ويب أطفال",
    "christmas comics": "قصص مصورة عيد الميلاد",
    "christmas film series": "سلاسل أفلام عيد الميلاد",
    "christmas television episodes": "حلقات تلفزيونية عيد الميلاد",
    "christmas television films": "أفلام تلفزيونية عيد الميلاد",
    "christmas television series": "مسلسلات تلفزيونية عيد الميلاد",
    "christmas video games": "ألعاب فيديو عيد الميلاد",
    "comedy comics": "قصص مصورة كوميدية",
    "comedy film series": "سلاسل أفلام كوميدية",
    "comedy horror television series": "مسلسلات تلفزيونية كوميدية رعب",
    "comedy horror web series": "مسلسلات ويب كوميدية رعب",
    "comedy television characters": "شخصيات تلفزيونية كوميدية",
    "comedy television episodes": "حلقات تلفزيونية كوميدية",
    "comedy television films": "أفلام تلفزيونية كوميدية",
    "comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية",
    "comedy television programmes": "برامج تلفزيونية كوميدية",
    "comedy television series": "مسلسلات تلفزيونية كوميدية",
    "comedy web series": "مسلسلات ويب كوميدية",
    "comedy-drama comics": "قصص مصورة كوميدية درامية",
    "comedy-drama television characters": "شخصيات تلفزيونية كوميدية درامية",
    "comedy-drama television films": "أفلام تلفزيونية كوميدية درامية",
    "comedy-drama television series": "مسلسلات تلفزيونية كوميدية درامية",
    "comedy-drama web series": "مسلسلات ويب كوميدية درامية",
    "comic science fiction television series": "مسلسلات تلفزيونية خيالية علمية كوميدية",
    "comics": "قصص مصورة",
    "coming-of-age comics": "قصص مصورة تقدم في العمر",
    "computer-animated television series": "مسلسلات تلفزيونية حركة حاسوبية",
    "crime comedy television series": "مسلسلات تلفزيونية جنائية كوميدية",
    "crime comics": "قصص مصورة جريمة",
    "crime film series": "سلاسل أفلام جريمة",
    "crime television characters": "شخصيات تلفزيونية جريمة",
    "crime television episodes": "حلقات تلفزيونية جريمة",
    "crime television films": "أفلام تلفزيونية جريمة",
    "crime television series": "مسلسلات تلفزيونية جريمة",
    "crime thriller television series": "مسلسلات تلفزيونية إثارة وجريمة",
    "crime thriller web series": "مسلسلات ويب إثارة وجريمة",
    "crime video games": "ألعاب فيديو جريمة",
    "crime web series": "مسلسلات ويب جريمة",
    "cyberpunk comics": "قصص مصورة سايبربانك",
    "cyberpunk television episodes": "حلقات تلفزيونية سايبربانك",
    "cyberpunk television series": "مسلسلات تلفزيونية سايبربانك",
    "cyberpunk video games": "ألعاب فيديو سايبربانك",
    "dance video games": "ألعاب فيديو رقص",
    "dark fantasy comics": "قصص مصورة فانتازيا مظلمة",
    "dark fantasy television series": "مسلسلات تلفزيونية فانتازيا مظلمة",
    "dark fantasy video games": "ألعاب فيديو فانتازيا مظلمة",
    "dark fantasy web series": "مسلسلات ويب فانتازيا مظلمة",
    "detective comics": "قصص مصورة مباحث",
    "detective television series": "مسلسلات تلفزيونية مباحث",
    "detective video games": "ألعاب فيديو مباحث",
    "disaster television films": "أفلام تلفزيونية كوارثية",
    "disaster television series": "مسلسلات تلفزيونية كوارثية",
    "disney animated film series": "سلاسل أفلام رسوم متحركة ديزني",
    "disney animated television series": "مسلسلات تلفزيونية رسوم متحركة ديزني",
    "docudrama television series": "مسلسلات تلفزيونية درامية وثائقية",
    "documentary film series": "سلاسل أفلام وثائقية",
    "documentary television films": "أفلام تلفزيونية وثائقية",
    "documentary television series": "مسلسلات تلفزيونية وثائقية",
    "documentary web series": "مسلسلات ويب وثائقية",
    "drama comics": "قصص مصورة درامية",
    "drama film series": "سلاسل أفلام درامية",
    "drama television characters": "شخصيات تلفزيونية درامية",
    "drama television episodes": "حلقات تلفزيونية درامية",
    "drama television films": "أفلام تلفزيونية درامية",
    "drama television miniseries": "مسلسلات قصيرة تلفزيونية درامية",
    "drama television series": "مسلسلات تلفزيونية درامية",
    "drama web series": "مسلسلات ويب درامية",
    "educational comics": "قصص مصورة تعليمية",
    "educational television episodes": "حلقات تلفزيونية تعليمية",
    "educational television series": "مسلسلات تلفزيونية تعليمية",
    "educational video games": "ألعاب فيديو تعليمية",
    "epic comics": "قصص مصورة ملحمية",
    "epic television series": "مسلسلات تلفزيونية ملحمية",
    "epic video games": "ألعاب فيديو ملحمية",
    "erotic comics": "قصص مصورة إغرائية",
    "erotic film series": "سلاسل أفلام إغرائية",
    "erotic television series": "مسلسلات تلفزيونية إغرائية",
    "erotic video games": "ألعاب فيديو إغرائية",
    "erotic web series": "مسلسلات ويب إغرائية",
    "experimental film series": "سلاسل أفلام تجريبية",
    "family television series": "مسلسلات تلفزيونية عائلية",
    "family video games": "ألعاب فيديو عائلية",
    "fantasy comics": "قصص مصورة فانتازيا",
    "fantasy film series": "سلاسل أفلام فانتازيا",
    "fantasy television characters": "شخصيات تلفزيونية فانتازيا",
    "fantasy television episodes": "حلقات تلفزيونية فانتازيا",
    "fantasy television films": "أفلام تلفزيونية فانتازيا",
    "fantasy television series": "مسلسلات تلفزيونية فانتازيا",
    "fantasy video games": "ألعاب فيديو فانتازيا",
    "fantasy web series": "مسلسلات ويب فانتازيا",
    "feature comics": "قصص مصورة طويلة",
    "feminist comics": "قصص مصورة نسوية",
    "fiction comics": "قصص مصورة خيالية",
    "fiction film series": "سلاسل أفلام خيالية",
    "fiction television characters": "شخصيات تلفزيونية خيالية",
    "fiction television episodes": "حلقات تلفزيونية خيالية",
    "fiction television films": "أفلام تلفزيونية خيالية",
    "fiction television series": "مسلسلات تلفزيونية خيالية",
    "fiction video games": "ألعاب فيديو خيالية",
    "fiction web series": "مسلسلات ويب خيالية",
    "film series": "سلاسل أفلام",
    "final fantasy video games": "ألعاب فيديو فاينل فانتازي",
    "found footage television episodes": "حلقات تلفزيونية تسجيلات مكتشفة",
    "hacking video games": "ألعاب فيديو إختراق",
    "heist film series": "سلاسل أفلام سرقة",
    "historical comics": "قصص مصورة تاريخية",
    "historical television films": "أفلام تلفزيونية تاريخية",
    "historical television series": "مسلسلات تلفزيونية تاريخية",
    "hood television episodes": "حلقات تلفزيونية هود",
    "hood television series": "مسلسلات تلفزيونية هود",
    "hood video games": "ألعاب فيديو هود",
    "horror comics": "قصص مصورة رعب",
    "horror film series": "سلاسل أفلام رعب",
    "horror television characters": "شخصيات تلفزيونية رعب",
    "horror television episodes": "حلقات تلفزيونية رعب",
    "horror television films": "أفلام تلفزيونية رعب",
    "horror television series": "مسلسلات تلفزيونية رعب",
    "horror video games": "ألعاب فيديو رعب",
    "horror web series": "مسلسلات ويب رعب",
    "independent comics": "قصص مصورة مستقلة",
    "kaiju video games": "ألعاب فيديو كايجو",
    "legal drama television series": "مسلسلات تلفزيونية دراما قانونية",
    "legal television series": "مسلسلات تلفزيونية قانونية",
    "lgbt television series": "مسلسلات تلفزيونية إل جي بي تي",
    "lgbtq comics": "قصص مصورة إل جي بي تي كيو",
    "lgbtq-related comics": "قصص مصورة متعلقة بإل جي بي تي كيو",
    "lgbtq-related television episodes": "حلقات تلفزيونية متعلقة بإل جي بي تي كيو",
    "lgbtq-related television films": "أفلام تلفزيونية متعلقة بإل جي بي تي كيو",
    "lgbtq-related television series": "مسلسلات تلفزيونية متعلقة بإل جي بي تي كيو",
    "lgbtq-related video games": "ألعاب فيديو متعلقة بإل جي بي تي كيو",
    "lgbtq-related web series": "مسلسلات ويب متعلقة بإل جي بي تي كيو",
    "live television series": "مسلسلات تلفزيونية مباشرة",
    "lost television episodes": "حلقات تلفزيونية مفقودة",
    "lost video games": "ألعاب فيديو مفقودة",
    "magical girl comics": "قصص مصورة فتاة ساحرة",
    "magical girl television series": "مسلسلات تلفزيونية فتاة ساحرة",
    "magical girl video games": "ألعاب فيديو فتاة ساحرة",
    "martial arts film series": "سلاسل أفلام فنون قتال",
    "martial arts web series": "مسلسلات ويب فنون قتال",
    "melodrama television series": "مسلسلات تلفزيونية ميلودراما",
    "metafictional comics": "قصص مصورة ما وراء القص",
    "metafictional television episodes": "حلقات تلفزيونية ما وراء القص",
    "metafictional television series": "مسلسلات تلفزيونية ما وراء القص",
    "metafictional video games": "ألعاب فيديو ما وراء القص",
    "military comics": "قصص مصورة عسكرية",
    "military television series": "مسلسلات تلفزيونية عسكرية",
    "miniseries": "مسلسلات قصيرة",
    "mockumentary television series": "مسلسلات تلفزيونية وثائقية كاذبة",
    "music television series": "مسلسلات تلفزيونية موسيقية",
    "music video games": "ألعاب فيديو موسيقية",
    "musical comedy television series": "مسلسلات تلفزيونية كوميدية موسيقية",
    "musical film series": "سلاسل أفلام موسيقية",
    "musical television episodes": "حلقات تلفزيونية موسيقية",
    "musical television films": "أفلام تلفزيونية موسيقية",
    "musical television series": "مسلسلات تلفزيونية موسيقية",
    "mystery comics": "قصص مصورة غموض",
    "mystery film series": "سلاسل أفلام غموض",
    "mystery television films": "أفلام تلفزيونية غموض",
    "mystery television series": "مسلسلات تلفزيونية غموض",
    "mystery video games": "ألعاب فيديو غموض",
    "mystery web series": "مسلسلات ويب غموض",
    "nautical comics": "قصص مصورة بحرية",
    "nautical television series": "مسلسلات تلفزيونية بحرية",
    "naval video games": "ألعاب فيديو بحرية عسكرية",
    "neo-noir comics": "قصص مصورة نيو-نوار",
    "neo-noir film series": "سلاسل أفلام نيو-نوار",
    "neo-noir television series": "مسلسلات تلفزيونية نيو-نوار",
    "neo-noir video games": "ألعاب فيديو نيو-نوار",
    "non-fiction comics": "قصص مصورة غير خيالية",
    "non-fiction television series": "مسلسلات تلفزيونية غير خيالية",
    "non-fiction web series": "مسلسلات ويب غير خيالية",
    "parody comics": "قصص مصورة ساخرة",
    "parody television episodes": "حلقات تلفزيونية ساخرة",
    "parody television series": "مسلسلات تلفزيونية ساخرة",
    "parody video games": "ألعاب فيديو ساخرة",
    "period television series": "مسلسلات تلفزيونية حقبية",
    "pirate comics": "قصص مصورة قراصنة",
    "pirate film series": "سلاسل أفلام قراصنة",
    "police procedural television series": "مسلسلات تلفزيونية إجراءات الشرطة",
    "political television episodes": "حلقات تلفزيونية سياسية",
    "political television series": "مسلسلات تلفزيونية سياسية",
    "political thriller television series": "مسلسلات تلفزيونية إثارة سياسية",
    "political video games": "ألعاب فيديو سياسية",
    "political web series": "مسلسلات ويب سياسية",
    "pornographic comics": "قصص مصورة إباحية",
    "pornographic film series": "سلاسل أفلام إباحية",
    "post-apocalyptic comics": "قصص مصورة ما بعد الكارثة",
    "post-apocalyptic film series": "سلاسل أفلام ما بعد الكارثة",
    "post-apocalyptic television episodes": "حلقات تلفزيونية ما بعد الكارثة",
    "post-apocalyptic television series": "مسلسلات تلفزيونية ما بعد الكارثة",
    "post-apocalyptic video games": "ألعاب فيديو ما بعد الكارثة",
    "post-apocalyptic web series": "مسلسلات ويب ما بعد الكارثة",
    "prequel comics": "قصص مصورة بادئة",
    "prequel television series": "مسلسلات تلفزيونية بادئة",
    "propaganda video games": "ألعاب فيديو دعائية",
    "psychological television series": "مسلسلات تلفزيونية نفسية",
    "psychological thriller television series": "مسلسلات تلفزيونية إثارة نفسية",
    "psychological thriller video games": "ألعاب فيديو إثارة نفسية",
    "psychological thriller web series": "مسلسلات ويب إثارة نفسية",
    "reality television series": "مسلسلات تلفزيونية واقعية",
    "reality web series": "مسلسلات ويب واقعية",
    "reboot comics": "قصص مصورة ريبوت",
    "rediscovered video games": "ألعاب فيديو اكتشاف",
    "religious comics": "قصص مصورة دينية",
    "religious television series": "مسلسلات تلفزيونية دينية",
    "robot comics": "قصص مصورة آلية",
    "romance comics": "قصص مصورة رومانسية",
    "romance film series": "سلاسل أفلام رومانسية",
    "romance television characters": "شخصيات تلفزيونية رومانسية",
    "romance television films": "أفلام تلفزيونية رومانسية",
    "romance television series": "مسلسلات تلفزيونية رومانسية",
    "romance video games": "ألعاب فيديو رومانسية",
    "romantic comedy comics": "قصص مصورة كوميدية رومانسية",
    "romantic comedy television series": "مسلسلات تلفزيونية كوميدية رومانسية",
    "romantic television series": "مسلسلات تلفزيونية رومانسية",
    "sailing video games": "ألعاب فيديو إبحار",
    "satire comics": "قصص مصورة هجائية",
    "satire video games": "ألعاب فيديو هجائية",
    "school television series": "مسلسلات تلفزيونية مدرسية",
    "science fantasy comics": "قصص مصورة فنتازيا علمية",
    "science fantasy television series": "مسلسلات تلفزيونية فنتازيا علمية",
    "science fantasy video games": "ألعاب فيديو فنتازيا علمية",
    "science fantasy web series": "مسلسلات ويب فنتازيا علمية",
    "science fiction comics": "قصص مصورة خيال علمي",
    "science fiction film series": "سلاسل أفلام خيال علمي",
    "science fiction television characters": "شخصيات تلفزيونية خيال علمي",
    "science fiction television episodes": "حلقات تلفزيونية خيال علمي",
    "science fiction television films": "أفلام تلفزيونية خيال علمي",
    "science fiction television series": "مسلسلات تلفزيونية خيال علمي",
    "science fiction video games": "ألعاب فيديو خيال علمي",
    "science fiction web series": "مسلسلات ويب خيال علمي",
    "sequel comics": "قصص مصورة متممة",
    "sequel television series": "مسلسلات تلفزيونية متممة",
    "sequel video games": "ألعاب فيديو متممة",
    "short comics": "قصص مصورة قصيرة",
    "short film series": "سلاسل أفلام قصيرة",
    "slapstick television series": "مسلسلات تلفزيونية كوميدية تهريجية",
    "slasher film series": "سلاسل أفلام تقطيع",
    "slasher television series": "مسلسلات تلفزيونية تقطيع",
    "soap opera": "مسلسلات طويلة",
    "spaghetti western film series": "سلاسل أفلام سباغيتي وسترن",
    "spaghetti western television series": "مسلسلات تلفزيونية سباغيتي وسترن",
    "speculative fiction comics": "قصص مصورة خيالية تأملية",
    "speculative fiction television characters": "شخصيات تلفزيونية خيالية تأملية",
    "speculative fiction television series": "مسلسلات تلفزيونية خيالية تأملية",
    "speculative fiction video games": "ألعاب فيديو خيالية تأملية",
    "speculative fiction web series": "مسلسلات ويب خيالية تأملية",
    "speculative television episodes": "حلقات تلفزيونية تأملية",
    "sports comics": "قصص مصورة رياضية",
    "sports film series": "سلاسل أفلام رياضية",
    "sports television films": "أفلام تلفزيونية رياضية",
    "sports television series": "مسلسلات تلفزيونية رياضية",
    "sports video games": "ألعاب فيديو رياضية",
    "spy comics": "قصص مصورة تجسسية",
    "spy film series": "سلاسل أفلام تجسسية",
    "spy television films": "أفلام تلفزيونية تجسسية",
    "spy television series": "مسلسلات تلفزيونية تجسسية",
    "spy video games": "ألعاب فيديو تجسسية",
    "street fighter television series": "مسلسلات تلفزيونية قتال شوارع",
    "superhero comics": "قصص مصورة أبطال خارقين",
    "superhero film series": "سلاسل أفلام أبطال خارقين",
    "superhero television characters": "شخصيات تلفزيونية أبطال خارقين",
    "superhero television episodes": "حلقات تلفزيونية أبطال خارقين",
    "superhero television films": "أفلام تلفزيونية أبطال خارقين",
    "superhero television series": "مسلسلات تلفزيونية أبطال خارقين",
    "superhero video games": "ألعاب فيديو أبطال خارقين",
    "superhero web series": "مسلسلات ويب أبطال خارقين",
    "supernatural comics": "قصص مصورة خارقة للطبيعة",
    "supernatural television series": "مسلسلات تلفزيونية خارقة للطبيعة",
    "survival video games": "ألعاب فيديو البقاء على قيد الحياة",
    "teen film series": "سلاسل أفلام مراهقة",
    "teen television series": "مسلسلات تلفزيونية مراهقة",
    "television characters": "شخصيات تلفزيونية",
    "television episodes": "حلقات تلفزيونية",
    "television film series": "سلاسل أفلام تلفزيونية",
    "television films": "أفلام تلفزيونية",
    "television miniseries": "مسلسلات قصيرة تلفزيونية",
    "television news": "أخبار تلفزيونية",
    "television programmes": "برامج تلفزيونية",
    "television programs": "برامج تلفزيونية",
    "television series": "مسلسلات تلفزيونية",
    "television series revived after cancellation": "مسلسلات تلفزيونية أعيدت بعد إلغائها",
    "television soap opera": "مسلسلات طويلة تلفزيونية",
    "thriller comics": "قصص مصورة إثارة",
    "thriller film series": "سلاسل أفلام إثارة",
    "thriller television films": "أفلام تلفزيونية إثارة",
    "thriller television series": "مسلسلات تلفزيونية إثارة",
    "thriller video games": "ألعاب فيديو إثارة",
    "thriller web series": "مسلسلات ويب إثارة",
    "unfinished comics": "قصص مصورة ناقصة",
    "upcoming television series": "مسلسلات تلفزيونية قادمة",
    "upcoming video games": "ألعاب فيديو قادمة",
    "vampire film series": "سلاسل أفلام مصاصي دماء",
    "video games": "ألعاب فيديو",
    "war comics": "قصص مصورة حربية",
    "war film series": "سلاسل أفلام حربية",
    "war television films": "أفلام تلفزيونية حربية",
    "war television series": "مسلسلات تلفزيونية حربية",
    "war video games": "ألعاب فيديو حربية",
    "web series": "مسلسلات ويب",
    "western comics": "قصص مصورة غرب أمريكية",
    "western film series": "سلاسل أفلام غرب أمريكية",
    "western television series": "مسلسلات تلفزيونية غرب أمريكية",
    "western video games": "ألعاب فيديو غرب أمريكية",
    "zombie film series": "سلاسل أفلام زومبي",
    "zombie web series": "مسلسلات ويب زومبي",
}


@pytest.mark.parametrize("category,expected", data_1.items(), ids=data_1.keys())
@pytest.mark.slow
def test_films_keys_1(category: str, expected: str) -> None:
    result2 = resolve_label_ar(category)
    assert result2 == expected


@pytest.mark.parametrize("category,expected", data_2.items(), ids=data_2.keys())
@pytest.mark.slow
def test_films_keys_2(category: str, expected: str) -> None:
    result2 = resolve_label_ar(category)
    assert result2 == expected


to_test = [
    ("test_films_keys_1", data_1, resolve_label_ar),
    ("test_films_keys_2", data_2, resolve_label_ar),
]

test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)
